const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-15";
pub const sdk_id: []const u8 = "EC2";
pub const arn_namespace: ?[]const u8 = "ec2";
pub const endpoint_prefix: []const u8 = "ec2";
pub const sigv4_name: []const u8 = "ec2";
pub const name: []const u8 = "AmazonEC2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.ec2_query;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-15",
    sdk_id: []const u8 = "EC2",
    arn_namespace: ?[]const u8 = "ec2",
    endpoint_prefix: []const u8 = "ec2",
    sigv4_name: []const u8 = "ec2",
    name: []const u8 = "AmazonEC2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.ec2_query,
} = .{};
pub const accept_address_transfer: struct {
    action_name: []const u8 = "AcceptAddressTransfer",
    Request: type = struct {
        address: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "Address",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_address_transfer) } {
            return .{ .service_metadata = service_metadata, .action = accept_address_transfer };
        }
    },
    Response: type = struct {
        address_transfer: ?AddressTransfer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_transfer = "addressTransfer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_reserved_instances_exchange_quote: struct {
    action_name: []const u8 = "AcceptReservedInstancesExchangeQuote",
    Request: type = struct {
        dry_run: ?bool = null,
        reserved_instance_ids: [][]const u8,
        target_configurations: ?[]TargetConfigurationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .reserved_instance_ids = "ReservedInstanceId",
                .target_configurations = "TargetConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_reserved_instances_exchange_quote) } {
            return .{ .service_metadata = service_metadata, .action = accept_reserved_instances_exchange_quote };
        }
    },
    Response: type = struct {
        exchange_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exchange_id = "exchangeId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_transit_gateway_multicast_domain_associations: struct {
    action_name: []const u8 = "AcceptTransitGatewayMulticastDomainAssociations",
    Request: type = struct {
        transit_gateway_multicast_domain_id: ?[]const u8 = null,
        transit_gateway_attachment_id: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .subnet_ids = "SubnetIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_transit_gateway_multicast_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = accept_transit_gateway_multicast_domain_associations };
        }
    },
    Response: type = struct {
        associations: ?TransitGatewayMulticastDomainAssociations = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_transit_gateway_peering_attachment: struct {
    action_name: []const u8 = "AcceptTransitGatewayPeeringAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_transit_gateway_peering_attachment) } {
            return .{ .service_metadata = service_metadata, .action = accept_transit_gateway_peering_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_peering_attachment: ?TransitGatewayPeeringAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering_attachment = "transitGatewayPeeringAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_transit_gateway_vpc_attachment: struct {
    action_name: []const u8 = "AcceptTransitGatewayVpcAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_transit_gateway_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = accept_transit_gateway_vpc_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachment: ?TransitGatewayVpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachment = "transitGatewayVpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_vpc_endpoint_connections: struct {
    action_name: []const u8 = "AcceptVpcEndpointConnections",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        vpc_endpoint_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .vpc_endpoint_ids = "VpcEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_vpc_endpoint_connections) } {
            return .{ .service_metadata = service_metadata, .action = accept_vpc_endpoint_connections };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const accept_vpc_peering_connection: struct {
    action_name: []const u8 = "AcceptVpcPeeringConnection",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_peering_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_peering_connection_id = "vpcPeeringConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = accept_vpc_peering_connection };
        }
    },
    Response: type = struct {
        vpc_peering_connection: ?VpcPeeringConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_connection = "vpcPeeringConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const advertise_byoip_cidr: struct {
    action_name: []const u8 = "AdvertiseByoipCidr",
    Request: type = struct {
        cidr: []const u8,
        asn: ?[]const u8 = null,
        dry_run: ?bool = null,
        network_border_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .asn = "Asn",
                .dry_run = "DryRun",
                .network_border_group = "NetworkBorderGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(advertise_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = advertise_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "byoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const allocate_address: struct {
    action_name: []const u8 = "AllocateAddress",
    Request: type = struct {
        domain: ?[]const u8 = null,
        address: ?[]const u8 = null,
        public_ipv4_pool: ?[]const u8 = null,
        network_border_group: ?[]const u8 = null,
        customer_owned_ipv4_pool: ?[]const u8 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .address = "Address",
                .public_ipv4_pool = "PublicIpv4Pool",
                .network_border_group = "NetworkBorderGroup",
                .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
                .dry_run = "dryRun",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_address) } {
            return .{ .service_metadata = service_metadata, .action = allocate_address };
        }
    },
    Response: type = struct {
        public_ip: ?[]const u8 = null,
        allocation_id: ?[]const u8 = null,
        public_ipv4_pool: ?[]const u8 = null,
        network_border_group: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        customer_owned_ip: ?[]const u8 = null,
        customer_owned_ipv4_pool: ?[]const u8 = null,
        carrier_ip: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_ip = "publicIp",
                .allocation_id = "allocationId",
                .public_ipv4_pool = "publicIpv4Pool",
                .network_border_group = "networkBorderGroup",
                .domain = "domain",
                .customer_owned_ip = "customerOwnedIp",
                .customer_owned_ipv4_pool = "customerOwnedIpv4Pool",
                .carrier_ip = "carrierIp",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const allocate_hosts: struct {
    action_name: []const u8 = "AllocateHosts",
    Request: type = struct {
        auto_placement: ?[]const u8 = null,
        availability_zone: []const u8,
        client_token: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        instance_family: ?[]const u8 = null,
        quantity: ?i64 = null,
        tag_specifications: ?[]TagSpecification = null,
        host_recovery: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        host_maintenance: ?[]const u8 = null,
        asset_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_placement = "autoPlacement",
                .availability_zone = "availabilityZone",
                .client_token = "clientToken",
                .instance_type = "instanceType",
                .instance_family = "InstanceFamily",
                .quantity = "quantity",
                .tag_specifications = "TagSpecification",
                .host_recovery = "HostRecovery",
                .outpost_arn = "OutpostArn",
                .host_maintenance = "HostMaintenance",
                .asset_ids = "AssetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_hosts) } {
            return .{ .service_metadata = service_metadata, .action = allocate_hosts };
        }
    },
    Response: type = struct {
        host_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_ids = "hostIdSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const allocate_ipam_pool_cidr: struct {
    action_name: []const u8 = "AllocateIpamPoolCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        cidr: ?[]const u8 = null,
        netmask_length: ?i64 = null,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        preview_next_cidr: ?bool = null,
        allowed_cidrs: ?[][]const u8 = null,
        disallowed_cidrs: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .cidr = "Cidr",
                .netmask_length = "NetmaskLength",
                .client_token = "ClientToken",
                .description = "Description",
                .preview_next_cidr = "PreviewNextCidr",
                .allowed_cidrs = "AllowedCidr",
                .disallowed_cidrs = "DisallowedCidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(allocate_ipam_pool_cidr) } {
            return .{ .service_metadata = service_metadata, .action = allocate_ipam_pool_cidr };
        }
    },
    Response: type = struct {
        ipam_pool_allocation: ?IpamPoolAllocation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool_allocation = "ipamPoolAllocation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const apply_security_groups_to_client_vpn_target_network: struct {
    action_name: []const u8 = "ApplySecurityGroupsToClientVpnTargetNetwork",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        vpc_id: []const u8,
        security_group_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .vpc_id = "VpcId",
                .security_group_ids = "SecurityGroupId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_security_groups_to_client_vpn_target_network) } {
            return .{ .service_metadata = service_metadata, .action = apply_security_groups_to_client_vpn_target_network };
        }
    },
    Response: type = struct {
        security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group_ids = "securityGroupIds",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const assign_ipv6_addresses: struct {
    action_name: []const u8 = "AssignIpv6Addresses",
    Request: type = struct {
        ipv6_address_count: ?i64 = null,
        ipv6_addresses: ?[][]const u8 = null,
        ipv6_prefix_count: ?i64 = null,
        ipv6_prefixes: ?[][]const u8 = null,
        network_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_address_count = "ipv6AddressCount",
                .ipv6_addresses = "ipv6Addresses",
                .ipv6_prefix_count = "Ipv6PrefixCount",
                .ipv6_prefixes = "Ipv6Prefix",
                .network_interface_id = "networkInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assign_ipv6_addresses) } {
            return .{ .service_metadata = service_metadata, .action = assign_ipv6_addresses };
        }
    },
    Response: type = struct {
        assigned_ipv6_addresses: ?[][]const u8 = null,
        assigned_ipv6_prefixes: ?[][]const u8 = null,
        network_interface_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assigned_ipv6_addresses = "assignedIpv6Addresses",
                .assigned_ipv6_prefixes = "assignedIpv6PrefixSet",
                .network_interface_id = "networkInterfaceId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const assign_private_ip_addresses: struct {
    action_name: []const u8 = "AssignPrivateIpAddresses",
    Request: type = struct {
        allow_reassignment: ?bool = null,
        network_interface_id: []const u8,
        private_ip_addresses: ?[][]const u8 = null,
        secondary_private_ip_address_count: ?i64 = null,
        ipv4_prefixes: ?[][]const u8 = null,
        ipv4_prefix_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allow_reassignment = "allowReassignment",
                .network_interface_id = "networkInterfaceId",
                .private_ip_addresses = "privateIpAddress",
                .secondary_private_ip_address_count = "secondaryPrivateIpAddressCount",
                .ipv4_prefixes = "Ipv4Prefix",
                .ipv4_prefix_count = "Ipv4PrefixCount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assign_private_ip_addresses) } {
            return .{ .service_metadata = service_metadata, .action = assign_private_ip_addresses };
        }
    },
    Response: type = struct {
        network_interface_id: ?[]const u8 = null,
        assigned_private_ip_addresses: ?[]struct {
            private_ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .private_ip_address = "privateIpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,
        assigned_ipv4_prefixes: ?[]Ipv4PrefixSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "networkInterfaceId",
                .assigned_private_ip_addresses = "assignedPrivateIpAddressesSet",
                .assigned_ipv4_prefixes = "assignedIpv4PrefixSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const assign_private_nat_gateway_address: struct {
    action_name: []const u8 = "AssignPrivateNatGatewayAddress",
    Request: type = struct {
        nat_gateway_id: []const u8,
        private_ip_addresses: ?[][]const u8 = null,
        private_ip_address_count: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "NatGatewayId",
                .private_ip_addresses = "PrivateIpAddress",
                .private_ip_address_count = "PrivateIpAddressCount",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assign_private_nat_gateway_address) } {
            return .{ .service_metadata = service_metadata, .action = assign_private_nat_gateway_address };
        }
    },
    Response: type = struct {
        nat_gateway_id: ?[]const u8 = null,
        nat_gateway_addresses: ?[]NatGatewayAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "natGatewayId",
                .nat_gateway_addresses = "natGatewayAddressSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_address: struct {
    action_name: []const u8 = "AssociateAddress",
    Request: type = struct {
        allocation_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        public_ip: ?[]const u8 = null,
        allow_reassociation: ?bool = null,
        dry_run: ?bool = null,
        network_interface_id: ?[]const u8 = null,
        private_ip_address: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .instance_id = "InstanceId",
                .public_ip = "PublicIp",
                .allow_reassociation = "allowReassociation",
                .dry_run = "dryRun",
                .network_interface_id = "networkInterfaceId",
                .private_ip_address = "privateIpAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_address) } {
            return .{ .service_metadata = service_metadata, .action = associate_address };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_client_vpn_target_network: struct {
    action_name: []const u8 = "AssociateClientVpnTargetNetwork",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        subnet_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .subnet_id = "SubnetId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_client_vpn_target_network) } {
            return .{ .service_metadata = service_metadata, .action = associate_client_vpn_target_network };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,
        status: ?AssociationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_dhcp_options: struct {
    action_name: []const u8 = "AssociateDhcpOptions",
    Request: type = struct {
        dhcp_options_id: []const u8,
        vpc_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_options_id = "DhcpOptionsId",
                .vpc_id = "VpcId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_dhcp_options) } {
            return .{ .service_metadata = service_metadata, .action = associate_dhcp_options };
        }
    },
    Response: type = struct {},
} = .{};
pub const associate_enclave_certificate_iam_role: struct {
    action_name: []const u8 = "AssociateEnclaveCertificateIamRole",
    Request: type = struct {
        certificate_arn: []const u8,
        role_arn: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .role_arn = "RoleArn",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_enclave_certificate_iam_role) } {
            return .{ .service_metadata = service_metadata, .action = associate_enclave_certificate_iam_role };
        }
    },
    Response: type = struct {
        certificate_s3_bucket_name: ?[]const u8 = null,
        certificate_s3_object_key: ?[]const u8 = null,
        encryption_kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_s3_bucket_name = "certificateS3BucketName",
                .certificate_s3_object_key = "certificateS3ObjectKey",
                .encryption_kms_key_id = "encryptionKmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_iam_instance_profile: struct {
    action_name: []const u8 = "AssociateIamInstanceProfile",
    Request: type = struct {
        iam_instance_profile: IamInstanceProfileSpecification,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile = "IamInstanceProfile",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_iam_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = associate_iam_instance_profile };
        }
    },
    Response: type = struct {
        iam_instance_profile_association: ?IamInstanceProfileAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile_association = "iamInstanceProfileAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_instance_event_window: struct {
    action_name: []const u8 = "AssociateInstanceEventWindow",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_event_window_id: []const u8,
        association_target: struct {
            instance_ids: ?[][]const u8 = null,
            instance_tags: ?[]Tag = null,
            dedicated_host_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_ids = "InstanceId",
                    .instance_tags = "InstanceTag",
                    .dedicated_host_ids = "DedicatedHostId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_event_window_id = "InstanceEventWindowId",
                .association_target = "AssociationTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_instance_event_window) } {
            return .{ .service_metadata = service_metadata, .action = associate_instance_event_window };
        }
    },
    Response: type = struct {
        instance_event_window: ?InstanceEventWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_window = "instanceEventWindow",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_ipam_byoasn: struct {
    action_name: []const u8 = "AssociateIpamByoasn",
    Request: type = struct {
        dry_run: ?bool = null,
        asn: []const u8,
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .asn = "Asn",
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_ipam_byoasn) } {
            return .{ .service_metadata = service_metadata, .action = associate_ipam_byoasn };
        }
    },
    Response: type = struct {
        asn_association: ?AsnAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asn_association = "asnAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_ipam_resource_discovery: struct {
    action_name: []const u8 = "AssociateIpamResourceDiscovery",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        ipam_resource_discovery_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_ipam_resource_discovery) } {
            return .{ .service_metadata = service_metadata, .action = associate_ipam_resource_discovery };
        }
    },
    Response: type = struct {
        ipam_resource_discovery_association: ?IpamResourceDiscoveryAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery_association = "ipamResourceDiscoveryAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_nat_gateway_address: struct {
    action_name: []const u8 = "AssociateNatGatewayAddress",
    Request: type = struct {
        nat_gateway_id: []const u8,
        allocation_ids: [][]const u8,
        private_ip_addresses: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "NatGatewayId",
                .allocation_ids = "AllocationId",
                .private_ip_addresses = "PrivateIpAddress",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_nat_gateway_address) } {
            return .{ .service_metadata = service_metadata, .action = associate_nat_gateway_address };
        }
    },
    Response: type = struct {
        nat_gateway_id: ?[]const u8 = null,
        nat_gateway_addresses: ?[]NatGatewayAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "natGatewayId",
                .nat_gateway_addresses = "natGatewayAddressSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_route_table: struct {
    action_name: []const u8 = "AssociateRouteTable",
    Request: type = struct {
        dry_run: ?bool = null,
        route_table_id: []const u8,
        subnet_id: ?[]const u8 = null,
        gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .route_table_id = "routeTableId",
                .subnet_id = "subnetId",
                .gateway_id = "GatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_route_table) } {
            return .{ .service_metadata = service_metadata, .action = associate_route_table };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,
        association_state: ?RouteTableAssociationState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .association_state = "associationState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_subnet_cidr_block: struct {
    action_name: []const u8 = "AssociateSubnetCidrBlock",
    Request: type = struct {
        ipv6_cidr_block: ?[]const u8 = null,
        subnet_id: []const u8,
        ipv6_ipam_pool_id: ?[]const u8 = null,
        ipv6_netmask_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_block = "ipv6CidrBlock",
                .subnet_id = "subnetId",
                .ipv6_ipam_pool_id = "Ipv6IpamPoolId",
                .ipv6_netmask_length = "Ipv6NetmaskLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_subnet_cidr_block) } {
            return .{ .service_metadata = service_metadata, .action = associate_subnet_cidr_block };
        }
    },
    Response: type = struct {
        ipv6_cidr_block_association: ?SubnetIpv6CidrBlockAssociation = null,
        subnet_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_block_association = "ipv6CidrBlockAssociation",
                .subnet_id = "subnetId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_transit_gateway_multicast_domain: struct {
    action_name: []const u8 = "AssociateTransitGatewayMulticastDomain",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        subnet_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .subnet_ids = "SubnetIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_transit_gateway_multicast_domain) } {
            return .{ .service_metadata = service_metadata, .action = associate_transit_gateway_multicast_domain };
        }
    },
    Response: type = struct {
        associations: ?TransitGatewayMulticastDomainAssociations = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_transit_gateway_policy_table: struct {
    action_name: []const u8 = "AssociateTransitGatewayPolicyTable",
    Request: type = struct {
        transit_gateway_policy_table_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_id = "TransitGatewayPolicyTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_transit_gateway_policy_table) } {
            return .{ .service_metadata = service_metadata, .action = associate_transit_gateway_policy_table };
        }
    },
    Response: type = struct {
        association: ?TransitGatewayPolicyTableAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_transit_gateway_route_table: struct {
    action_name: []const u8 = "AssociateTransitGatewayRouteTable",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_transit_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = associate_transit_gateway_route_table };
        }
    },
    Response: type = struct {
        association: ?TransitGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_trunk_interface: struct {
    action_name: []const u8 = "AssociateTrunkInterface",
    Request: type = struct {
        branch_interface_id: []const u8,
        trunk_interface_id: []const u8,
        vlan_id: ?i64 = null,
        gre_key: ?i64 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .branch_interface_id = "BranchInterfaceId",
                .trunk_interface_id = "TrunkInterfaceId",
                .vlan_id = "VlanId",
                .gre_key = "GreKey",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_trunk_interface) } {
            return .{ .service_metadata = service_metadata, .action = associate_trunk_interface };
        }
    },
    Response: type = struct {
        interface_association: ?TrunkInterfaceAssociation = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interface_association = "interfaceAssociation",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_vpc_cidr_block: struct {
    action_name: []const u8 = "AssociateVpcCidrBlock",
    Request: type = struct {
        amazon_provided_ipv6_cidr_block: ?bool = null,
        cidr_block: ?[]const u8 = null,
        vpc_id: []const u8,
        ipv6_cidr_block_network_border_group: ?[]const u8 = null,
        ipv6_pool: ?[]const u8 = null,
        ipv6_cidr_block: ?[]const u8 = null,
        ipv4_ipam_pool_id: ?[]const u8 = null,
        ipv4_netmask_length: ?i64 = null,
        ipv6_ipam_pool_id: ?[]const u8 = null,
        ipv6_netmask_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .amazon_provided_ipv6_cidr_block = "amazonProvidedIpv6CidrBlock",
                .cidr_block = "CidrBlock",
                .vpc_id = "vpcId",
                .ipv6_cidr_block_network_border_group = "Ipv6CidrBlockNetworkBorderGroup",
                .ipv6_pool = "Ipv6Pool",
                .ipv6_cidr_block = "Ipv6CidrBlock",
                .ipv4_ipam_pool_id = "Ipv4IpamPoolId",
                .ipv4_netmask_length = "Ipv4NetmaskLength",
                .ipv6_ipam_pool_id = "Ipv6IpamPoolId",
                .ipv6_netmask_length = "Ipv6NetmaskLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_vpc_cidr_block) } {
            return .{ .service_metadata = service_metadata, .action = associate_vpc_cidr_block };
        }
    },
    Response: type = struct {
        ipv6_cidr_block_association: ?VpcIpv6CidrBlockAssociation = null,
        cidr_block_association: ?VpcCidrBlockAssociation = null,
        vpc_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_block_association = "ipv6CidrBlockAssociation",
                .cidr_block_association = "cidrBlockAssociation",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const attach_classic_link_vpc: struct {
    action_name: []const u8 = "AttachClassicLinkVpc",
    Request: type = struct {
        dry_run: ?bool = null,
        groups: [][]const u8,
        instance_id: []const u8,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .groups = "SecurityGroupId",
                .instance_id = "instanceId",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_classic_link_vpc) } {
            return .{ .service_metadata = service_metadata, .action = attach_classic_link_vpc };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const attach_internet_gateway: struct {
    action_name: []const u8 = "AttachInternetGateway",
    Request: type = struct {
        dry_run: ?bool = null,
        internet_gateway_id: []const u8,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .internet_gateway_id = "internetGatewayId",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = attach_internet_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const attach_network_interface: struct {
    action_name: []const u8 = "AttachNetworkInterface",
    Request: type = struct {
        device_index: i64,
        dry_run: ?bool = null,
        instance_id: []const u8,
        network_interface_id: []const u8,
        network_card_index: ?i64 = null,
        ena_srd_specification: ?EnaSrdSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_index = "deviceIndex",
                .dry_run = "dryRun",
                .instance_id = "instanceId",
                .network_interface_id = "networkInterfaceId",
                .network_card_index = "NetworkCardIndex",
                .ena_srd_specification = "EnaSrdSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_network_interface) } {
            return .{ .service_metadata = service_metadata, .action = attach_network_interface };
        }
    },
    Response: type = struct {
        attachment_id: ?[]const u8 = null,
        network_card_index: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "attachmentId",
                .network_card_index = "networkCardIndex",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const attach_verified_access_trust_provider: struct {
    action_name: []const u8 = "AttachVerifiedAccessTrustProvider",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        verified_access_trust_provider_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .verified_access_trust_provider_id = "VerifiedAccessTrustProviderId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_verified_access_trust_provider) } {
            return .{ .service_metadata = service_metadata, .action = attach_verified_access_trust_provider };
        }
    },
    Response: type = struct {
        verified_access_trust_provider: ?VerifiedAccessTrustProvider = null,
        verified_access_instance: ?VerifiedAccessInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider = "verifiedAccessTrustProvider",
                .verified_access_instance = "verifiedAccessInstance",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const attach_volume: struct {
    action_name: []const u8 = "AttachVolume",
    Request: type = struct {
        device: []const u8,
        instance_id: []const u8,
        volume_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
                .instance_id = "InstanceId",
                .volume_id = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_volume) } {
            return .{ .service_metadata = service_metadata, .action = attach_volume };
        }
    },
    Response: type = struct {
        attach_time: ?i64 = null,
        device: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        volume_id: ?[]const u8 = null,
        delete_on_termination: ?bool = null,
        associated_resource: ?[]const u8 = null,
        instance_owning_service: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attach_time = "attachTime",
                .device = "device",
                .instance_id = "instanceId",
                .state = "status",
                .volume_id = "volumeId",
                .delete_on_termination = "deleteOnTermination",
                .associated_resource = "associatedResource",
                .instance_owning_service = "instanceOwningService",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const attach_vpn_gateway: struct {
    action_name: []const u8 = "AttachVpnGateway",
    Request: type = struct {
        vpc_id: []const u8,
        vpn_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .vpn_gateway_id = "VpnGatewayId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_vpn_gateway) } {
            return .{ .service_metadata = service_metadata, .action = attach_vpn_gateway };
        }
    },
    Response: type = struct {
        vpc_attachment: ?VpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_attachment = "attachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const authorize_client_vpn_ingress: struct {
    action_name: []const u8 = "AuthorizeClientVpnIngress",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        target_network_cidr: []const u8,
        access_group_id: ?[]const u8 = null,
        authorize_all_groups: ?bool = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .target_network_cidr = "TargetNetworkCidr",
                .access_group_id = "AccessGroupId",
                .authorize_all_groups = "AuthorizeAllGroups",
                .description = "Description",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_client_vpn_ingress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_client_vpn_ingress };
        }
    },
    Response: type = struct {
        status: ?ClientVpnAuthorizationRuleStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const authorize_security_group_egress: struct {
    action_name: []const u8 = "AuthorizeSecurityGroupEgress",
    Request: type = struct {
        dry_run: ?bool = null,
        group_id: []const u8,
        ip_permissions: ?[]IpPermission = null,
        tag_specifications: ?[]TagSpecification = null,
        cidr_ip: ?[]const u8 = null,
        from_port: ?i64 = null,
        ip_protocol: ?[]const u8 = null,
        to_port: ?i64 = null,
        source_security_group_name: ?[]const u8 = null,
        source_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .group_id = "groupId",
                .ip_permissions = "ipPermissions",
                .tag_specifications = "TagSpecification",
                .cidr_ip = "cidrIp",
                .from_port = "fromPort",
                .ip_protocol = "ipProtocol",
                .to_port = "toPort",
                .source_security_group_name = "sourceSecurityGroupName",
                .source_security_group_owner_id = "sourceSecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_security_group_egress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_security_group_egress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        security_group_rules: ?[]SecurityGroupRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .security_group_rules = "securityGroupRuleSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const authorize_security_group_ingress: struct {
    action_name: []const u8 = "AuthorizeSecurityGroupIngress",
    Request: type = struct {
        cidr_ip: ?[]const u8 = null,
        from_port: ?i64 = null,
        group_id: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        ip_permissions: ?[]IpPermission = null,
        ip_protocol: ?[]const u8 = null,
        source_security_group_name: ?[]const u8 = null,
        source_security_group_owner_id: ?[]const u8 = null,
        to_port: ?i64 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_ip = "CidrIp",
                .from_port = "FromPort",
                .group_id = "GroupId",
                .group_name = "GroupName",
                .ip_permissions = "IpPermissions",
                .ip_protocol = "IpProtocol",
                .source_security_group_name = "SourceSecurityGroupName",
                .source_security_group_owner_id = "SourceSecurityGroupOwnerId",
                .to_port = "ToPort",
                .dry_run = "dryRun",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_security_group_ingress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        security_group_rules: ?[]SecurityGroupRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .security_group_rules = "securityGroupRuleSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const bundle_instance: struct {
    action_name: []const u8 = "BundleInstance",
    Request: type = struct {
        instance_id: []const u8,
        storage: Storage,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .storage = "Storage",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(bundle_instance) } {
            return .{ .service_metadata = service_metadata, .action = bundle_instance };
        }
    },
    Response: type = struct {
        bundle_task: ?BundleTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_task = "bundleInstanceTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_bundle_task: struct {
    action_name: []const u8 = "CancelBundleTask",
    Request: type = struct {
        bundle_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_bundle_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_bundle_task };
        }
    },
    Response: type = struct {
        bundle_task: ?BundleTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_task = "bundleInstanceTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_capacity_reservation: struct {
    action_name: []const u8 = "CancelCapacityReservation",
    Request: type = struct {
        capacity_reservation_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_id = "CapacityReservationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_capacity_reservation };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_capacity_reservation_fleets: struct {
    action_name: []const u8 = "CancelCapacityReservationFleets",
    Request: type = struct {
        dry_run: ?bool = null,
        capacity_reservation_fleet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .capacity_reservation_fleet_ids = "CapacityReservationFleetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_capacity_reservation_fleets) } {
            return .{ .service_metadata = service_metadata, .action = cancel_capacity_reservation_fleets };
        }
    },
    Response: type = struct {
        successful_fleet_cancellations: ?[]struct {
            current_fleet_state: ?[]const u8 = null,
            previous_fleet_state: ?[]const u8 = null,
            capacity_reservation_fleet_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_fleet_state = "currentFleetState",
                    .previous_fleet_state = "previousFleetState",
                    .capacity_reservation_fleet_id = "capacityReservationFleetId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed_fleet_cancellations: ?[]struct {
            capacity_reservation_fleet_id: ?[]const u8 = null,
            cancel_capacity_reservation_fleet_error: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity_reservation_fleet_id = "capacityReservationFleetId",
                    .cancel_capacity_reservation_fleet_error = "cancelCapacityReservationFleetError",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_fleet_cancellations = "successfulFleetCancellationSet",
                .failed_fleet_cancellations = "failedFleetCancellationSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_conversion_task: struct {
    action_name: []const u8 = "CancelConversionTask",
    Request: type = struct {
        conversion_task_id: []const u8,
        dry_run: ?bool = null,
        reason_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversion_task_id = "conversionTaskId",
                .dry_run = "dryRun",
                .reason_message = "reasonMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_conversion_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_conversion_task };
        }
    },
    Response: type = struct {},
} = .{};
pub const cancel_export_task: struct {
    action_name: []const u8 = "CancelExportTask",
    Request: type = struct {
        export_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_id = "exportTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_export_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_export_task };
        }
    },
    Response: type = struct {},
} = .{};
pub const cancel_image_launch_permission: struct {
    action_name: []const u8 = "CancelImageLaunchPermission",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_image_launch_permission) } {
            return .{ .service_metadata = service_metadata, .action = cancel_image_launch_permission };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_import_task: struct {
    action_name: []const u8 = "CancelImportTask",
    Request: type = struct {
        cancel_reason: ?[]const u8 = null,
        dry_run: ?bool = null,
        import_task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancel_reason = "CancelReason",
                .dry_run = "DryRun",
                .import_task_id = "ImportTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_import_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_import_task };
        }
    },
    Response: type = struct {
        import_task_id: ?[]const u8 = null,
        previous_state: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_task_id = "importTaskId",
                .previous_state = "previousState",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_reserved_instances_listing: struct {
    action_name: []const u8 = "CancelReservedInstancesListing",
    Request: type = struct {
        reserved_instances_listing_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_listing_id = "reservedInstancesListingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_reserved_instances_listing) } {
            return .{ .service_metadata = service_metadata, .action = cancel_reserved_instances_listing };
        }
    },
    Response: type = struct {
        reserved_instances_listings: ?[]ReservedInstancesListing = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_listings = "reservedInstancesListingsSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_spot_fleet_requests: struct {
    action_name: []const u8 = "CancelSpotFleetRequests",
    Request: type = struct {
        dry_run: ?bool = null,
        spot_fleet_request_ids: [][]const u8,
        terminate_instances: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .spot_fleet_request_ids = "spotFleetRequestId",
                .terminate_instances = "terminateInstances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_spot_fleet_requests) } {
            return .{ .service_metadata = service_metadata, .action = cancel_spot_fleet_requests };
        }
    },
    Response: type = struct {
        successful_fleet_requests: ?[]struct {
            current_spot_fleet_request_state: ?[]const u8 = null,
            previous_spot_fleet_request_state: ?[]const u8 = null,
            spot_fleet_request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_spot_fleet_request_state = "currentSpotFleetRequestState",
                    .previous_spot_fleet_request_state = "previousSpotFleetRequestState",
                    .spot_fleet_request_id = "spotFleetRequestId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful_fleet_requests: ?[]struct {
            @"error": ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            spot_fleet_request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .@"error" = "error",
                    .spot_fleet_request_id = "spotFleetRequestId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_fleet_requests = "successfulFleetRequestSet",
                .unsuccessful_fleet_requests = "unsuccessfulFleetRequestSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const cancel_spot_instance_requests: struct {
    action_name: []const u8 = "CancelSpotInstanceRequests",
    Request: type = struct {
        dry_run: ?bool = null,
        spot_instance_request_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .spot_instance_request_ids = "SpotInstanceRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_spot_instance_requests) } {
            return .{ .service_metadata = service_metadata, .action = cancel_spot_instance_requests };
        }
    },
    Response: type = struct {
        cancelled_spot_instance_requests: ?[]struct {
            spot_instance_request_id: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .spot_instance_request_id = "spotInstanceRequestId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancelled_spot_instance_requests = "spotInstanceRequestSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const confirm_product_instance: struct {
    action_name: []const u8 = "ConfirmProductInstance",
    Request: type = struct {
        instance_id: []const u8,
        product_code: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .product_code = "ProductCode",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_product_instance) } {
            return .{ .service_metadata = service_metadata, .action = confirm_product_instance };
        }
    },
    Response: type = struct {
        owner_id: ?[]const u8 = null,
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_id = "ownerId",
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const copy_fpga_image: struct {
    action_name: []const u8 = "CopyFpgaImage",
    Request: type = struct {
        dry_run: ?bool = null,
        source_fpga_image_id: []const u8,
        description: ?[]const u8 = null,
        name: ?[]const u8 = null,
        source_region: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .source_fpga_image_id = "SourceFpgaImageId",
                .description = "Description",
                .name = "Name",
                .source_region = "SourceRegion",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_fpga_image) } {
            return .{ .service_metadata = service_metadata, .action = copy_fpga_image };
        }
    },
    Response: type = struct {
        fpga_image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fpga_image_id = "fpgaImageId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const copy_image: struct {
    action_name: []const u8 = "CopyImage",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        name: []const u8,
        source_image_id: []const u8,
        source_region: []const u8,
        destination_outpost_arn: ?[]const u8 = null,
        dry_run: ?bool = null,
        copy_image_tags: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .description = "Description",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
                .name = "Name",
                .source_image_id = "SourceImageId",
                .source_region = "SourceRegion",
                .destination_outpost_arn = "DestinationOutpostArn",
                .dry_run = "dryRun",
                .copy_image_tags = "CopyImageTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_image) } {
            return .{ .service_metadata = service_metadata, .action = copy_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const copy_snapshot: struct {
    action_name: []const u8 = "CopySnapshot",
    Request: type = struct {
        description: ?[]const u8 = null,
        destination_outpost_arn: ?[]const u8 = null,
        destination_region: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        presigned_url: ?[]const u8 = null,
        source_region: []const u8,
        source_snapshot_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .destination_outpost_arn = "DestinationOutpostArn",
                .destination_region = "destinationRegion",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
                .presigned_url = "presignedUrl",
                .source_region = "SourceRegion",
                .source_snapshot_id = "SourceSnapshotId",
                .tag_specifications = "TagSpecification",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_capacity_reservation: struct {
    action_name: []const u8 = "CreateCapacityReservation",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        instance_type: []const u8,
        instance_platform: []const u8,
        availability_zone: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        tenancy: ?[]const u8 = null,
        instance_count: i64,
        ebs_optimized: ?bool = null,
        ephemeral_storage: ?bool = null,
        end_date: ?i64 = null,
        end_date_type: ?[]const u8 = null,
        instance_match_criteria: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        outpost_arn: ?[]const u8 = null,
        placement_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .instance_type = "InstanceType",
                .instance_platform = "InstancePlatform",
                .availability_zone = "AvailabilityZone",
                .availability_zone_id = "AvailabilityZoneId",
                .tenancy = "Tenancy",
                .instance_count = "InstanceCount",
                .ebs_optimized = "EbsOptimized",
                .ephemeral_storage = "EphemeralStorage",
                .end_date = "EndDate",
                .end_date_type = "EndDateType",
                .instance_match_criteria = "InstanceMatchCriteria",
                .tag_specifications = "TagSpecifications",
                .dry_run = "DryRun",
                .outpost_arn = "OutpostArn",
                .placement_group_arn = "PlacementGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = create_capacity_reservation };
        }
    },
    Response: type = struct {
        capacity_reservation: ?CapacityReservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation = "capacityReservation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_capacity_reservation_fleet: struct {
    action_name: []const u8 = "CreateCapacityReservationFleet",
    Request: type = struct {
        allocation_strategy: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        instance_type_specifications: []struct {
            instance_type: ?[]const u8 = null,
            instance_platform: ?[]const u8 = null,
            weight: ?f64 = null,
            availability_zone: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            ebs_optimized: ?bool = null,
            priority: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "InstanceType",
                    .instance_platform = "InstancePlatform",
                    .weight = "Weight",
                    .availability_zone = "AvailabilityZone",
                    .availability_zone_id = "AvailabilityZoneId",
                    .ebs_optimized = "EbsOptimized",
                    .priority = "Priority",
                };
                return @field(mappings, field_name);
            }
        },
        tenancy: ?[]const u8 = null,
        total_target_capacity: i64,
        end_date: ?i64 = null,
        instance_match_criteria: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_strategy = "AllocationStrategy",
                .client_token = "ClientToken",
                .instance_type_specifications = "InstanceTypeSpecification",
                .tenancy = "Tenancy",
                .total_target_capacity = "TotalTargetCapacity",
                .end_date = "EndDate",
                .instance_match_criteria = "InstanceMatchCriteria",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_capacity_reservation_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_capacity_reservation_fleet };
        }
    },
    Response: type = struct {
        capacity_reservation_fleet_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        total_target_capacity: ?i64 = null,
        total_fulfilled_capacity: ?f64 = null,
        instance_match_criteria: ?[]const u8 = null,
        allocation_strategy: ?[]const u8 = null,
        create_time: ?i64 = null,
        end_date: ?i64 = null,
        tenancy: ?[]const u8 = null,
        fleet_capacity_reservations: ?[]FleetCapacityReservation = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_fleet_id = "capacityReservationFleetId",
                .state = "state",
                .total_target_capacity = "totalTargetCapacity",
                .total_fulfilled_capacity = "totalFulfilledCapacity",
                .instance_match_criteria = "instanceMatchCriteria",
                .allocation_strategy = "allocationStrategy",
                .create_time = "createTime",
                .end_date = "endDate",
                .tenancy = "tenancy",
                .fleet_capacity_reservations = "fleetCapacityReservationSet",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_carrier_gateway: struct {
    action_name: []const u8 = "CreateCarrierGateway",
    Request: type = struct {
        vpc_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_carrier_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_carrier_gateway };
        }
    },
    Response: type = struct {
        carrier_gateway: ?CarrierGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .carrier_gateway = "carrierGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_client_vpn_endpoint: struct {
    action_name: []const u8 = "CreateClientVpnEndpoint",
    Request: type = struct {
        client_cidr_block: []const u8,
        server_certificate_arn: []const u8,
        authentication_options: []struct {
            type: ?[]const u8 = null,
            active_directory: ?struct {
                directory_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .directory_id = "DirectoryId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            mutual_authentication: ?struct {
                client_root_certificate_chain_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_root_certificate_chain_arn = "ClientRootCertificateChainArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            federated_authentication: ?struct {
                saml_provider_arn: ?[]const u8 = null,
                self_service_saml_provider_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .saml_provider_arn = "SAMLProviderArn",
                        .self_service_saml_provider_arn = "SelfServiceSAMLProviderArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .active_directory = "ActiveDirectory",
                    .mutual_authentication = "MutualAuthentication",
                    .federated_authentication = "FederatedAuthentication",
                };
                return @field(mappings, field_name);
            }
        },
        connection_log_options: ConnectionLogOptions,
        dns_servers: ?[][]const u8 = null,
        transport_protocol: ?[]const u8 = null,
        vpn_port: ?i64 = null,
        description: ?[]const u8 = null,
        split_tunnel: ?bool = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        security_group_ids: ?[][]const u8 = null,
        vpc_id: ?[]const u8 = null,
        self_service_portal: ?[]const u8 = null,
        client_connect_options: ?ClientConnectOptions = null,
        session_timeout_hours: ?i64 = null,
        client_login_banner_options: ?ClientLoginBannerOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_cidr_block = "ClientCidrBlock",
                .server_certificate_arn = "ServerCertificateArn",
                .authentication_options = "Authentication",
                .connection_log_options = "ConnectionLogOptions",
                .dns_servers = "DnsServers",
                .transport_protocol = "TransportProtocol",
                .vpn_port = "VpnPort",
                .description = "Description",
                .split_tunnel = "SplitTunnel",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .tag_specifications = "TagSpecification",
                .security_group_ids = "SecurityGroupId",
                .vpc_id = "VpcId",
                .self_service_portal = "SelfServicePortal",
                .client_connect_options = "ClientConnectOptions",
                .session_timeout_hours = "SessionTimeoutHours",
                .client_login_banner_options = "ClientLoginBannerOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_client_vpn_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_client_vpn_endpoint };
        }
    },
    Response: type = struct {
        client_vpn_endpoint_id: ?[]const u8 = null,
        status: ?ClientVpnEndpointStatus = null,
        dns_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "clientVpnEndpointId",
                .status = "status",
                .dns_name = "dnsName",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_client_vpn_route: struct {
    action_name: []const u8 = "CreateClientVpnRoute",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        destination_cidr_block: []const u8,
        target_vpc_subnet_id: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .destination_cidr_block = "DestinationCidrBlock",
                .target_vpc_subnet_id = "TargetVpcSubnetId",
                .description = "Description",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_client_vpn_route) } {
            return .{ .service_metadata = service_metadata, .action = create_client_vpn_route };
        }
    },
    Response: type = struct {
        status: ?ClientVpnRouteStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_coip_cidr: struct {
    action_name: []const u8 = "CreateCoipCidr",
    Request: type = struct {
        cidr: []const u8,
        coip_pool_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .coip_pool_id = "CoipPoolId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_coip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = create_coip_cidr };
        }
    },
    Response: type = struct {
        coip_cidr: ?CoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_cidr = "coipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_coip_pool: struct {
    action_name: []const u8 = "CreateCoipPool",
    Request: type = struct {
        local_gateway_route_table_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_coip_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_coip_pool };
        }
    },
    Response: type = struct {
        coip_pool: ?CoipPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_pool = "coipPool",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_customer_gateway: struct {
    action_name: []const u8 = "CreateCustomerGateway",
    Request: type = struct {
        bgp_asn: ?i64 = null,
        public_ip: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        type: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        device_name: ?[]const u8 = null,
        ip_address: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bgp_asn = "BgpAsn",
                .public_ip = "PublicIp",
                .certificate_arn = "CertificateArn",
                .type = "Type",
                .tag_specifications = "TagSpecification",
                .device_name = "DeviceName",
                .ip_address = "IpAddress",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_customer_gateway };
        }
    },
    Response: type = struct {
        customer_gateway: ?CustomerGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway = "customerGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_default_subnet: struct {
    action_name: []const u8 = "CreateDefaultSubnet",
    Request: type = struct {
        availability_zone: []const u8,
        dry_run: ?bool = null,
        ipv6_native: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "AvailabilityZone",
                .dry_run = "DryRun",
                .ipv6_native = "Ipv6Native",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_default_subnet) } {
            return .{ .service_metadata = service_metadata, .action = create_default_subnet };
        }
    },
    Response: type = struct {
        subnet: ?Subnet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet = "subnet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_default_vpc: struct {
    action_name: []const u8 = "CreateDefaultVpc",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_default_vpc) } {
            return .{ .service_metadata = service_metadata, .action = create_default_vpc };
        }
    },
    Response: type = struct {
        vpc: ?Vpc = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_dhcp_options: struct {
    action_name: []const u8 = "CreateDhcpOptions",
    Request: type = struct {
        dhcp_configurations: []struct {
            key: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .values = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_configurations = "dhcpConfiguration",
                .tag_specifications = "TagSpecification",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dhcp_options) } {
            return .{ .service_metadata = service_metadata, .action = create_dhcp_options };
        }
    },
    Response: type = struct {
        dhcp_options: ?DhcpOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_options = "dhcpOptions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_egress_only_internet_gateway: struct {
    action_name: []const u8 = "CreateEgressOnlyInternetGateway",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        vpc_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .vpc_id = "VpcId",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_egress_only_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_egress_only_internet_gateway };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        egress_only_internet_gateway: ?EgressOnlyInternetGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .egress_only_internet_gateway = "egressOnlyInternetGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_fleet: struct {
    action_name: []const u8 = "CreateFleet",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        spot_options: ?struct {
            allocation_strategy: ?[]const u8 = null,
            maintenance_strategies: ?struct {
                capacity_rebalance: ?struct {
                    replacement_strategy: ?[]const u8 = null,
                    termination_delay: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .replacement_strategy = "ReplacementStrategy",
                            .termination_delay = "TerminationDelay",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .capacity_rebalance = "CapacityRebalance",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_interruption_behavior: ?[]const u8 = null,
            instance_pools_to_use_count: ?i64 = null,
            single_instance_type: ?bool = null,
            single_availability_zone: ?bool = null,
            min_target_capacity: ?i64 = null,
            max_total_price: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .allocation_strategy = "AllocationStrategy",
                    .maintenance_strategies = "MaintenanceStrategies",
                    .instance_interruption_behavior = "InstanceInterruptionBehavior",
                    .instance_pools_to_use_count = "InstancePoolsToUseCount",
                    .single_instance_type = "SingleInstanceType",
                    .single_availability_zone = "SingleAvailabilityZone",
                    .min_target_capacity = "MinTargetCapacity",
                    .max_total_price = "MaxTotalPrice",
                };
                return @field(mappings, field_name);
            }
        } = null,
        on_demand_options: ?struct {
            allocation_strategy: ?[]const u8 = null,
            capacity_reservation_options: ?struct {
                usage_strategy: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .usage_strategy = "UsageStrategy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            single_instance_type: ?bool = null,
            single_availability_zone: ?bool = null,
            min_target_capacity: ?i64 = null,
            max_total_price: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .allocation_strategy = "AllocationStrategy",
                    .capacity_reservation_options = "CapacityReservationOptions",
                    .single_instance_type = "SingleInstanceType",
                    .single_availability_zone = "SingleAvailabilityZone",
                    .min_target_capacity = "MinTargetCapacity",
                    .max_total_price = "MaxTotalPrice",
                };
                return @field(mappings, field_name);
            }
        } = null,
        excess_capacity_termination_policy: ?[]const u8 = null,
        launch_template_configs: []FleetLaunchTemplateConfigRequest,
        target_capacity_specification: TargetCapacitySpecificationRequest,
        terminate_instances_with_expiration: ?bool = null,
        type: ?[]const u8 = null,
        valid_from: ?i64 = null,
        valid_until: ?i64 = null,
        replace_unhealthy_instances: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        context: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .spot_options = "SpotOptions",
                .on_demand_options = "OnDemandOptions",
                .excess_capacity_termination_policy = "ExcessCapacityTerminationPolicy",
                .launch_template_configs = "LaunchTemplateConfigs",
                .target_capacity_specification = "TargetCapacitySpecification",
                .terminate_instances_with_expiration = "TerminateInstancesWithExpiration",
                .type = "Type",
                .valid_from = "ValidFrom",
                .valid_until = "ValidUntil",
                .replace_unhealthy_instances = "ReplaceUnhealthyInstances",
                .tag_specifications = "TagSpecification",
                .context = "Context",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet };
        }
    },
    Response: type = struct {
        fleet_id: ?[]const u8 = null,
        errors: ?[]struct {
            launch_template_and_overrides: ?LaunchTemplateAndOverridesResponse = null,
            lifecycle: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_and_overrides = "launchTemplateAndOverrides",
                    .lifecycle = "lifecycle",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        instances: ?[]struct {
            launch_template_and_overrides: ?LaunchTemplateAndOverridesResponse = null,
            lifecycle: ?[]const u8 = null,
            instance_ids: ?[][]const u8 = null,
            instance_type: ?[]const u8 = null,
            platform: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_and_overrides = "launchTemplateAndOverrides",
                    .lifecycle = "lifecycle",
                    .instance_ids = "instanceIds",
                    .instance_type = "instanceType",
                    .platform = "platform",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_id = "fleetId",
                .errors = "errorSet",
                .instances = "fleetInstanceSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_flow_logs: struct {
    action_name: []const u8 = "CreateFlowLogs",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        deliver_logs_permission_arn: ?[]const u8 = null,
        deliver_cross_account_role: ?[]const u8 = null,
        log_group_name: ?[]const u8 = null,
        resource_ids: [][]const u8,
        resource_type: []const u8,
        traffic_type: ?[]const u8 = null,
        log_destination_type: ?[]const u8 = null,
        log_destination: ?[]const u8 = null,
        log_format: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        max_aggregation_interval: ?i64 = null,
        destination_options: ?struct {
            file_format: ?[]const u8 = null,
            hive_compatible_partitions: ?bool = null,
            per_hour_partition: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_format = "FileFormat",
                    .hive_compatible_partitions = "HiveCompatiblePartitions",
                    .per_hour_partition = "PerHourPartition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .deliver_logs_permission_arn = "DeliverLogsPermissionArn",
                .deliver_cross_account_role = "DeliverCrossAccountRole",
                .log_group_name = "LogGroupName",
                .resource_ids = "ResourceId",
                .resource_type = "ResourceType",
                .traffic_type = "TrafficType",
                .log_destination_type = "LogDestinationType",
                .log_destination = "LogDestination",
                .log_format = "LogFormat",
                .tag_specifications = "TagSpecification",
                .max_aggregation_interval = "MaxAggregationInterval",
                .destination_options = "DestinationOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_flow_logs) } {
            return .{ .service_metadata = service_metadata, .action = create_flow_logs };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        flow_log_ids: ?[][]const u8 = null,
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .flow_log_ids = "flowLogIdSet",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_fpga_image: struct {
    action_name: []const u8 = "CreateFpgaImage",
    Request: type = struct {
        dry_run: ?bool = null,
        input_storage_location: StorageLocation,
        logs_storage_location: ?StorageLocation = null,
        description: ?[]const u8 = null,
        name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .input_storage_location = "InputStorageLocation",
                .logs_storage_location = "LogsStorageLocation",
                .description = "Description",
                .name = "Name",
                .client_token = "ClientToken",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fpga_image) } {
            return .{ .service_metadata = service_metadata, .action = create_fpga_image };
        }
    },
    Response: type = struct {
        fpga_image_id: ?[]const u8 = null,
        fpga_image_global_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fpga_image_id = "fpgaImageId",
                .fpga_image_global_id = "fpgaImageGlobalId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_image: struct {
    action_name: []const u8 = "CreateImage",
    Request: type = struct {
        block_device_mappings: ?[]BlockDeviceMapping = null,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        instance_id: []const u8,
        name: []const u8,
        no_reboot: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_device_mappings = "blockDeviceMapping",
                .description = "description",
                .dry_run = "dryRun",
                .instance_id = "instanceId",
                .name = "name",
                .no_reboot = "noReboot",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image) } {
            return .{ .service_metadata = service_metadata, .action = create_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_instance_connect_endpoint: struct {
    action_name: []const u8 = "CreateInstanceConnectEndpoint",
    Request: type = struct {
        dry_run: ?bool = null,
        subnet_id: []const u8,
        security_group_ids: ?[][]const u8 = null,
        preserve_client_ip: ?bool = null,
        client_token: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .subnet_id = "SubnetId",
                .security_group_ids = "SecurityGroupId",
                .preserve_client_ip = "PreserveClientIp",
                .client_token = "ClientToken",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_connect_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_connect_endpoint };
        }
    },
    Response: type = struct {
        instance_connect_endpoint: ?Ec2InstanceConnectEndpoint = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_connect_endpoint = "instanceConnectEndpoint",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_instance_event_window: struct {
    action_name: []const u8 = "CreateInstanceEventWindow",
    Request: type = struct {
        dry_run: ?bool = null,
        name: ?[]const u8 = null,
        time_ranges: ?[]InstanceEventWindowTimeRangeRequest = null,
        cron_expression: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .name = "Name",
                .time_ranges = "TimeRange",
                .cron_expression = "CronExpression",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_event_window) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_event_window };
        }
    },
    Response: type = struct {
        instance_event_window: ?InstanceEventWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_window = "instanceEventWindow",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_instance_export_task: struct {
    action_name: []const u8 = "CreateInstanceExportTask",
    Request: type = struct {
        description: ?[]const u8 = null,
        export_to_s3_task: struct {
            container_format: ?[]const u8 = null,
            disk_image_format: ?[]const u8 = null,
            s3_bucket: ?[]const u8 = null,
            s3_prefix: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .container_format = "containerFormat",
                    .disk_image_format = "diskImageFormat",
                    .s3_bucket = "s3Bucket",
                    .s3_prefix = "s3Prefix",
                };
                return @field(mappings, field_name);
            }
        },
        instance_id: []const u8,
        target_environment: []const u8,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .export_to_s3_task = "exportToS3",
                .instance_id = "instanceId",
                .target_environment = "targetEnvironment",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_export_task) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_export_task };
        }
    },
    Response: type = struct {
        export_task: ?ExportTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task = "exportTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_internet_gateway: struct {
    action_name: []const u8 = "CreateInternetGateway",
    Request: type = struct {
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_specifications = "TagSpecification",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_internet_gateway };
        }
    },
    Response: type = struct {
        internet_gateway: ?InternetGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .internet_gateway = "internetGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_ipam: struct {
    action_name: []const u8 = "CreateIpam",
    Request: type = struct {
        dry_run: ?bool = null,
        description: ?[]const u8 = null,
        operating_regions: ?[]AddIpamOperatingRegion = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        tier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .description = "Description",
                .operating_regions = "OperatingRegion",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .tier = "Tier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ipam) } {
            return .{ .service_metadata = service_metadata, .action = create_ipam };
        }
    },
    Response: type = struct {
        ipam: ?Ipam = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam = "ipam",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_ipam_pool: struct {
    action_name: []const u8 = "CreateIpamPool",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_scope_id: []const u8,
        locale: ?[]const u8 = null,
        source_ipam_pool_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        address_family: []const u8,
        auto_import: ?bool = null,
        publicly_advertisable: ?bool = null,
        allocation_min_netmask_length: ?i64 = null,
        allocation_max_netmask_length: ?i64 = null,
        allocation_default_netmask_length: ?i64 = null,
        allocation_resource_tags: ?[]RequestIpamResourceTag = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        aws_service: ?[]const u8 = null,
        public_ip_source: ?[]const u8 = null,
        source_resource: ?struct {
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_region: ?[]const u8 = null,
            resource_owner: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .resource_type = "ResourceType",
                    .resource_region = "ResourceRegion",
                    .resource_owner = "ResourceOwner",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_scope_id = "IpamScopeId",
                .locale = "Locale",
                .source_ipam_pool_id = "SourceIpamPoolId",
                .description = "Description",
                .address_family = "AddressFamily",
                .auto_import = "AutoImport",
                .publicly_advertisable = "PubliclyAdvertisable",
                .allocation_min_netmask_length = "AllocationMinNetmaskLength",
                .allocation_max_netmask_length = "AllocationMaxNetmaskLength",
                .allocation_default_netmask_length = "AllocationDefaultNetmaskLength",
                .allocation_resource_tags = "AllocationResourceTag",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .aws_service = "AwsService",
                .public_ip_source = "PublicIpSource",
                .source_resource = "SourceResource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ipam_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_ipam_pool };
        }
    },
    Response: type = struct {
        ipam_pool: ?IpamPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool = "ipamPool",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_ipam_resource_discovery: struct {
    action_name: []const u8 = "CreateIpamResourceDiscovery",
    Request: type = struct {
        dry_run: ?bool = null,
        description: ?[]const u8 = null,
        operating_regions: ?[]AddIpamOperatingRegion = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .description = "Description",
                .operating_regions = "OperatingRegion",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ipam_resource_discovery) } {
            return .{ .service_metadata = service_metadata, .action = create_ipam_resource_discovery };
        }
    },
    Response: type = struct {
        ipam_resource_discovery: ?IpamResourceDiscovery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery = "ipamResourceDiscovery",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_ipam_scope: struct {
    action_name: []const u8 = "CreateIpamScope",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ipam_scope) } {
            return .{ .service_metadata = service_metadata, .action = create_ipam_scope };
        }
    },
    Response: type = struct {
        ipam_scope: ?IpamScope = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_scope = "ipamScope",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_key_pair: struct {
    action_name: []const u8 = "CreateKeyPair",
    Request: type = struct {
        key_name: []const u8,
        dry_run: ?bool = null,
        key_type: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        key_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_name = "KeyName",
                .dry_run = "dryRun",
                .key_type = "KeyType",
                .tag_specifications = "TagSpecification",
                .key_format = "KeyFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = create_key_pair };
        }
    },
    Response: type = struct {
        key_fingerprint: ?[]const u8 = null,
        key_material: ?[]const u8 = null,
        key_name: ?[]const u8 = null,
        key_pair_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_fingerprint = "keyFingerprint",
                .key_material = "keyMaterial",
                .key_name = "keyName",
                .key_pair_id = "keyPairId",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_launch_template: struct {
    action_name: []const u8 = "CreateLaunchTemplate",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        launch_template_name: []const u8,
        version_description: ?[]const u8 = null,
        launch_template_data: RequestLaunchTemplateData,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .launch_template_name = "LaunchTemplateName",
                .version_description = "VersionDescription",
                .launch_template_data = "LaunchTemplateData",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_launch_template) } {
            return .{ .service_metadata = service_metadata, .action = create_launch_template };
        }
    },
    Response: type = struct {
        launch_template: ?LaunchTemplate = null,
        warning: ?ValidationWarning = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template = "launchTemplate",
                .warning = "warning",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_launch_template_version: struct {
    action_name: []const u8 = "CreateLaunchTemplateVersion",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        launch_template_id: ?[]const u8 = null,
        launch_template_name: ?[]const u8 = null,
        source_version: ?[]const u8 = null,
        version_description: ?[]const u8 = null,
        launch_template_data: RequestLaunchTemplateData,
        resolve_alias: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .launch_template_id = "LaunchTemplateId",
                .launch_template_name = "LaunchTemplateName",
                .source_version = "SourceVersion",
                .version_description = "VersionDescription",
                .launch_template_data = "LaunchTemplateData",
                .resolve_alias = "ResolveAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_launch_template_version) } {
            return .{ .service_metadata = service_metadata, .action = create_launch_template_version };
        }
    },
    Response: type = struct {
        launch_template_version: ?LaunchTemplateVersion = null,
        warning: ?ValidationWarning = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template_version = "launchTemplateVersion",
                .warning = "warning",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_local_gateway_route: struct {
    action_name: []const u8 = "CreateLocalGatewayRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        local_gateway_route_table_id: []const u8,
        local_gateway_virtual_interface_group_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        network_interface_id: ?[]const u8 = null,
        destination_prefix_list_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .local_gateway_virtual_interface_group_id = "LocalGatewayVirtualInterfaceGroupId",
                .dry_run = "DryRun",
                .network_interface_id = "NetworkInterfaceId",
                .destination_prefix_list_id = "DestinationPrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_local_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = create_local_gateway_route };
        }
    },
    Response: type = struct {
        route: ?LocalGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_local_gateway_route_table: struct {
    action_name: []const u8 = "CreateLocalGatewayRouteTable",
    Request: type = struct {
        local_gateway_id: []const u8,
        mode: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_id = "LocalGatewayId",
                .mode = "Mode",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_local_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = create_local_gateway_route_table };
        }
    },
    Response: type = struct {
        local_gateway_route_table: ?LocalGatewayRouteTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table = "localGatewayRouteTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_local_gateway_route_table_virtual_interface_group_association: struct {
    action_name: []const u8 = "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation",
    Request: type = struct {
        local_gateway_route_table_id: []const u8,
        local_gateway_virtual_interface_group_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .local_gateway_virtual_interface_group_id = "LocalGatewayVirtualInterfaceGroupId",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_local_gateway_route_table_virtual_interface_group_association) } {
            return .{ .service_metadata = service_metadata, .action = create_local_gateway_route_table_virtual_interface_group_association };
        }
    },
    Response: type = struct {
        local_gateway_route_table_virtual_interface_group_association: ?LocalGatewayRouteTableVirtualInterfaceGroupAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_virtual_interface_group_association = "localGatewayRouteTableVirtualInterfaceGroupAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_local_gateway_route_table_vpc_association: struct {
    action_name: []const u8 = "CreateLocalGatewayRouteTableVpcAssociation",
    Request: type = struct {
        local_gateway_route_table_id: []const u8,
        vpc_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .vpc_id = "VpcId",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_local_gateway_route_table_vpc_association) } {
            return .{ .service_metadata = service_metadata, .action = create_local_gateway_route_table_vpc_association };
        }
    },
    Response: type = struct {
        local_gateway_route_table_vpc_association: ?LocalGatewayRouteTableVpcAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_vpc_association = "localGatewayRouteTableVpcAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_managed_prefix_list: struct {
    action_name: []const u8 = "CreateManagedPrefixList",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_name: []const u8,
        entries: ?[]AddPrefixListEntry = null,
        max_entries: i64,
        tag_specifications: ?[]TagSpecification = null,
        address_family: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_name = "PrefixListName",
                .entries = "Entry",
                .max_entries = "MaxEntries",
                .tag_specifications = "TagSpecification",
                .address_family = "AddressFamily",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_managed_prefix_list) } {
            return .{ .service_metadata = service_metadata, .action = create_managed_prefix_list };
        }
    },
    Response: type = struct {
        prefix_list: ?ManagedPrefixList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prefix_list = "prefixList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_nat_gateway: struct {
    action_name: []const u8 = "CreateNatGateway",
    Request: type = struct {
        allocation_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        subnet_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        connectivity_type: ?[]const u8 = null,
        private_ip_address: ?[]const u8 = null,
        secondary_allocation_ids: ?[][]const u8 = null,
        secondary_private_ip_addresses: ?[][]const u8 = null,
        secondary_private_ip_address_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .subnet_id = "SubnetId",
                .tag_specifications = "TagSpecification",
                .connectivity_type = "ConnectivityType",
                .private_ip_address = "PrivateIpAddress",
                .secondary_allocation_ids = "SecondaryAllocationId",
                .secondary_private_ip_addresses = "SecondaryPrivateIpAddress",
                .secondary_private_ip_address_count = "SecondaryPrivateIpAddressCount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_nat_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_nat_gateway };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        nat_gateway: ?NatGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .nat_gateway = "natGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_network_acl: struct {
    action_name: []const u8 = "CreateNetworkAcl",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_id = "vpcId",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_acl) } {
            return .{ .service_metadata = service_metadata, .action = create_network_acl };
        }
    },
    Response: type = struct {
        network_acl: ?NetworkAcl = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_acl = "networkAcl",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_network_acl_entry: struct {
    action_name: []const u8 = "CreateNetworkAclEntry",
    Request: type = struct {
        cidr_block: ?[]const u8 = null,
        dry_run: ?bool = null,
        egress: bool,
        icmp_type_code: ?IcmpTypeCode = null,
        ipv6_cidr_block: ?[]const u8 = null,
        network_acl_id: []const u8,
        port_range: ?PortRange = null,
        protocol: []const u8,
        rule_action: []const u8,
        rule_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_block = "cidrBlock",
                .dry_run = "dryRun",
                .egress = "egress",
                .icmp_type_code = "Icmp",
                .ipv6_cidr_block = "ipv6CidrBlock",
                .network_acl_id = "networkAclId",
                .port_range = "portRange",
                .protocol = "protocol",
                .rule_action = "ruleAction",
                .rule_number = "ruleNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_acl_entry) } {
            return .{ .service_metadata = service_metadata, .action = create_network_acl_entry };
        }
    },
    Response: type = struct {},
} = .{};
pub const create_network_insights_access_scope: struct {
    action_name: []const u8 = "CreateNetworkInsightsAccessScope",
    Request: type = struct {
        match_paths: ?[]AccessScopePathRequest = null,
        exclude_paths: ?[]AccessScopePathRequest = null,
        client_token: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .match_paths = "MatchPath",
                .exclude_paths = "ExcludePath",
                .client_token = "ClientToken",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_insights_access_scope) } {
            return .{ .service_metadata = service_metadata, .action = create_network_insights_access_scope };
        }
    },
    Response: type = struct {
        network_insights_access_scope: ?NetworkInsightsAccessScope = null,
        network_insights_access_scope_content: ?NetworkInsightsAccessScopeContent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope = "networkInsightsAccessScope",
                .network_insights_access_scope_content = "networkInsightsAccessScopeContent",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_network_insights_path: struct {
    action_name: []const u8 = "CreateNetworkInsightsPath",
    Request: type = struct {
        source_ip: ?[]const u8 = null,
        destination_ip: ?[]const u8 = null,
        source: []const u8,
        destination: ?[]const u8 = null,
        protocol: []const u8,
        destination_port: ?i64 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        client_token: []const u8,
        filter_at_source: ?PathRequestFilter = null,
        filter_at_destination: ?PathRequestFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_ip = "SourceIp",
                .destination_ip = "DestinationIp",
                .source = "Source",
                .destination = "Destination",
                .protocol = "Protocol",
                .destination_port = "DestinationPort",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .filter_at_source = "FilterAtSource",
                .filter_at_destination = "FilterAtDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_insights_path) } {
            return .{ .service_metadata = service_metadata, .action = create_network_insights_path };
        }
    },
    Response: type = struct {
        network_insights_path: ?NetworkInsightsPath = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_path = "networkInsightsPath",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_network_interface: struct {
    action_name: []const u8 = "CreateNetworkInterface",
    Request: type = struct {
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        groups: ?[][]const u8 = null,
        ipv6_address_count: ?i64 = null,
        ipv6_addresses: ?[]InstanceIpv6Address = null,
        private_ip_address: ?[]const u8 = null,
        private_ip_addresses: ?[]PrivateIpAddressSpecification = null,
        secondary_private_ip_address_count: ?i64 = null,
        ipv4_prefixes: ?[]Ipv4PrefixSpecificationRequest = null,
        ipv4_prefix_count: ?i64 = null,
        ipv6_prefixes: ?[]Ipv6PrefixSpecificationRequest = null,
        ipv6_prefix_count: ?i64 = null,
        interface_type: ?[]const u8 = null,
        subnet_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        enable_primary_ipv6: ?bool = null,
        connection_tracking_specification: ?ConnectionTrackingSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .dry_run = "dryRun",
                .groups = "SecurityGroupId",
                .ipv6_address_count = "ipv6AddressCount",
                .ipv6_addresses = "ipv6Addresses",
                .private_ip_address = "privateIpAddress",
                .private_ip_addresses = "privateIpAddresses",
                .secondary_private_ip_address_count = "secondaryPrivateIpAddressCount",
                .ipv4_prefixes = "Ipv4Prefix",
                .ipv4_prefix_count = "Ipv4PrefixCount",
                .ipv6_prefixes = "Ipv6Prefix",
                .ipv6_prefix_count = "Ipv6PrefixCount",
                .interface_type = "InterfaceType",
                .subnet_id = "subnetId",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .enable_primary_ipv6 = "EnablePrimaryIpv6",
                .connection_tracking_specification = "ConnectionTrackingSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_interface) } {
            return .{ .service_metadata = service_metadata, .action = create_network_interface };
        }
    },
    Response: type = struct {
        network_interface: ?NetworkInterface = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface = "networkInterface",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_network_interface_permission: struct {
    action_name: []const u8 = "CreateNetworkInterfacePermission",
    Request: type = struct {
        network_interface_id: []const u8,
        aws_account_id: ?[]const u8 = null,
        aws_service: ?[]const u8 = null,
        permission: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "NetworkInterfaceId",
                .aws_account_id = "AwsAccountId",
                .aws_service = "AwsService",
                .permission = "Permission",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_interface_permission) } {
            return .{ .service_metadata = service_metadata, .action = create_network_interface_permission };
        }
    },
    Response: type = struct {
        interface_permission: ?NetworkInterfacePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interface_permission = "interfacePermission",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_placement_group: struct {
    action_name: []const u8 = "CreatePlacementGroup",
    Request: type = struct {
        dry_run: ?bool = null,
        group_name: ?[]const u8 = null,
        strategy: ?[]const u8 = null,
        partition_count: ?i64 = null,
        tag_specifications: ?[]TagSpecification = null,
        spread_level: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .group_name = "groupName",
                .strategy = "strategy",
                .partition_count = "PartitionCount",
                .tag_specifications = "TagSpecification",
                .spread_level = "SpreadLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_placement_group) } {
            return .{ .service_metadata = service_metadata, .action = create_placement_group };
        }
    },
    Response: type = struct {
        placement_group: ?PlacementGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_group = "placementGroup",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_public_ipv4_pool: struct {
    action_name: []const u8 = "CreatePublicIpv4Pool",
    Request: type = struct {
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_public_ipv4_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_public_ipv4_pool };
        }
    },
    Response: type = struct {
        pool_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "poolId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_replace_root_volume_task: struct {
    action_name: []const u8 = "CreateReplaceRootVolumeTask",
    Request: type = struct {
        instance_id: []const u8,
        snapshot_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        image_id: ?[]const u8 = null,
        delete_replaced_root_volume: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .snapshot_id = "SnapshotId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
                .image_id = "ImageId",
                .delete_replaced_root_volume = "DeleteReplacedRootVolume",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replace_root_volume_task) } {
            return .{ .service_metadata = service_metadata, .action = create_replace_root_volume_task };
        }
    },
    Response: type = struct {
        replace_root_volume_task: ?ReplaceRootVolumeTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replace_root_volume_task = "replaceRootVolumeTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_reserved_instances_listing: struct {
    action_name: []const u8 = "CreateReservedInstancesListing",
    Request: type = struct {
        client_token: []const u8,
        instance_count: i64,
        price_schedules: []struct {
            currency_code: ?[]const u8 = null,
            price: ?f64 = null,
            term: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .currency_code = "currencyCode",
                    .price = "price",
                    .term = "term",
                };
                return @field(mappings, field_name);
            }
        },
        reserved_instances_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .instance_count = "instanceCount",
                .price_schedules = "priceSchedules",
                .reserved_instances_id = "reservedInstancesId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_reserved_instances_listing) } {
            return .{ .service_metadata = service_metadata, .action = create_reserved_instances_listing };
        }
    },
    Response: type = struct {
        reserved_instances_listings: ?[]ReservedInstancesListing = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_listings = "reservedInstancesListingsSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_restore_image_task: struct {
    action_name: []const u8 = "CreateRestoreImageTask",
    Request: type = struct {
        bucket: []const u8,
        object_key: []const u8,
        name: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .object_key = "ObjectKey",
                .name = "Name",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_restore_image_task) } {
            return .{ .service_metadata = service_metadata, .action = create_restore_image_task };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_route: struct {
    action_name: []const u8 = "CreateRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        destination_ipv6_cidr_block: ?[]const u8 = null,
        destination_prefix_list_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        vpc_endpoint_id: ?[]const u8 = null,
        egress_only_internet_gateway_id: ?[]const u8 = null,
        gateway_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        nat_gateway_id: ?[]const u8 = null,
        transit_gateway_id: ?[]const u8 = null,
        local_gateway_id: ?[]const u8 = null,
        carrier_gateway_id: ?[]const u8 = null,
        network_interface_id: ?[]const u8 = null,
        route_table_id: []const u8,
        vpc_peering_connection_id: ?[]const u8 = null,
        core_network_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "destinationCidrBlock",
                .destination_ipv6_cidr_block = "destinationIpv6CidrBlock",
                .destination_prefix_list_id = "DestinationPrefixListId",
                .dry_run = "dryRun",
                .vpc_endpoint_id = "VpcEndpointId",
                .egress_only_internet_gateway_id = "egressOnlyInternetGatewayId",
                .gateway_id = "gatewayId",
                .instance_id = "instanceId",
                .nat_gateway_id = "natGatewayId",
                .transit_gateway_id = "TransitGatewayId",
                .local_gateway_id = "LocalGatewayId",
                .carrier_gateway_id = "CarrierGatewayId",
                .network_interface_id = "networkInterfaceId",
                .route_table_id = "routeTableId",
                .vpc_peering_connection_id = "vpcPeeringConnectionId",
                .core_network_arn = "CoreNetworkArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_route) } {
            return .{ .service_metadata = service_metadata, .action = create_route };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_route_table: struct {
    action_name: []const u8 = "CreateRouteTable",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_id = "vpcId",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_route_table) } {
            return .{ .service_metadata = service_metadata, .action = create_route_table };
        }
    },
    Response: type = struct {
        route_table: ?RouteTable = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_table = "routeTable",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_security_group: struct {
    action_name: []const u8 = "CreateSecurityGroup",
    Request: type = struct {
        description: []const u8,
        group_name: []const u8,
        vpc_id: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "GroupDescription",
                .group_name = "GroupName",
                .vpc_id = "VpcId",
                .tag_specifications = "TagSpecification",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_group) } {
            return .{ .service_metadata = service_metadata, .action = create_security_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "groupId",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        description: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        volume_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .outpost_arn = "OutpostArn",
                .volume_id = "VolumeId",
                .tag_specifications = "TagSpecification",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        data_encryption_key_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        owner_id: ?[]const u8 = null,
        progress: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        state: ?[]const u8 = null,
        state_message: ?[]const u8 = null,
        volume_id: ?[]const u8 = null,
        volume_size: ?i64 = null,
        owner_alias: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        storage_tier: ?[]const u8 = null,
        restore_expiry_time: ?i64 = null,
        sse_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_encryption_key_id = "dataEncryptionKeyId",
                .description = "description",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
                .owner_id = "ownerId",
                .progress = "progress",
                .snapshot_id = "snapshotId",
                .start_time = "startTime",
                .state = "status",
                .state_message = "statusMessage",
                .volume_id = "volumeId",
                .volume_size = "volumeSize",
                .owner_alias = "ownerAlias",
                .outpost_arn = "outpostArn",
                .tags = "tagSet",
                .storage_tier = "storageTier",
                .restore_expiry_time = "restoreExpiryTime",
                .sse_type = "sseType",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_snapshots: struct {
    action_name: []const u8 = "CreateSnapshots",
    Request: type = struct {
        description: ?[]const u8 = null,
        instance_specification: struct {
            instance_id: []const u8,
            exclude_boot_volume: ?bool = null,
            exclude_data_volume_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .exclude_boot_volume = "ExcludeBootVolume",
                    .exclude_data_volume_ids = "ExcludeDataVolumeId",
                };
                return @field(mappings, field_name);
            }
        },
        outpost_arn: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        copy_tags_from_source: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .instance_specification = "InstanceSpecification",
                .outpost_arn = "OutpostArn",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .copy_tags_from_source = "CopyTagsFromSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]struct {
            description: ?[]const u8 = null,
            tags: ?[]Tag = null,
            encrypted: ?bool = null,
            volume_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            volume_size: ?i64 = null,
            start_time: ?i64 = null,
            progress: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            snapshot_id: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,
            sse_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "description",
                    .tags = "tagSet",
                    .encrypted = "encrypted",
                    .volume_id = "volumeId",
                    .state = "state",
                    .volume_size = "volumeSize",
                    .start_time = "startTime",
                    .progress = "progress",
                    .owner_id = "ownerId",
                    .snapshot_id = "snapshotId",
                    .outpost_arn = "outpostArn",
                    .sse_type = "sseType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "snapshotSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_spot_datafeed_subscription: struct {
    action_name: []const u8 = "CreateSpotDatafeedSubscription",
    Request: type = struct {
        bucket: []const u8,
        dry_run: ?bool = null,
        prefix: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "bucket",
                .dry_run = "dryRun",
                .prefix = "prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_spot_datafeed_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_spot_datafeed_subscription };
        }
    },
    Response: type = struct {
        spot_datafeed_subscription: ?SpotDatafeedSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_datafeed_subscription = "spotDatafeedSubscription",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_store_image_task: struct {
    action_name: []const u8 = "CreateStoreImageTask",
    Request: type = struct {
        image_id: []const u8,
        bucket: []const u8,
        s3_object_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .bucket = "Bucket",
                .s3_object_tags = "S3ObjectTag",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_store_image_task) } {
            return .{ .service_metadata = service_metadata, .action = create_store_image_task };
        }
    },
    Response: type = struct {
        object_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_key = "objectKey",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_subnet: struct {
    action_name: []const u8 = "CreateSubnet",
    Request: type = struct {
        tag_specifications: ?[]TagSpecification = null,
        availability_zone: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        cidr_block: ?[]const u8 = null,
        ipv6_cidr_block: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        vpc_id: []const u8,
        dry_run: ?bool = null,
        ipv6_native: ?bool = null,
        ipv4_ipam_pool_id: ?[]const u8 = null,
        ipv4_netmask_length: ?i64 = null,
        ipv6_ipam_pool_id: ?[]const u8 = null,
        ipv6_netmask_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_specifications = "TagSpecification",
                .availability_zone = "AvailabilityZone",
                .availability_zone_id = "AvailabilityZoneId",
                .cidr_block = "CidrBlock",
                .ipv6_cidr_block = "Ipv6CidrBlock",
                .outpost_arn = "OutpostArn",
                .vpc_id = "VpcId",
                .dry_run = "dryRun",
                .ipv6_native = "Ipv6Native",
                .ipv4_ipam_pool_id = "Ipv4IpamPoolId",
                .ipv4_netmask_length = "Ipv4NetmaskLength",
                .ipv6_ipam_pool_id = "Ipv6IpamPoolId",
                .ipv6_netmask_length = "Ipv6NetmaskLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subnet) } {
            return .{ .service_metadata = service_metadata, .action = create_subnet };
        }
    },
    Response: type = struct {
        subnet: ?Subnet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet = "subnet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_subnet_cidr_reservation: struct {
    action_name: []const u8 = "CreateSubnetCidrReservation",
    Request: type = struct {
        subnet_id: []const u8,
        cidr: []const u8,
        reservation_type: []const u8,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_id = "SubnetId",
                .cidr = "Cidr",
                .reservation_type = "ReservationType",
                .description = "Description",
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subnet_cidr_reservation) } {
            return .{ .service_metadata = service_metadata, .action = create_subnet_cidr_reservation };
        }
    },
    Response: type = struct {
        subnet_cidr_reservation: ?SubnetCidrReservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_cidr_reservation = "subnetCidrReservation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_tags: struct {
    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        dry_run: ?bool = null,
        resources: [][]const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .resources = "ResourceId",
                .tags = "Tag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {},
} = .{};
pub const create_traffic_mirror_filter: struct {
    action_name: []const u8 = "CreateTrafficMirrorFilter",
    Request: type = struct {
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_mirror_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_mirror_filter };
        }
    },
    Response: type = struct {
        traffic_mirror_filter: ?TrafficMirrorFilter = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter = "trafficMirrorFilter",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_traffic_mirror_filter_rule: struct {
    action_name: []const u8 = "CreateTrafficMirrorFilterRule",
    Request: type = struct {
        traffic_mirror_filter_id: []const u8,
        traffic_direction: []const u8,
        rule_number: i64,
        rule_action: []const u8,
        destination_port_range: ?TrafficMirrorPortRangeRequest = null,
        source_port_range: ?TrafficMirrorPortRangeRequest = null,
        protocol: ?i64 = null,
        destination_cidr_block: []const u8,
        source_cidr_block: []const u8,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_id = "TrafficMirrorFilterId",
                .traffic_direction = "TrafficDirection",
                .rule_number = "RuleNumber",
                .rule_action = "RuleAction",
                .destination_port_range = "DestinationPortRange",
                .source_port_range = "SourcePortRange",
                .protocol = "Protocol",
                .destination_cidr_block = "DestinationCidrBlock",
                .source_cidr_block = "SourceCidrBlock",
                .description = "Description",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_mirror_filter_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_mirror_filter_rule };
        }
    },
    Response: type = struct {
        traffic_mirror_filter_rule: ?TrafficMirrorFilterRule = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_rule = "trafficMirrorFilterRule",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_traffic_mirror_session: struct {
    action_name: []const u8 = "CreateTrafficMirrorSession",
    Request: type = struct {
        network_interface_id: []const u8,
        traffic_mirror_target_id: []const u8,
        traffic_mirror_filter_id: []const u8,
        packet_length: ?i64 = null,
        session_number: i64,
        virtual_network_id: ?i64 = null,
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "NetworkInterfaceId",
                .traffic_mirror_target_id = "TrafficMirrorTargetId",
                .traffic_mirror_filter_id = "TrafficMirrorFilterId",
                .packet_length = "PacketLength",
                .session_number = "SessionNumber",
                .virtual_network_id = "VirtualNetworkId",
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_mirror_session) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_mirror_session };
        }
    },
    Response: type = struct {
        traffic_mirror_session: ?TrafficMirrorSession = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session = "trafficMirrorSession",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_traffic_mirror_target: struct {
    action_name: []const u8 = "CreateTrafficMirrorTarget",
    Request: type = struct {
        network_interface_id: ?[]const u8 = null,
        network_load_balancer_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        gateway_load_balancer_endpoint_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "NetworkInterfaceId",
                .network_load_balancer_arn = "NetworkLoadBalancerArn",
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .gateway_load_balancer_endpoint_id = "GatewayLoadBalancerEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_mirror_target) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_mirror_target };
        }
    },
    Response: type = struct {
        traffic_mirror_target: ?TrafficMirrorTarget = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_target = "trafficMirrorTarget",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway: struct {
    action_name: []const u8 = "CreateTransitGateway",
    Request: type = struct {
        description: ?[]const u8 = null,
        options: ?struct {
            amazon_side_asn: ?i64 = null,
            auto_accept_shared_attachments: ?[]const u8 = null,
            default_route_table_association: ?[]const u8 = null,
            default_route_table_propagation: ?[]const u8 = null,
            vpn_ecmp_support: ?[]const u8 = null,
            dns_support: ?[]const u8 = null,
            security_group_referencing_support: ?[]const u8 = null,
            multicast_support: ?[]const u8 = null,
            transit_gateway_cidr_blocks: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amazon_side_asn = "AmazonSideAsn",
                    .auto_accept_shared_attachments = "AutoAcceptSharedAttachments",
                    .default_route_table_association = "DefaultRouteTableAssociation",
                    .default_route_table_propagation = "DefaultRouteTablePropagation",
                    .vpn_ecmp_support = "VpnEcmpSupport",
                    .dns_support = "DnsSupport",
                    .security_group_referencing_support = "SecurityGroupReferencingSupport",
                    .multicast_support = "MulticastSupport",
                    .transit_gateway_cidr_blocks = "TransitGatewayCidrBlocks",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .options = "Options",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway: ?TransitGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway = "transitGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_connect: struct {
    action_name: []const u8 = "CreateTransitGatewayConnect",
    Request: type = struct {
        transport_transit_gateway_attachment_id: []const u8,
        options: struct {
            protocol: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .protocol = "Protocol",
                };
                return @field(mappings, field_name);
            }
        },
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transport_transit_gateway_attachment_id = "TransportTransitGatewayAttachmentId",
                .options = "Options",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_connect) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_connect };
        }
    },
    Response: type = struct {
        transit_gateway_connect: ?TransitGatewayConnect = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect = "transitGatewayConnect",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_connect_peer: struct {
    action_name: []const u8 = "CreateTransitGatewayConnectPeer",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        transit_gateway_address: ?[]const u8 = null,
        peer_address: []const u8,
        bgp_options: ?struct {
            peer_asn: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .peer_asn = "PeerAsn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        inside_cidr_blocks: [][]const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .transit_gateway_address = "TransitGatewayAddress",
                .peer_address = "PeerAddress",
                .bgp_options = "BgpOptions",
                .inside_cidr_blocks = "InsideCidrBlocks",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer: ?TransitGatewayConnectPeer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer = "transitGatewayConnectPeer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_multicast_domain: struct {
    action_name: []const u8 = "CreateTransitGatewayMulticastDomain",
    Request: type = struct {
        transit_gateway_id: []const u8,
        options: ?struct {
            igmpv2_support: ?[]const u8 = null,
            static_sources_support: ?[]const u8 = null,
            auto_accept_shared_associations: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .igmpv2_support = "Igmpv2Support",
                    .static_sources_support = "StaticSourcesSupport",
                    .auto_accept_shared_associations = "AutoAcceptSharedAssociations",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .options = "Options",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_multicast_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_multicast_domain };
        }
    },
    Response: type = struct {
        transit_gateway_multicast_domain: ?TransitGatewayMulticastDomain = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain = "transitGatewayMulticastDomain",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_peering_attachment: struct {
    action_name: []const u8 = "CreateTransitGatewayPeeringAttachment",
    Request: type = struct {
        transit_gateway_id: []const u8,
        peer_transit_gateway_id: []const u8,
        peer_account_id: []const u8,
        peer_region: []const u8,
        options: ?struct {
            dynamic_routing: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dynamic_routing = "DynamicRouting",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .peer_transit_gateway_id = "PeerTransitGatewayId",
                .peer_account_id = "PeerAccountId",
                .peer_region = "PeerRegion",
                .options = "Options",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_peering_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_peering_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_peering_attachment: ?TransitGatewayPeeringAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering_attachment = "transitGatewayPeeringAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_policy_table: struct {
    action_name: []const u8 = "CreateTransitGatewayPolicyTable",
    Request: type = struct {
        transit_gateway_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .tag_specifications = "TagSpecifications",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_policy_table) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_policy_table };
        }
    },
    Response: type = struct {
        transit_gateway_policy_table: ?TransitGatewayPolicyTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table = "transitGatewayPolicyTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_prefix_list_reference: struct {
    action_name: []const u8 = "CreateTransitGatewayPrefixListReference",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        prefix_list_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        blackhole: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .prefix_list_id = "PrefixListId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .blackhole = "Blackhole",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_prefix_list_reference) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_prefix_list_reference };
        }
    },
    Response: type = struct {
        transit_gateway_prefix_list_reference: ?TransitGatewayPrefixListReference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_prefix_list_reference = "transitGatewayPrefixListReference",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_route: struct {
    action_name: []const u8 = "CreateTransitGatewayRoute",
    Request: type = struct {
        destination_cidr_block: []const u8,
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        blackhole: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .blackhole = "Blackhole",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_route };
        }
    },
    Response: type = struct {
        route: ?TransitGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_route_table: struct {
    action_name: []const u8 = "CreateTransitGatewayRouteTable",
    Request: type = struct {
        transit_gateway_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .tag_specifications = "TagSpecifications",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_route_table };
        }
    },
    Response: type = struct {
        transit_gateway_route_table: ?TransitGatewayRouteTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table = "transitGatewayRouteTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_route_table_announcement: struct {
    action_name: []const u8 = "CreateTransitGatewayRouteTableAnnouncement",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        peering_attachment_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .peering_attachment_id = "PeeringAttachmentId",
                .tag_specifications = "TagSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_route_table_announcement) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_route_table_announcement };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_announcement: ?TransitGatewayRouteTableAnnouncement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_announcement = "transitGatewayRouteTableAnnouncement",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_transit_gateway_vpc_attachment: struct {
    action_name: []const u8 = "CreateTransitGatewayVpcAttachment",
    Request: type = struct {
        transit_gateway_id: []const u8,
        vpc_id: []const u8,
        subnet_ids: [][]const u8,
        options: ?struct {
            dns_support: ?[]const u8 = null,
            security_group_referencing_support: ?[]const u8 = null,
            ipv6_support: ?[]const u8 = null,
            appliance_mode_support: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dns_support = "DnsSupport",
                    .security_group_referencing_support = "SecurityGroupReferencingSupport",
                    .ipv6_support = "Ipv6Support",
                    .appliance_mode_support = "ApplianceModeSupport",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .vpc_id = "VpcId",
                .subnet_ids = "SubnetIds",
                .options = "Options",
                .tag_specifications = "TagSpecifications",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_vpc_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachment: ?TransitGatewayVpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachment = "transitGatewayVpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_verified_access_endpoint: struct {
    action_name: []const u8 = "CreateVerifiedAccessEndpoint",
    Request: type = struct {
        verified_access_group_id: []const u8,
        endpoint_type: []const u8,
        attachment_type: []const u8,
        domain_certificate_arn: []const u8,
        application_domain: []const u8,
        endpoint_domain_prefix: []const u8,
        security_group_ids: ?[][]const u8 = null,
        load_balancer_options: ?struct {
            protocol: ?[]const u8 = null,
            port: ?i64 = null,
            load_balancer_arn: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .protocol = "Protocol",
                    .port = "Port",
                    .load_balancer_arn = "LoadBalancerArn",
                    .subnet_ids = "SubnetId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        network_interface_options: ?struct {
            network_interface_id: ?[]const u8 = null,
            protocol: ?[]const u8 = null,
            port: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network_interface_id = "NetworkInterfaceId",
                    .protocol = "Protocol",
                    .port = "Port",
                };
                return @field(mappings, field_name);
            }
        } = null,
        description: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_id = "VerifiedAccessGroupId",
                .endpoint_type = "EndpointType",
                .attachment_type = "AttachmentType",
                .domain_certificate_arn = "DomainCertificateArn",
                .application_domain = "ApplicationDomain",
                .endpoint_domain_prefix = "EndpointDomainPrefix",
                .security_group_ids = "SecurityGroupId",
                .load_balancer_options = "LoadBalancerOptions",
                .network_interface_options = "NetworkInterfaceOptions",
                .description = "Description",
                .policy_document = "PolicyDocument",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_verified_access_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_verified_access_endpoint };
        }
    },
    Response: type = struct {
        verified_access_endpoint: ?VerifiedAccessEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint = "verifiedAccessEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_verified_access_group: struct {
    action_name: []const u8 = "CreateVerifiedAccessGroup",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        description: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .description = "Description",
                .policy_document = "PolicyDocument",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_verified_access_group) } {
            return .{ .service_metadata = service_metadata, .action = create_verified_access_group };
        }
    },
    Response: type = struct {
        verified_access_group: ?VerifiedAccessGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group = "verifiedAccessGroup",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_verified_access_instance: struct {
    action_name: []const u8 = "CreateVerifiedAccessInstance",
    Request: type = struct {
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        fips_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .fips_enabled = "FIPSEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_verified_access_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_verified_access_instance };
        }
    },
    Response: type = struct {
        verified_access_instance: ?VerifiedAccessInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance = "verifiedAccessInstance",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_verified_access_trust_provider: struct {
    action_name: []const u8 = "CreateVerifiedAccessTrustProvider",
    Request: type = struct {
        trust_provider_type: []const u8,
        user_trust_provider_type: ?[]const u8 = null,
        device_trust_provider_type: ?[]const u8 = null,
        oidc_options: ?struct {
            issuer: ?[]const u8 = null,
            authorization_endpoint: ?[]const u8 = null,
            token_endpoint: ?[]const u8 = null,
            user_info_endpoint: ?[]const u8 = null,
            client_id: ?[]const u8 = null,
            client_secret: ?[]const u8 = null,
            scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .issuer = "Issuer",
                    .authorization_endpoint = "AuthorizationEndpoint",
                    .token_endpoint = "TokenEndpoint",
                    .user_info_endpoint = "UserInfoEndpoint",
                    .client_id = "ClientId",
                    .client_secret = "ClientSecret",
                    .scope = "Scope",
                };
                return @field(mappings, field_name);
            }
        } = null,
        device_options: ?struct {
            tenant_id: ?[]const u8 = null,
            public_signing_key_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tenant_id = "TenantId",
                    .public_signing_key_url = "PublicSigningKeyUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        policy_reference_name: []const u8,
        description: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trust_provider_type = "TrustProviderType",
                .user_trust_provider_type = "UserTrustProviderType",
                .device_trust_provider_type = "DeviceTrustProviderType",
                .oidc_options = "OidcOptions",
                .device_options = "DeviceOptions",
                .policy_reference_name = "PolicyReferenceName",
                .description = "Description",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_verified_access_trust_provider) } {
            return .{ .service_metadata = service_metadata, .action = create_verified_access_trust_provider };
        }
    },
    Response: type = struct {
        verified_access_trust_provider: ?VerifiedAccessTrustProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider = "verifiedAccessTrustProvider",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_volume: struct {
    action_name: []const u8 = "CreateVolume",
    Request: type = struct {
        availability_zone: []const u8,
        encrypted: ?bool = null,
        iops: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        size: ?i64 = null,
        snapshot_id: ?[]const u8 = null,
        volume_type: ?[]const u8 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        multi_attach_enabled: ?bool = null,
        throughput: ?i64 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "AvailabilityZone",
                .encrypted = "encrypted",
                .iops = "Iops",
                .kms_key_id = "KmsKeyId",
                .outpost_arn = "OutpostArn",
                .size = "Size",
                .snapshot_id = "SnapshotId",
                .volume_type = "VolumeType",
                .dry_run = "dryRun",
                .tag_specifications = "TagSpecification",
                .multi_attach_enabled = "MultiAttachEnabled",
                .throughput = "Throughput",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_volume) } {
            return .{ .service_metadata = service_metadata, .action = create_volume };
        }
    },
    Response: type = struct {
        attachments: ?[]VolumeAttachment = null,
        availability_zone: ?[]const u8 = null,
        create_time: ?i64 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        size: ?i64 = null,
        snapshot_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        volume_id: ?[]const u8 = null,
        iops: ?i64 = null,
        tags: ?[]Tag = null,
        volume_type: ?[]const u8 = null,
        fast_restored: ?bool = null,
        multi_attach_enabled: ?bool = null,
        throughput: ?i64 = null,
        sse_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachments = "attachmentSet",
                .availability_zone = "availabilityZone",
                .create_time = "createTime",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
                .outpost_arn = "outpostArn",
                .size = "size",
                .snapshot_id = "snapshotId",
                .state = "status",
                .volume_id = "volumeId",
                .iops = "iops",
                .tags = "tagSet",
                .volume_type = "volumeType",
                .fast_restored = "fastRestored",
                .multi_attach_enabled = "multiAttachEnabled",
                .throughput = "throughput",
                .sse_type = "sseType",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpc: struct {
    action_name: []const u8 = "CreateVpc",
    Request: type = struct {
        cidr_block: ?[]const u8 = null,
        amazon_provided_ipv6_cidr_block: ?bool = null,
        ipv6_pool: ?[]const u8 = null,
        ipv6_cidr_block: ?[]const u8 = null,
        ipv4_ipam_pool_id: ?[]const u8 = null,
        ipv4_netmask_length: ?i64 = null,
        ipv6_ipam_pool_id: ?[]const u8 = null,
        ipv6_netmask_length: ?i64 = null,
        dry_run: ?bool = null,
        instance_tenancy: ?[]const u8 = null,
        ipv6_cidr_block_network_border_group: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_block = "CidrBlock",
                .amazon_provided_ipv6_cidr_block = "amazonProvidedIpv6CidrBlock",
                .ipv6_pool = "Ipv6Pool",
                .ipv6_cidr_block = "Ipv6CidrBlock",
                .ipv4_ipam_pool_id = "Ipv4IpamPoolId",
                .ipv4_netmask_length = "Ipv4NetmaskLength",
                .ipv6_ipam_pool_id = "Ipv6IpamPoolId",
                .ipv6_netmask_length = "Ipv6NetmaskLength",
                .dry_run = "dryRun",
                .instance_tenancy = "instanceTenancy",
                .ipv6_cidr_block_network_border_group = "Ipv6CidrBlockNetworkBorderGroup",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc };
        }
    },
    Response: type = struct {
        vpc: ?Vpc = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpc_endpoint: struct {
    action_name: []const u8 = "CreateVpcEndpoint",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_endpoint_type: ?[]const u8 = null,
        vpc_id: []const u8,
        service_name: []const u8,
        policy_document: ?[]const u8 = null,
        route_table_ids: ?[][]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        dns_options: ?DnsOptionsSpecification = null,
        client_token: ?[]const u8 = null,
        private_dns_enabled: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        subnet_configurations: ?[]SubnetConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .vpc_endpoint_type = "VpcEndpointType",
                .vpc_id = "VpcId",
                .service_name = "ServiceName",
                .policy_document = "PolicyDocument",
                .route_table_ids = "RouteTableId",
                .subnet_ids = "SubnetId",
                .security_group_ids = "SecurityGroupId",
                .ip_address_type = "IpAddressType",
                .dns_options = "DnsOptions",
                .client_token = "ClientToken",
                .private_dns_enabled = "PrivateDnsEnabled",
                .tag_specifications = "TagSpecification",
                .subnet_configurations = "SubnetConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint: ?VpcEndpoint = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint = "vpcEndpoint",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpc_endpoint_connection_notification: struct {
    action_name: []const u8 = "CreateVpcEndpointConnectionNotification",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: ?[]const u8 = null,
        vpc_endpoint_id: ?[]const u8 = null,
        connection_notification_arn: []const u8,
        connection_events: [][]const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .vpc_endpoint_id = "VpcEndpointId",
                .connection_notification_arn = "ConnectionNotificationArn",
                .connection_events = "ConnectionEvents",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_endpoint_connection_notification) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_endpoint_connection_notification };
        }
    },
    Response: type = struct {
        connection_notification: ?ConnectionNotification = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_notification = "connectionNotification",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpc_endpoint_service_configuration: struct {
    action_name: []const u8 = "CreateVpcEndpointServiceConfiguration",
    Request: type = struct {
        dry_run: ?bool = null,
        acceptance_required: ?bool = null,
        private_dns_name: ?[]const u8 = null,
        network_load_balancer_arns: ?[][]const u8 = null,
        gateway_load_balancer_arns: ?[][]const u8 = null,
        supported_ip_address_types: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .acceptance_required = "AcceptanceRequired",
                .private_dns_name = "PrivateDnsName",
                .network_load_balancer_arns = "NetworkLoadBalancerArn",
                .gateway_load_balancer_arns = "GatewayLoadBalancerArn",
                .supported_ip_address_types = "SupportedIpAddressType",
                .client_token = "ClientToken",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_endpoint_service_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_endpoint_service_configuration };
        }
    },
    Response: type = struct {
        service_configuration: ?ServiceConfiguration = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_configuration = "serviceConfiguration",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpc_peering_connection: struct {
    action_name: []const u8 = "CreateVpcPeeringConnection",
    Request: type = struct {
        dry_run: ?bool = null,
        peer_owner_id: ?[]const u8 = null,
        peer_vpc_id: ?[]const u8 = null,
        vpc_id: []const u8,
        peer_region: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .peer_owner_id = "peerOwnerId",
                .peer_vpc_id = "peerVpcId",
                .vpc_id = "vpcId",
                .peer_region = "PeerRegion",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_peering_connection };
        }
    },
    Response: type = struct {
        vpc_peering_connection: ?VpcPeeringConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_connection = "vpcPeeringConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpn_connection: struct {
    action_name: []const u8 = "CreateVpnConnection",
    Request: type = struct {
        customer_gateway_id: []const u8,
        type: []const u8,
        vpn_gateway_id: ?[]const u8 = null,
        transit_gateway_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        options: ?struct {
            enable_acceleration: ?bool = null,
            static_routes_only: ?bool = null,
            tunnel_inside_ip_version: ?[]const u8 = null,
            tunnel_options: ?[]struct {
                tunnel_inside_cidr: ?[]const u8 = null,
                tunnel_inside_ipv6_cidr: ?[]const u8 = null,
                pre_shared_key: ?[]const u8 = null,
                phase1_lifetime_seconds: ?i64 = null,
                phase2_lifetime_seconds: ?i64 = null,
                rekey_margin_time_seconds: ?i64 = null,
                rekey_fuzz_percentage: ?i64 = null,
                replay_window_size: ?i64 = null,
                dpd_timeout_seconds: ?i64 = null,
                dpd_timeout_action: ?[]const u8 = null,
                phase1_encryption_algorithms: ?[]Phase1EncryptionAlgorithmsRequestListValue = null,
                phase2_encryption_algorithms: ?[]Phase2EncryptionAlgorithmsRequestListValue = null,
                phase1_integrity_algorithms: ?[]Phase1IntegrityAlgorithmsRequestListValue = null,
                phase2_integrity_algorithms: ?[]Phase2IntegrityAlgorithmsRequestListValue = null,
                phase1dh_group_numbers: ?[]Phase1DHGroupNumbersRequestListValue = null,
                phase2dh_group_numbers: ?[]Phase2DHGroupNumbersRequestListValue = null,
                ike_versions: ?[]IKEVersionsRequestListValue = null,
                startup_action: ?[]const u8 = null,
                log_options: ?VpnTunnelLogOptionsSpecification = null,
                enable_tunnel_lifecycle_control: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .tunnel_inside_cidr = "TunnelInsideCidr",
                        .tunnel_inside_ipv6_cidr = "TunnelInsideIpv6Cidr",
                        .pre_shared_key = "PreSharedKey",
                        .phase1_lifetime_seconds = "Phase1LifetimeSeconds",
                        .phase2_lifetime_seconds = "Phase2LifetimeSeconds",
                        .rekey_margin_time_seconds = "RekeyMarginTimeSeconds",
                        .rekey_fuzz_percentage = "RekeyFuzzPercentage",
                        .replay_window_size = "ReplayWindowSize",
                        .dpd_timeout_seconds = "DPDTimeoutSeconds",
                        .dpd_timeout_action = "DPDTimeoutAction",
                        .phase1_encryption_algorithms = "Phase1EncryptionAlgorithm",
                        .phase2_encryption_algorithms = "Phase2EncryptionAlgorithm",
                        .phase1_integrity_algorithms = "Phase1IntegrityAlgorithm",
                        .phase2_integrity_algorithms = "Phase2IntegrityAlgorithm",
                        .phase1dh_group_numbers = "Phase1DHGroupNumber",
                        .phase2dh_group_numbers = "Phase2DHGroupNumber",
                        .ike_versions = "IKEVersion",
                        .startup_action = "StartupAction",
                        .log_options = "LogOptions",
                        .enable_tunnel_lifecycle_control = "EnableTunnelLifecycleControl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            local_ipv4_network_cidr: ?[]const u8 = null,
            remote_ipv4_network_cidr: ?[]const u8 = null,
            local_ipv6_network_cidr: ?[]const u8 = null,
            remote_ipv6_network_cidr: ?[]const u8 = null,
            outside_ip_address_type: ?[]const u8 = null,
            transport_transit_gateway_attachment_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enable_acceleration = "EnableAcceleration",
                    .static_routes_only = "staticRoutesOnly",
                    .tunnel_inside_ip_version = "TunnelInsideIpVersion",
                    .tunnel_options = "TunnelOptions",
                    .local_ipv4_network_cidr = "LocalIpv4NetworkCidr",
                    .remote_ipv4_network_cidr = "RemoteIpv4NetworkCidr",
                    .local_ipv6_network_cidr = "LocalIpv6NetworkCidr",
                    .remote_ipv6_network_cidr = "RemoteIpv6NetworkCidr",
                    .outside_ip_address_type = "OutsideIpAddressType",
                    .transport_transit_gateway_attachment_id = "TransportTransitGatewayAttachmentId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_id = "CustomerGatewayId",
                .type = "Type",
                .vpn_gateway_id = "VpnGatewayId",
                .transit_gateway_id = "TransitGatewayId",
                .dry_run = "dryRun",
                .options = "options",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpn_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_vpn_connection };
        }
    },
    Response: type = struct {
        vpn_connection: ?VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection = "vpnConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_vpn_connection_route: struct {
    action_name: []const u8 = "CreateVpnConnectionRoute",
    Request: type = struct {
        destination_cidr_block: []const u8,
        vpn_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .vpn_connection_id = "VpnConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpn_connection_route) } {
            return .{ .service_metadata = service_metadata, .action = create_vpn_connection_route };
        }
    },
    Response: type = struct {},
} = .{};
pub const create_vpn_gateway: struct {
    action_name: []const u8 = "CreateVpnGateway",
    Request: type = struct {
        availability_zone: ?[]const u8 = null,
        type: []const u8,
        tag_specifications: ?[]TagSpecification = null,
        amazon_side_asn: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "AvailabilityZone",
                .type = "Type",
                .tag_specifications = "TagSpecification",
                .amazon_side_asn = "AmazonSideAsn",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpn_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_vpn_gateway };
        }
    },
    Response: type = struct {
        vpn_gateway: ?VpnGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_gateway = "vpnGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_carrier_gateway: struct {
    action_name: []const u8 = "DeleteCarrierGateway",
    Request: type = struct {
        carrier_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .carrier_gateway_id = "CarrierGatewayId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_carrier_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_carrier_gateway };
        }
    },
    Response: type = struct {
        carrier_gateway: ?CarrierGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .carrier_gateway = "carrierGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_client_vpn_endpoint: struct {
    action_name: []const u8 = "DeleteClientVpnEndpoint",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_client_vpn_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_client_vpn_endpoint };
        }
    },
    Response: type = struct {
        status: ?ClientVpnEndpointStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_client_vpn_route: struct {
    action_name: []const u8 = "DeleteClientVpnRoute",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        target_vpc_subnet_id: ?[]const u8 = null,
        destination_cidr_block: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .target_vpc_subnet_id = "TargetVpcSubnetId",
                .destination_cidr_block = "DestinationCidrBlock",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_client_vpn_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_client_vpn_route };
        }
    },
    Response: type = struct {
        status: ?ClientVpnRouteStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_coip_cidr: struct {
    action_name: []const u8 = "DeleteCoipCidr",
    Request: type = struct {
        cidr: []const u8,
        coip_pool_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .coip_pool_id = "CoipPoolId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_coip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = delete_coip_cidr };
        }
    },
    Response: type = struct {
        coip_cidr: ?CoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_cidr = "coipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_coip_pool: struct {
    action_name: []const u8 = "DeleteCoipPool",
    Request: type = struct {
        coip_pool_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_pool_id = "CoipPoolId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_coip_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_coip_pool };
        }
    },
    Response: type = struct {
        coip_pool: ?CoipPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_pool = "coipPool",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_customer_gateway: struct {
    action_name: []const u8 = "DeleteCustomerGateway",
    Request: type = struct {
        customer_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_id = "CustomerGatewayId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_customer_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_dhcp_options: struct {
    action_name: []const u8 = "DeleteDhcpOptions",
    Request: type = struct {
        dhcp_options_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_options_id = "DhcpOptionsId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dhcp_options) } {
            return .{ .service_metadata = service_metadata, .action = delete_dhcp_options };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_egress_only_internet_gateway: struct {
    action_name: []const u8 = "DeleteEgressOnlyInternetGateway",
    Request: type = struct {
        dry_run: ?bool = null,
        egress_only_internet_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .egress_only_internet_gateway_id = "EgressOnlyInternetGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_egress_only_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_egress_only_internet_gateway };
        }
    },
    Response: type = struct {
        return_code: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_code = "returnCode",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_fleets: struct {
    action_name: []const u8 = "DeleteFleets",
    Request: type = struct {
        dry_run: ?bool = null,
        fleet_ids: [][]const u8,
        terminate_instances: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fleet_ids = "FleetId",
                .terminate_instances = "TerminateInstances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleets) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleets };
        }
    },
    Response: type = struct {
        successful_fleet_deletions: ?[]struct {
            current_fleet_state: ?[]const u8 = null,
            previous_fleet_state: ?[]const u8 = null,
            fleet_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_fleet_state = "currentFleetState",
                    .previous_fleet_state = "previousFleetState",
                    .fleet_id = "fleetId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful_fleet_deletions: ?[]struct {
            @"error": ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fleet_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .@"error" = "error",
                    .fleet_id = "fleetId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_fleet_deletions = "successfulFleetDeletionSet",
                .unsuccessful_fleet_deletions = "unsuccessfulFleetDeletionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_flow_logs: struct {
    action_name: []const u8 = "DeleteFlowLogs",
    Request: type = struct {
        dry_run: ?bool = null,
        flow_log_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .flow_log_ids = "FlowLogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_flow_logs) } {
            return .{ .service_metadata = service_metadata, .action = delete_flow_logs };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_fpga_image: struct {
    action_name: []const u8 = "DeleteFpgaImage",
    Request: type = struct {
        dry_run: ?bool = null,
        fpga_image_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fpga_image_id = "FpgaImageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fpga_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_fpga_image };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_instance_connect_endpoint: struct {
    action_name: []const u8 = "DeleteInstanceConnectEndpoint",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_connect_endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_connect_endpoint_id = "InstanceConnectEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_connect_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_connect_endpoint };
        }
    },
    Response: type = struct {
        instance_connect_endpoint: ?Ec2InstanceConnectEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_connect_endpoint = "instanceConnectEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_instance_event_window: struct {
    action_name: []const u8 = "DeleteInstanceEventWindow",
    Request: type = struct {
        dry_run: ?bool = null,
        force_delete: ?bool = null,
        instance_event_window_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .force_delete = "ForceDelete",
                .instance_event_window_id = "InstanceEventWindowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_event_window) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_event_window };
        }
    },
    Response: type = struct {
        instance_event_window_state: ?struct {
            instance_event_window_id: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_event_window_id = "instanceEventWindowId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_window_state = "instanceEventWindowState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_internet_gateway: struct {
    action_name: []const u8 = "DeleteInternetGateway",
    Request: type = struct {
        dry_run: ?bool = null,
        internet_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .internet_gateway_id = "internetGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_internet_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_ipam: struct {
    action_name: []const u8 = "DeleteIpam",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        cascade: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .cascade = "Cascade",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ipam) } {
            return .{ .service_metadata = service_metadata, .action = delete_ipam };
        }
    },
    Response: type = struct {
        ipam: ?Ipam = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam = "ipam",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_ipam_pool: struct {
    action_name: []const u8 = "DeleteIpamPool",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        cascade: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .cascade = "Cascade",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ipam_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_ipam_pool };
        }
    },
    Response: type = struct {
        ipam_pool: ?IpamPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool = "ipamPool",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_ipam_resource_discovery: struct {
    action_name: []const u8 = "DeleteIpamResourceDiscovery",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ipam_resource_discovery) } {
            return .{ .service_metadata = service_metadata, .action = delete_ipam_resource_discovery };
        }
    },
    Response: type = struct {
        ipam_resource_discovery: ?IpamResourceDiscovery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery = "ipamResourceDiscovery",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_ipam_scope: struct {
    action_name: []const u8 = "DeleteIpamScope",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_scope_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_scope_id = "IpamScopeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ipam_scope) } {
            return .{ .service_metadata = service_metadata, .action = delete_ipam_scope };
        }
    },
    Response: type = struct {
        ipam_scope: ?IpamScope = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_scope = "ipamScope",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_key_pair: struct {
    action_name: []const u8 = "DeleteKeyPair",
    Request: type = struct {
        key_name: ?[]const u8 = null,
        key_pair_id: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_name = "KeyName",
                .key_pair_id = "KeyPairId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = delete_key_pair };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        key_pair_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .key_pair_id = "keyPairId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_launch_template: struct {
    action_name: []const u8 = "DeleteLaunchTemplate",
    Request: type = struct {
        dry_run: ?bool = null,
        launch_template_id: ?[]const u8 = null,
        launch_template_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .launch_template_id = "LaunchTemplateId",
                .launch_template_name = "LaunchTemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_launch_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_launch_template };
        }
    },
    Response: type = struct {
        launch_template: ?LaunchTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template = "launchTemplate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_launch_template_versions: struct {
    action_name: []const u8 = "DeleteLaunchTemplateVersions",
    Request: type = struct {
        dry_run: ?bool = null,
        launch_template_id: ?[]const u8 = null,
        launch_template_name: ?[]const u8 = null,
        versions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .launch_template_id = "LaunchTemplateId",
                .launch_template_name = "LaunchTemplateName",
                .versions = "LaunchTemplateVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_launch_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = delete_launch_template_versions };
        }
    },
    Response: type = struct {
        successfully_deleted_launch_template_versions: ?[]struct {
            launch_template_id: ?[]const u8 = null,
            launch_template_name: ?[]const u8 = null,
            version_number: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_id = "launchTemplateId",
                    .launch_template_name = "launchTemplateName",
                    .version_number = "versionNumber",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessfully_deleted_launch_template_versions: ?[]struct {
            launch_template_id: ?[]const u8 = null,
            launch_template_name: ?[]const u8 = null,
            version_number: ?i64 = null,
            response_error: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_id = "launchTemplateId",
                    .launch_template_name = "launchTemplateName",
                    .version_number = "versionNumber",
                    .response_error = "responseError",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successfully_deleted_launch_template_versions = "successfullyDeletedLaunchTemplateVersionSet",
                .unsuccessfully_deleted_launch_template_versions = "unsuccessfullyDeletedLaunchTemplateVersionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_local_gateway_route: struct {
    action_name: []const u8 = "DeleteLocalGatewayRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        local_gateway_route_table_id: []const u8,
        dry_run: ?bool = null,
        destination_prefix_list_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .dry_run = "DryRun",
                .destination_prefix_list_id = "DestinationPrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_local_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_local_gateway_route };
        }
    },
    Response: type = struct {
        route: ?LocalGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_local_gateway_route_table: struct {
    action_name: []const u8 = "DeleteLocalGatewayRouteTable",
    Request: type = struct {
        local_gateway_route_table_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_local_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_local_gateway_route_table };
        }
    },
    Response: type = struct {
        local_gateway_route_table: ?LocalGatewayRouteTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table = "localGatewayRouteTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_local_gateway_route_table_virtual_interface_group_association: struct {
    action_name: []const u8 = "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation",
    Request: type = struct {
        local_gateway_route_table_virtual_interface_group_association_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_virtual_interface_group_association_id = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_local_gateway_route_table_virtual_interface_group_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_local_gateway_route_table_virtual_interface_group_association };
        }
    },
    Response: type = struct {
        local_gateway_route_table_virtual_interface_group_association: ?LocalGatewayRouteTableVirtualInterfaceGroupAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_virtual_interface_group_association = "localGatewayRouteTableVirtualInterfaceGroupAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_local_gateway_route_table_vpc_association: struct {
    action_name: []const u8 = "DeleteLocalGatewayRouteTableVpcAssociation",
    Request: type = struct {
        local_gateway_route_table_vpc_association_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_vpc_association_id = "LocalGatewayRouteTableVpcAssociationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_local_gateway_route_table_vpc_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_local_gateway_route_table_vpc_association };
        }
    },
    Response: type = struct {
        local_gateway_route_table_vpc_association: ?LocalGatewayRouteTableVpcAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_vpc_association = "localGatewayRouteTableVpcAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_managed_prefix_list: struct {
    action_name: []const u8 = "DeleteManagedPrefixList",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_id = "PrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_managed_prefix_list) } {
            return .{ .service_metadata = service_metadata, .action = delete_managed_prefix_list };
        }
    },
    Response: type = struct {
        prefix_list: ?ManagedPrefixList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prefix_list = "prefixList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_nat_gateway: struct {
    action_name: []const u8 = "DeleteNatGateway",
    Request: type = struct {
        dry_run: ?bool = null,
        nat_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .nat_gateway_id = "NatGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_nat_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_nat_gateway };
        }
    },
    Response: type = struct {
        nat_gateway_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "natGatewayId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_network_acl: struct {
    action_name: []const u8 = "DeleteNetworkAcl",
    Request: type = struct {
        dry_run: ?bool = null,
        network_acl_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .network_acl_id = "networkAclId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_acl) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_acl };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_network_acl_entry: struct {
    action_name: []const u8 = "DeleteNetworkAclEntry",
    Request: type = struct {
        dry_run: ?bool = null,
        egress: bool,
        network_acl_id: []const u8,
        rule_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .egress = "egress",
                .network_acl_id = "networkAclId",
                .rule_number = "ruleNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_acl_entry) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_acl_entry };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_network_insights_access_scope: struct {
    action_name: []const u8 = "DeleteNetworkInsightsAccessScope",
    Request: type = struct {
        dry_run: ?bool = null,
        network_insights_access_scope_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .network_insights_access_scope_id = "NetworkInsightsAccessScopeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_insights_access_scope) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_insights_access_scope };
        }
    },
    Response: type = struct {
        network_insights_access_scope_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_id = "networkInsightsAccessScopeId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_network_insights_access_scope_analysis: struct {
    action_name: []const u8 = "DeleteNetworkInsightsAccessScopeAnalysis",
    Request: type = struct {
        network_insights_access_scope_analysis_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis_id = "NetworkInsightsAccessScopeAnalysisId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_insights_access_scope_analysis) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_insights_access_scope_analysis };
        }
    },
    Response: type = struct {
        network_insights_access_scope_analysis_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis_id = "networkInsightsAccessScopeAnalysisId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_network_insights_analysis: struct {
    action_name: []const u8 = "DeleteNetworkInsightsAnalysis",
    Request: type = struct {
        dry_run: ?bool = null,
        network_insights_analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .network_insights_analysis_id = "NetworkInsightsAnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_insights_analysis) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_insights_analysis };
        }
    },
    Response: type = struct {
        network_insights_analysis_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_analysis_id = "networkInsightsAnalysisId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_network_insights_path: struct {
    action_name: []const u8 = "DeleteNetworkInsightsPath",
    Request: type = struct {
        dry_run: ?bool = null,
        network_insights_path_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .network_insights_path_id = "NetworkInsightsPathId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_insights_path) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_insights_path };
        }
    },
    Response: type = struct {
        network_insights_path_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_path_id = "networkInsightsPathId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_network_interface: struct {
    action_name: []const u8 = "DeleteNetworkInterface",
    Request: type = struct {
        dry_run: ?bool = null,
        network_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .network_interface_id = "networkInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_interface) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_interface };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_network_interface_permission: struct {
    action_name: []const u8 = "DeleteNetworkInterfacePermission",
    Request: type = struct {
        network_interface_permission_id: []const u8,
        force: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_permission_id = "NetworkInterfacePermissionId",
                .force = "Force",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_interface_permission) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_interface_permission };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_placement_group: struct {
    action_name: []const u8 = "DeletePlacementGroup",
    Request: type = struct {
        dry_run: ?bool = null,
        group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .group_name = "groupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_placement_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_placement_group };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_public_ipv4_pool: struct {
    action_name: []const u8 = "DeletePublicIpv4Pool",
    Request: type = struct {
        dry_run: ?bool = null,
        pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .pool_id = "PoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_public_ipv4_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_public_ipv4_pool };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "returnValue",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_queued_reserved_instances: struct {
    action_name: []const u8 = "DeleteQueuedReservedInstances",
    Request: type = struct {
        dry_run: ?bool = null,
        reserved_instances_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .reserved_instances_ids = "ReservedInstancesId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queued_reserved_instances) } {
            return .{ .service_metadata = service_metadata, .action = delete_queued_reserved_instances };
        }
    },
    Response: type = struct {
        successful_queued_purchase_deletions: ?[]struct {
            reserved_instances_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_instances_id = "reservedInstancesId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed_queued_purchase_deletions: ?[]struct {
            @"error": ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            reserved_instances_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .@"error" = "error",
                    .reserved_instances_id = "reservedInstancesId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_queued_purchase_deletions = "successfulQueuedPurchaseDeletionSet",
                .failed_queued_purchase_deletions = "failedQueuedPurchaseDeletionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_route: struct {
    action_name: []const u8 = "DeleteRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        destination_ipv6_cidr_block: ?[]const u8 = null,
        destination_prefix_list_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        route_table_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "destinationCidrBlock",
                .destination_ipv6_cidr_block = "destinationIpv6CidrBlock",
                .destination_prefix_list_id = "DestinationPrefixListId",
                .dry_run = "dryRun",
                .route_table_id = "routeTableId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_route };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_route_table: struct {
    action_name: []const u8 = "DeleteRouteTable",
    Request: type = struct {
        dry_run: ?bool = null,
        route_table_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .route_table_id = "routeTableId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_route_table };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_security_group: struct {
    action_name: []const u8 = "DeleteSecurityGroup",
    Request: type = struct {
        group_id: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .group_name = "GroupName",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_group };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_snapshot: struct {
    action_name: []const u8 = "DeleteSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_spot_datafeed_subscription: struct {
    action_name: []const u8 = "DeleteSpotDatafeedSubscription",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_spot_datafeed_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_spot_datafeed_subscription };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_subnet: struct {
    action_name: []const u8 = "DeleteSubnet",
    Request: type = struct {
        subnet_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_id = "SubnetId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subnet) } {
            return .{ .service_metadata = service_metadata, .action = delete_subnet };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_subnet_cidr_reservation: struct {
    action_name: []const u8 = "DeleteSubnetCidrReservation",
    Request: type = struct {
        subnet_cidr_reservation_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_cidr_reservation_id = "SubnetCidrReservationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subnet_cidr_reservation) } {
            return .{ .service_metadata = service_metadata, .action = delete_subnet_cidr_reservation };
        }
    },
    Response: type = struct {
        deleted_subnet_cidr_reservation: ?SubnetCidrReservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_subnet_cidr_reservation = "deletedSubnetCidrReservation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        dry_run: ?bool = null,
        resources: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .resources = "resourceId",
                .tags = "tag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_traffic_mirror_filter: struct {
    action_name: []const u8 = "DeleteTrafficMirrorFilter",
    Request: type = struct {
        traffic_mirror_filter_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_id = "TrafficMirrorFilterId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_mirror_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_mirror_filter };
        }
    },
    Response: type = struct {
        traffic_mirror_filter_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_id = "trafficMirrorFilterId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_traffic_mirror_filter_rule: struct {
    action_name: []const u8 = "DeleteTrafficMirrorFilterRule",
    Request: type = struct {
        traffic_mirror_filter_rule_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_rule_id = "TrafficMirrorFilterRuleId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_mirror_filter_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_mirror_filter_rule };
        }
    },
    Response: type = struct {
        traffic_mirror_filter_rule_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_rule_id = "trafficMirrorFilterRuleId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_traffic_mirror_session: struct {
    action_name: []const u8 = "DeleteTrafficMirrorSession",
    Request: type = struct {
        traffic_mirror_session_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session_id = "TrafficMirrorSessionId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_mirror_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_mirror_session };
        }
    },
    Response: type = struct {
        traffic_mirror_session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session_id = "trafficMirrorSessionId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_traffic_mirror_target: struct {
    action_name: []const u8 = "DeleteTrafficMirrorTarget",
    Request: type = struct {
        traffic_mirror_target_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_target_id = "TrafficMirrorTargetId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_mirror_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_mirror_target };
        }
    },
    Response: type = struct {
        traffic_mirror_target_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_target_id = "trafficMirrorTargetId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway: struct {
    action_name: []const u8 = "DeleteTransitGateway",
    Request: type = struct {
        transit_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway: ?TransitGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway = "transitGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_connect: struct {
    action_name: []const u8 = "DeleteTransitGatewayConnect",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_connect) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_connect };
        }
    },
    Response: type = struct {
        transit_gateway_connect: ?TransitGatewayConnect = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect = "transitGatewayConnect",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_connect_peer: struct {
    action_name: []const u8 = "DeleteTransitGatewayConnectPeer",
    Request: type = struct {
        transit_gateway_connect_peer_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_id = "TransitGatewayConnectPeerId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer: ?TransitGatewayConnectPeer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer = "transitGatewayConnectPeer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_multicast_domain: struct {
    action_name: []const u8 = "DeleteTransitGatewayMulticastDomain",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_multicast_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_multicast_domain };
        }
    },
    Response: type = struct {
        transit_gateway_multicast_domain: ?TransitGatewayMulticastDomain = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain = "transitGatewayMulticastDomain",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_peering_attachment: struct {
    action_name: []const u8 = "DeleteTransitGatewayPeeringAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_peering_attachment) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_peering_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_peering_attachment: ?TransitGatewayPeeringAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering_attachment = "transitGatewayPeeringAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_policy_table: struct {
    action_name: []const u8 = "DeleteTransitGatewayPolicyTable",
    Request: type = struct {
        transit_gateway_policy_table_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_id = "TransitGatewayPolicyTableId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_policy_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_policy_table };
        }
    },
    Response: type = struct {
        transit_gateway_policy_table: ?TransitGatewayPolicyTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table = "transitGatewayPolicyTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_prefix_list_reference: struct {
    action_name: []const u8 = "DeleteTransitGatewayPrefixListReference",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        prefix_list_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .prefix_list_id = "PrefixListId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_prefix_list_reference) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_prefix_list_reference };
        }
    },
    Response: type = struct {
        transit_gateway_prefix_list_reference: ?TransitGatewayPrefixListReference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_prefix_list_reference = "transitGatewayPrefixListReference",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_route: struct {
    action_name: []const u8 = "DeleteTransitGatewayRoute",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        destination_cidr_block: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .destination_cidr_block = "DestinationCidrBlock",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_route };
        }
    },
    Response: type = struct {
        route: ?TransitGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_route_table: struct {
    action_name: []const u8 = "DeleteTransitGatewayRouteTable",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_route_table };
        }
    },
    Response: type = struct {
        transit_gateway_route_table: ?TransitGatewayRouteTable = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table = "transitGatewayRouteTable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_route_table_announcement: struct {
    action_name: []const u8 = "DeleteTransitGatewayRouteTableAnnouncement",
    Request: type = struct {
        transit_gateway_route_table_announcement_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_announcement_id = "TransitGatewayRouteTableAnnouncementId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_route_table_announcement) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_route_table_announcement };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_announcement: ?TransitGatewayRouteTableAnnouncement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_announcement = "transitGatewayRouteTableAnnouncement",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_transit_gateway_vpc_attachment: struct {
    action_name: []const u8 = "DeleteTransitGatewayVpcAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transit_gateway_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = delete_transit_gateway_vpc_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachment: ?TransitGatewayVpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachment = "transitGatewayVpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_verified_access_endpoint: struct {
    action_name: []const u8 = "DeleteVerifiedAccessEndpoint",
    Request: type = struct {
        verified_access_endpoint_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint_id = "VerifiedAccessEndpointId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_access_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_access_endpoint };
        }
    },
    Response: type = struct {
        verified_access_endpoint: ?VerifiedAccessEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint = "verifiedAccessEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_verified_access_group: struct {
    action_name: []const u8 = "DeleteVerifiedAccessGroup",
    Request: type = struct {
        verified_access_group_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_id = "VerifiedAccessGroupId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_access_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_access_group };
        }
    },
    Response: type = struct {
        verified_access_group: ?VerifiedAccessGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group = "verifiedAccessGroup",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_verified_access_instance: struct {
    action_name: []const u8 = "DeleteVerifiedAccessInstance",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_access_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_access_instance };
        }
    },
    Response: type = struct {
        verified_access_instance: ?VerifiedAccessInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance = "verifiedAccessInstance",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_verified_access_trust_provider: struct {
    action_name: []const u8 = "DeleteVerifiedAccessTrustProvider",
    Request: type = struct {
        verified_access_trust_provider_id: []const u8,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider_id = "VerifiedAccessTrustProviderId",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_access_trust_provider) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_access_trust_provider };
        }
    },
    Response: type = struct {
        verified_access_trust_provider: ?VerifiedAccessTrustProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider = "verifiedAccessTrustProvider",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_volume: struct {
    action_name: []const u8 = "DeleteVolume",
    Request: type = struct {
        volume_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_id = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_volume) } {
            return .{ .service_metadata = service_metadata, .action = delete_volume };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_vpc: struct {
    action_name: []const u8 = "DeleteVpc",
    Request: type = struct {
        vpc_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_vpc_endpoint_connection_notifications: struct {
    action_name: []const u8 = "DeleteVpcEndpointConnectionNotifications",
    Request: type = struct {
        dry_run: ?bool = null,
        connection_notification_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .connection_notification_ids = "ConnectionNotificationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_endpoint_connection_notifications) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_endpoint_connection_notifications };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_vpc_endpoints: struct {
    action_name: []const u8 = "DeleteVpcEndpoints",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_endpoint_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .vpc_endpoint_ids = "VpcEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_endpoints };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_vpc_endpoint_service_configurations: struct {
    action_name: []const u8 = "DeleteVpcEndpointServiceConfigurations",
    Request: type = struct {
        dry_run: ?bool = null,
        service_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_ids = "ServiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_endpoint_service_configurations) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_endpoint_service_configurations };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_vpc_peering_connection: struct {
    action_name: []const u8 = "DeleteVpcPeeringConnection",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_peering_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_peering_connection_id = "vpcPeeringConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_peering_connection };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_vpn_connection: struct {
    action_name: []const u8 = "DeleteVpnConnection",
    Request: type = struct {
        vpn_connection_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpn_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpn_connection };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_vpn_connection_route: struct {
    action_name: []const u8 = "DeleteVpnConnectionRoute",
    Request: type = struct {
        destination_cidr_block: []const u8,
        vpn_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .vpn_connection_id = "VpnConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpn_connection_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpn_connection_route };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_vpn_gateway: struct {
    action_name: []const u8 = "DeleteVpnGateway",
    Request: type = struct {
        vpn_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_gateway_id = "VpnGatewayId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpn_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpn_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const deprovision_byoip_cidr: struct {
    action_name: []const u8 = "DeprovisionByoipCidr",
    Request: type = struct {
        cidr: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprovision_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = deprovision_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "byoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deprovision_ipam_byoasn: struct {
    action_name: []const u8 = "DeprovisionIpamByoasn",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        asn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .asn = "Asn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprovision_ipam_byoasn) } {
            return .{ .service_metadata = service_metadata, .action = deprovision_ipam_byoasn };
        }
    },
    Response: type = struct {
        byoasn: ?Byoasn = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoasn = "byoasn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deprovision_ipam_pool_cidr: struct {
    action_name: []const u8 = "DeprovisionIpamPoolCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        cidr: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprovision_ipam_pool_cidr) } {
            return .{ .service_metadata = service_metadata, .action = deprovision_ipam_pool_cidr };
        }
    },
    Response: type = struct {
        ipam_pool_cidr: ?IpamPoolCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool_cidr = "ipamPoolCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deprovision_public_ipv4_pool_cidr: struct {
    action_name: []const u8 = "DeprovisionPublicIpv4PoolCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        pool_id: []const u8,
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .pool_id = "PoolId",
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprovision_public_ipv4_pool_cidr) } {
            return .{ .service_metadata = service_metadata, .action = deprovision_public_ipv4_pool_cidr };
        }
    },
    Response: type = struct {
        pool_id: ?[]const u8 = null,
        deprovisioned_addresses: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "poolId",
                .deprovisioned_addresses = "deprovisionedAddressSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deregister_image: struct {
    action_name: []const u8 = "DeregisterImage",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_image) } {
            return .{ .service_metadata = service_metadata, .action = deregister_image };
        }
    },
    Response: type = struct {},
} = .{};
pub const deregister_instance_event_notification_attributes: struct {
    action_name: []const u8 = "DeregisterInstanceEventNotificationAttributes",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_tag_attribute: struct {
            include_all_tags_of_instance: ?bool = null,
            instance_tag_keys: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .include_all_tags_of_instance = "IncludeAllTagsOfInstance",
                    .instance_tag_keys = "InstanceTagKey",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_tag_attribute = "InstanceTagAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_instance_event_notification_attributes) } {
            return .{ .service_metadata = service_metadata, .action = deregister_instance_event_notification_attributes };
        }
    },
    Response: type = struct {
        instance_tag_attribute: ?InstanceTagNotificationAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_tag_attribute = "instanceTagAttribute",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deregister_transit_gateway_multicast_group_members: struct {
    action_name: []const u8 = "DeregisterTransitGatewayMulticastGroupMembers",
    Request: type = struct {
        transit_gateway_multicast_domain_id: ?[]const u8 = null,
        group_ip_address: ?[]const u8 = null,
        network_interface_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .group_ip_address = "GroupIpAddress",
                .network_interface_ids = "NetworkInterfaceIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_transit_gateway_multicast_group_members) } {
            return .{ .service_metadata = service_metadata, .action = deregister_transit_gateway_multicast_group_members };
        }
    },
    Response: type = struct {
        deregistered_multicast_group_members: ?struct {
            transit_gateway_multicast_domain_id: ?[]const u8 = null,
            deregistered_network_interface_ids: ?[][]const u8 = null,
            group_ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
                    .deregistered_network_interface_ids = "deregisteredNetworkInterfaceIds",
                    .group_ip_address = "groupIpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deregistered_multicast_group_members = "deregisteredMulticastGroupMembers",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const deregister_transit_gateway_multicast_group_sources: struct {
    action_name: []const u8 = "DeregisterTransitGatewayMulticastGroupSources",
    Request: type = struct {
        transit_gateway_multicast_domain_id: ?[]const u8 = null,
        group_ip_address: ?[]const u8 = null,
        network_interface_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .group_ip_address = "GroupIpAddress",
                .network_interface_ids = "NetworkInterfaceIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_transit_gateway_multicast_group_sources) } {
            return .{ .service_metadata = service_metadata, .action = deregister_transit_gateway_multicast_group_sources };
        }
    },
    Response: type = struct {
        deregistered_multicast_group_sources: ?struct {
            transit_gateway_multicast_domain_id: ?[]const u8 = null,
            deregistered_network_interface_ids: ?[][]const u8 = null,
            group_ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
                    .deregistered_network_interface_ids = "deregisteredNetworkInterfaceIds",
                    .group_ip_address = "groupIpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deregistered_multicast_group_sources = "deregisteredMulticastGroupSources",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {
        attribute_names: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_names = "attributeName",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_attributes: ?[]struct {
            attribute_name: ?[]const u8 = null,
            attribute_values: ?[]struct {
                attribute_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attribute_value = "attributeValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .attribute_values = "attributeValueSet",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_attributes = "accountAttributeSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_addresses: struct {
    action_name: []const u8 = "DescribeAddresses",
    Request: type = struct {
        filters: ?[]Filter = null,
        public_ips: ?[][]const u8 = null,
        allocation_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .public_ips = "PublicIp",
                .allocation_ids = "AllocationId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addresses) } {
            return .{ .service_metadata = service_metadata, .action = describe_addresses };
        }
    },
    Response: type = struct {
        addresses: ?[]struct {
            instance_id: ?[]const u8 = null,
            public_ip: ?[]const u8 = null,
            allocation_id: ?[]const u8 = null,
            association_id: ?[]const u8 = null,
            domain: ?[]const u8 = null,
            network_interface_id: ?[]const u8 = null,
            network_interface_owner_id: ?[]const u8 = null,
            private_ip_address: ?[]const u8 = null,
            tags: ?[]Tag = null,
            public_ipv4_pool: ?[]const u8 = null,
            network_border_group: ?[]const u8 = null,
            customer_owned_ip: ?[]const u8 = null,
            customer_owned_ipv4_pool: ?[]const u8 = null,
            carrier_ip: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "instanceId",
                    .public_ip = "publicIp",
                    .allocation_id = "allocationId",
                    .association_id = "associationId",
                    .domain = "domain",
                    .network_interface_id = "networkInterfaceId",
                    .network_interface_owner_id = "networkInterfaceOwnerId",
                    .private_ip_address = "privateIpAddress",
                    .tags = "tagSet",
                    .public_ipv4_pool = "publicIpv4Pool",
                    .network_border_group = "networkBorderGroup",
                    .customer_owned_ip = "customerOwnedIp",
                    .customer_owned_ipv4_pool = "customerOwnedIpv4Pool",
                    .carrier_ip = "carrierIp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addresses = "addressesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_addresses_attribute: struct {
    action_name: []const u8 = "DescribeAddressesAttribute",
    Request: type = struct {
        allocation_ids: ?[][]const u8 = null,
        attribute: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_ids = "AllocationId",
                .attribute = "Attribute",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addresses_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_addresses_attribute };
        }
    },
    Response: type = struct {
        addresses: ?[]AddressAttribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addresses = "addressSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_address_transfers: struct {
    action_name: []const u8 = "DescribeAddressTransfers",
    Request: type = struct {
        allocation_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_ids = "AllocationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_address_transfers) } {
            return .{ .service_metadata = service_metadata, .action = describe_address_transfers };
        }
    },
    Response: type = struct {
        address_transfers: ?[]AddressTransfer = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_transfers = "addressTransferSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_aggregate_id_format: struct {
    action_name: []const u8 = "DescribeAggregateIdFormat",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_aggregate_id_format) } {
            return .{ .service_metadata = service_metadata, .action = describe_aggregate_id_format };
        }
    },
    Response: type = struct {
        use_long_ids_aggregated: ?bool = null,
        statuses: ?[]IdFormat = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .use_long_ids_aggregated = "useLongIdsAggregated",
                .statuses = "statusSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_availability_zones: struct {
    action_name: []const u8 = "DescribeAvailabilityZones",
    Request: type = struct {
        filters: ?[]Filter = null,
        zone_names: ?[][]const u8 = null,
        zone_ids: ?[][]const u8 = null,
        all_availability_zones: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .zone_names = "ZoneName",
                .zone_ids = "ZoneId",
                .all_availability_zones = "AllAvailabilityZones",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_availability_zones) } {
            return .{ .service_metadata = service_metadata, .action = describe_availability_zones };
        }
    },
    Response: type = struct {
        availability_zones: ?[]struct {
            state: ?[]const u8 = null,
            opt_in_status: ?[]const u8 = null,
            messages: ?[]struct {
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            region_name: ?[]const u8 = null,
            zone_name: ?[]const u8 = null,
            zone_id: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            network_border_group: ?[]const u8 = null,
            zone_type: ?[]const u8 = null,
            parent_zone_name: ?[]const u8 = null,
            parent_zone_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .state = "zoneState",
                    .opt_in_status = "optInStatus",
                    .messages = "messageSet",
                    .region_name = "regionName",
                    .zone_name = "zoneName",
                    .zone_id = "zoneId",
                    .group_name = "groupName",
                    .network_border_group = "networkBorderGroup",
                    .zone_type = "zoneType",
                    .parent_zone_name = "parentZoneName",
                    .parent_zone_id = "parentZoneId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "availabilityZoneInfo",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_aws_network_performance_metric_subscriptions: struct {
    action_name: []const u8 = "DescribeAwsNetworkPerformanceMetricSubscriptions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_aws_network_performance_metric_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_aws_network_performance_metric_subscriptions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        subscriptions: ?[]struct {
            source: ?[]const u8 = null,
            destination: ?[]const u8 = null,
            metric: ?[]const u8 = null,
            statistic: ?[]const u8 = null,
            period: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .destination = "destination",
                    .metric = "metric",
                    .statistic = "statistic",
                    .period = "period",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .subscriptions = "subscriptionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_bundle_tasks: struct {
    action_name: []const u8 = "DescribeBundleTasks",
    Request: type = struct {
        bundle_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_ids = "BundleId",
                .filters = "Filter",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bundle_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_bundle_tasks };
        }
    },
    Response: type = struct {
        bundle_tasks: ?[]BundleTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_tasks = "bundleInstanceTasksSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_byoip_cidrs: struct {
    action_name: []const u8 = "DescribeByoipCidrs",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_byoip_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = describe_byoip_cidrs };
        }
    },
    Response: type = struct {
        byoip_cidrs: ?[]ByoipCidr = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidrs = "byoipCidrSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_capacity_block_offerings: struct {
    action_name: []const u8 = "DescribeCapacityBlockOfferings",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_type: []const u8,
        instance_count: i64,
        start_date_range: ?i64 = null,
        end_date_range: ?i64 = null,
        capacity_duration_hours: i64,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_type = "InstanceType",
                .instance_count = "InstanceCount",
                .start_date_range = "StartDateRange",
                .end_date_range = "EndDateRange",
                .capacity_duration_hours = "CapacityDurationHours",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_capacity_block_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_capacity_block_offerings };
        }
    },
    Response: type = struct {
        capacity_block_offerings: ?[]struct {
            capacity_block_offering_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            instance_count: ?i64 = null,
            start_date: ?i64 = null,
            end_date: ?i64 = null,
            capacity_block_duration_hours: ?i64 = null,
            upfront_fee: ?[]const u8 = null,
            currency_code: ?[]const u8 = null,
            tenancy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity_block_offering_id = "capacityBlockOfferingId",
                    .instance_type = "instanceType",
                    .availability_zone = "availabilityZone",
                    .instance_count = "instanceCount",
                    .start_date = "startDate",
                    .end_date = "endDate",
                    .capacity_block_duration_hours = "capacityBlockDurationHours",
                    .upfront_fee = "upfrontFee",
                    .currency_code = "currencyCode",
                    .tenancy = "tenancy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_block_offerings = "capacityBlockOfferingSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_capacity_reservation_fleets: struct {
    action_name: []const u8 = "DescribeCapacityReservationFleets",
    Request: type = struct {
        capacity_reservation_fleet_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_fleet_ids = "CapacityReservationFleetId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_capacity_reservation_fleets) } {
            return .{ .service_metadata = service_metadata, .action = describe_capacity_reservation_fleets };
        }
    },
    Response: type = struct {
        capacity_reservation_fleets: ?[]struct {
            capacity_reservation_fleet_id: ?[]const u8 = null,
            capacity_reservation_fleet_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            total_target_capacity: ?i64 = null,
            total_fulfilled_capacity: ?f64 = null,
            tenancy: ?[]const u8 = null,
            end_date: ?i64 = null,
            create_time: ?i64 = null,
            instance_match_criteria: ?[]const u8 = null,
            allocation_strategy: ?[]const u8 = null,
            instance_type_specifications: ?[]FleetCapacityReservation = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .capacity_reservation_fleet_id = "capacityReservationFleetId",
                    .capacity_reservation_fleet_arn = "capacityReservationFleetArn",
                    .state = "state",
                    .total_target_capacity = "totalTargetCapacity",
                    .total_fulfilled_capacity = "totalFulfilledCapacity",
                    .tenancy = "tenancy",
                    .end_date = "endDate",
                    .create_time = "createTime",
                    .instance_match_criteria = "instanceMatchCriteria",
                    .allocation_strategy = "allocationStrategy",
                    .instance_type_specifications = "instanceTypeSpecificationSet",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_fleets = "capacityReservationFleetSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_capacity_reservations: struct {
    action_name: []const u8 = "DescribeCapacityReservations",
    Request: type = struct {
        capacity_reservation_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_ids = "CapacityReservationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_capacity_reservations) } {
            return .{ .service_metadata = service_metadata, .action = describe_capacity_reservations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        capacity_reservations: ?[]CapacityReservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .capacity_reservations = "capacityReservationSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_carrier_gateways: struct {
    action_name: []const u8 = "DescribeCarrierGateways",
    Request: type = struct {
        carrier_gateway_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .carrier_gateway_ids = "CarrierGatewayId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_carrier_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_carrier_gateways };
        }
    },
    Response: type = struct {
        carrier_gateways: ?[]CarrierGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .carrier_gateways = "carrierGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_classic_link_instances: struct {
    action_name: []const u8 = "DescribeClassicLinkInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        instance_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .instance_ids = "InstanceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_classic_link_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_classic_link_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            groups: ?[]GroupIdentifier = null,
            instance_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .groups = "groupSet",
                    .instance_id = "instanceId",
                    .tags = "tagSet",
                    .vpc_id = "vpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "instancesSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_client_vpn_authorization_rules: struct {
    action_name: []const u8 = "DescribeClientVpnAuthorizationRules",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .dry_run = "DryRun",
                .next_token = "NextToken",
                .filters = "Filter",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_vpn_authorization_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_vpn_authorization_rules };
        }
    },
    Response: type = struct {
        authorization_rules: ?[]struct {
            client_vpn_endpoint_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            group_id: ?[]const u8 = null,
            access_all: ?bool = null,
            destination_cidr: ?[]const u8 = null,
            status: ?ClientVpnAuthorizationRuleStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_vpn_endpoint_id = "clientVpnEndpointId",
                    .description = "description",
                    .group_id = "groupId",
                    .access_all = "accessAll",
                    .destination_cidr = "destinationCidr",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization_rules = "authorizationRule",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_client_vpn_connections: struct {
    action_name: []const u8 = "DescribeClientVpnConnections",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_vpn_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_vpn_connections };
        }
    },
    Response: type = struct {
        connections: ?[]struct {
            client_vpn_endpoint_id: ?[]const u8 = null,
            timestamp: ?[]const u8 = null,
            connection_id: ?[]const u8 = null,
            username: ?[]const u8 = null,
            connection_established_time: ?[]const u8 = null,
            ingress_bytes: ?[]const u8 = null,
            egress_bytes: ?[]const u8 = null,
            ingress_packets: ?[]const u8 = null,
            egress_packets: ?[]const u8 = null,
            client_ip: ?[]const u8 = null,
            common_name: ?[]const u8 = null,
            status: ?ClientVpnConnectionStatus = null,
            connection_end_time: ?[]const u8 = null,
            posture_compliance_statuses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_vpn_endpoint_id = "clientVpnEndpointId",
                    .timestamp = "timestamp",
                    .connection_id = "connectionId",
                    .username = "username",
                    .connection_established_time = "connectionEstablishedTime",
                    .ingress_bytes = "ingressBytes",
                    .egress_bytes = "egressBytes",
                    .ingress_packets = "ingressPackets",
                    .egress_packets = "egressPackets",
                    .client_ip = "clientIp",
                    .common_name = "commonName",
                    .status = "status",
                    .connection_end_time = "connectionEndTime",
                    .posture_compliance_statuses = "postureComplianceStatusSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "connections",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_client_vpn_endpoints: struct {
    action_name: []const u8 = "DescribeClientVpnEndpoints",
    Request: type = struct {
        client_vpn_endpoint_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_ids = "ClientVpnEndpointId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_vpn_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_vpn_endpoints };
        }
    },
    Response: type = struct {
        client_vpn_endpoints: ?[]struct {
            client_vpn_endpoint_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?ClientVpnEndpointStatus = null,
            creation_time: ?[]const u8 = null,
            deletion_time: ?[]const u8 = null,
            dns_name: ?[]const u8 = null,
            client_cidr_block: ?[]const u8 = null,
            dns_servers: ?[][]const u8 = null,
            split_tunnel: ?bool = null,
            vpn_protocol: ?[]const u8 = null,
            transport_protocol: ?[]const u8 = null,
            vpn_port: ?i64 = null,
            associated_target_networks: ?[]struct {
                network_id: ?[]const u8 = null,
                network_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .network_id = "networkId",
                        .network_type = "networkType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            server_certificate_arn: ?[]const u8 = null,
            authentication_options: ?[]struct {
                type: ?[]const u8 = null,
                active_directory: ?struct {
                    directory_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .directory_id = "directoryId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                mutual_authentication: ?struct {
                    client_root_certificate_chain: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .client_root_certificate_chain = "clientRootCertificateChain",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                federated_authentication: ?struct {
                    saml_provider_arn: ?[]const u8 = null,
                    self_service_saml_provider_arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .saml_provider_arn = "samlProviderArn",
                            .self_service_saml_provider_arn = "selfServiceSamlProviderArn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .active_directory = "activeDirectory",
                        .mutual_authentication = "mutualAuthentication",
                        .federated_authentication = "federatedAuthentication",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            connection_log_options: ?struct {
                enabled: ?bool = null,
                cloudwatch_log_group: ?[]const u8 = null,
                cloudwatch_log_stream: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "Enabled",
                        .cloudwatch_log_group = "CloudwatchLogGroup",
                        .cloudwatch_log_stream = "CloudwatchLogStream",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,
            security_group_ids: ?[][]const u8 = null,
            vpc_id: ?[]const u8 = null,
            self_service_portal_url: ?[]const u8 = null,
            client_connect_options: ?struct {
                enabled: ?bool = null,
                lambda_function_arn: ?[]const u8 = null,
                status: ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "code",
                            .message = "message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "enabled",
                        .lambda_function_arn = "lambdaFunctionArn",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            session_timeout_hours: ?i64 = null,
            client_login_banner_options: ?struct {
                enabled: ?bool = null,
                banner_text: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "enabled",
                        .banner_text = "bannerText",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_vpn_endpoint_id = "clientVpnEndpointId",
                    .description = "description",
                    .status = "status",
                    .creation_time = "creationTime",
                    .deletion_time = "deletionTime",
                    .dns_name = "dnsName",
                    .client_cidr_block = "clientCidrBlock",
                    .dns_servers = "dnsServer",
                    .split_tunnel = "splitTunnel",
                    .vpn_protocol = "vpnProtocol",
                    .transport_protocol = "transportProtocol",
                    .vpn_port = "vpnPort",
                    .associated_target_networks = "associatedTargetNetwork",
                    .server_certificate_arn = "serverCertificateArn",
                    .authentication_options = "authenticationOptions",
                    .connection_log_options = "connectionLogOptions",
                    .tags = "tagSet",
                    .security_group_ids = "securityGroupIdSet",
                    .vpc_id = "vpcId",
                    .self_service_portal_url = "selfServicePortalUrl",
                    .client_connect_options = "clientConnectOptions",
                    .session_timeout_hours = "sessionTimeoutHours",
                    .client_login_banner_options = "clientLoginBannerOptions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoints = "clientVpnEndpoint",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_client_vpn_routes: struct {
    action_name: []const u8 = "DescribeClientVpnRoutes",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_vpn_routes) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_vpn_routes };
        }
    },
    Response: type = struct {
        routes: ?[]struct {
            client_vpn_endpoint_id: ?[]const u8 = null,
            destination_cidr: ?[]const u8 = null,
            target_subnet: ?[]const u8 = null,
            type: ?[]const u8 = null,
            origin: ?[]const u8 = null,
            status: ?ClientVpnRouteStatus = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_vpn_endpoint_id = "clientVpnEndpointId",
                    .destination_cidr = "destinationCidr",
                    .target_subnet = "targetSubnet",
                    .type = "type",
                    .origin = "origin",
                    .status = "status",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routes = "routes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_client_vpn_target_networks: struct {
    action_name: []const u8 = "DescribeClientVpnTargetNetworks",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        association_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .association_ids = "AssociationIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_vpn_target_networks) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_vpn_target_networks };
        }
    },
    Response: type = struct {
        client_vpn_target_networks: ?[]struct {
            association_id: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            target_network_id: ?[]const u8 = null,
            client_vpn_endpoint_id: ?[]const u8 = null,
            status: ?AssociationStatus = null,
            security_groups: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "associationId",
                    .vpc_id = "vpcId",
                    .target_network_id = "targetNetworkId",
                    .client_vpn_endpoint_id = "clientVpnEndpointId",
                    .status = "status",
                    .security_groups = "securityGroups",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_target_networks = "clientVpnTargetNetworks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_coip_pools: struct {
    action_name: []const u8 = "DescribeCoipPools",
    Request: type = struct {
        pool_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_ids = "PoolId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_coip_pools) } {
            return .{ .service_metadata = service_metadata, .action = describe_coip_pools };
        }
    },
    Response: type = struct {
        coip_pools: ?[]CoipPool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_pools = "coipPoolSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_conversion_tasks: struct {
    action_name: []const u8 = "DescribeConversionTasks",
    Request: type = struct {
        conversion_task_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversion_task_ids = "conversionTaskId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conversion_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_conversion_tasks };
        }
    },
    Response: type = struct {
        conversion_tasks: ?[]ConversionTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversion_tasks = "conversionTasks",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_customer_gateways: struct {
    action_name: []const u8 = "DescribeCustomerGateways",
    Request: type = struct {
        customer_gateway_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_ids = "CustomerGatewayId",
                .filters = "Filter",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_customer_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_customer_gateways };
        }
    },
    Response: type = struct {
        customer_gateways: ?[]CustomerGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateways = "customerGatewaySet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_dhcp_options: struct {
    action_name: []const u8 = "DescribeDhcpOptions",
    Request: type = struct {
        dhcp_options_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_options_ids = "DhcpOptionsId",
                .filters = "Filter",
                .dry_run = "dryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dhcp_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_dhcp_options };
        }
    },
    Response: type = struct {
        dhcp_options: ?[]DhcpOptions = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dhcp_options = "dhcpOptionsSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_egress_only_internet_gateways: struct {
    action_name: []const u8 = "DescribeEgressOnlyInternetGateways",
    Request: type = struct {
        dry_run: ?bool = null,
        egress_only_internet_gateway_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .egress_only_internet_gateway_ids = "EgressOnlyInternetGatewayId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_egress_only_internet_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_egress_only_internet_gateways };
        }
    },
    Response: type = struct {
        egress_only_internet_gateways: ?[]EgressOnlyInternetGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .egress_only_internet_gateways = "egressOnlyInternetGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_elastic_gpus: struct {
    action_name: []const u8 = "DescribeElasticGpus",
    Request: type = struct {
        elastic_gpu_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .elastic_gpu_ids = "ElasticGpuId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_elastic_gpus) } {
            return .{ .service_metadata = service_metadata, .action = describe_elastic_gpus };
        }
    },
    Response: type = struct {
        elastic_gpu_set: ?[]struct {
            elastic_gpu_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            elastic_gpu_type: ?[]const u8 = null,
            elastic_gpu_health: ?struct {
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            elastic_gpu_state: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .elastic_gpu_id = "elasticGpuId",
                    .availability_zone = "availabilityZone",
                    .elastic_gpu_type = "elasticGpuType",
                    .elastic_gpu_health = "elasticGpuHealth",
                    .elastic_gpu_state = "elasticGpuState",
                    .instance_id = "instanceId",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .elastic_gpu_set = "elasticGpuSet",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_export_image_tasks: struct {
    action_name: []const u8 = "DescribeExportImageTasks",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        export_image_task_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .export_image_task_ids = "ExportImageTaskId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export_image_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_export_image_tasks };
        }
    },
    Response: type = struct {
        export_image_tasks: ?[]struct {
            description: ?[]const u8 = null,
            export_image_task_id: ?[]const u8 = null,
            image_id: ?[]const u8 = null,
            progress: ?[]const u8 = null,
            s3_export_location: ?ExportTaskS3Location = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "description",
                    .export_image_task_id = "exportImageTaskId",
                    .image_id = "imageId",
                    .progress = "progress",
                    .s3_export_location = "s3ExportLocation",
                    .status = "status",
                    .status_message = "statusMessage",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_image_tasks = "exportImageTaskSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_export_tasks: struct {
    action_name: []const u8 = "DescribeExportTasks",
    Request: type = struct {
        export_task_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_task_ids = "exportTaskId",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_export_tasks };
        }
    },
    Response: type = struct {
        export_tasks: ?[]ExportTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_tasks = "exportTaskSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fast_launch_images: struct {
    action_name: []const u8 = "DescribeFastLaunchImages",
    Request: type = struct {
        image_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "ImageId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fast_launch_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_fast_launch_images };
        }
    },
    Response: type = struct {
        fast_launch_images: ?[]struct {
            image_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            snapshot_configuration: ?FastLaunchSnapshotConfigurationResponse = null,
            launch_template: ?FastLaunchLaunchTemplateSpecificationResponse = null,
            max_parallel_launches: ?i64 = null,
            owner_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_transition_reason: ?[]const u8 = null,
            state_transition_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_id = "imageId",
                    .resource_type = "resourceType",
                    .snapshot_configuration = "snapshotConfiguration",
                    .launch_template = "launchTemplate",
                    .max_parallel_launches = "maxParallelLaunches",
                    .owner_id = "ownerId",
                    .state = "state",
                    .state_transition_reason = "stateTransitionReason",
                    .state_transition_time = "stateTransitionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fast_launch_images = "fastLaunchImageSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fast_snapshot_restores: struct {
    action_name: []const u8 = "DescribeFastSnapshotRestores",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fast_snapshot_restores) } {
            return .{ .service_metadata = service_metadata, .action = describe_fast_snapshot_restores };
        }
    },
    Response: type = struct {
        fast_snapshot_restores: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_transition_reason: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            owner_alias: ?[]const u8 = null,
            enabling_time: ?i64 = null,
            optimizing_time: ?i64 = null,
            enabled_time: ?i64 = null,
            disabling_time: ?i64 = null,
            disabled_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .availability_zone = "availabilityZone",
                    .state = "state",
                    .state_transition_reason = "stateTransitionReason",
                    .owner_id = "ownerId",
                    .owner_alias = "ownerAlias",
                    .enabling_time = "enablingTime",
                    .optimizing_time = "optimizingTime",
                    .enabled_time = "enabledTime",
                    .disabling_time = "disablingTime",
                    .disabled_time = "disabledTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fast_snapshot_restores = "fastSnapshotRestoreSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fleet_history: struct {
    action_name: []const u8 = "DescribeFleetHistory",
    Request: type = struct {
        dry_run: ?bool = null,
        event_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        fleet_id: []const u8,
        start_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .event_type = "EventType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .fleet_id = "FleetId",
                .start_time = "StartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_history) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_history };
        }
    },
    Response: type = struct {
        history_records: ?[]struct {
            event_information: ?EventInformation = null,
            event_type: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_information = "eventInformation",
                    .event_type = "eventType",
                    .timestamp = "timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_evaluated_time: ?i64 = null,
        next_token: ?[]const u8 = null,
        fleet_id: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history_records = "historyRecordSet",
                .last_evaluated_time = "lastEvaluatedTime",
                .next_token = "nextToken",
                .fleet_id = "fleetId",
                .start_time = "startTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fleet_instances: struct {
    action_name: []const u8 = "DescribeFleetInstances",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        fleet_id: []const u8,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .fleet_id = "FleetId",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_instances };
        }
    },
    Response: type = struct {
        active_instances: ?[]ActiveInstance = null,
        next_token: ?[]const u8 = null,
        fleet_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_instances = "activeInstanceSet",
                .next_token = "nextToken",
                .fleet_id = "fleetId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fleets: struct {
    action_name: []const u8 = "DescribeFleets",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        fleet_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .fleet_ids = "FleetId",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleets) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        fleets: ?[]struct {
            activity_status: ?[]const u8 = null,
            create_time: ?i64 = null,
            fleet_id: ?[]const u8 = null,
            fleet_state: ?[]const u8 = null,
            client_token: ?[]const u8 = null,
            excess_capacity_termination_policy: ?[]const u8 = null,
            fulfilled_capacity: ?f64 = null,
            fulfilled_on_demand_capacity: ?f64 = null,
            launch_template_configs: ?[]struct {
                launch_template_specification: ?FleetLaunchTemplateSpecification = null,
                overrides: ?[]FleetLaunchTemplateOverrides = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .launch_template_specification = "launchTemplateSpecification",
                        .overrides = "overrides",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            target_capacity_specification: ?struct {
                total_target_capacity: ?i64 = null,
                on_demand_target_capacity: ?i64 = null,
                spot_target_capacity: ?i64 = null,
                default_target_capacity_type: ?[]const u8 = null,
                target_capacity_unit_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_target_capacity = "totalTargetCapacity",
                        .on_demand_target_capacity = "onDemandTargetCapacity",
                        .spot_target_capacity = "spotTargetCapacity",
                        .default_target_capacity_type = "defaultTargetCapacityType",
                        .target_capacity_unit_type = "targetCapacityUnitType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            terminate_instances_with_expiration: ?bool = null,
            type: ?[]const u8 = null,
            valid_from: ?i64 = null,
            valid_until: ?i64 = null,
            replace_unhealthy_instances: ?bool = null,
            spot_options: ?struct {
                allocation_strategy: ?[]const u8 = null,
                maintenance_strategies: ?struct {
                    capacity_rebalance: ?struct {
                        replacement_strategy: ?[]const u8 = null,
                        termination_delay: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .replacement_strategy = "replacementStrategy",
                                .termination_delay = "terminationDelay",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .capacity_rebalance = "capacityRebalance",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                instance_interruption_behavior: ?[]const u8 = null,
                instance_pools_to_use_count: ?i64 = null,
                single_instance_type: ?bool = null,
                single_availability_zone: ?bool = null,
                min_target_capacity: ?i64 = null,
                max_total_price: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .allocation_strategy = "allocationStrategy",
                        .maintenance_strategies = "maintenanceStrategies",
                        .instance_interruption_behavior = "instanceInterruptionBehavior",
                        .instance_pools_to_use_count = "instancePoolsToUseCount",
                        .single_instance_type = "singleInstanceType",
                        .single_availability_zone = "singleAvailabilityZone",
                        .min_target_capacity = "minTargetCapacity",
                        .max_total_price = "maxTotalPrice",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            on_demand_options: ?struct {
                allocation_strategy: ?[]const u8 = null,
                capacity_reservation_options: ?struct {
                    usage_strategy: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .usage_strategy = "usageStrategy",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                single_instance_type: ?bool = null,
                single_availability_zone: ?bool = null,
                min_target_capacity: ?i64 = null,
                max_total_price: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .allocation_strategy = "allocationStrategy",
                        .capacity_reservation_options = "capacityReservationOptions",
                        .single_instance_type = "singleInstanceType",
                        .single_availability_zone = "singleAvailabilityZone",
                        .min_target_capacity = "minTargetCapacity",
                        .max_total_price = "maxTotalPrice",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,
            errors: ?[]struct {
                launch_template_and_overrides: ?LaunchTemplateAndOverridesResponse = null,
                lifecycle: ?[]const u8 = null,
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .launch_template_and_overrides = "launchTemplateAndOverrides",
                        .lifecycle = "lifecycle",
                        .error_code = "errorCode",
                        .error_message = "errorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instances: ?[]struct {
                launch_template_and_overrides: ?LaunchTemplateAndOverridesResponse = null,
                lifecycle: ?[]const u8 = null,
                instance_ids: ?[][]const u8 = null,
                instance_type: ?[]const u8 = null,
                platform: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .launch_template_and_overrides = "launchTemplateAndOverrides",
                        .lifecycle = "lifecycle",
                        .instance_ids = "instanceIds",
                        .instance_type = "instanceType",
                        .platform = "platform",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            context: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_status = "activityStatus",
                    .create_time = "createTime",
                    .fleet_id = "fleetId",
                    .fleet_state = "fleetState",
                    .client_token = "clientToken",
                    .excess_capacity_termination_policy = "excessCapacityTerminationPolicy",
                    .fulfilled_capacity = "fulfilledCapacity",
                    .fulfilled_on_demand_capacity = "fulfilledOnDemandCapacity",
                    .launch_template_configs = "launchTemplateConfigs",
                    .target_capacity_specification = "targetCapacitySpecification",
                    .terminate_instances_with_expiration = "terminateInstancesWithExpiration",
                    .type = "type",
                    .valid_from = "validFrom",
                    .valid_until = "validUntil",
                    .replace_unhealthy_instances = "replaceUnhealthyInstances",
                    .spot_options = "spotOptions",
                    .on_demand_options = "onDemandOptions",
                    .tags = "tagSet",
                    .errors = "errorSet",
                    .instances = "fleetInstanceSet",
                    .context = "context",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .fleets = "fleetSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_flow_logs: struct {
    action_name: []const u8 = "DescribeFlowLogs",
    Request: type = struct {
        dry_run: ?bool = null,
        filter: ?[]Filter = null,
        flow_log_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filter = "Filter",
                .flow_log_ids = "FlowLogId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow_logs) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow_logs };
        }
    },
    Response: type = struct {
        flow_logs: ?[]struct {
            creation_time: ?i64 = null,
            deliver_logs_error_message: ?[]const u8 = null,
            deliver_logs_permission_arn: ?[]const u8 = null,
            deliver_cross_account_role: ?[]const u8 = null,
            deliver_logs_status: ?[]const u8 = null,
            flow_log_id: ?[]const u8 = null,
            flow_log_status: ?[]const u8 = null,
            log_group_name: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            traffic_type: ?[]const u8 = null,
            log_destination_type: ?[]const u8 = null,
            log_destination: ?[]const u8 = null,
            log_format: ?[]const u8 = null,
            tags: ?[]Tag = null,
            max_aggregation_interval: ?i64 = null,
            destination_options: ?struct {
                file_format: ?[]const u8 = null,
                hive_compatible_partitions: ?bool = null,
                per_hour_partition: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .file_format = "fileFormat",
                        .hive_compatible_partitions = "hiveCompatiblePartitions",
                        .per_hour_partition = "perHourPartition",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "creationTime",
                    .deliver_logs_error_message = "deliverLogsErrorMessage",
                    .deliver_logs_permission_arn = "deliverLogsPermissionArn",
                    .deliver_cross_account_role = "deliverCrossAccountRole",
                    .deliver_logs_status = "deliverLogsStatus",
                    .flow_log_id = "flowLogId",
                    .flow_log_status = "flowLogStatus",
                    .log_group_name = "logGroupName",
                    .resource_id = "resourceId",
                    .traffic_type = "trafficType",
                    .log_destination_type = "logDestinationType",
                    .log_destination = "logDestination",
                    .log_format = "logFormat",
                    .tags = "tagSet",
                    .max_aggregation_interval = "maxAggregationInterval",
                    .destination_options = "destinationOptions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_logs = "flowLogSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fpga_image_attribute: struct {
    action_name: []const u8 = "DescribeFpgaImageAttribute",
    Request: type = struct {
        dry_run: ?bool = null,
        fpga_image_id: []const u8,
        attribute: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fpga_image_id = "FpgaImageId",
                .attribute = "Attribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fpga_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_fpga_image_attribute };
        }
    },
    Response: type = struct {
        fpga_image_attribute: ?FpgaImageAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fpga_image_attribute = "fpgaImageAttribute",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fpga_images: struct {
    action_name: []const u8 = "DescribeFpgaImages",
    Request: type = struct {
        dry_run: ?bool = null,
        fpga_image_ids: ?[][]const u8 = null,
        owners: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fpga_image_ids = "FpgaImageId",
                .owners = "Owner",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fpga_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_fpga_images };
        }
    },
    Response: type = struct {
        fpga_images: ?[]struct {
            fpga_image_id: ?[]const u8 = null,
            fpga_image_global_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            shell_version: ?[]const u8 = null,
            pci_id: ?struct {
                device_id: ?[]const u8 = null,
                vendor_id: ?[]const u8 = null,
                subsystem_id: ?[]const u8 = null,
                subsystem_vendor_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .device_id = "DeviceId",
                        .vendor_id = "VendorId",
                        .subsystem_id = "SubsystemId",
                        .subsystem_vendor_id = "SubsystemVendorId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            create_time: ?i64 = null,
            update_time: ?i64 = null,
            owner_id: ?[]const u8 = null,
            owner_alias: ?[]const u8 = null,
            product_codes: ?[]ProductCode = null,
            tags: ?[]Tag = null,
            public: ?bool = null,
            data_retention_support: ?bool = null,
            instance_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fpga_image_id = "fpgaImageId",
                    .fpga_image_global_id = "fpgaImageGlobalId",
                    .name = "name",
                    .description = "description",
                    .shell_version = "shellVersion",
                    .pci_id = "pciId",
                    .state = "state",
                    .create_time = "createTime",
                    .update_time = "updateTime",
                    .owner_id = "ownerId",
                    .owner_alias = "ownerAlias",
                    .product_codes = "productCodes",
                    .tags = "tags",
                    .public = "public",
                    .data_retention_support = "dataRetentionSupport",
                    .instance_types = "instanceTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fpga_images = "fpgaImageSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_host_reservation_offerings: struct {
    action_name: []const u8 = "DescribeHostReservationOfferings",
    Request: type = struct {
        filter: ?[]Filter = null,
        max_duration: ?i64 = null,
        max_results: ?i64 = null,
        min_duration: ?i64 = null,
        next_token: ?[]const u8 = null,
        offering_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .max_duration = "MaxDuration",
                .max_results = "MaxResults",
                .min_duration = "MinDuration",
                .next_token = "NextToken",
                .offering_id = "OfferingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_host_reservation_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_host_reservation_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        offering_set: ?[]struct {
            currency_code: ?[]const u8 = null,
            duration: ?i64 = null,
            hourly_price: ?[]const u8 = null,
            instance_family: ?[]const u8 = null,
            offering_id: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            upfront_price: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .currency_code = "currencyCode",
                    .duration = "duration",
                    .hourly_price = "hourlyPrice",
                    .instance_family = "instanceFamily",
                    .offering_id = "offeringId",
                    .payment_option = "paymentOption",
                    .upfront_price = "upfrontPrice",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .offering_set = "offeringSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_host_reservations: struct {
    action_name: []const u8 = "DescribeHostReservations",
    Request: type = struct {
        filter: ?[]Filter = null,
        host_reservation_id_set: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .host_reservation_id_set = "HostReservationIdSet",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_host_reservations) } {
            return .{ .service_metadata = service_metadata, .action = describe_host_reservations };
        }
    },
    Response: type = struct {
        host_reservation_set: ?[]struct {
            count: ?i64 = null,
            currency_code: ?[]const u8 = null,
            duration: ?i64 = null,
            end: ?i64 = null,
            host_id_set: ?[][]const u8 = null,
            host_reservation_id: ?[]const u8 = null,
            hourly_price: ?[]const u8 = null,
            instance_family: ?[]const u8 = null,
            offering_id: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            start: ?i64 = null,
            state: ?[]const u8 = null,
            upfront_price: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count = "count",
                    .currency_code = "currencyCode",
                    .duration = "duration",
                    .end = "end",
                    .host_id_set = "hostIdSet",
                    .host_reservation_id = "hostReservationId",
                    .hourly_price = "hourlyPrice",
                    .instance_family = "instanceFamily",
                    .offering_id = "offeringId",
                    .payment_option = "paymentOption",
                    .start = "start",
                    .state = "state",
                    .upfront_price = "upfrontPrice",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_reservation_set = "hostReservationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_hosts: struct {
    action_name: []const u8 = "DescribeHosts",
    Request: type = struct {
        filter: ?[]Filter = null,
        host_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
                .host_ids = "hostId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hosts) } {
            return .{ .service_metadata = service_metadata, .action = describe_hosts };
        }
    },
    Response: type = struct {
        hosts: ?[]struct {
            auto_placement: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            available_capacity: ?struct {
                available_instance_capacity: ?[]struct {
                    available_capacity: ?i64 = null,
                    instance_type: ?[]const u8 = null,
                    total_capacity: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .available_capacity = "availableCapacity",
                            .instance_type = "instanceType",
                            .total_capacity = "totalCapacity",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                available_v_cpus: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .available_instance_capacity = "availableInstanceCapacity",
                        .available_v_cpus = "availableVCpus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            client_token: ?[]const u8 = null,
            host_id: ?[]const u8 = null,
            host_properties: ?struct {
                cores: ?i64 = null,
                instance_type: ?[]const u8 = null,
                instance_family: ?[]const u8 = null,
                sockets: ?i64 = null,
                total_v_cpus: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cores = "cores",
                        .instance_type = "instanceType",
                        .instance_family = "instanceFamily",
                        .sockets = "sockets",
                        .total_v_cpus = "totalVCpus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            host_reservation_id: ?[]const u8 = null,
            instances: ?[]struct {
                instance_id: ?[]const u8 = null,
                instance_type: ?[]const u8 = null,
                owner_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_id = "instanceId",
                        .instance_type = "instanceType",
                        .owner_id = "ownerId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state: ?[]const u8 = null,
            allocation_time: ?i64 = null,
            release_time: ?i64 = null,
            tags: ?[]Tag = null,
            host_recovery: ?[]const u8 = null,
            allows_multiple_instance_types: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            member_of_service_linked_resource_group: ?bool = null,
            outpost_arn: ?[]const u8 = null,
            host_maintenance: ?[]const u8 = null,
            asset_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_placement = "autoPlacement",
                    .availability_zone = "availabilityZone",
                    .available_capacity = "availableCapacity",
                    .client_token = "clientToken",
                    .host_id = "hostId",
                    .host_properties = "hostProperties",
                    .host_reservation_id = "hostReservationId",
                    .instances = "instances",
                    .state = "state",
                    .allocation_time = "allocationTime",
                    .release_time = "releaseTime",
                    .tags = "tagSet",
                    .host_recovery = "hostRecovery",
                    .allows_multiple_instance_types = "allowsMultipleInstanceTypes",
                    .owner_id = "ownerId",
                    .availability_zone_id = "availabilityZoneId",
                    .member_of_service_linked_resource_group = "memberOfServiceLinkedResourceGroup",
                    .outpost_arn = "outpostArn",
                    .host_maintenance = "hostMaintenance",
                    .asset_id = "assetId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosts = "hostSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_iam_instance_profile_associations: struct {
    action_name: []const u8 = "DescribeIamInstanceProfileAssociations",
    Request: type = struct {
        association_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_ids = "AssociationId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_iam_instance_profile_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_iam_instance_profile_associations };
        }
    },
    Response: type = struct {
        iam_instance_profile_associations: ?[]IamInstanceProfileAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile_associations = "iamInstanceProfileAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_identity_id_format: struct {
    action_name: []const u8 = "DescribeIdentityIdFormat",
    Request: type = struct {
        principal_arn: []const u8,
        resource: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_arn = "principalArn",
                .resource = "resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_id_format) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_id_format };
        }
    },
    Response: type = struct {
        statuses: ?[]IdFormat = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statuses = "statusSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_id_format: struct {
    action_name: []const u8 = "DescribeIdFormat",
    Request: type = struct {
        resource: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_id_format) } {
            return .{ .service_metadata = service_metadata, .action = describe_id_format };
        }
    },
    Response: type = struct {
        statuses: ?[]IdFormat = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statuses = "statusSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_image_attribute: struct {
    action_name: []const u8 = "DescribeImageAttribute",
    Request: type = struct {
        attribute: []const u8,
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .image_id = "ImageId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_attribute };
        }
    },
    Response: type = struct {
        block_device_mappings: ?[]BlockDeviceMapping = null,
        image_id: ?[]const u8 = null,
        launch_permissions: ?[]LaunchPermission = null,
        product_codes: ?[]ProductCode = null,
        description: ?AttributeValue = null,
        kernel_id: ?AttributeValue = null,
        ramdisk_id: ?AttributeValue = null,
        sriov_net_support: ?AttributeValue = null,
        boot_mode: ?AttributeValue = null,
        tpm_support: ?AttributeValue = null,
        uefi_data: ?AttributeValue = null,
        last_launched_time: ?AttributeValue = null,
        imds_support: ?AttributeValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_device_mappings = "blockDeviceMapping",
                .image_id = "imageId",
                .launch_permissions = "launchPermission",
                .product_codes = "productCodes",
                .description = "description",
                .kernel_id = "kernel",
                .ramdisk_id = "ramdisk",
                .sriov_net_support = "sriovNetSupport",
                .boot_mode = "bootMode",
                .tpm_support = "tpmSupport",
                .uefi_data = "uefiData",
                .last_launched_time = "lastLaunchedTime",
                .imds_support = "imdsSupport",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_images: struct {
    action_name: []const u8 = "DescribeImages",
    Request: type = struct {
        executable_users: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        image_ids: ?[][]const u8 = null,
        owners: ?[][]const u8 = null,
        include_deprecated: ?bool = null,
        include_disabled: ?bool = null,
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .executable_users = "ExecutableBy",
                .filters = "Filter",
                .image_ids = "ImageId",
                .owners = "Owner",
                .include_deprecated = "IncludeDeprecated",
                .include_disabled = "IncludeDisabled",
                .dry_run = "dryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_images };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            architecture: ?[]const u8 = null,
            creation_date: ?[]const u8 = null,
            image_id: ?[]const u8 = null,
            image_location: ?[]const u8 = null,
            image_type: ?[]const u8 = null,
            public: ?bool = null,
            kernel_id: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            platform_details: ?[]const u8 = null,
            usage_operation: ?[]const u8 = null,
            product_codes: ?[]ProductCode = null,
            ramdisk_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            block_device_mappings: ?[]BlockDeviceMapping = null,
            description: ?[]const u8 = null,
            ena_support: ?bool = null,
            hypervisor: ?[]const u8 = null,
            image_owner_alias: ?[]const u8 = null,
            name: ?[]const u8 = null,
            root_device_name: ?[]const u8 = null,
            root_device_type: ?[]const u8 = null,
            sriov_net_support: ?[]const u8 = null,
            state_reason: ?StateReason = null,
            tags: ?[]Tag = null,
            virtualization_type: ?[]const u8 = null,
            boot_mode: ?[]const u8 = null,
            tpm_support: ?[]const u8 = null,
            deprecation_time: ?[]const u8 = null,
            imds_support: ?[]const u8 = null,
            source_instance_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .architecture = "architecture",
                    .creation_date = "creationDate",
                    .image_id = "imageId",
                    .image_location = "imageLocation",
                    .image_type = "imageType",
                    .public = "isPublic",
                    .kernel_id = "kernelId",
                    .owner_id = "imageOwnerId",
                    .platform = "platform",
                    .platform_details = "platformDetails",
                    .usage_operation = "usageOperation",
                    .product_codes = "productCodes",
                    .ramdisk_id = "ramdiskId",
                    .state = "imageState",
                    .block_device_mappings = "blockDeviceMapping",
                    .description = "description",
                    .ena_support = "enaSupport",
                    .hypervisor = "hypervisor",
                    .image_owner_alias = "imageOwnerAlias",
                    .name = "name",
                    .root_device_name = "rootDeviceName",
                    .root_device_type = "rootDeviceType",
                    .sriov_net_support = "sriovNetSupport",
                    .state_reason = "stateReason",
                    .tags = "tagSet",
                    .virtualization_type = "virtualizationType",
                    .boot_mode = "bootMode",
                    .tpm_support = "tpmSupport",
                    .deprecation_time = "deprecationTime",
                    .imds_support = "imdsSupport",
                    .source_instance_id = "sourceInstanceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "imagesSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_import_image_tasks: struct {
    action_name: []const u8 = "DescribeImportImageTasks",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        import_task_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filters",
                .import_task_ids = "ImportTaskId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_import_image_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_import_image_tasks };
        }
    },
    Response: type = struct {
        import_image_tasks: ?[]struct {
            architecture: ?[]const u8 = null,
            description: ?[]const u8 = null,
            encrypted: ?bool = null,
            hypervisor: ?[]const u8 = null,
            image_id: ?[]const u8 = null,
            import_task_id: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            license_type: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            progress: ?[]const u8 = null,
            snapshot_details: ?[]SnapshotDetail = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            tags: ?[]Tag = null,
            license_specifications: ?[]ImportImageLicenseConfigurationResponse = null,
            usage_operation: ?[]const u8 = null,
            boot_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .architecture = "architecture",
                    .description = "description",
                    .encrypted = "encrypted",
                    .hypervisor = "hypervisor",
                    .image_id = "imageId",
                    .import_task_id = "importTaskId",
                    .kms_key_id = "kmsKeyId",
                    .license_type = "licenseType",
                    .platform = "platform",
                    .progress = "progress",
                    .snapshot_details = "snapshotDetailSet",
                    .status = "status",
                    .status_message = "statusMessage",
                    .tags = "tagSet",
                    .license_specifications = "licenseSpecifications",
                    .usage_operation = "usageOperation",
                    .boot_mode = "bootMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_image_tasks = "importImageTaskSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_import_snapshot_tasks: struct {
    action_name: []const u8 = "DescribeImportSnapshotTasks",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        import_task_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filters",
                .import_task_ids = "ImportTaskId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_import_snapshot_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_import_snapshot_tasks };
        }
    },
    Response: type = struct {
        import_snapshot_tasks: ?[]struct {
            description: ?[]const u8 = null,
            import_task_id: ?[]const u8 = null,
            snapshot_task_detail: ?SnapshotTaskDetail = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "description",
                    .import_task_id = "importTaskId",
                    .snapshot_task_detail = "snapshotTaskDetail",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_snapshot_tasks = "importSnapshotTaskSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_attribute: struct {
    action_name: []const u8 = "DescribeInstanceAttribute",
    Request: type = struct {
        attribute: []const u8,
        dry_run: ?bool = null,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "attribute",
                .dry_run = "dryRun",
                .instance_id = "instanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_attribute };
        }
    },
    Response: type = struct {
        groups: ?[]GroupIdentifier = null,
        block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
        disable_api_termination: ?AttributeBooleanValue = null,
        ena_support: ?AttributeBooleanValue = null,
        enclave_options: ?EnclaveOptions = null,
        ebs_optimized: ?AttributeBooleanValue = null,
        instance_id: ?[]const u8 = null,
        instance_initiated_shutdown_behavior: ?AttributeValue = null,
        instance_type: ?AttributeValue = null,
        kernel_id: ?AttributeValue = null,
        product_codes: ?[]ProductCode = null,
        ramdisk_id: ?AttributeValue = null,
        root_device_name: ?AttributeValue = null,
        source_dest_check: ?AttributeBooleanValue = null,
        sriov_net_support: ?AttributeValue = null,
        user_data: ?AttributeValue = null,
        disable_api_stop: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "groupSet",
                .block_device_mappings = "blockDeviceMapping",
                .disable_api_termination = "disableApiTermination",
                .ena_support = "enaSupport",
                .enclave_options = "enclaveOptions",
                .ebs_optimized = "ebsOptimized",
                .instance_id = "instanceId",
                .instance_initiated_shutdown_behavior = "instanceInitiatedShutdownBehavior",
                .instance_type = "instanceType",
                .kernel_id = "kernel",
                .product_codes = "productCodes",
                .ramdisk_id = "ramdisk",
                .root_device_name = "rootDeviceName",
                .source_dest_check = "sourceDestCheck",
                .sriov_net_support = "sriovNetSupport",
                .user_data = "userData",
                .disable_api_stop = "disableApiStop",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_connect_endpoints: struct {
    action_name: []const u8 = "DescribeInstanceConnectEndpoints",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        instance_connect_endpoint_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .instance_connect_endpoint_ids = "InstanceConnectEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_connect_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_connect_endpoints };
        }
    },
    Response: type = struct {
        instance_connect_endpoints: ?[]Ec2InstanceConnectEndpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_connect_endpoints = "instanceConnectEndpointSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_credit_specifications: struct {
    action_name: []const u8 = "DescribeInstanceCreditSpecifications",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        instance_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .instance_ids = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_credit_specifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_credit_specifications };
        }
    },
    Response: type = struct {
        instance_credit_specifications: ?[]struct {
            instance_id: ?[]const u8 = null,
            cpu_credits: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "instanceId",
                    .cpu_credits = "cpuCredits",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_credit_specifications = "instanceCreditSpecificationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_event_notification_attributes: struct {
    action_name: []const u8 = "DescribeInstanceEventNotificationAttributes",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_event_notification_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_event_notification_attributes };
        }
    },
    Response: type = struct {
        instance_tag_attribute: ?InstanceTagNotificationAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_tag_attribute = "instanceTagAttribute",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_event_windows: struct {
    action_name: []const u8 = "DescribeInstanceEventWindows",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_event_window_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_event_window_ids = "InstanceEventWindowId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_event_windows) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_event_windows };
        }
    },
    Response: type = struct {
        instance_event_windows: ?[]InstanceEventWindow = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_windows = "instanceEventWindowSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instances: struct {
    action_name: []const u8 = "DescribeInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        instance_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .instance_ids = "InstanceId",
                .dry_run = "dryRun",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_instances };
        }
    },
    Response: type = struct {
        reservations: ?[]Reservation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservations = "reservationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_status: struct {
    action_name: []const u8 = "DescribeInstanceStatus",
    Request: type = struct {
        filters: ?[]Filter = null,
        instance_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        include_all_instances: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .instance_ids = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "dryRun",
                .include_all_instances = "includeAllInstances",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_status };
        }
    },
    Response: type = struct {
        instance_statuses: ?[]struct {
            availability_zone: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,
            events: ?[]InstanceStatusEvent = null,
            instance_id: ?[]const u8 = null,
            instance_state: ?InstanceState = null,
            instance_status: ?InstanceStatusSummary = null,
            system_status: ?InstanceStatusSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .outpost_arn = "outpostArn",
                    .events = "eventsSet",
                    .instance_id = "instanceId",
                    .instance_state = "instanceState",
                    .instance_status = "instanceStatus",
                    .system_status = "systemStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_statuses = "instanceStatusSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_topology: struct {
    action_name: []const u8 = "DescribeInstanceTopology",
    Request: type = struct {
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        instance_ids: ?[][]const u8 = null,
        group_names: ?[][]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .instance_ids = "InstanceId",
                .group_names = "GroupName",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_topology) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_topology };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            instance_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            network_nodes: ?[][]const u8 = null,
            availability_zone: ?[]const u8 = null,
            zone_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "instanceId",
                    .instance_type = "instanceType",
                    .group_name = "groupName",
                    .network_nodes = "networkNodeSet",
                    .availability_zone = "availabilityZone",
                    .zone_id = "zoneId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "instanceSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_type_offerings: struct {
    action_name: []const u8 = "DescribeInstanceTypeOfferings",
    Request: type = struct {
        dry_run: ?bool = null,
        location_type: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .location_type = "LocationType",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_type_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_type_offerings };
        }
    },
    Response: type = struct {
        instance_type_offerings: ?[]struct {
            instance_type: ?[]const u8 = null,
            location_type: ?[]const u8 = null,
            location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "instanceType",
                    .location_type = "locationType",
                    .location = "location",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_type_offerings = "instanceTypeOfferingSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_instance_types: struct {
    action_name: []const u8 = "DescribeInstanceTypes",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_types: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_types = "InstanceType",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_types };
        }
    },
    Response: type = struct {
        instance_types: ?[]struct {
            instance_type: ?[]const u8 = null,
            current_generation: ?bool = null,
            free_tier_eligible: ?bool = null,
            supported_usage_classes: ?[][]const u8 = null,
            supported_root_device_types: ?[][]const u8 = null,
            supported_virtualization_types: ?[][]const u8 = null,
            bare_metal: ?bool = null,
            hypervisor: ?[]const u8 = null,
            processor_info: ?struct {
                supported_architectures: ?[][]const u8 = null,
                sustained_clock_speed_in_ghz: ?f64 = null,
                supported_features: ?[][]const u8 = null,
                manufacturer: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .supported_architectures = "supportedArchitectures",
                        .sustained_clock_speed_in_ghz = "sustainedClockSpeedInGhz",
                        .supported_features = "supportedFeatures",
                        .manufacturer = "manufacturer",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            v_cpu_info: ?struct {
                default_v_cpus: ?i64 = null,
                default_cores: ?i64 = null,
                default_threads_per_core: ?i64 = null,
                valid_cores: ?[]i64 = null,
                valid_threads_per_core: ?[]i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .default_v_cpus = "defaultVCpus",
                        .default_cores = "defaultCores",
                        .default_threads_per_core = "defaultThreadsPerCore",
                        .valid_cores = "validCores",
                        .valid_threads_per_core = "validThreadsPerCore",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            memory_info: ?struct {
                size_in_mib: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .size_in_mib = "sizeInMiB",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_storage_supported: ?bool = null,
            instance_storage_info: ?struct {
                total_size_in_gb: ?i64 = null,
                disks: ?[]struct {
                    size_in_gb: ?i64 = null,
                    count: ?i64 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .size_in_gb = "sizeInGB",
                            .count = "count",
                            .type = "type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                nvme_support: ?[]const u8 = null,
                encryption_support: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_size_in_gb = "totalSizeInGB",
                        .disks = "disks",
                        .nvme_support = "nvmeSupport",
                        .encryption_support = "encryptionSupport",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ebs_info: ?struct {
                ebs_optimized_support: ?[]const u8 = null,
                encryption_support: ?[]const u8 = null,
                ebs_optimized_info: ?struct {
                    baseline_bandwidth_in_mbps: ?i64 = null,
                    baseline_throughput_in_m_bps: ?f64 = null,
                    baseline_iops: ?i64 = null,
                    maximum_bandwidth_in_mbps: ?i64 = null,
                    maximum_throughput_in_m_bps: ?f64 = null,
                    maximum_iops: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .baseline_bandwidth_in_mbps = "baselineBandwidthInMbps",
                            .baseline_throughput_in_m_bps = "baselineThroughputInMBps",
                            .baseline_iops = "baselineIops",
                            .maximum_bandwidth_in_mbps = "maximumBandwidthInMbps",
                            .maximum_throughput_in_m_bps = "maximumThroughputInMBps",
                            .maximum_iops = "maximumIops",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                nvme_support: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ebs_optimized_support = "ebsOptimizedSupport",
                        .encryption_support = "encryptionSupport",
                        .ebs_optimized_info = "ebsOptimizedInfo",
                        .nvme_support = "nvmeSupport",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            network_info: ?struct {
                network_performance: ?[]const u8 = null,
                maximum_network_interfaces: ?i64 = null,
                maximum_network_cards: ?i64 = null,
                default_network_card_index: ?i64 = null,
                network_cards: ?[]struct {
                    network_card_index: ?i64 = null,
                    network_performance: ?[]const u8 = null,
                    maximum_network_interfaces: ?i64 = null,
                    baseline_bandwidth_in_gbps: ?f64 = null,
                    peak_bandwidth_in_gbps: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .network_card_index = "networkCardIndex",
                            .network_performance = "networkPerformance",
                            .maximum_network_interfaces = "maximumNetworkInterfaces",
                            .baseline_bandwidth_in_gbps = "baselineBandwidthInGbps",
                            .peak_bandwidth_in_gbps = "peakBandwidthInGbps",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ipv4_addresses_per_interface: ?i64 = null,
                ipv6_addresses_per_interface: ?i64 = null,
                ipv6_supported: ?bool = null,
                ena_support: ?[]const u8 = null,
                efa_supported: ?bool = null,
                efa_info: ?struct {
                    maximum_efa_interfaces: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .maximum_efa_interfaces = "maximumEfaInterfaces",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                encryption_in_transit_supported: ?bool = null,
                ena_srd_supported: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .network_performance = "networkPerformance",
                        .maximum_network_interfaces = "maximumNetworkInterfaces",
                        .maximum_network_cards = "maximumNetworkCards",
                        .default_network_card_index = "defaultNetworkCardIndex",
                        .network_cards = "networkCards",
                        .ipv4_addresses_per_interface = "ipv4AddressesPerInterface",
                        .ipv6_addresses_per_interface = "ipv6AddressesPerInterface",
                        .ipv6_supported = "ipv6Supported",
                        .ena_support = "enaSupport",
                        .efa_supported = "efaSupported",
                        .efa_info = "efaInfo",
                        .encryption_in_transit_supported = "encryptionInTransitSupported",
                        .ena_srd_supported = "enaSrdSupported",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            gpu_info: ?struct {
                gpus: ?[]struct {
                    name: ?[]const u8 = null,
                    manufacturer: ?[]const u8 = null,
                    count: ?i64 = null,
                    memory_info: ?struct {
                        size_in_mib: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .size_in_mib = "sizeInMiB",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .manufacturer = "manufacturer",
                            .count = "count",
                            .memory_info = "memoryInfo",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                total_gpu_memory_in_mib: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .gpus = "gpus",
                        .total_gpu_memory_in_mib = "totalGpuMemoryInMiB",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fpga_info: ?struct {
                fpgas: ?[]struct {
                    name: ?[]const u8 = null,
                    manufacturer: ?[]const u8 = null,
                    count: ?i64 = null,
                    memory_info: ?struct {
                        size_in_mib: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .size_in_mib = "sizeInMiB",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .manufacturer = "manufacturer",
                            .count = "count",
                            .memory_info = "memoryInfo",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                total_fpga_memory_in_mib: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .fpgas = "fpgas",
                        .total_fpga_memory_in_mib = "totalFpgaMemoryInMiB",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            placement_group_info: ?struct {
                supported_strategies: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .supported_strategies = "supportedStrategies",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            inference_accelerator_info: ?struct {
                accelerators: ?[]struct {
                    count: ?i64 = null,
                    name: ?[]const u8 = null,
                    manufacturer: ?[]const u8 = null,
                    memory_info: ?struct {
                        size_in_mib: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .size_in_mib = "sizeInMiB",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .count = "count",
                            .name = "name",
                            .manufacturer = "manufacturer",
                            .memory_info = "memoryInfo",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                total_inference_memory_in_mib: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .accelerators = "accelerators",
                        .total_inference_memory_in_mib = "totalInferenceMemoryInMiB",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            hibernation_supported: ?bool = null,
            burstable_performance_supported: ?bool = null,
            dedicated_hosts_supported: ?bool = null,
            auto_recovery_supported: ?bool = null,
            supported_boot_modes: ?[][]const u8 = null,
            nitro_enclaves_support: ?[]const u8 = null,
            nitro_tpm_support: ?[]const u8 = null,
            nitro_tpm_info: ?struct {
                supported_versions: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .supported_versions = "supportedVersions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "instanceType",
                    .current_generation = "currentGeneration",
                    .free_tier_eligible = "freeTierEligible",
                    .supported_usage_classes = "supportedUsageClasses",
                    .supported_root_device_types = "supportedRootDeviceTypes",
                    .supported_virtualization_types = "supportedVirtualizationTypes",
                    .bare_metal = "bareMetal",
                    .hypervisor = "hypervisor",
                    .processor_info = "processorInfo",
                    .v_cpu_info = "vCpuInfo",
                    .memory_info = "memoryInfo",
                    .instance_storage_supported = "instanceStorageSupported",
                    .instance_storage_info = "instanceStorageInfo",
                    .ebs_info = "ebsInfo",
                    .network_info = "networkInfo",
                    .gpu_info = "gpuInfo",
                    .fpga_info = "fpgaInfo",
                    .placement_group_info = "placementGroupInfo",
                    .inference_accelerator_info = "inferenceAcceleratorInfo",
                    .hibernation_supported = "hibernationSupported",
                    .burstable_performance_supported = "burstablePerformanceSupported",
                    .dedicated_hosts_supported = "dedicatedHostsSupported",
                    .auto_recovery_supported = "autoRecoverySupported",
                    .supported_boot_modes = "supportedBootModes",
                    .nitro_enclaves_support = "nitroEnclavesSupport",
                    .nitro_tpm_support = "nitroTpmSupport",
                    .nitro_tpm_info = "nitroTpmInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_types = "instanceTypeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_internet_gateways: struct {
    action_name: []const u8 = "DescribeInternetGateways",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        internet_gateway_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .internet_gateway_ids = "internetGatewayId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_internet_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_internet_gateways };
        }
    },
    Response: type = struct {
        internet_gateways: ?[]InternetGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .internet_gateways = "internetGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipam_byoasn: struct {
    action_name: []const u8 = "DescribeIpamByoasn",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipam_byoasn) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipam_byoasn };
        }
    },
    Response: type = struct {
        byoasns: ?[]Byoasn = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoasns = "byoasnSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipam_pools: struct {
    action_name: []const u8 = "DescribeIpamPools",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ipam_pool_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .ipam_pool_ids = "IpamPoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipam_pools) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipam_pools };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ipam_pools: ?[]IpamPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ipam_pools = "ipamPoolSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipam_resource_discoveries: struct {
    action_name: []const u8 = "DescribeIpamResourceDiscoveries",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_ids = "IpamResourceDiscoveryId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipam_resource_discoveries) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipam_resource_discoveries };
        }
    },
    Response: type = struct {
        ipam_resource_discoveries: ?[]IpamResourceDiscovery = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discoveries = "ipamResourceDiscoverySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipam_resource_discovery_associations: struct {
    action_name: []const u8 = "DescribeIpamResourceDiscoveryAssociations",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_association_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_association_ids = "IpamResourceDiscoveryAssociationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipam_resource_discovery_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipam_resource_discovery_associations };
        }
    },
    Response: type = struct {
        ipam_resource_discovery_associations: ?[]IpamResourceDiscoveryAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery_associations = "ipamResourceDiscoveryAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipams: struct {
    action_name: []const u8 = "DescribeIpams",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ipam_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .ipam_ids = "IpamId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipams) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipams };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ipams: ?[]Ipam = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ipams = "ipamSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipam_scopes: struct {
    action_name: []const u8 = "DescribeIpamScopes",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ipam_scope_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .ipam_scope_ids = "IpamScopeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipam_scopes) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipam_scopes };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ipam_scopes: ?[]IpamScope = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ipam_scopes = "ipamScopeSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_ipv6_pools: struct {
    action_name: []const u8 = "DescribeIpv6Pools",
    Request: type = struct {
        pool_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_ids = "PoolId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ipv6_pools) } {
            return .{ .service_metadata = service_metadata, .action = describe_ipv6_pools };
        }
    },
    Response: type = struct {
        ipv6_pools: ?[]struct {
            pool_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            pool_cidr_blocks: ?[]struct {
                cidr: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cidr = "poolCidrBlock",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_id = "poolId",
                    .description = "description",
                    .pool_cidr_blocks = "poolCidrBlockSet",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_pools = "ipv6PoolSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_key_pairs: struct {
    action_name: []const u8 = "DescribeKeyPairs",
    Request: type = struct {
        filters: ?[]Filter = null,
        key_names: ?[][]const u8 = null,
        key_pair_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        include_public_key: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .key_names = "KeyName",
                .key_pair_ids = "KeyPairId",
                .dry_run = "dryRun",
                .include_public_key = "IncludePublicKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_key_pairs) } {
            return .{ .service_metadata = service_metadata, .action = describe_key_pairs };
        }
    },
    Response: type = struct {
        key_pairs: ?[]struct {
            key_pair_id: ?[]const u8 = null,
            key_fingerprint: ?[]const u8 = null,
            key_name: ?[]const u8 = null,
            key_type: ?[]const u8 = null,
            tags: ?[]Tag = null,
            public_key: ?[]const u8 = null,
            create_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_pair_id = "keyPairId",
                    .key_fingerprint = "keyFingerprint",
                    .key_name = "keyName",
                    .key_type = "keyType",
                    .tags = "tagSet",
                    .public_key = "publicKey",
                    .create_time = "createTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_pairs = "keySet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_launch_templates: struct {
    action_name: []const u8 = "DescribeLaunchTemplates",
    Request: type = struct {
        dry_run: ?bool = null,
        launch_template_ids: ?[][]const u8 = null,
        launch_template_names: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .launch_template_ids = "LaunchTemplateId",
                .launch_template_names = "LaunchTemplateName",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_launch_templates) } {
            return .{ .service_metadata = service_metadata, .action = describe_launch_templates };
        }
    },
    Response: type = struct {
        launch_templates: ?[]LaunchTemplate = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_templates = "launchTemplates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_launch_template_versions: struct {
    action_name: []const u8 = "DescribeLaunchTemplateVersions",
    Request: type = struct {
        dry_run: ?bool = null,
        launch_template_id: ?[]const u8 = null,
        launch_template_name: ?[]const u8 = null,
        versions: ?[][]const u8 = null,
        min_version: ?[]const u8 = null,
        max_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        resolve_alias: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .launch_template_id = "LaunchTemplateId",
                .launch_template_name = "LaunchTemplateName",
                .versions = "LaunchTemplateVersion",
                .min_version = "MinVersion",
                .max_version = "MaxVersion",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
                .resolve_alias = "ResolveAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_launch_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_launch_template_versions };
        }
    },
    Response: type = struct {
        launch_template_versions: ?[]LaunchTemplateVersion = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template_versions = "launchTemplateVersionSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateway_route_tables: struct {
    action_name: []const u8 = "DescribeLocalGatewayRouteTables",
    Request: type = struct {
        local_gateway_route_table_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_ids = "LocalGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateway_route_tables) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateway_route_tables };
        }
    },
    Response: type = struct {
        local_gateway_route_tables: ?[]LocalGatewayRouteTable = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_tables = "localGatewayRouteTableSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateway_route_table_virtual_interface_group_associations: struct {
    action_name: []const u8 = "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations",
    Request: type = struct {
        local_gateway_route_table_virtual_interface_group_association_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_virtual_interface_group_association_ids = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateway_route_table_virtual_interface_group_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateway_route_table_virtual_interface_group_associations };
        }
    },
    Response: type = struct {
        local_gateway_route_table_virtual_interface_group_associations: ?[]LocalGatewayRouteTableVirtualInterfaceGroupAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_virtual_interface_group_associations = "localGatewayRouteTableVirtualInterfaceGroupAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateway_route_table_vpc_associations: struct {
    action_name: []const u8 = "DescribeLocalGatewayRouteTableVpcAssociations",
    Request: type = struct {
        local_gateway_route_table_vpc_association_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_vpc_association_ids = "LocalGatewayRouteTableVpcAssociationId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateway_route_table_vpc_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateway_route_table_vpc_associations };
        }
    },
    Response: type = struct {
        local_gateway_route_table_vpc_associations: ?[]LocalGatewayRouteTableVpcAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_vpc_associations = "localGatewayRouteTableVpcAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateways: struct {
    action_name: []const u8 = "DescribeLocalGateways",
    Request: type = struct {
        local_gateway_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_ids = "LocalGatewayId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateways };
        }
    },
    Response: type = struct {
        local_gateways: ?[]struct {
            local_gateway_id: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .local_gateway_id = "localGatewayId",
                    .outpost_arn = "outpostArn",
                    .owner_id = "ownerId",
                    .state = "state",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateways = "localGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateway_virtual_interface_groups: struct {
    action_name: []const u8 = "DescribeLocalGatewayVirtualInterfaceGroups",
    Request: type = struct {
        local_gateway_virtual_interface_group_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_virtual_interface_group_ids = "LocalGatewayVirtualInterfaceGroupId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateway_virtual_interface_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateway_virtual_interface_groups };
        }
    },
    Response: type = struct {
        local_gateway_virtual_interface_groups: ?[]struct {
            local_gateway_virtual_interface_group_id: ?[]const u8 = null,
            local_gateway_virtual_interface_ids: ?[][]const u8 = null,
            local_gateway_id: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .local_gateway_virtual_interface_group_id = "localGatewayVirtualInterfaceGroupId",
                    .local_gateway_virtual_interface_ids = "localGatewayVirtualInterfaceIdSet",
                    .local_gateway_id = "localGatewayId",
                    .owner_id = "ownerId",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_virtual_interface_groups = "localGatewayVirtualInterfaceGroupSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_local_gateway_virtual_interfaces: struct {
    action_name: []const u8 = "DescribeLocalGatewayVirtualInterfaces",
    Request: type = struct {
        local_gateway_virtual_interface_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_virtual_interface_ids = "LocalGatewayVirtualInterfaceId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_local_gateway_virtual_interfaces) } {
            return .{ .service_metadata = service_metadata, .action = describe_local_gateway_virtual_interfaces };
        }
    },
    Response: type = struct {
        local_gateway_virtual_interfaces: ?[]struct {
            local_gateway_virtual_interface_id: ?[]const u8 = null,
            local_gateway_id: ?[]const u8 = null,
            vlan: ?i64 = null,
            local_address: ?[]const u8 = null,
            peer_address: ?[]const u8 = null,
            local_bgp_asn: ?i64 = null,
            peer_bgp_asn: ?i64 = null,
            owner_id: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .local_gateway_virtual_interface_id = "localGatewayVirtualInterfaceId",
                    .local_gateway_id = "localGatewayId",
                    .vlan = "vlan",
                    .local_address = "localAddress",
                    .peer_address = "peerAddress",
                    .local_bgp_asn = "localBgpAsn",
                    .peer_bgp_asn = "peerBgpAsn",
                    .owner_id = "ownerId",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_virtual_interfaces = "localGatewayVirtualInterfaceSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_locked_snapshots: struct {
    action_name: []const u8 = "DescribeLockedSnapshots",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        snapshot_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .snapshot_ids = "SnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_locked_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_locked_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]struct {
            owner_id: ?[]const u8 = null,
            snapshot_id: ?[]const u8 = null,
            lock_state: ?[]const u8 = null,
            lock_duration: ?i64 = null,
            cool_off_period: ?i64 = null,
            cool_off_period_expires_on: ?i64 = null,
            lock_created_on: ?i64 = null,
            lock_duration_start_time: ?i64 = null,
            lock_expires_on: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .owner_id = "ownerId",
                    .snapshot_id = "snapshotId",
                    .lock_state = "lockState",
                    .lock_duration = "lockDuration",
                    .cool_off_period = "coolOffPeriod",
                    .cool_off_period_expires_on = "coolOffPeriodExpiresOn",
                    .lock_created_on = "lockCreatedOn",
                    .lock_duration_start_time = "lockDurationStartTime",
                    .lock_expires_on = "lockExpiresOn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "snapshotSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_managed_prefix_lists: struct {
    action_name: []const u8 = "DescribeManagedPrefixLists",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        prefix_list_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .prefix_list_ids = "PrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_prefix_lists) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_prefix_lists };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        prefix_lists: ?[]ManagedPrefixList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .prefix_lists = "prefixListSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_moving_addresses: struct {
    action_name: []const u8 = "DescribeMovingAddresses",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        public_ips: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filter",
                .dry_run = "dryRun",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .public_ips = "publicIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_moving_addresses) } {
            return .{ .service_metadata = service_metadata, .action = describe_moving_addresses };
        }
    },
    Response: type = struct {
        moving_address_statuses: ?[]struct {
            move_status: ?[]const u8 = null,
            public_ip: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .move_status = "moveStatus",
                    .public_ip = "publicIp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .moving_address_statuses = "movingAddressStatusSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_nat_gateways: struct {
    action_name: []const u8 = "DescribeNatGateways",
    Request: type = struct {
        dry_run: ?bool = null,
        filter: ?[]Filter = null,
        max_results: ?i64 = null,
        nat_gateway_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filter = "Filter",
                .max_results = "MaxResults",
                .nat_gateway_ids = "NatGatewayId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_nat_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_nat_gateways };
        }
    },
    Response: type = struct {
        nat_gateways: ?[]NatGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateways = "natGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_acls: struct {
    action_name: []const u8 = "DescribeNetworkAcls",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        network_acl_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .network_acl_ids = "NetworkAclId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_acls) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_acls };
        }
    },
    Response: type = struct {
        network_acls: ?[]NetworkAcl = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_acls = "networkAclSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_insights_access_scope_analyses: struct {
    action_name: []const u8 = "DescribeNetworkInsightsAccessScopeAnalyses",
    Request: type = struct {
        network_insights_access_scope_analysis_ids: ?[][]const u8 = null,
        network_insights_access_scope_id: ?[]const u8 = null,
        analysis_start_time_begin: ?i64 = null,
        analysis_start_time_end: ?i64 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis_ids = "NetworkInsightsAccessScopeAnalysisId",
                .network_insights_access_scope_id = "NetworkInsightsAccessScopeId",
                .analysis_start_time_begin = "AnalysisStartTimeBegin",
                .analysis_start_time_end = "AnalysisStartTimeEnd",
                .filters = "Filter",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_insights_access_scope_analyses) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_insights_access_scope_analyses };
        }
    },
    Response: type = struct {
        network_insights_access_scope_analyses: ?[]NetworkInsightsAccessScopeAnalysis = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analyses = "networkInsightsAccessScopeAnalysisSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_insights_access_scopes: struct {
    action_name: []const u8 = "DescribeNetworkInsightsAccessScopes",
    Request: type = struct {
        network_insights_access_scope_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_ids = "NetworkInsightsAccessScopeId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_insights_access_scopes) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_insights_access_scopes };
        }
    },
    Response: type = struct {
        network_insights_access_scopes: ?[]NetworkInsightsAccessScope = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scopes = "networkInsightsAccessScopeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_insights_analyses: struct {
    action_name: []const u8 = "DescribeNetworkInsightsAnalyses",
    Request: type = struct {
        network_insights_analysis_ids: ?[][]const u8 = null,
        network_insights_path_id: ?[]const u8 = null,
        analysis_start_time: ?i64 = null,
        analysis_end_time: ?i64 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_analysis_ids = "NetworkInsightsAnalysisId",
                .network_insights_path_id = "NetworkInsightsPathId",
                .analysis_start_time = "AnalysisStartTime",
                .analysis_end_time = "AnalysisEndTime",
                .filters = "Filter",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_insights_analyses) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_insights_analyses };
        }
    },
    Response: type = struct {
        network_insights_analyses: ?[]NetworkInsightsAnalysis = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_analyses = "networkInsightsAnalysisSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_insights_paths: struct {
    action_name: []const u8 = "DescribeNetworkInsightsPaths",
    Request: type = struct {
        network_insights_path_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_path_ids = "NetworkInsightsPathId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_insights_paths) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_insights_paths };
        }
    },
    Response: type = struct {
        network_insights_paths: ?[]NetworkInsightsPath = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_paths = "networkInsightsPathSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_interface_attribute: struct {
    action_name: []const u8 = "DescribeNetworkInterfaceAttribute",
    Request: type = struct {
        attribute: ?[]const u8 = null,
        dry_run: ?bool = null,
        network_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "attribute",
                .dry_run = "dryRun",
                .network_interface_id = "networkInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_interface_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_interface_attribute };
        }
    },
    Response: type = struct {
        attachment: ?NetworkInterfaceAttachment = null,
        description: ?AttributeValue = null,
        groups: ?[]GroupIdentifier = null,
        network_interface_id: ?[]const u8 = null,
        source_dest_check: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "attachment",
                .description = "description",
                .groups = "groupSet",
                .network_interface_id = "networkInterfaceId",
                .source_dest_check = "sourceDestCheck",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_interface_permissions: struct {
    action_name: []const u8 = "DescribeNetworkInterfacePermissions",
    Request: type = struct {
        network_interface_permission_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_permission_ids = "NetworkInterfacePermissionId",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_interface_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_interface_permissions };
        }
    },
    Response: type = struct {
        network_interface_permissions: ?[]NetworkInterfacePermission = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_permissions = "networkInterfacePermissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_network_interfaces: struct {
    action_name: []const u8 = "DescribeNetworkInterfaces",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        network_interface_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filter",
                .dry_run = "dryRun",
                .network_interface_ids = "NetworkInterfaceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_network_interfaces) } {
            return .{ .service_metadata = service_metadata, .action = describe_network_interfaces };
        }
    },
    Response: type = struct {
        network_interfaces: ?[]NetworkInterface = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interfaces = "networkInterfaceSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_placement_groups: struct {
    action_name: []const u8 = "DescribePlacementGroups",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        group_names: ?[][]const u8 = null,
        group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .group_names = "groupName",
                .group_ids = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_placement_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_placement_groups };
        }
    },
    Response: type = struct {
        placement_groups: ?[]PlacementGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .placement_groups = "placementGroupSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_prefix_lists: struct {
    action_name: []const u8 = "DescribePrefixLists",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        prefix_list_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .prefix_list_ids = "PrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_prefix_lists) } {
            return .{ .service_metadata = service_metadata, .action = describe_prefix_lists };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        prefix_lists: ?[]struct {
            cidrs: ?[][]const u8 = null,
            prefix_list_id: ?[]const u8 = null,
            prefix_list_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cidrs = "cidrSet",
                    .prefix_list_id = "prefixListId",
                    .prefix_list_name = "prefixListName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .prefix_lists = "prefixListSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_principal_id_format: struct {
    action_name: []const u8 = "DescribePrincipalIdFormat",
    Request: type = struct {
        dry_run: ?bool = null,
        resources: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .resources = "Resource",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_principal_id_format) } {
            return .{ .service_metadata = service_metadata, .action = describe_principal_id_format };
        }
    },
    Response: type = struct {
        principals: ?[]struct {
            arn: ?[]const u8 = null,
            statuses: ?[]IdFormat = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .statuses = "statusSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "principalSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_public_ipv4_pools: struct {
    action_name: []const u8 = "DescribePublicIpv4Pools",
    Request: type = struct {
        pool_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_ids = "PoolId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_public_ipv4_pools) } {
            return .{ .service_metadata = service_metadata, .action = describe_public_ipv4_pools };
        }
    },
    Response: type = struct {
        public_ipv4_pools: ?[]struct {
            pool_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            pool_address_ranges: ?[]PublicIpv4PoolRange = null,
            total_address_count: ?i64 = null,
            total_available_address_count: ?i64 = null,
            network_border_group: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_id = "poolId",
                    .description = "description",
                    .pool_address_ranges = "poolAddressRangeSet",
                    .total_address_count = "totalAddressCount",
                    .total_available_address_count = "totalAvailableAddressCount",
                    .network_border_group = "networkBorderGroup",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_ipv4_pools = "publicIpv4PoolSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_regions: struct {
    action_name: []const u8 = "DescribeRegions",
    Request: type = struct {
        filters: ?[]Filter = null,
        region_names: ?[][]const u8 = null,
        dry_run: ?bool = null,
        all_regions: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .region_names = "RegionName",
                .dry_run = "dryRun",
                .all_regions = "AllRegions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_regions) } {
            return .{ .service_metadata = service_metadata, .action = describe_regions };
        }
    },
    Response: type = struct {
        regions: ?[]struct {
            endpoint: ?[]const u8 = null,
            region_name: ?[]const u8 = null,
            opt_in_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint = "regionEndpoint",
                    .region_name = "regionName",
                    .opt_in_status = "optInStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regions = "regionInfo",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_replace_root_volume_tasks: struct {
    action_name: []const u8 = "DescribeReplaceRootVolumeTasks",
    Request: type = struct {
        replace_root_volume_task_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replace_root_volume_task_ids = "ReplaceRootVolumeTaskId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replace_root_volume_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_replace_root_volume_tasks };
        }
    },
    Response: type = struct {
        replace_root_volume_tasks: ?[]ReplaceRootVolumeTask = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replace_root_volume_tasks = "replaceRootVolumeTaskSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_reserved_instances: struct {
    action_name: []const u8 = "DescribeReservedInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        offering_class: ?[]const u8 = null,
        reserved_instances_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        offering_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .offering_class = "OfferingClass",
                .reserved_instances_ids = "ReservedInstancesId",
                .dry_run = "dryRun",
                .offering_type = "offeringType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instances };
        }
    },
    Response: type = struct {
        reserved_instances: ?[]struct {
            availability_zone: ?[]const u8 = null,
            duration: ?i64 = null,
            end: ?i64 = null,
            fixed_price: ?f32 = null,
            instance_count: ?i64 = null,
            instance_type: ?[]const u8 = null,
            product_description: ?[]const u8 = null,
            reserved_instances_id: ?[]const u8 = null,
            start: ?i64 = null,
            state: ?[]const u8 = null,
            usage_price: ?f32 = null,
            currency_code: ?[]const u8 = null,
            instance_tenancy: ?[]const u8 = null,
            offering_class: ?[]const u8 = null,
            offering_type: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,
            scope: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .duration = "duration",
                    .end = "end",
                    .fixed_price = "fixedPrice",
                    .instance_count = "instanceCount",
                    .instance_type = "instanceType",
                    .product_description = "productDescription",
                    .reserved_instances_id = "reservedInstancesId",
                    .start = "start",
                    .state = "state",
                    .usage_price = "usagePrice",
                    .currency_code = "currencyCode",
                    .instance_tenancy = "instanceTenancy",
                    .offering_class = "offeringClass",
                    .offering_type = "offeringType",
                    .recurring_charges = "recurringCharges",
                    .scope = "scope",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances = "reservedInstancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_reserved_instances_listings: struct {
    action_name: []const u8 = "DescribeReservedInstancesListings",
    Request: type = struct {
        filters: ?[]Filter = null,
        reserved_instances_id: ?[]const u8 = null,
        reserved_instances_listing_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .reserved_instances_id = "reservedInstancesId",
                .reserved_instances_listing_id = "reservedInstancesListingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instances_listings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instances_listings };
        }
    },
    Response: type = struct {
        reserved_instances_listings: ?[]ReservedInstancesListing = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_listings = "reservedInstancesListingsSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_reserved_instances_modifications: struct {
    action_name: []const u8 = "DescribeReservedInstancesModifications",
    Request: type = struct {
        filters: ?[]Filter = null,
        reserved_instances_modification_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .reserved_instances_modification_ids = "ReservedInstancesModificationId",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instances_modifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instances_modifications };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_instances_modifications: ?[]struct {
            client_token: ?[]const u8 = null,
            create_date: ?i64 = null,
            effective_date: ?i64 = null,
            modification_results: ?[]struct {
                reserved_instances_id: ?[]const u8 = null,
                target_configuration: ?ReservedInstancesConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reserved_instances_id = "reservedInstancesId",
                        .target_configuration = "targetConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            reserved_instances_ids: ?[]struct {
                reserved_instances_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reserved_instances_id = "reservedInstancesId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            reserved_instances_modification_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            update_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_token = "clientToken",
                    .create_date = "createDate",
                    .effective_date = "effectiveDate",
                    .modification_results = "modificationResultSet",
                    .reserved_instances_ids = "reservedInstancesSet",
                    .reserved_instances_modification_id = "reservedInstancesModificationId",
                    .status = "status",
                    .status_message = "statusMessage",
                    .update_date = "updateDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .reserved_instances_modifications = "reservedInstancesModificationsSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_reserved_instances_offerings: struct {
    action_name: []const u8 = "DescribeReservedInstancesOfferings",
    Request: type = struct {
        availability_zone: ?[]const u8 = null,
        filters: ?[]Filter = null,
        include_marketplace: ?bool = null,
        instance_type: ?[]const u8 = null,
        max_duration: ?i64 = null,
        max_instance_count: ?i64 = null,
        min_duration: ?i64 = null,
        offering_class: ?[]const u8 = null,
        product_description: ?[]const u8 = null,
        reserved_instances_offering_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        instance_tenancy: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "AvailabilityZone",
                .filters = "Filter",
                .include_marketplace = "IncludeMarketplace",
                .instance_type = "InstanceType",
                .max_duration = "MaxDuration",
                .max_instance_count = "MaxInstanceCount",
                .min_duration = "MinDuration",
                .offering_class = "OfferingClass",
                .product_description = "ProductDescription",
                .reserved_instances_offering_ids = "ReservedInstancesOfferingId",
                .dry_run = "dryRun",
                .instance_tenancy = "instanceTenancy",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .offering_type = "offeringType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instances_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instances_offerings };
        }
    },
    Response: type = struct {
        reserved_instances_offerings: ?[]struct {
            availability_zone: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f32 = null,
            instance_type: ?[]const u8 = null,
            product_description: ?[]const u8 = null,
            reserved_instances_offering_id: ?[]const u8 = null,
            usage_price: ?f32 = null,
            currency_code: ?[]const u8 = null,
            instance_tenancy: ?[]const u8 = null,
            marketplace: ?bool = null,
            offering_class: ?[]const u8 = null,
            offering_type: ?[]const u8 = null,
            pricing_details: ?[]struct {
                count: ?i64 = null,
                price: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .count = "count",
                        .price = "price",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recurring_charges: ?[]RecurringCharge = null,
            scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .duration = "duration",
                    .fixed_price = "fixedPrice",
                    .instance_type = "instanceType",
                    .product_description = "productDescription",
                    .reserved_instances_offering_id = "reservedInstancesOfferingId",
                    .usage_price = "usagePrice",
                    .currency_code = "currencyCode",
                    .instance_tenancy = "instanceTenancy",
                    .marketplace = "marketplace",
                    .offering_class = "offeringClass",
                    .offering_type = "offeringType",
                    .pricing_details = "pricingDetailsSet",
                    .recurring_charges = "recurringCharges",
                    .scope = "scope",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_offerings = "reservedInstancesOfferingsSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_route_tables: struct {
    action_name: []const u8 = "DescribeRouteTables",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        route_table_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .route_table_ids = "RouteTableId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_route_tables) } {
            return .{ .service_metadata = service_metadata, .action = describe_route_tables };
        }
    },
    Response: type = struct {
        route_tables: ?[]RouteTable = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_tables = "routeTableSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_scheduled_instance_availability: struct {
    action_name: []const u8 = "DescribeScheduledInstanceAvailability",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        first_slot_start_time_range: struct {
            earliest_time: i64,
            latest_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .earliest_time = "EarliestTime",
                    .latest_time = "LatestTime",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        max_slot_duration_in_hours: ?i64 = null,
        min_slot_duration_in_hours: ?i64 = null,
        next_token: ?[]const u8 = null,
        recurrence: struct {
            frequency: ?[]const u8 = null,
            interval: ?i64 = null,
            occurrence_days: ?[]i64 = null,
            occurrence_relative_to_end: ?bool = null,
            occurrence_unit: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .frequency = "Frequency",
                    .interval = "Interval",
                    .occurrence_days = "OccurrenceDay",
                    .occurrence_relative_to_end = "OccurrenceRelativeToEnd",
                    .occurrence_unit = "OccurrenceUnit",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .first_slot_start_time_range = "FirstSlotStartTimeRange",
                .max_results = "MaxResults",
                .max_slot_duration_in_hours = "MaxSlotDurationInHours",
                .min_slot_duration_in_hours = "MinSlotDurationInHours",
                .next_token = "NextToken",
                .recurrence = "Recurrence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_instance_availability) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_instance_availability };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        scheduled_instance_availability_set: ?[]struct {
            availability_zone: ?[]const u8 = null,
            available_instance_count: ?i64 = null,
            first_slot_start_time: ?i64 = null,
            hourly_price: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            max_term_duration_in_days: ?i64 = null,
            min_term_duration_in_days: ?i64 = null,
            network_platform: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            purchase_token: ?[]const u8 = null,
            recurrence: ?ScheduledInstanceRecurrence = null,
            slot_duration_in_hours: ?i64 = null,
            total_scheduled_instance_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .available_instance_count = "availableInstanceCount",
                    .first_slot_start_time = "firstSlotStartTime",
                    .hourly_price = "hourlyPrice",
                    .instance_type = "instanceType",
                    .max_term_duration_in_days = "maxTermDurationInDays",
                    .min_term_duration_in_days = "minTermDurationInDays",
                    .network_platform = "networkPlatform",
                    .platform = "platform",
                    .purchase_token = "purchaseToken",
                    .recurrence = "recurrence",
                    .slot_duration_in_hours = "slotDurationInHours",
                    .total_scheduled_instance_hours = "totalScheduledInstanceHours",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .scheduled_instance_availability_set = "scheduledInstanceAvailabilitySet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_scheduled_instances: struct {
    action_name: []const u8 = "DescribeScheduledInstances",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        scheduled_instance_ids: ?[][]const u8 = null,
        slot_start_time_range: ?struct {
            earliest_time: ?i64 = null,
            latest_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .earliest_time = "EarliestTime",
                    .latest_time = "LatestTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .scheduled_instance_ids = "ScheduledInstanceId",
                .slot_start_time_range = "SlotStartTimeRange",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        scheduled_instance_set: ?[]ScheduledInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .scheduled_instance_set = "scheduledInstanceSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_security_group_references: struct {
    action_name: []const u8 = "DescribeSecurityGroupReferences",
    Request: type = struct {
        dry_run: ?bool = null,
        group_id: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_group_references) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_group_references };
        }
    },
    Response: type = struct {
        security_group_reference_set: ?[]struct {
            group_id: ?[]const u8 = null,
            referencing_vpc_id: ?[]const u8 = null,
            vpc_peering_connection_id: ?[]const u8 = null,
            transit_gateway_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "groupId",
                    .referencing_vpc_id = "referencingVpcId",
                    .vpc_peering_connection_id = "vpcPeeringConnectionId",
                    .transit_gateway_id = "transitGatewayId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group_reference_set = "securityGroupReferenceSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_security_group_rules: struct {
    action_name: []const u8 = "DescribeSecurityGroupRules",
    Request: type = struct {
        filters: ?[]Filter = null,
        security_group_rule_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .security_group_rule_ids = "SecurityGroupRuleId",
                .dry_run = "DryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_group_rules) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_group_rules };
        }
    },
    Response: type = struct {
        security_group_rules: ?[]SecurityGroupRule = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group_rules = "securityGroupRuleSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_security_groups: struct {
    action_name: []const u8 = "DescribeSecurityGroups",
    Request: type = struct {
        filters: ?[]Filter = null,
        group_ids: ?[][]const u8 = null,
        group_names: ?[][]const u8 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .group_ids = "GroupId",
                .group_names = "GroupName",
                .dry_run = "dryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_groups };
        }
    },
    Response: type = struct {
        security_groups: ?[]struct {
            description: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            ip_permissions: ?[]IpPermission = null,
            owner_id: ?[]const u8 = null,
            group_id: ?[]const u8 = null,
            ip_permissions_egress: ?[]IpPermission = null,
            tags: ?[]Tag = null,
            vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "groupDescription",
                    .group_name = "groupName",
                    .ip_permissions = "ipPermissions",
                    .owner_id = "ownerId",
                    .group_id = "groupId",
                    .ip_permissions_egress = "ipPermissionsEgress",
                    .tags = "tagSet",
                    .vpc_id = "vpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_groups = "securityGroupInfo",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_snapshot_attribute: struct {
    action_name: []const u8 = "DescribeSnapshotAttribute",
    Request: type = struct {
        attribute: []const u8,
        snapshot_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .snapshot_id = "SnapshotId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshot_attribute };
        }
    },
    Response: type = struct {
        create_volume_permissions: ?[]CreateVolumePermission = null,
        product_codes: ?[]ProductCode = null,
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_volume_permissions = "createVolumePermission",
                .product_codes = "productCodes",
                .snapshot_id = "snapshotId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_snapshots: struct {
    action_name: []const u8 = "DescribeSnapshots",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        owner_ids: ?[][]const u8 = null,
        restorable_by_user_ids: ?[][]const u8 = null,
        snapshot_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .owner_ids = "Owner",
                .restorable_by_user_ids = "RestorableBy",
                .snapshot_ids = "SnapshotId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshots };
        }
    },
    Response: type = struct {
        snapshots: ?[]Snapshot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "snapshotSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_snapshot_tier_status: struct {
    action_name: []const u8 = "DescribeSnapshotTierStatus",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "DryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshot_tier_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshot_tier_status };
        }
    },
    Response: type = struct {
        snapshot_tier_statuses: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            volume_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            storage_tier: ?[]const u8 = null,
            last_tiering_start_time: ?i64 = null,
            last_tiering_progress: ?i64 = null,
            last_tiering_operation_status: ?[]const u8 = null,
            last_tiering_operation_status_detail: ?[]const u8 = null,
            archival_complete_time: ?i64 = null,
            restore_expiry_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .volume_id = "volumeId",
                    .status = "status",
                    .owner_id = "ownerId",
                    .tags = "tagSet",
                    .storage_tier = "storageTier",
                    .last_tiering_start_time = "lastTieringStartTime",
                    .last_tiering_progress = "lastTieringProgress",
                    .last_tiering_operation_status = "lastTieringOperationStatus",
                    .last_tiering_operation_status_detail = "lastTieringOperationStatusDetail",
                    .archival_complete_time = "archivalCompleteTime",
                    .restore_expiry_time = "restoreExpiryTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_tier_statuses = "snapshotTierStatusSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_datafeed_subscription: struct {
    action_name: []const u8 = "DescribeSpotDatafeedSubscription",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_datafeed_subscription) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_datafeed_subscription };
        }
    },
    Response: type = struct {
        spot_datafeed_subscription: ?SpotDatafeedSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_datafeed_subscription = "spotDatafeedSubscription",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_fleet_instances: struct {
    action_name: []const u8 = "DescribeSpotFleetInstances",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        spot_fleet_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .spot_fleet_request_id = "spotFleetRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_fleet_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_fleet_instances };
        }
    },
    Response: type = struct {
        active_instances: ?[]ActiveInstance = null,
        next_token: ?[]const u8 = null,
        spot_fleet_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_instances = "activeInstanceSet",
                .next_token = "nextToken",
                .spot_fleet_request_id = "spotFleetRequestId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_fleet_request_history: struct {
    action_name: []const u8 = "DescribeSpotFleetRequestHistory",
    Request: type = struct {
        dry_run: ?bool = null,
        event_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        spot_fleet_request_id: []const u8,
        start_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .event_type = "eventType",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .spot_fleet_request_id = "spotFleetRequestId",
                .start_time = "startTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_fleet_request_history) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_fleet_request_history };
        }
    },
    Response: type = struct {
        history_records: ?[]struct {
            event_information: ?EventInformation = null,
            event_type: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_information = "eventInformation",
                    .event_type = "eventType",
                    .timestamp = "timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_evaluated_time: ?i64 = null,
        next_token: ?[]const u8 = null,
        spot_fleet_request_id: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history_records = "historyRecordSet",
                .last_evaluated_time = "lastEvaluatedTime",
                .next_token = "nextToken",
                .spot_fleet_request_id = "spotFleetRequestId",
                .start_time = "startTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_fleet_requests: struct {
    action_name: []const u8 = "DescribeSpotFleetRequests",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        spot_fleet_request_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .spot_fleet_request_ids = "spotFleetRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_fleet_requests) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_fleet_requests };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        spot_fleet_request_configs: ?[]struct {
            activity_status: ?[]const u8 = null,
            create_time: ?i64 = null,
            spot_fleet_request_config: ?SpotFleetRequestConfigData = null,
            spot_fleet_request_id: ?[]const u8 = null,
            spot_fleet_request_state: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_status = "activityStatus",
                    .create_time = "createTime",
                    .spot_fleet_request_config = "spotFleetRequestConfig",
                    .spot_fleet_request_id = "spotFleetRequestId",
                    .spot_fleet_request_state = "spotFleetRequestState",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .spot_fleet_request_configs = "spotFleetRequestConfigSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_instance_requests: struct {
    action_name: []const u8 = "DescribeSpotInstanceRequests",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        spot_instance_request_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .spot_instance_request_ids = "SpotInstanceRequestId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_instance_requests) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_instance_requests };
        }
    },
    Response: type = struct {
        spot_instance_requests: ?[]SpotInstanceRequest = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_instance_requests = "spotInstanceRequestSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_spot_price_history: struct {
    action_name: []const u8 = "DescribeSpotPriceHistory",
    Request: type = struct {
        filters: ?[]Filter = null,
        availability_zone: ?[]const u8 = null,
        dry_run: ?bool = null,
        end_time: ?i64 = null,
        instance_types: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        product_descriptions: ?[][]const u8 = null,
        start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .availability_zone = "availabilityZone",
                .dry_run = "dryRun",
                .end_time = "endTime",
                .instance_types = "InstanceType",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .product_descriptions = "ProductDescription",
                .start_time = "startTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spot_price_history) } {
            return .{ .service_metadata = service_metadata, .action = describe_spot_price_history };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        spot_price_history: ?[]struct {
            availability_zone: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            product_description: ?[]const u8 = null,
            spot_price: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .instance_type = "instanceType",
                    .product_description = "productDescription",
                    .spot_price = "spotPrice",
                    .timestamp = "timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .spot_price_history = "spotPriceHistorySet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_stale_security_groups: struct {
    action_name: []const u8 = "DescribeStaleSecurityGroups",
    Request: type = struct {
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .vpc_id = "VpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stale_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_stale_security_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        stale_security_group_set: ?[]struct {
            description: ?[]const u8 = null,
            group_id: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            stale_ip_permissions: ?[]StaleIpPermission = null,
            stale_ip_permissions_egress: ?[]StaleIpPermission = null,
            vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "description",
                    .group_id = "groupId",
                    .group_name = "groupName",
                    .stale_ip_permissions = "staleIpPermissions",
                    .stale_ip_permissions_egress = "staleIpPermissionsEgress",
                    .vpc_id = "vpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .stale_security_group_set = "staleSecurityGroupSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_store_image_tasks: struct {
    action_name: []const u8 = "DescribeStoreImageTasks",
    Request: type = struct {
        image_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "ImageId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_store_image_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_store_image_tasks };
        }
    },
    Response: type = struct {
        store_image_task_results: ?[]struct {
            ami_id: ?[]const u8 = null,
            task_start_time: ?i64 = null,
            bucket: ?[]const u8 = null,
            s3object_key: ?[]const u8 = null,
            progress_percentage: ?i64 = null,
            store_task_state: ?[]const u8 = null,
            store_task_failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ami_id = "amiId",
                    .task_start_time = "taskStartTime",
                    .bucket = "bucket",
                    .s3object_key = "s3objectKey",
                    .progress_percentage = "progressPercentage",
                    .store_task_state = "storeTaskState",
                    .store_task_failure_reason = "storeTaskFailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .store_image_task_results = "storeImageTaskResultSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_subnets: struct {
    action_name: []const u8 = "DescribeSubnets",
    Request: type = struct {
        filters: ?[]Filter = null,
        subnet_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .subnet_ids = "SubnetId",
                .dry_run = "dryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_subnets) } {
            return .{ .service_metadata = service_metadata, .action = describe_subnets };
        }
    },
    Response: type = struct {
        subnets: ?[]Subnet = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnets = "subnetSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .filters = "Filter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .resource_id = "resourceId",
                    .resource_type = "resourceType",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_traffic_mirror_filters: struct {
    action_name: []const u8 = "DescribeTrafficMirrorFilters",
    Request: type = struct {
        traffic_mirror_filter_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_ids = "TrafficMirrorFilterId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_traffic_mirror_filters) } {
            return .{ .service_metadata = service_metadata, .action = describe_traffic_mirror_filters };
        }
    },
    Response: type = struct {
        traffic_mirror_filters: ?[]TrafficMirrorFilter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filters = "trafficMirrorFilterSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_traffic_mirror_sessions: struct {
    action_name: []const u8 = "DescribeTrafficMirrorSessions",
    Request: type = struct {
        traffic_mirror_session_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session_ids = "TrafficMirrorSessionId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_traffic_mirror_sessions) } {
            return .{ .service_metadata = service_metadata, .action = describe_traffic_mirror_sessions };
        }
    },
    Response: type = struct {
        traffic_mirror_sessions: ?[]TrafficMirrorSession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_sessions = "trafficMirrorSessionSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_traffic_mirror_targets: struct {
    action_name: []const u8 = "DescribeTrafficMirrorTargets",
    Request: type = struct {
        traffic_mirror_target_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_target_ids = "TrafficMirrorTargetId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_traffic_mirror_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_traffic_mirror_targets };
        }
    },
    Response: type = struct {
        traffic_mirror_targets: ?[]TrafficMirrorTarget = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_targets = "trafficMirrorTargetSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_attachments: struct {
    action_name: []const u8 = "DescribeTransitGatewayAttachments",
    Request: type = struct {
        transit_gateway_attachment_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_ids = "TransitGatewayAttachmentIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_attachments) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_attachments };
        }
    },
    Response: type = struct {
        transit_gateway_attachments: ?[]struct {
            transit_gateway_attachment_id: ?[]const u8 = null,
            transit_gateway_id: ?[]const u8 = null,
            transit_gateway_owner_id: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            association: ?struct {
                transit_gateway_route_table_id: ?[]const u8 = null,
                state: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transit_gateway_route_table_id = "transitGatewayRouteTableId",
                        .state = "state",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            creation_time: ?i64 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_attachment_id = "transitGatewayAttachmentId",
                    .transit_gateway_id = "transitGatewayId",
                    .transit_gateway_owner_id = "transitGatewayOwnerId",
                    .resource_owner_id = "resourceOwnerId",
                    .resource_type = "resourceType",
                    .resource_id = "resourceId",
                    .state = "state",
                    .association = "association",
                    .creation_time = "creationTime",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachments = "transitGatewayAttachments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_connect_peers: struct {
    action_name: []const u8 = "DescribeTransitGatewayConnectPeers",
    Request: type = struct {
        transit_gateway_connect_peer_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_ids = "TransitGatewayConnectPeerIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_connect_peers) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_connect_peers };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peers: ?[]TransitGatewayConnectPeer = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peers = "transitGatewayConnectPeerSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_connects: struct {
    action_name: []const u8 = "DescribeTransitGatewayConnects",
    Request: type = struct {
        transit_gateway_attachment_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_ids = "TransitGatewayAttachmentIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_connects) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_connects };
        }
    },
    Response: type = struct {
        transit_gateway_connects: ?[]TransitGatewayConnect = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connects = "transitGatewayConnectSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_multicast_domains: struct {
    action_name: []const u8 = "DescribeTransitGatewayMulticastDomains",
    Request: type = struct {
        transit_gateway_multicast_domain_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_ids = "TransitGatewayMulticastDomainIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_multicast_domains) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_multicast_domains };
        }
    },
    Response: type = struct {
        transit_gateway_multicast_domains: ?[]TransitGatewayMulticastDomain = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domains = "transitGatewayMulticastDomains",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_peering_attachments: struct {
    action_name: []const u8 = "DescribeTransitGatewayPeeringAttachments",
    Request: type = struct {
        transit_gateway_attachment_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_ids = "TransitGatewayAttachmentIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_peering_attachments) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_peering_attachments };
        }
    },
    Response: type = struct {
        transit_gateway_peering_attachments: ?[]TransitGatewayPeeringAttachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering_attachments = "transitGatewayPeeringAttachments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_policy_tables: struct {
    action_name: []const u8 = "DescribeTransitGatewayPolicyTables",
    Request: type = struct {
        transit_gateway_policy_table_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_ids = "TransitGatewayPolicyTableIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_policy_tables) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_policy_tables };
        }
    },
    Response: type = struct {
        transit_gateway_policy_tables: ?[]TransitGatewayPolicyTable = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_tables = "transitGatewayPolicyTables",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_route_table_announcements: struct {
    action_name: []const u8 = "DescribeTransitGatewayRouteTableAnnouncements",
    Request: type = struct {
        transit_gateway_route_table_announcement_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_announcement_ids = "TransitGatewayRouteTableAnnouncementIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_route_table_announcements) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_route_table_announcements };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_announcements: ?[]TransitGatewayRouteTableAnnouncement = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_announcements = "transitGatewayRouteTableAnnouncements",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_route_tables: struct {
    action_name: []const u8 = "DescribeTransitGatewayRouteTables",
    Request: type = struct {
        transit_gateway_route_table_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_ids = "TransitGatewayRouteTableIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_route_tables) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_route_tables };
        }
    },
    Response: type = struct {
        transit_gateway_route_tables: ?[]TransitGatewayRouteTable = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_tables = "transitGatewayRouteTables",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateways: struct {
    action_name: []const u8 = "DescribeTransitGateways",
    Request: type = struct {
        transit_gateway_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_ids = "TransitGatewayIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateways };
        }
    },
    Response: type = struct {
        transit_gateways: ?[]TransitGateway = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateways = "transitGatewaySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_transit_gateway_vpc_attachments: struct {
    action_name: []const u8 = "DescribeTransitGatewayVpcAttachments",
    Request: type = struct {
        transit_gateway_attachment_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_ids = "TransitGatewayAttachmentIds",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transit_gateway_vpc_attachments) } {
            return .{ .service_metadata = service_metadata, .action = describe_transit_gateway_vpc_attachments };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachments: ?[]TransitGatewayVpcAttachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachments = "transitGatewayVpcAttachments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_trunk_interface_associations: struct {
    action_name: []const u8 = "DescribeTrunkInterfaceAssociations",
    Request: type = struct {
        association_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_ids = "AssociationId",
                .dry_run = "DryRun",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trunk_interface_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_trunk_interface_associations };
        }
    },
    Response: type = struct {
        interface_associations: ?[]TrunkInterfaceAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .interface_associations = "interfaceAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_verified_access_endpoints: struct {
    action_name: []const u8 = "DescribeVerifiedAccessEndpoints",
    Request: type = struct {
        verified_access_endpoint_ids: ?[][]const u8 = null,
        verified_access_instance_id: ?[]const u8 = null,
        verified_access_group_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint_ids = "VerifiedAccessEndpointId",
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .verified_access_group_id = "VerifiedAccessGroupId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_access_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_access_endpoints };
        }
    },
    Response: type = struct {
        verified_access_endpoints: ?[]VerifiedAccessEndpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoints = "verifiedAccessEndpointSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_verified_access_groups: struct {
    action_name: []const u8 = "DescribeVerifiedAccessGroups",
    Request: type = struct {
        verified_access_group_ids: ?[][]const u8 = null,
        verified_access_instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_ids = "VerifiedAccessGroupId",
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_access_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_access_groups };
        }
    },
    Response: type = struct {
        verified_access_groups: ?[]VerifiedAccessGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_groups = "verifiedAccessGroupSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_verified_access_instance_logging_configurations: struct {
    action_name: []const u8 = "DescribeVerifiedAccessInstanceLoggingConfigurations",
    Request: type = struct {
        verified_access_instance_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_ids = "VerifiedAccessInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_access_instance_logging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_access_instance_logging_configurations };
        }
    },
    Response: type = struct {
        logging_configurations: ?[]VerifiedAccessInstanceLoggingConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configurations = "loggingConfigurationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_verified_access_instances: struct {
    action_name: []const u8 = "DescribeVerifiedAccessInstances",
    Request: type = struct {
        verified_access_instance_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_ids = "VerifiedAccessInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_access_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_access_instances };
        }
    },
    Response: type = struct {
        verified_access_instances: ?[]VerifiedAccessInstance = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instances = "verifiedAccessInstanceSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_verified_access_trust_providers: struct {
    action_name: []const u8 = "DescribeVerifiedAccessTrustProviders",
    Request: type = struct {
        verified_access_trust_provider_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider_ids = "VerifiedAccessTrustProviderId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_access_trust_providers) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_access_trust_providers };
        }
    },
    Response: type = struct {
        verified_access_trust_providers: ?[]VerifiedAccessTrustProvider = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_providers = "verifiedAccessTrustProviderSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_volume_attribute: struct {
    action_name: []const u8 = "DescribeVolumeAttribute",
    Request: type = struct {
        attribute: []const u8,
        volume_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .volume_id = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_volume_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_volume_attribute };
        }
    },
    Response: type = struct {
        auto_enable_io: ?AttributeBooleanValue = null,
        product_codes: ?[]ProductCode = null,
        volume_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable_io = "autoEnableIO",
                .product_codes = "productCodes",
                .volume_id = "volumeId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_volumes: struct {
    action_name: []const u8 = "DescribeVolumes",
    Request: type = struct {
        filters: ?[]Filter = null,
        volume_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .volume_ids = "VolumeId",
                .dry_run = "dryRun",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_volumes) } {
            return .{ .service_metadata = service_metadata, .action = describe_volumes };
        }
    },
    Response: type = struct {
        volumes: ?[]Volume = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volumes = "volumeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_volumes_modifications: struct {
    action_name: []const u8 = "DescribeVolumesModifications",
    Request: type = struct {
        dry_run: ?bool = null,
        volume_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .volume_ids = "VolumeId",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_volumes_modifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_volumes_modifications };
        }
    },
    Response: type = struct {
        volumes_modifications: ?[]VolumeModification = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volumes_modifications = "volumeModificationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_volume_status: struct {
    action_name: []const u8 = "DescribeVolumeStatus",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        volume_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .volume_ids = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_volume_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_volume_status };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        volume_statuses: ?[]struct {
            actions: ?[]struct {
                code: ?[]const u8 = null,
                description: ?[]const u8 = null,
                event_id: ?[]const u8 = null,
                event_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .description = "description",
                        .event_id = "eventId",
                        .event_type = "eventType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            availability_zone: ?[]const u8 = null,
            outpost_arn: ?[]const u8 = null,
            events: ?[]struct {
                description: ?[]const u8 = null,
                event_id: ?[]const u8 = null,
                event_type: ?[]const u8 = null,
                not_after: ?i64 = null,
                not_before: ?i64 = null,
                instance_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "description",
                        .event_id = "eventId",
                        .event_type = "eventType",
                        .not_after = "notAfter",
                        .not_before = "notBefore",
                        .instance_id = "instanceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            volume_id: ?[]const u8 = null,
            volume_status: ?struct {
                details: ?[]struct {
                    name: ?[]const u8 = null,
                    status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .status = "status",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .details = "details",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attachment_statuses: ?[]struct {
                io_performance: ?[]const u8 = null,
                instance_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .io_performance = "ioPerformance",
                        .instance_id = "instanceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .actions = "actionsSet",
                    .availability_zone = "availabilityZone",
                    .outpost_arn = "outpostArn",
                    .events = "eventsSet",
                    .volume_id = "volumeId",
                    .volume_status = "volumeStatus",
                    .attachment_statuses = "attachmentStatuses",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .volume_statuses = "volumeStatusSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_attribute: struct {
    action_name: []const u8 = "DescribeVpcAttribute",
    Request: type = struct {
        attribute: []const u8,
        vpc_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .vpc_id = "VpcId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_attribute };
        }
    },
    Response: type = struct {
        vpc_id: ?[]const u8 = null,
        enable_dns_hostnames: ?AttributeBooleanValue = null,
        enable_dns_support: ?AttributeBooleanValue = null,
        enable_network_address_usage_metrics: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "vpcId",
                .enable_dns_hostnames = "enableDnsHostnames",
                .enable_dns_support = "enableDnsSupport",
                .enable_network_address_usage_metrics = "enableNetworkAddressUsageMetrics",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_classic_link: struct {
    action_name: []const u8 = "DescribeVpcClassicLink",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        vpc_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .vpc_ids = "VpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_classic_link) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_classic_link };
        }
    },
    Response: type = struct {
        vpcs: ?[]struct {
            classic_link_enabled: ?bool = null,
            tags: ?[]Tag = null,
            vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classic_link_enabled = "classicLinkEnabled",
                    .tags = "tagSet",
                    .vpc_id = "vpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpcs = "vpcSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_classic_link_dns_support: struct {
    action_name: []const u8 = "DescribeVpcClassicLinkDnsSupport",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        vpc_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .vpc_ids = "VpcIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_classic_link_dns_support) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_classic_link_dns_support };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        vpcs: ?[]struct {
            classic_link_dns_supported: ?bool = null,
            vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classic_link_dns_supported = "classicLinkDnsSupported",
                    .vpc_id = "vpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .vpcs = "vpcs",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoint_connection_notifications: struct {
    action_name: []const u8 = "DescribeVpcEndpointConnectionNotifications",
    Request: type = struct {
        dry_run: ?bool = null,
        connection_notification_id: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .connection_notification_id = "ConnectionNotificationId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoint_connection_notifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoint_connection_notifications };
        }
    },
    Response: type = struct {
        connection_notification_set: ?[]ConnectionNotification = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_notification_set = "connectionNotificationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoint_connections: struct {
    action_name: []const u8 = "DescribeVpcEndpointConnections",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoint_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoint_connections };
        }
    },
    Response: type = struct {
        vpc_endpoint_connections: ?[]struct {
            service_id: ?[]const u8 = null,
            vpc_endpoint_id: ?[]const u8 = null,
            vpc_endpoint_owner: ?[]const u8 = null,
            vpc_endpoint_state: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            dns_entries: ?[]DnsEntry = null,
            network_load_balancer_arns: ?[][]const u8 = null,
            gateway_load_balancer_arns: ?[][]const u8 = null,
            ip_address_type: ?[]const u8 = null,
            vpc_endpoint_connection_id: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_id = "serviceId",
                    .vpc_endpoint_id = "vpcEndpointId",
                    .vpc_endpoint_owner = "vpcEndpointOwner",
                    .vpc_endpoint_state = "vpcEndpointState",
                    .creation_timestamp = "creationTimestamp",
                    .dns_entries = "dnsEntrySet",
                    .network_load_balancer_arns = "networkLoadBalancerArnSet",
                    .gateway_load_balancer_arns = "gatewayLoadBalancerArnSet",
                    .ip_address_type = "ipAddressType",
                    .vpc_endpoint_connection_id = "vpcEndpointConnectionId",
                    .tags = "tagSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_connections = "vpcEndpointConnectionSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoints: struct {
    action_name: []const u8 = "DescribeVpcEndpoints",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_endpoint_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .vpc_endpoint_ids = "VpcEndpointId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoints };
        }
    },
    Response: type = struct {
        vpc_endpoints: ?[]VpcEndpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoints = "vpcEndpointSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoint_service_configurations: struct {
    action_name: []const u8 = "DescribeVpcEndpointServiceConfigurations",
    Request: type = struct {
        dry_run: ?bool = null,
        service_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_ids = "ServiceId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoint_service_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoint_service_configurations };
        }
    },
    Response: type = struct {
        service_configurations: ?[]ServiceConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_configurations = "serviceConfigurationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoint_service_permissions: struct {
    action_name: []const u8 = "DescribeVpcEndpointServicePermissions",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoint_service_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoint_service_permissions };
        }
    },
    Response: type = struct {
        allowed_principals: ?[]struct {
            principal_type: ?[]const u8 = null,
            principal: ?[]const u8 = null,
            service_permission_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            service_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_type = "principalType",
                    .principal = "principal",
                    .service_permission_id = "servicePermissionId",
                    .tags = "tagSet",
                    .service_id = "serviceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allowed_principals = "allowedPrincipals",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_endpoint_services: struct {
    action_name: []const u8 = "DescribeVpcEndpointServices",
    Request: type = struct {
        dry_run: ?bool = null,
        service_names: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_names = "ServiceName",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoint_services) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoint_services };
        }
    },
    Response: type = struct {
        service_names: ?[][]const u8 = null,
        service_details: ?[]struct {
            service_name: ?[]const u8 = null,
            service_id: ?[]const u8 = null,
            service_type: ?[]ServiceTypeDetail = null,
            availability_zones: ?[][]const u8 = null,
            owner: ?[]const u8 = null,
            base_endpoint_dns_names: ?[][]const u8 = null,
            private_dns_name: ?[]const u8 = null,
            private_dns_names: ?[]struct {
                private_dns_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .private_dns_name = "privateDnsName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vpc_endpoint_policy_supported: ?bool = null,
            acceptance_required: ?bool = null,
            manages_vpc_endpoints: ?bool = null,
            payer_responsibility: ?[]const u8 = null,
            tags: ?[]Tag = null,
            private_dns_name_verification_state: ?[]const u8 = null,
            supported_ip_address_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_name = "serviceName",
                    .service_id = "serviceId",
                    .service_type = "serviceType",
                    .availability_zones = "availabilityZoneSet",
                    .owner = "owner",
                    .base_endpoint_dns_names = "baseEndpointDnsNameSet",
                    .private_dns_name = "privateDnsName",
                    .private_dns_names = "privateDnsNameSet",
                    .vpc_endpoint_policy_supported = "vpcEndpointPolicySupported",
                    .acceptance_required = "acceptanceRequired",
                    .manages_vpc_endpoints = "managesVpcEndpoints",
                    .payer_responsibility = "payerResponsibility",
                    .tags = "tagSet",
                    .private_dns_name_verification_state = "privateDnsNameVerificationState",
                    .supported_ip_address_types = "supportedIpAddressTypeSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_names = "serviceNameSet",
                .service_details = "serviceDetailSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpc_peering_connections: struct {
    action_name: []const u8 = "DescribeVpcPeeringConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        dry_run: ?bool = null,
        vpc_peering_connection_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .dry_run = "dryRun",
                .vpc_peering_connection_ids = "VpcPeeringConnectionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_peering_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_peering_connections };
        }
    },
    Response: type = struct {
        vpc_peering_connections: ?[]VpcPeeringConnection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_peering_connections = "vpcPeeringConnectionSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpcs: struct {
    action_name: []const u8 = "DescribeVpcs",
    Request: type = struct {
        filters: ?[]Filter = null,
        vpc_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .vpc_ids = "VpcId",
                .dry_run = "dryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpcs) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpcs };
        }
    },
    Response: type = struct {
        vpcs: ?[]Vpc = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpcs = "vpcSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpn_connections: struct {
    action_name: []const u8 = "DescribeVpnConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        vpn_connection_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .vpn_connection_ids = "VpnConnectionId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpn_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpn_connections };
        }
    },
    Response: type = struct {
        vpn_connections: ?[]VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connections = "vpnConnectionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_vpn_gateways: struct {
    action_name: []const u8 = "DescribeVpnGateways",
    Request: type = struct {
        filters: ?[]Filter = null,
        vpn_gateway_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .vpn_gateway_ids = "VpnGatewayId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpn_gateways) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpn_gateways };
        }
    },
    Response: type = struct {
        vpn_gateways: ?[]VpnGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_gateways = "vpnGatewaySet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const detach_classic_link_vpc: struct {
    action_name: []const u8 = "DetachClassicLinkVpc",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_id: []const u8,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .instance_id = "instanceId",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_classic_link_vpc) } {
            return .{ .service_metadata = service_metadata, .action = detach_classic_link_vpc };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const detach_internet_gateway: struct {
    action_name: []const u8 = "DetachInternetGateway",
    Request: type = struct {
        dry_run: ?bool = null,
        internet_gateway_id: []const u8,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .internet_gateway_id = "internetGatewayId",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_internet_gateway) } {
            return .{ .service_metadata = service_metadata, .action = detach_internet_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const detach_network_interface: struct {
    action_name: []const u8 = "DetachNetworkInterface",
    Request: type = struct {
        attachment_id: []const u8,
        dry_run: ?bool = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "attachmentId",
                .dry_run = "dryRun",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_network_interface) } {
            return .{ .service_metadata = service_metadata, .action = detach_network_interface };
        }
    },
    Response: type = struct {},
} = .{};
pub const detach_verified_access_trust_provider: struct {
    action_name: []const u8 = "DetachVerifiedAccessTrustProvider",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        verified_access_trust_provider_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .verified_access_trust_provider_id = "VerifiedAccessTrustProviderId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_verified_access_trust_provider) } {
            return .{ .service_metadata = service_metadata, .action = detach_verified_access_trust_provider };
        }
    },
    Response: type = struct {
        verified_access_trust_provider: ?VerifiedAccessTrustProvider = null,
        verified_access_instance: ?VerifiedAccessInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider = "verifiedAccessTrustProvider",
                .verified_access_instance = "verifiedAccessInstance",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const detach_volume: struct {
    action_name: []const u8 = "DetachVolume",
    Request: type = struct {
        device: ?[]const u8 = null,
        force: ?bool = null,
        instance_id: ?[]const u8 = null,
        volume_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
                .force = "Force",
                .instance_id = "InstanceId",
                .volume_id = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_volume) } {
            return .{ .service_metadata = service_metadata, .action = detach_volume };
        }
    },
    Response: type = struct {
        attach_time: ?i64 = null,
        device: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        volume_id: ?[]const u8 = null,
        delete_on_termination: ?bool = null,
        associated_resource: ?[]const u8 = null,
        instance_owning_service: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attach_time = "attachTime",
                .device = "device",
                .instance_id = "instanceId",
                .state = "status",
                .volume_id = "volumeId",
                .delete_on_termination = "deleteOnTermination",
                .associated_resource = "associatedResource",
                .instance_owning_service = "instanceOwningService",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const detach_vpn_gateway: struct {
    action_name: []const u8 = "DetachVpnGateway",
    Request: type = struct {
        vpc_id: []const u8,
        vpn_gateway_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .vpn_gateway_id = "VpnGatewayId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_vpn_gateway) } {
            return .{ .service_metadata = service_metadata, .action = detach_vpn_gateway };
        }
    },
    Response: type = struct {},
} = .{};
pub const disable_address_transfer: struct {
    action_name: []const u8 = "DisableAddressTransfer",
    Request: type = struct {
        allocation_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_address_transfer) } {
            return .{ .service_metadata = service_metadata, .action = disable_address_transfer };
        }
    },
    Response: type = struct {
        address_transfer: ?AddressTransfer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_transfer = "addressTransfer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_aws_network_performance_metric_subscription: struct {
    action_name: []const u8 = "DisableAwsNetworkPerformanceMetricSubscription",
    Request: type = struct {
        source: ?[]const u8 = null,
        destination: ?[]const u8 = null,
        metric: ?[]const u8 = null,
        statistic: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .destination = "Destination",
                .metric = "Metric",
                .statistic = "Statistic",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_aws_network_performance_metric_subscription) } {
            return .{ .service_metadata = service_metadata, .action = disable_aws_network_performance_metric_subscription };
        }
    },
    Response: type = struct {
        output: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_ebs_encryption_by_default: struct {
    action_name: []const u8 = "DisableEbsEncryptionByDefault",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_ebs_encryption_by_default) } {
            return .{ .service_metadata = service_metadata, .action = disable_ebs_encryption_by_default };
        }
    },
    Response: type = struct {
        ebs_encryption_by_default: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ebs_encryption_by_default = "ebsEncryptionByDefault",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_fast_launch: struct {
    action_name: []const u8 = "DisableFastLaunch",
    Request: type = struct {
        image_id: []const u8,
        force: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .force = "Force",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_fast_launch) } {
            return .{ .service_metadata = service_metadata, .action = disable_fast_launch };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        snapshot_configuration: ?FastLaunchSnapshotConfigurationResponse = null,
        launch_template: ?FastLaunchLaunchTemplateSpecificationResponse = null,
        max_parallel_launches: ?i64 = null,
        owner_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        state_transition_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
                .resource_type = "resourceType",
                .snapshot_configuration = "snapshotConfiguration",
                .launch_template = "launchTemplate",
                .max_parallel_launches = "maxParallelLaunches",
                .owner_id = "ownerId",
                .state = "state",
                .state_transition_reason = "stateTransitionReason",
                .state_transition_time = "stateTransitionTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_fast_snapshot_restores: struct {
    action_name: []const u8 = "DisableFastSnapshotRestores",
    Request: type = struct {
        availability_zones: [][]const u8,
        source_snapshot_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZone",
                .source_snapshot_ids = "SourceSnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_fast_snapshot_restores) } {
            return .{ .service_metadata = service_metadata, .action = disable_fast_snapshot_restores };
        }
    },
    Response: type = struct {
        successful: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_transition_reason: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            owner_alias: ?[]const u8 = null,
            enabling_time: ?i64 = null,
            optimizing_time: ?i64 = null,
            enabled_time: ?i64 = null,
            disabling_time: ?i64 = null,
            disabled_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .availability_zone = "availabilityZone",
                    .state = "state",
                    .state_transition_reason = "stateTransitionReason",
                    .owner_id = "ownerId",
                    .owner_alias = "ownerAlias",
                    .enabling_time = "enablingTime",
                    .optimizing_time = "optimizingTime",
                    .enabled_time = "enabledTime",
                    .disabling_time = "disablingTime",
                    .disabled_time = "disabledTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            fast_snapshot_restore_state_errors: ?[]struct {
                availability_zone: ?[]const u8 = null,
                @"error": ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "code",
                            .message = "message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .availability_zone = "availabilityZone",
                        .@"error" = "error",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .fast_snapshot_restore_state_errors = "fastSnapshotRestoreStateErrorSet",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_image: struct {
    action_name: []const u8 = "DisableImage",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_image) } {
            return .{ .service_metadata = service_metadata, .action = disable_image };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_image_block_public_access: struct {
    action_name: []const u8 = "DisableImageBlockPublicAccess",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_image_block_public_access) } {
            return .{ .service_metadata = service_metadata, .action = disable_image_block_public_access };
        }
    },
    Response: type = struct {
        image_block_public_access_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_block_public_access_state = "imageBlockPublicAccessState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_image_deprecation: struct {
    action_name: []const u8 = "DisableImageDeprecation",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_image_deprecation) } {
            return .{ .service_metadata = service_metadata, .action = disable_image_deprecation };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_ipam_organization_admin_account: struct {
    action_name: []const u8 = "DisableIpamOrganizationAdminAccount",
    Request: type = struct {
        dry_run: ?bool = null,
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .delegated_admin_account_id = "DelegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_ipam_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_ipam_organization_admin_account };
        }
    },
    Response: type = struct {
        success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .success = "success",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_serial_console_access: struct {
    action_name: []const u8 = "DisableSerialConsoleAccess",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_serial_console_access) } {
            return .{ .service_metadata = service_metadata, .action = disable_serial_console_access };
        }
    },
    Response: type = struct {
        serial_console_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serial_console_access_enabled = "serialConsoleAccessEnabled",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_snapshot_block_public_access: struct {
    action_name: []const u8 = "DisableSnapshotBlockPublicAccess",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_snapshot_block_public_access) } {
            return .{ .service_metadata = service_metadata, .action = disable_snapshot_block_public_access };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_transit_gateway_route_table_propagation: struct {
    action_name: []const u8 = "DisableTransitGatewayRouteTablePropagation",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        transit_gateway_route_table_announcement_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
                .transit_gateway_route_table_announcement_id = "TransitGatewayRouteTableAnnouncementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_transit_gateway_route_table_propagation) } {
            return .{ .service_metadata = service_metadata, .action = disable_transit_gateway_route_table_propagation };
        }
    },
    Response: type = struct {
        propagation: ?TransitGatewayPropagation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .propagation = "propagation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_vgw_route_propagation: struct {
    action_name: []const u8 = "DisableVgwRoutePropagation",
    Request: type = struct {
        gateway_id: []const u8,
        route_table_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "GatewayId",
                .route_table_id = "RouteTableId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_vgw_route_propagation) } {
            return .{ .service_metadata = service_metadata, .action = disable_vgw_route_propagation };
        }
    },
    Response: type = struct {},
} = .{};
pub const disable_vpc_classic_link: struct {
    action_name: []const u8 = "DisableVpcClassicLink",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_vpc_classic_link) } {
            return .{ .service_metadata = service_metadata, .action = disable_vpc_classic_link };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_vpc_classic_link_dns_support: struct {
    action_name: []const u8 = "DisableVpcClassicLinkDnsSupport",
    Request: type = struct {
        vpc_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_vpc_classic_link_dns_support) } {
            return .{ .service_metadata = service_metadata, .action = disable_vpc_classic_link_dns_support };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_address: struct {
    action_name: []const u8 = "DisassociateAddress",
    Request: type = struct {
        association_id: ?[]const u8 = null,
        public_ip: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .public_ip = "PublicIp",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_address) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_address };
        }
    },
    Response: type = struct {},
} = .{};
pub const disassociate_client_vpn_target_network: struct {
    action_name: []const u8 = "DisassociateClientVpnTargetNetwork",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        association_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .association_id = "AssociationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_client_vpn_target_network) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_client_vpn_target_network };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,
        status: ?AssociationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_enclave_certificate_iam_role: struct {
    action_name: []const u8 = "DisassociateEnclaveCertificateIamRole",
    Request: type = struct {
        certificate_arn: []const u8,
        role_arn: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .role_arn = "RoleArn",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_enclave_certificate_iam_role) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_enclave_certificate_iam_role };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_iam_instance_profile: struct {
    action_name: []const u8 = "DisassociateIamInstanceProfile",
    Request: type = struct {
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_iam_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_iam_instance_profile };
        }
    },
    Response: type = struct {
        iam_instance_profile_association: ?IamInstanceProfileAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile_association = "iamInstanceProfileAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_instance_event_window: struct {
    action_name: []const u8 = "DisassociateInstanceEventWindow",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_event_window_id: []const u8,
        association_target: struct {
            instance_ids: ?[][]const u8 = null,
            instance_tags: ?[]Tag = null,
            dedicated_host_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_ids = "InstanceId",
                    .instance_tags = "InstanceTag",
                    .dedicated_host_ids = "DedicatedHostId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_event_window_id = "InstanceEventWindowId",
                .association_target = "AssociationTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_instance_event_window) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_instance_event_window };
        }
    },
    Response: type = struct {
        instance_event_window: ?InstanceEventWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_window = "instanceEventWindow",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_ipam_byoasn: struct {
    action_name: []const u8 = "DisassociateIpamByoasn",
    Request: type = struct {
        dry_run: ?bool = null,
        asn: []const u8,
        cidr: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .asn = "Asn",
                .cidr = "Cidr",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_ipam_byoasn) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_ipam_byoasn };
        }
    },
    Response: type = struct {
        asn_association: ?AsnAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asn_association = "asnAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_ipam_resource_discovery: struct {
    action_name: []const u8 = "DisassociateIpamResourceDiscovery",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_association_id = "IpamResourceDiscoveryAssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_ipam_resource_discovery) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_ipam_resource_discovery };
        }
    },
    Response: type = struct {
        ipam_resource_discovery_association: ?IpamResourceDiscoveryAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery_association = "ipamResourceDiscoveryAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_nat_gateway_address: struct {
    action_name: []const u8 = "DisassociateNatGatewayAddress",
    Request: type = struct {
        nat_gateway_id: []const u8,
        association_ids: [][]const u8,
        max_drain_duration_seconds: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "NatGatewayId",
                .association_ids = "AssociationId",
                .max_drain_duration_seconds = "MaxDrainDurationSeconds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_nat_gateway_address) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_nat_gateway_address };
        }
    },
    Response: type = struct {
        nat_gateway_id: ?[]const u8 = null,
        nat_gateway_addresses: ?[]NatGatewayAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "natGatewayId",
                .nat_gateway_addresses = "natGatewayAddressSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_route_table: struct {
    action_name: []const u8 = "DisassociateRouteTable",
    Request: type = struct {
        association_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_route_table) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_route_table };
        }
    },
    Response: type = struct {},
} = .{};
pub const disassociate_subnet_cidr_block: struct {
    action_name: []const u8 = "DisassociateSubnetCidrBlock",
    Request: type = struct {
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_subnet_cidr_block) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_subnet_cidr_block };
        }
    },
    Response: type = struct {
        ipv6_cidr_block_association: ?SubnetIpv6CidrBlockAssociation = null,
        subnet_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_block_association = "ipv6CidrBlockAssociation",
                .subnet_id = "subnetId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_transit_gateway_multicast_domain: struct {
    action_name: []const u8 = "DisassociateTransitGatewayMulticastDomain",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        subnet_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .subnet_ids = "SubnetIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_transit_gateway_multicast_domain) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_transit_gateway_multicast_domain };
        }
    },
    Response: type = struct {
        associations: ?TransitGatewayMulticastDomainAssociations = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_transit_gateway_policy_table: struct {
    action_name: []const u8 = "DisassociateTransitGatewayPolicyTable",
    Request: type = struct {
        transit_gateway_policy_table_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_id = "TransitGatewayPolicyTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_transit_gateway_policy_table) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_transit_gateway_policy_table };
        }
    },
    Response: type = struct {
        association: ?TransitGatewayPolicyTableAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_transit_gateway_route_table: struct {
    action_name: []const u8 = "DisassociateTransitGatewayRouteTable",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_transit_gateway_route_table) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_transit_gateway_route_table };
        }
    },
    Response: type = struct {
        association: ?TransitGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "association",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_trunk_interface: struct {
    action_name: []const u8 = "DisassociateTrunkInterface",
    Request: type = struct {
        association_id: []const u8,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_trunk_interface) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_trunk_interface };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_vpc_cidr_block: struct {
    action_name: []const u8 = "DisassociateVpcCidrBlock",
    Request: type = struct {
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_vpc_cidr_block) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_vpc_cidr_block };
        }
    },
    Response: type = struct {
        ipv6_cidr_block_association: ?VpcIpv6CidrBlockAssociation = null,
        cidr_block_association: ?VpcCidrBlockAssociation = null,
        vpc_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_block_association = "ipv6CidrBlockAssociation",
                .cidr_block_association = "cidrBlockAssociation",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_address_transfer: struct {
    action_name: []const u8 = "EnableAddressTransfer",
    Request: type = struct {
        allocation_id: []const u8,
        transfer_account_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .transfer_account_id = "TransferAccountId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_address_transfer) } {
            return .{ .service_metadata = service_metadata, .action = enable_address_transfer };
        }
    },
    Response: type = struct {
        address_transfer: ?AddressTransfer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_transfer = "addressTransfer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_aws_network_performance_metric_subscription: struct {
    action_name: []const u8 = "EnableAwsNetworkPerformanceMetricSubscription",
    Request: type = struct {
        source: ?[]const u8 = null,
        destination: ?[]const u8 = null,
        metric: ?[]const u8 = null,
        statistic: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .destination = "Destination",
                .metric = "Metric",
                .statistic = "Statistic",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_aws_network_performance_metric_subscription) } {
            return .{ .service_metadata = service_metadata, .action = enable_aws_network_performance_metric_subscription };
        }
    },
    Response: type = struct {
        output: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_ebs_encryption_by_default: struct {
    action_name: []const u8 = "EnableEbsEncryptionByDefault",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_ebs_encryption_by_default) } {
            return .{ .service_metadata = service_metadata, .action = enable_ebs_encryption_by_default };
        }
    },
    Response: type = struct {
        ebs_encryption_by_default: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ebs_encryption_by_default = "ebsEncryptionByDefault",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_fast_launch: struct {
    action_name: []const u8 = "EnableFastLaunch",
    Request: type = struct {
        image_id: []const u8,
        resource_type: ?[]const u8 = null,
        snapshot_configuration: ?struct {
            target_resource_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_resource_count = "TargetResourceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        launch_template: ?struct {
            launch_template_id: ?[]const u8 = null,
            launch_template_name: ?[]const u8 = null,
            version: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_id = "LaunchTemplateId",
                    .launch_template_name = "LaunchTemplateName",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_parallel_launches: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .resource_type = "ResourceType",
                .snapshot_configuration = "SnapshotConfiguration",
                .launch_template = "LaunchTemplate",
                .max_parallel_launches = "MaxParallelLaunches",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_fast_launch) } {
            return .{ .service_metadata = service_metadata, .action = enable_fast_launch };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        snapshot_configuration: ?FastLaunchSnapshotConfigurationResponse = null,
        launch_template: ?FastLaunchLaunchTemplateSpecificationResponse = null,
        max_parallel_launches: ?i64 = null,
        owner_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        state_transition_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
                .resource_type = "resourceType",
                .snapshot_configuration = "snapshotConfiguration",
                .launch_template = "launchTemplate",
                .max_parallel_launches = "maxParallelLaunches",
                .owner_id = "ownerId",
                .state = "state",
                .state_transition_reason = "stateTransitionReason",
                .state_transition_time = "stateTransitionTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_fast_snapshot_restores: struct {
    action_name: []const u8 = "EnableFastSnapshotRestores",
    Request: type = struct {
        availability_zones: [][]const u8,
        source_snapshot_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "AvailabilityZone",
                .source_snapshot_ids = "SourceSnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_fast_snapshot_restores) } {
            return .{ .service_metadata = service_metadata, .action = enable_fast_snapshot_restores };
        }
    },
    Response: type = struct {
        successful: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_transition_reason: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            owner_alias: ?[]const u8 = null,
            enabling_time: ?i64 = null,
            optimizing_time: ?i64 = null,
            enabled_time: ?i64 = null,
            disabling_time: ?i64 = null,
            disabled_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .availability_zone = "availabilityZone",
                    .state = "state",
                    .state_transition_reason = "stateTransitionReason",
                    .owner_id = "ownerId",
                    .owner_alias = "ownerAlias",
                    .enabling_time = "enablingTime",
                    .optimizing_time = "optimizingTime",
                    .enabled_time = "enabledTime",
                    .disabling_time = "disablingTime",
                    .disabled_time = "disabledTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            fast_snapshot_restore_state_errors: ?[]struct {
                availability_zone: ?[]const u8 = null,
                @"error": ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "code",
                            .message = "message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .availability_zone = "availabilityZone",
                        .@"error" = "error",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .fast_snapshot_restore_state_errors = "fastSnapshotRestoreStateErrorSet",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_image: struct {
    action_name: []const u8 = "EnableImage",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_image) } {
            return .{ .service_metadata = service_metadata, .action = enable_image };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_image_block_public_access: struct {
    action_name: []const u8 = "EnableImageBlockPublicAccess",
    Request: type = struct {
        image_block_public_access_state: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_block_public_access_state = "ImageBlockPublicAccessState",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_image_block_public_access) } {
            return .{ .service_metadata = service_metadata, .action = enable_image_block_public_access };
        }
    },
    Response: type = struct {
        image_block_public_access_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_block_public_access_state = "imageBlockPublicAccessState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_image_deprecation: struct {
    action_name: []const u8 = "EnableImageDeprecation",
    Request: type = struct {
        image_id: []const u8,
        deprecate_at: i64,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .deprecate_at = "DeprecateAt",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_image_deprecation) } {
            return .{ .service_metadata = service_metadata, .action = enable_image_deprecation };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_ipam_organization_admin_account: struct {
    action_name: []const u8 = "EnableIpamOrganizationAdminAccount",
    Request: type = struct {
        dry_run: ?bool = null,
        delegated_admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .delegated_admin_account_id = "DelegatedAdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_ipam_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_ipam_organization_admin_account };
        }
    },
    Response: type = struct {
        success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .success = "success",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_reachability_analyzer_organization_sharing: struct {
    action_name: []const u8 = "EnableReachabilityAnalyzerOrganizationSharing",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_reachability_analyzer_organization_sharing) } {
            return .{ .service_metadata = service_metadata, .action = enable_reachability_analyzer_organization_sharing };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "returnValue",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_serial_console_access: struct {
    action_name: []const u8 = "EnableSerialConsoleAccess",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_serial_console_access) } {
            return .{ .service_metadata = service_metadata, .action = enable_serial_console_access };
        }
    },
    Response: type = struct {
        serial_console_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serial_console_access_enabled = "serialConsoleAccessEnabled",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_snapshot_block_public_access: struct {
    action_name: []const u8 = "EnableSnapshotBlockPublicAccess",
    Request: type = struct {
        state: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_snapshot_block_public_access) } {
            return .{ .service_metadata = service_metadata, .action = enable_snapshot_block_public_access };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_transit_gateway_route_table_propagation: struct {
    action_name: []const u8 = "EnableTransitGatewayRouteTablePropagation",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        transit_gateway_route_table_announcement_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
                .transit_gateway_route_table_announcement_id = "TransitGatewayRouteTableAnnouncementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_transit_gateway_route_table_propagation) } {
            return .{ .service_metadata = service_metadata, .action = enable_transit_gateway_route_table_propagation };
        }
    },
    Response: type = struct {
        propagation: ?TransitGatewayPropagation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .propagation = "propagation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_vgw_route_propagation: struct {
    action_name: []const u8 = "EnableVgwRoutePropagation",
    Request: type = struct {
        gateway_id: []const u8,
        route_table_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_id = "GatewayId",
                .route_table_id = "RouteTableId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_vgw_route_propagation) } {
            return .{ .service_metadata = service_metadata, .action = enable_vgw_route_propagation };
        }
    },
    Response: type = struct {},
} = .{};
pub const enable_volume_io: struct {
    action_name: []const u8 = "EnableVolumeIO",
    Request: type = struct {
        dry_run: ?bool = null,
        volume_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .volume_id = "volumeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_volume_io) } {
            return .{ .service_metadata = service_metadata, .action = enable_volume_io };
        }
    },
    Response: type = struct {},
} = .{};
pub const enable_vpc_classic_link: struct {
    action_name: []const u8 = "EnableVpcClassicLink",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_id = "vpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_vpc_classic_link) } {
            return .{ .service_metadata = service_metadata, .action = enable_vpc_classic_link };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const enable_vpc_classic_link_dns_support: struct {
    action_name: []const u8 = "EnableVpcClassicLinkDnsSupport",
    Request: type = struct {
        vpc_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_vpc_classic_link_dns_support) } {
            return .{ .service_metadata = service_metadata, .action = enable_vpc_classic_link_dns_support };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const export_client_vpn_client_certificate_revocation_list: struct {
    action_name: []const u8 = "ExportClientVpnClientCertificateRevocationList",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_client_vpn_client_certificate_revocation_list) } {
            return .{ .service_metadata = service_metadata, .action = export_client_vpn_client_certificate_revocation_list };
        }
    },
    Response: type = struct {
        certificate_revocation_list: ?[]const u8 = null,
        status: ?struct {
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_revocation_list = "certificateRevocationList",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const export_client_vpn_client_configuration: struct {
    action_name: []const u8 = "ExportClientVpnClientConfiguration",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_client_vpn_client_configuration) } {
            return .{ .service_metadata = service_metadata, .action = export_client_vpn_client_configuration };
        }
    },
    Response: type = struct {
        client_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_configuration = "clientConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const export_image: struct {
    action_name: []const u8 = "ExportImage",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        disk_image_format: []const u8,
        dry_run: ?bool = null,
        image_id: []const u8,
        s3_export_location: struct {
            s3_bucket: []const u8,
            s3_prefix: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_bucket = "S3Bucket",
                    .s3_prefix = "S3Prefix",
                };
                return @field(mappings, field_name);
            }
        },
        role_name: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .description = "Description",
                .disk_image_format = "DiskImageFormat",
                .dry_run = "DryRun",
                .image_id = "ImageId",
                .s3_export_location = "S3ExportLocation",
                .role_name = "RoleName",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_image) } {
            return .{ .service_metadata = service_metadata, .action = export_image };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        disk_image_format: ?[]const u8 = null,
        export_image_task_id: ?[]const u8 = null,
        image_id: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        progress: ?[]const u8 = null,
        s3_export_location: ?ExportTaskS3Location = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .disk_image_format = "diskImageFormat",
                .export_image_task_id = "exportImageTaskId",
                .image_id = "imageId",
                .role_name = "roleName",
                .progress = "progress",
                .s3_export_location = "s3ExportLocation",
                .status = "status",
                .status_message = "statusMessage",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const export_transit_gateway_routes: struct {
    action_name: []const u8 = "ExportTransitGatewayRoutes",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        filters: ?[]Filter = null,
        s3_bucket: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .filters = "Filter",
                .s3_bucket = "S3Bucket",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_transit_gateway_routes) } {
            return .{ .service_metadata = service_metadata, .action = export_transit_gateway_routes };
        }
    },
    Response: type = struct {
        s3_location: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_location = "s3Location",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_associated_enclave_certificate_iam_roles: struct {
    action_name: []const u8 = "GetAssociatedEnclaveCertificateIamRoles",
    Request: type = struct {
        certificate_arn: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_associated_enclave_certificate_iam_roles) } {
            return .{ .service_metadata = service_metadata, .action = get_associated_enclave_certificate_iam_roles };
        }
    },
    Response: type = struct {
        associated_roles: ?[]struct {
            associated_role_arn: ?[]const u8 = null,
            certificate_s3_bucket_name: ?[]const u8 = null,
            certificate_s3_object_key: ?[]const u8 = null,
            encryption_kms_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .associated_role_arn = "associatedRoleArn",
                    .certificate_s3_bucket_name = "certificateS3BucketName",
                    .certificate_s3_object_key = "certificateS3ObjectKey",
                    .encryption_kms_key_id = "encryptionKmsKeyId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_roles = "associatedRoleSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_associated_ipv6_pool_cidrs: struct {
    action_name: []const u8 = "GetAssociatedIpv6PoolCidrs",
    Request: type = struct {
        pool_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_associated_ipv6_pool_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = get_associated_ipv6_pool_cidrs };
        }
    },
    Response: type = struct {
        ipv6_cidr_associations: ?[]struct {
            ipv6_cidr: ?[]const u8 = null,
            associated_resource: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ipv6_cidr = "ipv6Cidr",
                    .associated_resource = "associatedResource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_cidr_associations = "ipv6CidrAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_aws_network_performance_data: struct {
    action_name: []const u8 = "GetAwsNetworkPerformanceData",
    Request: type = struct {
        data_queries: ?[]struct {
            id: ?[]const u8 = null,
            source: ?[]const u8 = null,
            destination: ?[]const u8 = null,
            metric: ?[]const u8 = null,
            statistic: ?[]const u8 = null,
            period: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .source = "Source",
                    .destination = "Destination",
                    .metric = "Metric",
                    .statistic = "Statistic",
                    .period = "Period",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_queries = "DataQuery",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aws_network_performance_data) } {
            return .{ .service_metadata = service_metadata, .action = get_aws_network_performance_data };
        }
    },
    Response: type = struct {
        data_responses: ?[]struct {
            id: ?[]const u8 = null,
            source: ?[]const u8 = null,
            destination: ?[]const u8 = null,
            metric: ?[]const u8 = null,
            statistic: ?[]const u8 = null,
            period: ?[]const u8 = null,
            metric_points: ?[]struct {
                start_date: ?i64 = null,
                end_date: ?i64 = null,
                value: ?f32 = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_date = "startDate",
                        .end_date = "endDate",
                        .value = "value",
                        .status = "status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .source = "source",
                    .destination = "destination",
                    .metric = "metric",
                    .statistic = "statistic",
                    .period = "period",
                    .metric_points = "metricPointSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_responses = "dataResponseSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_capacity_reservation_usage: struct {
    action_name: []const u8 = "GetCapacityReservationUsage",
    Request: type = struct {
        capacity_reservation_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_id = "CapacityReservationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_capacity_reservation_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_capacity_reservation_usage };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        capacity_reservation_id: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        total_instance_count: ?i64 = null,
        available_instance_count: ?i64 = null,
        state: ?[]const u8 = null,
        instance_usages: ?[]struct {
            account_id: ?[]const u8 = null,
            used_instance_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .used_instance_count = "usedInstanceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .capacity_reservation_id = "capacityReservationId",
                .instance_type = "instanceType",
                .total_instance_count = "totalInstanceCount",
                .available_instance_count = "availableInstanceCount",
                .state = "state",
                .instance_usages = "instanceUsageSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_coip_pool_usage: struct {
    action_name: []const u8 = "GetCoipPoolUsage",
    Request: type = struct {
        pool_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_coip_pool_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_coip_pool_usage };
        }
    },
    Response: type = struct {
        coip_pool_id: ?[]const u8 = null,
        coip_address_usages: ?[]struct {
            allocation_id: ?[]const u8 = null,
            aws_account_id: ?[]const u8 = null,
            aws_service: ?[]const u8 = null,
            co_ip: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .allocation_id = "allocationId",
                    .aws_account_id = "awsAccountId",
                    .aws_service = "awsService",
                    .co_ip = "coIp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        local_gateway_route_table_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .coip_pool_id = "coipPoolId",
                .coip_address_usages = "coipAddressUsageSet",
                .local_gateway_route_table_id = "localGatewayRouteTableId",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_console_output: struct {
    action_name: []const u8 = "GetConsoleOutput",
    Request: type = struct {
        instance_id: []const u8,
        dry_run: ?bool = null,
        latest: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .dry_run = "dryRun",
                .latest = "Latest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_console_output) } {
            return .{ .service_metadata = service_metadata, .action = get_console_output };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        output: ?[]const u8 = null,
        timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "instanceId",
                .output = "output",
                .timestamp = "timestamp",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_console_screenshot: struct {
    action_name: []const u8 = "GetConsoleScreenshot",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_id: []const u8,
        wake_up: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_id = "InstanceId",
                .wake_up = "WakeUp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_console_screenshot) } {
            return .{ .service_metadata = service_metadata, .action = get_console_screenshot };
        }
    },
    Response: type = struct {
        image_data: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_data = "imageData",
                .instance_id = "instanceId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_default_credit_specification: struct {
    action_name: []const u8 = "GetDefaultCreditSpecification",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_family: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_family = "InstanceFamily",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_default_credit_specification) } {
            return .{ .service_metadata = service_metadata, .action = get_default_credit_specification };
        }
    },
    Response: type = struct {
        instance_family_credit_specification: ?InstanceFamilyCreditSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_family_credit_specification = "instanceFamilyCreditSpecification",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ebs_default_kms_key_id: struct {
    action_name: []const u8 = "GetEbsDefaultKmsKeyId",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ebs_default_kms_key_id) } {
            return .{ .service_metadata = service_metadata, .action = get_ebs_default_kms_key_id };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ebs_encryption_by_default: struct {
    action_name: []const u8 = "GetEbsEncryptionByDefault",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ebs_encryption_by_default) } {
            return .{ .service_metadata = service_metadata, .action = get_ebs_encryption_by_default };
        }
    },
    Response: type = struct {
        ebs_encryption_by_default: ?bool = null,
        sse_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ebs_encryption_by_default = "ebsEncryptionByDefault",
                .sse_type = "sseType",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_flow_logs_integration_template: struct {
    action_name: []const u8 = "GetFlowLogsIntegrationTemplate",
    Request: type = struct {
        dry_run: ?bool = null,
        flow_log_id: []const u8,
        config_delivery_s3_destination_arn: []const u8,
        integrate_services: struct {
            athena_integrations: ?[]struct {
                integration_result_s3_destination_arn: []const u8,
                partition_load_frequency: []const u8,
                partition_start_date: ?i64 = null,
                partition_end_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .integration_result_s3_destination_arn = "IntegrationResultS3DestinationArn",
                        .partition_load_frequency = "PartitionLoadFrequency",
                        .partition_start_date = "PartitionStartDate",
                        .partition_end_date = "PartitionEndDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .athena_integrations = "AthenaIntegration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .flow_log_id = "FlowLogId",
                .config_delivery_s3_destination_arn = "ConfigDeliveryS3DestinationArn",
                .integrate_services = "IntegrateService",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_flow_logs_integration_template) } {
            return .{ .service_metadata = service_metadata, .action = get_flow_logs_integration_template };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "result",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_groups_for_capacity_reservation: struct {
    action_name: []const u8 = "GetGroupsForCapacityReservation",
    Request: type = struct {
        capacity_reservation_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_id = "CapacityReservationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_groups_for_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = get_groups_for_capacity_reservation };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        capacity_reservation_groups: ?[]struct {
            group_arn: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_arn = "groupArn",
                    .owner_id = "ownerId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .capacity_reservation_groups = "capacityReservationGroupSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_host_reservation_purchase_preview: struct {
    action_name: []const u8 = "GetHostReservationPurchasePreview",
    Request: type = struct {
        host_id_set: [][]const u8,
        offering_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_id_set = "HostIdSet",
                .offering_id = "OfferingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_host_reservation_purchase_preview) } {
            return .{ .service_metadata = service_metadata, .action = get_host_reservation_purchase_preview };
        }
    },
    Response: type = struct {
        currency_code: ?[]const u8 = null,
        purchase: ?[]Purchase = null,
        total_hourly_price: ?[]const u8 = null,
        total_upfront_price: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .currency_code = "currencyCode",
                .purchase = "purchase",
                .total_hourly_price = "totalHourlyPrice",
                .total_upfront_price = "totalUpfrontPrice",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_image_block_public_access_state: struct {
    action_name: []const u8 = "GetImageBlockPublicAccessState",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_block_public_access_state) } {
            return .{ .service_metadata = service_metadata, .action = get_image_block_public_access_state };
        }
    },
    Response: type = struct {
        image_block_public_access_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_block_public_access_state = "imageBlockPublicAccessState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_instance_types_from_instance_requirements: struct {
    action_name: []const u8 = "GetInstanceTypesFromInstanceRequirements",
    Request: type = struct {
        dry_run: ?bool = null,
        architecture_types: [][]const u8,
        virtualization_types: [][]const u8,
        instance_requirements: InstanceRequirementsRequest,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .architecture_types = "ArchitectureType",
                .virtualization_types = "VirtualizationType",
                .instance_requirements = "InstanceRequirements",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance_types_from_instance_requirements) } {
            return .{ .service_metadata = service_metadata, .action = get_instance_types_from_instance_requirements };
        }
    },
    Response: type = struct {
        instance_types: ?[]struct {
            instance_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "instanceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_types = "instanceTypeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_instance_uefi_data: struct {
    action_name: []const u8 = "GetInstanceUefiData",
    Request: type = struct {
        instance_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance_uefi_data) } {
            return .{ .service_metadata = service_metadata, .action = get_instance_uefi_data };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        uefi_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "instanceId",
                .uefi_data = "uefiData",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_address_history: struct {
    action_name: []const u8 = "GetIpamAddressHistory",
    Request: type = struct {
        dry_run: ?bool = null,
        cidr: []const u8,
        ipam_scope_id: []const u8,
        vpc_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .cidr = "Cidr",
                .ipam_scope_id = "IpamScopeId",
                .vpc_id = "VpcId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_address_history) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_address_history };
        }
    },
    Response: type = struct {
        history_records: ?[]struct {
            resource_owner_id: ?[]const u8 = null,
            resource_region: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_cidr: ?[]const u8 = null,
            resource_name: ?[]const u8 = null,
            resource_compliance_status: ?[]const u8 = null,
            resource_overlap_status: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            sampled_start_time: ?i64 = null,
            sampled_end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_owner_id = "resourceOwnerId",
                    .resource_region = "resourceRegion",
                    .resource_type = "resourceType",
                    .resource_id = "resourceId",
                    .resource_cidr = "resourceCidr",
                    .resource_name = "resourceName",
                    .resource_compliance_status = "resourceComplianceStatus",
                    .resource_overlap_status = "resourceOverlapStatus",
                    .vpc_id = "vpcId",
                    .sampled_start_time = "sampledStartTime",
                    .sampled_end_time = "sampledEndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history_records = "historyRecordSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_discovered_accounts: struct {
    action_name: []const u8 = "GetIpamDiscoveredAccounts",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_id: []const u8,
        discovery_region: []const u8,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
                .discovery_region = "DiscoveryRegion",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_discovered_accounts) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_discovered_accounts };
        }
    },
    Response: type = struct {
        ipam_discovered_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            discovery_region: ?[]const u8 = null,
            failure_reason: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_attempted_discovery_time: ?i64 = null,
            last_successful_discovery_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .discovery_region = "discoveryRegion",
                    .failure_reason = "failureReason",
                    .last_attempted_discovery_time = "lastAttemptedDiscoveryTime",
                    .last_successful_discovery_time = "lastSuccessfulDiscoveryTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_discovered_accounts = "ipamDiscoveredAccountSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_discovered_public_addresses: struct {
    action_name: []const u8 = "GetIpamDiscoveredPublicAddresses",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_id: []const u8,
        address_region: []const u8,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
                .address_region = "AddressRegion",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_discovered_public_addresses) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_discovered_public_addresses };
        }
    },
    Response: type = struct {
        ipam_discovered_public_addresses: ?[]struct {
            ipam_resource_discovery_id: ?[]const u8 = null,
            address_region: ?[]const u8 = null,
            address: ?[]const u8 = null,
            address_owner_id: ?[]const u8 = null,
            address_allocation_id: ?[]const u8 = null,
            association_status: ?[]const u8 = null,
            address_type: ?[]const u8 = null,
            service: ?[]const u8 = null,
            service_resource: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            subnet_id: ?[]const u8 = null,
            public_ipv4_pool_id: ?[]const u8 = null,
            network_interface_id: ?[]const u8 = null,
            network_interface_description: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            tags: ?struct {
                eip_tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .key = "key",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .eip_tags = "eipTagSet",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            network_border_group: ?[]const u8 = null,
            security_groups: ?[]struct {
                group_name: ?[]const u8 = null,
                group_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_name = "groupName",
                        .group_id = "groupId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sample_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ipam_resource_discovery_id = "ipamResourceDiscoveryId",
                    .address_region = "addressRegion",
                    .address = "address",
                    .address_owner_id = "addressOwnerId",
                    .address_allocation_id = "addressAllocationId",
                    .association_status = "associationStatus",
                    .address_type = "addressType",
                    .service = "service",
                    .service_resource = "serviceResource",
                    .vpc_id = "vpcId",
                    .subnet_id = "subnetId",
                    .public_ipv4_pool_id = "publicIpv4PoolId",
                    .network_interface_id = "networkInterfaceId",
                    .network_interface_description = "networkInterfaceDescription",
                    .instance_id = "instanceId",
                    .tags = "tags",
                    .network_border_group = "networkBorderGroup",
                    .security_groups = "securityGroupSet",
                    .sample_time = "sampleTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        oldest_sample_time: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_discovered_public_addresses = "ipamDiscoveredPublicAddressSet",
                .oldest_sample_time = "oldestSampleTime",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_discovered_resource_cidrs: struct {
    action_name: []const u8 = "GetIpamDiscoveredResourceCidrs",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_id: []const u8,
        resource_region: []const u8,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
                .resource_region = "ResourceRegion",
                .filters = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_discovered_resource_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_discovered_resource_cidrs };
        }
    },
    Response: type = struct {
        ipam_discovered_resource_cidrs: ?[]struct {
            ipam_resource_discovery_id: ?[]const u8 = null,
            resource_region: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            resource_cidr: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_tags: ?[]IpamResourceTag = null,
            ip_usage: ?f64 = null,
            vpc_id: ?[]const u8 = null,
            sample_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ipam_resource_discovery_id = "ipamResourceDiscoveryId",
                    .resource_region = "resourceRegion",
                    .resource_id = "resourceId",
                    .resource_owner_id = "resourceOwnerId",
                    .resource_cidr = "resourceCidr",
                    .resource_type = "resourceType",
                    .resource_tags = "resourceTagSet",
                    .ip_usage = "ipUsage",
                    .vpc_id = "vpcId",
                    .sample_time = "sampleTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_discovered_resource_cidrs = "ipamDiscoveredResourceCidrSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_pool_allocations: struct {
    action_name: []const u8 = "GetIpamPoolAllocations",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        ipam_pool_allocation_id: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .ipam_pool_allocation_id = "IpamPoolAllocationId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_pool_allocations) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_pool_allocations };
        }
    },
    Response: type = struct {
        ipam_pool_allocations: ?[]IpamPoolAllocation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool_allocations = "ipamPoolAllocationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_pool_cidrs: struct {
    action_name: []const u8 = "GetIpamPoolCidrs",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_pool_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_pool_cidrs };
        }
    },
    Response: type = struct {
        ipam_pool_cidrs: ?[]IpamPoolCidr = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool_cidrs = "ipamPoolCidrSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_ipam_resource_cidrs: struct {
    action_name: []const u8 = "GetIpamResourceCidrs",
    Request: type = struct {
        dry_run: ?bool = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ipam_scope_id: []const u8,
        ipam_pool_id: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_tag: ?RequestIpamResourceTag = null,
        resource_owner: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .ipam_scope_id = "IpamScopeId",
                .ipam_pool_id = "IpamPoolId",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
                .resource_tag = "ResourceTag",
                .resource_owner = "ResourceOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ipam_resource_cidrs) } {
            return .{ .service_metadata = service_metadata, .action = get_ipam_resource_cidrs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ipam_resource_cidrs: ?[]IpamResourceCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ipam_resource_cidrs = "ipamResourceCidrSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_launch_template_data: struct {
    action_name: []const u8 = "GetLaunchTemplateData",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_launch_template_data) } {
            return .{ .service_metadata = service_metadata, .action = get_launch_template_data };
        }
    },
    Response: type = struct {
        launch_template_data: ?ResponseLaunchTemplateData = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template_data = "launchTemplateData",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_managed_prefix_list_associations: struct {
    action_name: []const u8 = "GetManagedPrefixListAssociations",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_id = "PrefixListId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_managed_prefix_list_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_managed_prefix_list_associations };
        }
    },
    Response: type = struct {
        prefix_list_associations: ?[]struct {
            resource_id: ?[]const u8 = null,
            resource_owner: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "resourceId",
                    .resource_owner = "resourceOwner",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prefix_list_associations = "prefixListAssociationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_managed_prefix_list_entries: struct {
    action_name: []const u8 = "GetManagedPrefixListEntries",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_id: []const u8,
        target_version: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_id = "PrefixListId",
                .target_version = "TargetVersion",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_managed_prefix_list_entries) } {
            return .{ .service_metadata = service_metadata, .action = get_managed_prefix_list_entries };
        }
    },
    Response: type = struct {
        entries: ?[]struct {
            cidr: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cidr = "cidr",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "entrySet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_network_insights_access_scope_analysis_findings: struct {
    action_name: []const u8 = "GetNetworkInsightsAccessScopeAnalysisFindings",
    Request: type = struct {
        network_insights_access_scope_analysis_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis_id = "NetworkInsightsAccessScopeAnalysisId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_insights_access_scope_analysis_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_network_insights_access_scope_analysis_findings };
        }
    },
    Response: type = struct {
        network_insights_access_scope_analysis_id: ?[]const u8 = null,
        analysis_status: ?[]const u8 = null,
        analysis_findings: ?[]struct {
            network_insights_access_scope_analysis_id: ?[]const u8 = null,
            network_insights_access_scope_id: ?[]const u8 = null,
            finding_id: ?[]const u8 = null,
            finding_components: ?[]PathComponent = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network_insights_access_scope_analysis_id = "networkInsightsAccessScopeAnalysisId",
                    .network_insights_access_scope_id = "networkInsightsAccessScopeId",
                    .finding_id = "findingId",
                    .finding_components = "findingComponentSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis_id = "networkInsightsAccessScopeAnalysisId",
                .analysis_status = "analysisStatus",
                .analysis_findings = "analysisFindingSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_network_insights_access_scope_content: struct {
    action_name: []const u8 = "GetNetworkInsightsAccessScopeContent",
    Request: type = struct {
        network_insights_access_scope_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_id = "NetworkInsightsAccessScopeId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_insights_access_scope_content) } {
            return .{ .service_metadata = service_metadata, .action = get_network_insights_access_scope_content };
        }
    },
    Response: type = struct {
        network_insights_access_scope_content: ?NetworkInsightsAccessScopeContent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_content = "networkInsightsAccessScopeContent",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_password_data: struct {
    action_name: []const u8 = "GetPasswordData",
    Request: type = struct {
        instance_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_password_data) } {
            return .{ .service_metadata = service_metadata, .action = get_password_data };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        password_data: ?[]const u8 = null,
        timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "instanceId",
                .password_data = "passwordData",
                .timestamp = "timestamp",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_reserved_instances_exchange_quote: struct {
    action_name: []const u8 = "GetReservedInstancesExchangeQuote",
    Request: type = struct {
        dry_run: ?bool = null,
        reserved_instance_ids: [][]const u8,
        target_configurations: ?[]TargetConfigurationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .reserved_instance_ids = "ReservedInstanceId",
                .target_configurations = "TargetConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reserved_instances_exchange_quote) } {
            return .{ .service_metadata = service_metadata, .action = get_reserved_instances_exchange_quote };
        }
    },
    Response: type = struct {
        currency_code: ?[]const u8 = null,
        is_valid_exchange: ?bool = null,
        output_reserved_instances_will_expire_at: ?i64 = null,
        payment_due: ?[]const u8 = null,
        reserved_instance_value_rollup: ?ReservationValue = null,
        reserved_instance_value_set: ?[]struct {
            reservation_value: ?ReservationValue = null,
            reserved_instance_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reservation_value = "reservationValue",
                    .reserved_instance_id = "reservedInstanceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        target_configuration_value_rollup: ?ReservationValue = null,
        target_configuration_value_set: ?[]struct {
            reservation_value: ?ReservationValue = null,
            target_configuration: ?struct {
                instance_count: ?i64 = null,
                offering_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_count = "instanceCount",
                        .offering_id = "offeringId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reservation_value = "reservationValue",
                    .target_configuration = "targetConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        validation_failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .currency_code = "currencyCode",
                .is_valid_exchange = "isValidExchange",
                .output_reserved_instances_will_expire_at = "outputReservedInstancesWillExpireAt",
                .payment_due = "paymentDue",
                .reserved_instance_value_rollup = "reservedInstanceValueRollup",
                .reserved_instance_value_set = "reservedInstanceValueSet",
                .target_configuration_value_rollup = "targetConfigurationValueRollup",
                .target_configuration_value_set = "targetConfigurationValueSet",
                .validation_failure_reason = "validationFailureReason",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_security_groups_for_vpc: struct {
    action_name: []const u8 = "GetSecurityGroupsForVpc",
    Request: type = struct {
        vpc_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filter",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_groups_for_vpc) } {
            return .{ .service_metadata = service_metadata, .action = get_security_groups_for_vpc };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        security_group_for_vpcs: ?[]struct {
            description: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            group_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            primary_vpc_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "description",
                    .group_name = "groupName",
                    .owner_id = "ownerId",
                    .group_id = "groupId",
                    .tags = "tagSet",
                    .primary_vpc_id = "primaryVpcId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .security_group_for_vpcs = "securityGroupForVpcSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_serial_console_access_status: struct {
    action_name: []const u8 = "GetSerialConsoleAccessStatus",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_serial_console_access_status) } {
            return .{ .service_metadata = service_metadata, .action = get_serial_console_access_status };
        }
    },
    Response: type = struct {
        serial_console_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .serial_console_access_enabled = "serialConsoleAccessEnabled",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_snapshot_block_public_access_state: struct {
    action_name: []const u8 = "GetSnapshotBlockPublicAccessState",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_snapshot_block_public_access_state) } {
            return .{ .service_metadata = service_metadata, .action = get_snapshot_block_public_access_state };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_spot_placement_scores: struct {
    action_name: []const u8 = "GetSpotPlacementScores",
    Request: type = struct {
        instance_types: ?[][]const u8 = null,
        target_capacity: i64,
        target_capacity_unit_type: ?[]const u8 = null,
        single_availability_zone: ?bool = null,
        region_names: ?[][]const u8 = null,
        instance_requirements_with_metadata: ?struct {
            architecture_types: ?[][]const u8 = null,
            virtualization_types: ?[][]const u8 = null,
            instance_requirements: ?InstanceRequirementsRequest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .architecture_types = "ArchitectureType",
                    .virtualization_types = "VirtualizationType",
                    .instance_requirements = "InstanceRequirements",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_types = "InstanceType",
                .target_capacity = "TargetCapacity",
                .target_capacity_unit_type = "TargetCapacityUnitType",
                .single_availability_zone = "SingleAvailabilityZone",
                .region_names = "RegionName",
                .instance_requirements_with_metadata = "InstanceRequirementsWithMetadata",
                .dry_run = "DryRun",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_spot_placement_scores) } {
            return .{ .service_metadata = service_metadata, .action = get_spot_placement_scores };
        }
    },
    Response: type = struct {
        spot_placement_scores: ?[]struct {
            region: ?[]const u8 = null,
            availability_zone_id: ?[]const u8 = null,
            score: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "region",
                    .availability_zone_id = "availabilityZoneId",
                    .score = "score",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_placement_scores = "spotPlacementScoreSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_subnet_cidr_reservations: struct {
    action_name: []const u8 = "GetSubnetCidrReservations",
    Request: type = struct {
        filters: ?[]Filter = null,
        subnet_id: []const u8,
        dry_run: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filter",
                .subnet_id = "SubnetId",
                .dry_run = "DryRun",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subnet_cidr_reservations) } {
            return .{ .service_metadata = service_metadata, .action = get_subnet_cidr_reservations };
        }
    },
    Response: type = struct {
        subnet_ipv4_cidr_reservations: ?[]SubnetCidrReservation = null,
        subnet_ipv6_cidr_reservations: ?[]SubnetCidrReservation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_ipv4_cidr_reservations = "subnetIpv4CidrReservationSet",
                .subnet_ipv6_cidr_reservations = "subnetIpv6CidrReservationSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_attachment_propagations: struct {
    action_name: []const u8 = "GetTransitGatewayAttachmentPropagations",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_attachment_propagations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_attachment_propagations };
        }
    },
    Response: type = struct {
        transit_gateway_attachment_propagations: ?[]struct {
            transit_gateway_route_table_id: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_route_table_id = "transitGatewayRouteTableId",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_propagations = "transitGatewayAttachmentPropagations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_multicast_domain_associations: struct {
    action_name: []const u8 = "GetTransitGatewayMulticastDomainAssociations",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_multicast_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_multicast_domain_associations };
        }
    },
    Response: type = struct {
        multicast_domain_associations: ?[]struct {
            transit_gateway_attachment_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            subnet: ?SubnetAssociation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_attachment_id = "transitGatewayAttachmentId",
                    .resource_id = "resourceId",
                    .resource_type = "resourceType",
                    .resource_owner_id = "resourceOwnerId",
                    .subnet = "subnet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multicast_domain_associations = "multicastDomainAssociations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_policy_table_associations: struct {
    action_name: []const u8 = "GetTransitGatewayPolicyTableAssociations",
    Request: type = struct {
        transit_gateway_policy_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_id = "TransitGatewayPolicyTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_policy_table_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_policy_table_associations };
        }
    },
    Response: type = struct {
        associations: ?[]TransitGatewayPolicyTableAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_policy_table_entries: struct {
    action_name: []const u8 = "GetTransitGatewayPolicyTableEntries",
    Request: type = struct {
        transit_gateway_policy_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_id = "TransitGatewayPolicyTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_policy_table_entries) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_policy_table_entries };
        }
    },
    Response: type = struct {
        transit_gateway_policy_table_entries: ?[]struct {
            policy_rule_number: ?[]const u8 = null,
            policy_rule: ?struct {
                source_cidr_block: ?[]const u8 = null,
                source_port_range: ?[]const u8 = null,
                destination_cidr_block: ?[]const u8 = null,
                destination_port_range: ?[]const u8 = null,
                protocol: ?[]const u8 = null,
                meta_data: ?struct {
                    meta_data_key: ?[]const u8 = null,
                    meta_data_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .meta_data_key = "metaDataKey",
                            .meta_data_value = "metaDataValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .source_cidr_block = "sourceCidrBlock",
                        .source_port_range = "sourcePortRange",
                        .destination_cidr_block = "destinationCidrBlock",
                        .destination_port_range = "destinationPortRange",
                        .protocol = "protocol",
                        .meta_data = "metaData",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            target_route_table_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_rule_number = "policyRuleNumber",
                    .policy_rule = "policyRule",
                    .target_route_table_id = "targetRouteTableId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_policy_table_entries = "transitGatewayPolicyTableEntries",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_prefix_list_references: struct {
    action_name: []const u8 = "GetTransitGatewayPrefixListReferences",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_prefix_list_references) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_prefix_list_references };
        }
    },
    Response: type = struct {
        transit_gateway_prefix_list_references: ?[]TransitGatewayPrefixListReference = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_prefix_list_references = "transitGatewayPrefixListReferenceSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_route_table_associations: struct {
    action_name: []const u8 = "GetTransitGatewayRouteTableAssociations",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_route_table_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_route_table_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            transit_gateway_attachment_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_attachment_id = "transitGatewayAttachmentId",
                    .resource_id = "resourceId",
                    .resource_type = "resourceType",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_transit_gateway_route_table_propagations: struct {
    action_name: []const u8 = "GetTransitGatewayRouteTablePropagations",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_route_table_propagations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_route_table_propagations };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_propagations: ?[]struct {
            transit_gateway_attachment_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            transit_gateway_route_table_announcement_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_attachment_id = "transitGatewayAttachmentId",
                    .resource_id = "resourceId",
                    .resource_type = "resourceType",
                    .state = "state",
                    .transit_gateway_route_table_announcement_id = "transitGatewayRouteTableAnnouncementId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_propagations = "transitGatewayRouteTablePropagations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_verified_access_endpoint_policy: struct {
    action_name: []const u8 = "GetVerifiedAccessEndpointPolicy",
    Request: type = struct {
        verified_access_endpoint_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint_id = "VerifiedAccessEndpointId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_verified_access_endpoint_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_verified_access_endpoint_policy };
        }
    },
    Response: type = struct {
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_enabled = "policyEnabled",
                .policy_document = "policyDocument",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_verified_access_group_policy: struct {
    action_name: []const u8 = "GetVerifiedAccessGroupPolicy",
    Request: type = struct {
        verified_access_group_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_id = "VerifiedAccessGroupId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_verified_access_group_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_verified_access_group_policy };
        }
    },
    Response: type = struct {
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_enabled = "policyEnabled",
                .policy_document = "policyDocument",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_vpn_connection_device_sample_configuration: struct {
    action_name: []const u8 = "GetVpnConnectionDeviceSampleConfiguration",
    Request: type = struct {
        vpn_connection_id: []const u8,
        vpn_connection_device_type_id: []const u8,
        internet_key_exchange_version: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .vpn_connection_device_type_id = "VpnConnectionDeviceTypeId",
                .internet_key_exchange_version = "InternetKeyExchangeVersion",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpn_connection_device_sample_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_vpn_connection_device_sample_configuration };
        }
    },
    Response: type = struct {
        vpn_connection_device_sample_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_device_sample_configuration = "vpnConnectionDeviceSampleConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_vpn_connection_device_types: struct {
    action_name: []const u8 = "GetVpnConnectionDeviceTypes",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpn_connection_device_types) } {
            return .{ .service_metadata = service_metadata, .action = get_vpn_connection_device_types };
        }
    },
    Response: type = struct {
        vpn_connection_device_types: ?[]struct {
            vpn_connection_device_type_id: ?[]const u8 = null,
            vendor: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            software: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpn_connection_device_type_id = "vpnConnectionDeviceTypeId",
                    .vendor = "vendor",
                    .platform = "platform",
                    .software = "software",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_device_types = "vpnConnectionDeviceTypeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_vpn_tunnel_replacement_status: struct {
    action_name: []const u8 = "GetVpnTunnelReplacementStatus",
    Request: type = struct {
        vpn_connection_id: []const u8,
        vpn_tunnel_outside_ip_address: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .vpn_tunnel_outside_ip_address = "VpnTunnelOutsideIpAddress",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpn_tunnel_replacement_status) } {
            return .{ .service_metadata = service_metadata, .action = get_vpn_tunnel_replacement_status };
        }
    },
    Response: type = struct {
        vpn_connection_id: ?[]const u8 = null,
        transit_gateway_id: ?[]const u8 = null,
        customer_gateway_id: ?[]const u8 = null,
        vpn_gateway_id: ?[]const u8 = null,
        vpn_tunnel_outside_ip_address: ?[]const u8 = null,
        maintenance_details: ?struct {
            pending_maintenance: ?[]const u8 = null,
            maintenance_auto_applied_after: ?i64 = null,
            last_maintenance_applied: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pending_maintenance = "pendingMaintenance",
                    .maintenance_auto_applied_after = "maintenanceAutoAppliedAfter",
                    .last_maintenance_applied = "lastMaintenanceApplied",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "vpnConnectionId",
                .transit_gateway_id = "transitGatewayId",
                .customer_gateway_id = "customerGatewayId",
                .vpn_gateway_id = "vpnGatewayId",
                .vpn_tunnel_outside_ip_address = "vpnTunnelOutsideIpAddress",
                .maintenance_details = "maintenanceDetails",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_client_vpn_client_certificate_revocation_list: struct {
    action_name: []const u8 = "ImportClientVpnClientCertificateRevocationList",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        certificate_revocation_list: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .certificate_revocation_list = "CertificateRevocationList",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_client_vpn_client_certificate_revocation_list) } {
            return .{ .service_metadata = service_metadata, .action = import_client_vpn_client_certificate_revocation_list };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_image: struct {
    action_name: []const u8 = "ImportImage",
    Request: type = struct {
        architecture: ?[]const u8 = null,
        client_data: ?ClientData = null,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        disk_containers: ?[]struct {
            description: ?[]const u8 = null,
            device_name: ?[]const u8 = null,
            format: ?[]const u8 = null,
            snapshot_id: ?[]const u8 = null,
            url: ?[]const u8 = null,
            user_bucket: ?UserBucket = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .device_name = "DeviceName",
                    .format = "Format",
                    .snapshot_id = "SnapshotId",
                    .url = "Url",
                    .user_bucket = "UserBucket",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,
        encrypted: ?bool = null,
        hypervisor: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        license_type: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        license_specifications: ?[]struct {
            license_configuration_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .license_configuration_arn = "LicenseConfigurationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        usage_operation: ?[]const u8 = null,
        boot_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .architecture = "Architecture",
                .client_data = "ClientData",
                .client_token = "ClientToken",
                .description = "Description",
                .disk_containers = "DiskContainer",
                .dry_run = "DryRun",
                .encrypted = "Encrypted",
                .hypervisor = "Hypervisor",
                .kms_key_id = "KmsKeyId",
                .license_type = "LicenseType",
                .platform = "Platform",
                .role_name = "RoleName",
                .license_specifications = "LicenseSpecifications",
                .tag_specifications = "TagSpecification",
                .usage_operation = "UsageOperation",
                .boot_mode = "BootMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_image) } {
            return .{ .service_metadata = service_metadata, .action = import_image };
        }
    },
    Response: type = struct {
        architecture: ?[]const u8 = null,
        description: ?[]const u8 = null,
        encrypted: ?bool = null,
        hypervisor: ?[]const u8 = null,
        image_id: ?[]const u8 = null,
        import_task_id: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        license_type: ?[]const u8 = null,
        platform: ?[]const u8 = null,
        progress: ?[]const u8 = null,
        snapshot_details: ?[]SnapshotDetail = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        license_specifications: ?[]ImportImageLicenseConfigurationResponse = null,
        tags: ?[]Tag = null,
        usage_operation: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .architecture = "architecture",
                .description = "description",
                .encrypted = "encrypted",
                .hypervisor = "hypervisor",
                .image_id = "imageId",
                .import_task_id = "importTaskId",
                .kms_key_id = "kmsKeyId",
                .license_type = "licenseType",
                .platform = "platform",
                .progress = "progress",
                .snapshot_details = "snapshotDetailSet",
                .status = "status",
                .status_message = "statusMessage",
                .license_specifications = "licenseSpecifications",
                .tags = "tagSet",
                .usage_operation = "usageOperation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_instance: struct {
    action_name: []const u8 = "ImportInstance",
    Request: type = struct {
        description: ?[]const u8 = null,
        disk_images: ?[]struct {
            description: ?[]const u8 = null,
            image: ?DiskImageDetail = null,
            volume: ?VolumeDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .image = "Image",
                    .volume = "Volume",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,
        launch_specification: ?struct {
            additional_info: ?[]const u8 = null,
            architecture: ?[]const u8 = null,
            group_ids: ?[][]const u8 = null,
            group_names: ?[][]const u8 = null,
            instance_initiated_shutdown_behavior: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            monitoring: ?bool = null,
            placement: ?Placement = null,
            private_ip_address: ?[]const u8 = null,
            subnet_id: ?[]const u8 = null,
            user_data: ?struct {
                data: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data = "data",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .additional_info = "additionalInfo",
                    .architecture = "architecture",
                    .group_ids = "GroupId",
                    .group_names = "GroupName",
                    .instance_initiated_shutdown_behavior = "instanceInitiatedShutdownBehavior",
                    .instance_type = "instanceType",
                    .monitoring = "monitoring",
                    .placement = "placement",
                    .private_ip_address = "privateIpAddress",
                    .subnet_id = "subnetId",
                    .user_data = "userData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        platform: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .disk_images = "diskImage",
                .dry_run = "dryRun",
                .launch_specification = "launchSpecification",
                .platform = "platform",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_instance) } {
            return .{ .service_metadata = service_metadata, .action = import_instance };
        }
    },
    Response: type = struct {
        conversion_task: ?ConversionTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversion_task = "conversionTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_key_pair: struct {
    action_name: []const u8 = "ImportKeyPair",
    Request: type = struct {
        dry_run: ?bool = null,
        key_name: []const u8,
        public_key_material: []const u8,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .key_name = "keyName",
                .public_key_material = "publicKeyMaterial",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_key_pair) } {
            return .{ .service_metadata = service_metadata, .action = import_key_pair };
        }
    },
    Response: type = struct {
        key_fingerprint: ?[]const u8 = null,
        key_name: ?[]const u8 = null,
        key_pair_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_fingerprint = "keyFingerprint",
                .key_name = "keyName",
                .key_pair_id = "keyPairId",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_snapshot: struct {
    action_name: []const u8 = "ImportSnapshot",
    Request: type = struct {
        client_data: ?ClientData = null,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        disk_container: ?struct {
            description: ?[]const u8 = null,
            format: ?[]const u8 = null,
            url: ?[]const u8 = null,
            user_bucket: ?UserBucket = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .format = "Format",
                    .url = "Url",
                    .user_bucket = "UserBucket",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_data = "ClientData",
                .client_token = "ClientToken",
                .description = "Description",
                .disk_container = "DiskContainer",
                .dry_run = "DryRun",
                .encrypted = "Encrypted",
                .kms_key_id = "KmsKeyId",
                .role_name = "RoleName",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = import_snapshot };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        import_task_id: ?[]const u8 = null,
        snapshot_task_detail: ?SnapshotTaskDetail = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .import_task_id = "importTaskId",
                .snapshot_task_detail = "snapshotTaskDetail",
                .tags = "tagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const import_volume: struct {
    action_name: []const u8 = "ImportVolume",
    Request: type = struct {
        availability_zone: []const u8,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        image: DiskImageDetail,
        volume: VolumeDetail,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "availabilityZone",
                .description = "description",
                .dry_run = "dryRun",
                .image = "image",
                .volume = "volume",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_volume) } {
            return .{ .service_metadata = service_metadata, .action = import_volume };
        }
    },
    Response: type = struct {
        conversion_task: ?ConversionTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversion_task = "conversionTask",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_images_in_recycle_bin: struct {
    action_name: []const u8 = "ListImagesInRecycleBin",
    Request: type = struct {
        image_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "ImageId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_images_in_recycle_bin) } {
            return .{ .service_metadata = service_metadata, .action = list_images_in_recycle_bin };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            image_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            recycle_bin_enter_time: ?i64 = null,
            recycle_bin_exit_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_id = "imageId",
                    .name = "name",
                    .description = "description",
                    .recycle_bin_enter_time = "recycleBinEnterTime",
                    .recycle_bin_exit_time = "recycleBinExitTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "imageSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_snapshots_in_recycle_bin: struct {
    action_name: []const u8 = "ListSnapshotsInRecycleBin",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        snapshot_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .snapshot_ids = "SnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_snapshots_in_recycle_bin) } {
            return .{ .service_metadata = service_metadata, .action = list_snapshots_in_recycle_bin };
        }
    },
    Response: type = struct {
        snapshots: ?[]struct {
            snapshot_id: ?[]const u8 = null,
            recycle_bin_enter_time: ?i64 = null,
            recycle_bin_exit_time: ?i64 = null,
            description: ?[]const u8 = null,
            volume_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .snapshot_id = "snapshotId",
                    .recycle_bin_enter_time = "recycleBinEnterTime",
                    .recycle_bin_exit_time = "recycleBinExitTime",
                    .description = "description",
                    .volume_id = "volumeId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshots = "snapshotSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const lock_snapshot: struct {
    action_name: []const u8 = "LockSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,
        dry_run: ?bool = null,
        lock_mode: []const u8,
        cool_off_period: ?i64 = null,
        lock_duration: ?i64 = null,
        expiration_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .dry_run = "DryRun",
                .lock_mode = "LockMode",
                .cool_off_period = "CoolOffPeriod",
                .lock_duration = "LockDuration",
                .expiration_date = "ExpirationDate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lock_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = lock_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        lock_state: ?[]const u8 = null,
        lock_duration: ?i64 = null,
        cool_off_period: ?i64 = null,
        cool_off_period_expires_on: ?i64 = null,
        lock_created_on: ?i64 = null,
        lock_expires_on: ?i64 = null,
        lock_duration_start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
                .lock_state = "lockState",
                .lock_duration = "lockDuration",
                .cool_off_period = "coolOffPeriod",
                .cool_off_period_expires_on = "coolOffPeriodExpiresOn",
                .lock_created_on = "lockCreatedOn",
                .lock_expires_on = "lockExpiresOn",
                .lock_duration_start_time = "lockDurationStartTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_address_attribute: struct {
    action_name: []const u8 = "ModifyAddressAttribute",
    Request: type = struct {
        allocation_id: []const u8,
        domain_name: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .domain_name = "DomainName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_address_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_address_attribute };
        }
    },
    Response: type = struct {
        address: ?AddressAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "address",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_availability_zone_group: struct {
    action_name: []const u8 = "ModifyAvailabilityZoneGroup",
    Request: type = struct {
        group_name: []const u8,
        opt_in_status: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .opt_in_status = "OptInStatus",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_availability_zone_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_availability_zone_group };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_capacity_reservation: struct {
    action_name: []const u8 = "ModifyCapacityReservation",
    Request: type = struct {
        capacity_reservation_id: []const u8,
        instance_count: ?i64 = null,
        end_date: ?i64 = null,
        end_date_type: ?[]const u8 = null,
        accept: ?bool = null,
        dry_run: ?bool = null,
        additional_info: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_id = "CapacityReservationId",
                .instance_count = "InstanceCount",
                .end_date = "EndDate",
                .end_date_type = "EndDateType",
                .accept = "Accept",
                .dry_run = "DryRun",
                .additional_info = "AdditionalInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_capacity_reservation) } {
            return .{ .service_metadata = service_metadata, .action = modify_capacity_reservation };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_capacity_reservation_fleet: struct {
    action_name: []const u8 = "ModifyCapacityReservationFleet",
    Request: type = struct {
        capacity_reservation_fleet_id: []const u8,
        total_target_capacity: ?i64 = null,
        end_date: ?i64 = null,
        dry_run: ?bool = null,
        remove_end_date: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation_fleet_id = "CapacityReservationFleetId",
                .total_target_capacity = "TotalTargetCapacity",
                .end_date = "EndDate",
                .dry_run = "DryRun",
                .remove_end_date = "RemoveEndDate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_capacity_reservation_fleet) } {
            return .{ .service_metadata = service_metadata, .action = modify_capacity_reservation_fleet };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_client_vpn_endpoint: struct {
    action_name: []const u8 = "ModifyClientVpnEndpoint",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        server_certificate_arn: ?[]const u8 = null,
        connection_log_options: ?ConnectionLogOptions = null,
        dns_servers: ?struct {
            custom_dns_servers: ?[][]const u8 = null,
            enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .custom_dns_servers = "CustomDnsServers",
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        vpn_port: ?i64 = null,
        description: ?[]const u8 = null,
        split_tunnel: ?bool = null,
        dry_run: ?bool = null,
        security_group_ids: ?[][]const u8 = null,
        vpc_id: ?[]const u8 = null,
        self_service_portal: ?[]const u8 = null,
        client_connect_options: ?ClientConnectOptions = null,
        session_timeout_hours: ?i64 = null,
        client_login_banner_options: ?ClientLoginBannerOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .server_certificate_arn = "ServerCertificateArn",
                .connection_log_options = "ConnectionLogOptions",
                .dns_servers = "DnsServers",
                .vpn_port = "VpnPort",
                .description = "Description",
                .split_tunnel = "SplitTunnel",
                .dry_run = "DryRun",
                .security_group_ids = "SecurityGroupId",
                .vpc_id = "VpcId",
                .self_service_portal = "SelfServicePortal",
                .client_connect_options = "ClientConnectOptions",
                .session_timeout_hours = "SessionTimeoutHours",
                .client_login_banner_options = "ClientLoginBannerOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_client_vpn_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_client_vpn_endpoint };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_default_credit_specification: struct {
    action_name: []const u8 = "ModifyDefaultCreditSpecification",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_family: []const u8,
        cpu_credits: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_family = "InstanceFamily",
                .cpu_credits = "CpuCredits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_default_credit_specification) } {
            return .{ .service_metadata = service_metadata, .action = modify_default_credit_specification };
        }
    },
    Response: type = struct {
        instance_family_credit_specification: ?InstanceFamilyCreditSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_family_credit_specification = "instanceFamilyCreditSpecification",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ebs_default_kms_key_id: struct {
    action_name: []const u8 = "ModifyEbsDefaultKmsKeyId",
    Request: type = struct {
        kms_key_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "KmsKeyId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ebs_default_kms_key_id) } {
            return .{ .service_metadata = service_metadata, .action = modify_ebs_default_kms_key_id };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_fleet: struct {
    action_name: []const u8 = "ModifyFleet",
    Request: type = struct {
        dry_run: ?bool = null,
        excess_capacity_termination_policy: ?[]const u8 = null,
        launch_template_configs: ?[]FleetLaunchTemplateConfigRequest = null,
        fleet_id: []const u8,
        target_capacity_specification: ?TargetCapacitySpecificationRequest = null,
        context: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .excess_capacity_termination_policy = "ExcessCapacityTerminationPolicy",
                .launch_template_configs = "LaunchTemplateConfig",
                .fleet_id = "FleetId",
                .target_capacity_specification = "TargetCapacitySpecification",
                .context = "Context",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_fleet) } {
            return .{ .service_metadata = service_metadata, .action = modify_fleet };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_fpga_image_attribute: struct {
    action_name: []const u8 = "ModifyFpgaImageAttribute",
    Request: type = struct {
        dry_run: ?bool = null,
        fpga_image_id: []const u8,
        attribute: ?[]const u8 = null,
        operation_type: ?[]const u8 = null,
        user_ids: ?[][]const u8 = null,
        user_groups: ?[][]const u8 = null,
        product_codes: ?[][]const u8 = null,
        load_permission: ?struct {
            add: ?[]LoadPermissionRequest = null,
            remove: ?[]LoadPermissionRequest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add = "Add",
                    .remove = "Remove",
                };
                return @field(mappings, field_name);
            }
        } = null,
        description: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fpga_image_id = "FpgaImageId",
                .attribute = "Attribute",
                .operation_type = "OperationType",
                .user_ids = "UserId",
                .user_groups = "UserGroup",
                .product_codes = "ProductCode",
                .load_permission = "LoadPermission",
                .description = "Description",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_fpga_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_fpga_image_attribute };
        }
    },
    Response: type = struct {
        fpga_image_attribute: ?FpgaImageAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fpga_image_attribute = "fpgaImageAttribute",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_hosts: struct {
    action_name: []const u8 = "ModifyHosts",
    Request: type = struct {
        auto_placement: ?[]const u8 = null,
        host_ids: [][]const u8,
        host_recovery: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        instance_family: ?[]const u8 = null,
        host_maintenance: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_placement = "autoPlacement",
                .host_ids = "hostId",
                .host_recovery = "HostRecovery",
                .instance_type = "InstanceType",
                .instance_family = "InstanceFamily",
                .host_maintenance = "HostMaintenance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_hosts) } {
            return .{ .service_metadata = service_metadata, .action = modify_hosts };
        }
    },
    Response: type = struct {
        successful: ?[][]const u8 = null,
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_identity_id_format: struct {
    action_name: []const u8 = "ModifyIdentityIdFormat",
    Request: type = struct {
        principal_arn: []const u8,
        resource: []const u8,
        use_long_ids: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_arn = "principalArn",
                .resource = "resource",
                .use_long_ids = "useLongIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_identity_id_format) } {
            return .{ .service_metadata = service_metadata, .action = modify_identity_id_format };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_id_format: struct {
    action_name: []const u8 = "ModifyIdFormat",
    Request: type = struct {
        resource: []const u8,
        use_long_ids: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .use_long_ids = "UseLongIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_id_format) } {
            return .{ .service_metadata = service_metadata, .action = modify_id_format };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_image_attribute: struct {
    action_name: []const u8 = "ModifyImageAttribute",
    Request: type = struct {
        attribute: ?[]const u8 = null,
        description: ?AttributeValue = null,
        image_id: []const u8,
        launch_permission: ?struct {
            add: ?[]LaunchPermission = null,
            remove: ?[]LaunchPermission = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add = "Add",
                    .remove = "Remove",
                };
                return @field(mappings, field_name);
            }
        } = null,
        operation_type: ?[]const u8 = null,
        product_codes: ?[][]const u8 = null,
        user_groups: ?[][]const u8 = null,
        user_ids: ?[][]const u8 = null,
        value: ?[]const u8 = null,
        dry_run: ?bool = null,
        organization_arns: ?[][]const u8 = null,
        organizational_unit_arns: ?[][]const u8 = null,
        imds_support: ?AttributeValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .description = "Description",
                .image_id = "ImageId",
                .launch_permission = "LaunchPermission",
                .operation_type = "OperationType",
                .product_codes = "ProductCode",
                .user_groups = "UserGroup",
                .user_ids = "UserId",
                .value = "Value",
                .dry_run = "dryRun",
                .organization_arns = "OrganizationArn",
                .organizational_unit_arns = "OrganizationalUnitArn",
                .imds_support = "ImdsSupport",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_image_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_instance_attribute: struct {
    action_name: []const u8 = "ModifyInstanceAttribute",
    Request: type = struct {
        source_dest_check: ?AttributeBooleanValue = null,
        attribute: ?[]const u8 = null,
        block_device_mappings: ?[]struct {
            device_name: ?[]const u8 = null,
            ebs: ?struct {
                delete_on_termination: ?bool = null,
                volume_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .delete_on_termination = "deleteOnTermination",
                        .volume_id = "volumeId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            no_device: ?[]const u8 = null,
            virtual_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_name = "deviceName",
                    .ebs = "ebs",
                    .no_device = "noDevice",
                    .virtual_name = "virtualName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        disable_api_termination: ?AttributeBooleanValue = null,
        dry_run: ?bool = null,
        ebs_optimized: ?AttributeBooleanValue = null,
        ena_support: ?AttributeBooleanValue = null,
        groups: ?[][]const u8 = null,
        instance_id: []const u8,
        instance_initiated_shutdown_behavior: ?AttributeValue = null,
        instance_type: ?AttributeValue = null,
        kernel: ?AttributeValue = null,
        ramdisk: ?AttributeValue = null,
        sriov_net_support: ?AttributeValue = null,
        user_data: ?struct {
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        value: ?[]const u8 = null,
        disable_api_stop: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_dest_check = "SourceDestCheck",
                .attribute = "attribute",
                .block_device_mappings = "blockDeviceMapping",
                .disable_api_termination = "disableApiTermination",
                .dry_run = "dryRun",
                .ebs_optimized = "ebsOptimized",
                .ena_support = "enaSupport",
                .groups = "GroupId",
                .instance_id = "instanceId",
                .instance_initiated_shutdown_behavior = "instanceInitiatedShutdownBehavior",
                .instance_type = "instanceType",
                .kernel = "kernel",
                .ramdisk = "ramdisk",
                .sriov_net_support = "sriovNetSupport",
                .user_data = "userData",
                .value = "value",
                .disable_api_stop = "DisableApiStop",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_instance_capacity_reservation_attributes: struct {
    action_name: []const u8 = "ModifyInstanceCapacityReservationAttributes",
    Request: type = struct {
        instance_id: []const u8,
        capacity_reservation_specification: CapacityReservationSpecification,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .capacity_reservation_specification = "CapacityReservationSpecification",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_capacity_reservation_attributes) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_capacity_reservation_attributes };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_credit_specification: struct {
    action_name: []const u8 = "ModifyInstanceCreditSpecification",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        instance_credit_specifications: []struct {
            instance_id: []const u8,
            cpu_credits: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .cpu_credits = "CpuCredits",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .instance_credit_specifications = "InstanceCreditSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_credit_specification) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_credit_specification };
        }
    },
    Response: type = struct {
        successful_instance_credit_specifications: ?[]struct {
            instance_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "instanceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful_instance_credit_specifications: ?[]struct {
            instance_id: ?[]const u8 = null,
            @"error": ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "instanceId",
                    .@"error" = "error",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_instance_credit_specifications = "successfulInstanceCreditSpecificationSet",
                .unsuccessful_instance_credit_specifications = "unsuccessfulInstanceCreditSpecificationSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_event_start_time: struct {
    action_name: []const u8 = "ModifyInstanceEventStartTime",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_id: []const u8,
        instance_event_id: []const u8,
        not_before: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_id = "InstanceId",
                .instance_event_id = "InstanceEventId",
                .not_before = "NotBefore",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_event_start_time) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_event_start_time };
        }
    },
    Response: type = struct {
        event: ?InstanceStatusEvent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event = "event",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_event_window: struct {
    action_name: []const u8 = "ModifyInstanceEventWindow",
    Request: type = struct {
        dry_run: ?bool = null,
        name: ?[]const u8 = null,
        instance_event_window_id: []const u8,
        time_ranges: ?[]InstanceEventWindowTimeRangeRequest = null,
        cron_expression: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .name = "Name",
                .instance_event_window_id = "InstanceEventWindowId",
                .time_ranges = "TimeRange",
                .cron_expression = "CronExpression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_event_window) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_event_window };
        }
    },
    Response: type = struct {
        instance_event_window: ?InstanceEventWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_event_window = "instanceEventWindow",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_maintenance_options: struct {
    action_name: []const u8 = "ModifyInstanceMaintenanceOptions",
    Request: type = struct {
        instance_id: []const u8,
        auto_recovery: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .auto_recovery = "AutoRecovery",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_maintenance_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_maintenance_options };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        auto_recovery: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "instanceId",
                .auto_recovery = "autoRecovery",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_metadata_options: struct {
    action_name: []const u8 = "ModifyInstanceMetadataOptions",
    Request: type = struct {
        instance_id: []const u8,
        http_tokens: ?[]const u8 = null,
        http_put_response_hop_limit: ?i64 = null,
        http_endpoint: ?[]const u8 = null,
        dry_run: ?bool = null,
        http_protocol_ipv6: ?[]const u8 = null,
        instance_metadata_tags: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .http_tokens = "HttpTokens",
                .http_put_response_hop_limit = "HttpPutResponseHopLimit",
                .http_endpoint = "HttpEndpoint",
                .dry_run = "DryRun",
                .http_protocol_ipv6 = "HttpProtocolIpv6",
                .instance_metadata_tags = "InstanceMetadataTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_metadata_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_metadata_options };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        instance_metadata_options: ?InstanceMetadataOptionsResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "instanceId",
                .instance_metadata_options = "instanceMetadataOptions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_instance_placement: struct {
    action_name: []const u8 = "ModifyInstancePlacement",
    Request: type = struct {
        affinity: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        host_id: ?[]const u8 = null,
        instance_id: []const u8,
        tenancy: ?[]const u8 = null,
        partition_number: ?i64 = null,
        host_resource_group_arn: ?[]const u8 = null,
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .affinity = "affinity",
                .group_name = "GroupName",
                .host_id = "hostId",
                .instance_id = "instanceId",
                .tenancy = "tenancy",
                .partition_number = "PartitionNumber",
                .host_resource_group_arn = "HostResourceGroupArn",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_placement) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_placement };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ipam: struct {
    action_name: []const u8 = "ModifyIpam",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        description: ?[]const u8 = null,
        add_operating_regions: ?[]AddIpamOperatingRegion = null,
        remove_operating_regions: ?[]RemoveIpamOperatingRegion = null,
        tier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .description = "Description",
                .add_operating_regions = "AddOperatingRegion",
                .remove_operating_regions = "RemoveOperatingRegion",
                .tier = "Tier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ipam) } {
            return .{ .service_metadata = service_metadata, .action = modify_ipam };
        }
    },
    Response: type = struct {
        ipam: ?Ipam = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam = "ipam",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ipam_pool: struct {
    action_name: []const u8 = "ModifyIpamPool",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        description: ?[]const u8 = null,
        auto_import: ?bool = null,
        allocation_min_netmask_length: ?i64 = null,
        allocation_max_netmask_length: ?i64 = null,
        allocation_default_netmask_length: ?i64 = null,
        clear_allocation_default_netmask_length: ?bool = null,
        add_allocation_resource_tags: ?[]RequestIpamResourceTag = null,
        remove_allocation_resource_tags: ?[]RequestIpamResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .description = "Description",
                .auto_import = "AutoImport",
                .allocation_min_netmask_length = "AllocationMinNetmaskLength",
                .allocation_max_netmask_length = "AllocationMaxNetmaskLength",
                .allocation_default_netmask_length = "AllocationDefaultNetmaskLength",
                .clear_allocation_default_netmask_length = "ClearAllocationDefaultNetmaskLength",
                .add_allocation_resource_tags = "AddAllocationResourceTag",
                .remove_allocation_resource_tags = "RemoveAllocationResourceTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ipam_pool) } {
            return .{ .service_metadata = service_metadata, .action = modify_ipam_pool };
        }
    },
    Response: type = struct {
        ipam_pool: ?IpamPool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool = "ipamPool",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ipam_resource_cidr: struct {
    action_name: []const u8 = "ModifyIpamResourceCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        resource_id: []const u8,
        resource_cidr: []const u8,
        resource_region: []const u8,
        current_ipam_scope_id: []const u8,
        destination_ipam_scope_id: ?[]const u8 = null,
        monitored: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .resource_id = "ResourceId",
                .resource_cidr = "ResourceCidr",
                .resource_region = "ResourceRegion",
                .current_ipam_scope_id = "CurrentIpamScopeId",
                .destination_ipam_scope_id = "DestinationIpamScopeId",
                .monitored = "Monitored",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ipam_resource_cidr) } {
            return .{ .service_metadata = service_metadata, .action = modify_ipam_resource_cidr };
        }
    },
    Response: type = struct {
        ipam_resource_cidr: ?IpamResourceCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_cidr = "ipamResourceCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ipam_resource_discovery: struct {
    action_name: []const u8 = "ModifyIpamResourceDiscovery",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_resource_discovery_id: []const u8,
        description: ?[]const u8 = null,
        add_operating_regions: ?[]AddIpamOperatingRegion = null,
        remove_operating_regions: ?[]RemoveIpamOperatingRegion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_resource_discovery_id = "IpamResourceDiscoveryId",
                .description = "Description",
                .add_operating_regions = "AddOperatingRegion",
                .remove_operating_regions = "RemoveOperatingRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ipam_resource_discovery) } {
            return .{ .service_metadata = service_metadata, .action = modify_ipam_resource_discovery };
        }
    },
    Response: type = struct {
        ipam_resource_discovery: ?IpamResourceDiscovery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_resource_discovery = "ipamResourceDiscovery",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_ipam_scope: struct {
    action_name: []const u8 = "ModifyIpamScope",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_scope_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_scope_id = "IpamScopeId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_ipam_scope) } {
            return .{ .service_metadata = service_metadata, .action = modify_ipam_scope };
        }
    },
    Response: type = struct {
        ipam_scope: ?IpamScope = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_scope = "ipamScope",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_launch_template: struct {
    action_name: []const u8 = "ModifyLaunchTemplate",
    Request: type = struct {
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        launch_template_id: ?[]const u8 = null,
        launch_template_name: ?[]const u8 = null,
        default_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .launch_template_id = "LaunchTemplateId",
                .launch_template_name = "LaunchTemplateName",
                .default_version = "SetDefaultVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_launch_template) } {
            return .{ .service_metadata = service_metadata, .action = modify_launch_template };
        }
    },
    Response: type = struct {
        launch_template: ?LaunchTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_template = "launchTemplate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_local_gateway_route: struct {
    action_name: []const u8 = "ModifyLocalGatewayRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        local_gateway_route_table_id: []const u8,
        local_gateway_virtual_interface_group_id: ?[]const u8 = null,
        network_interface_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        destination_prefix_list_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .local_gateway_virtual_interface_group_id = "LocalGatewayVirtualInterfaceGroupId",
                .network_interface_id = "NetworkInterfaceId",
                .dry_run = "DryRun",
                .destination_prefix_list_id = "DestinationPrefixListId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_local_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = modify_local_gateway_route };
        }
    },
    Response: type = struct {
        route: ?LocalGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_managed_prefix_list: struct {
    action_name: []const u8 = "ModifyManagedPrefixList",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_id: []const u8,
        current_version: ?i64 = null,
        prefix_list_name: ?[]const u8 = null,
        add_entries: ?[]AddPrefixListEntry = null,
        remove_entries: ?[]struct {
            cidr: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cidr = "Cidr",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_entries: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_id = "PrefixListId",
                .current_version = "CurrentVersion",
                .prefix_list_name = "PrefixListName",
                .add_entries = "AddEntry",
                .remove_entries = "RemoveEntry",
                .max_entries = "MaxEntries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_managed_prefix_list) } {
            return .{ .service_metadata = service_metadata, .action = modify_managed_prefix_list };
        }
    },
    Response: type = struct {
        prefix_list: ?ManagedPrefixList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prefix_list = "prefixList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_network_interface_attribute: struct {
    action_name: []const u8 = "ModifyNetworkInterfaceAttribute",
    Request: type = struct {
        attachment: ?struct {
            attachment_id: ?[]const u8 = null,
            delete_on_termination: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attachment_id = "attachmentId",
                    .delete_on_termination = "deleteOnTermination",
                };
                return @field(mappings, field_name);
            }
        } = null,
        description: ?AttributeValue = null,
        dry_run: ?bool = null,
        groups: ?[][]const u8 = null,
        network_interface_id: []const u8,
        source_dest_check: ?AttributeBooleanValue = null,
        ena_srd_specification: ?EnaSrdSpecification = null,
        enable_primary_ipv6: ?bool = null,
        connection_tracking_specification: ?ConnectionTrackingSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "attachment",
                .description = "description",
                .dry_run = "dryRun",
                .groups = "SecurityGroupId",
                .network_interface_id = "networkInterfaceId",
                .source_dest_check = "sourceDestCheck",
                .ena_srd_specification = "EnaSrdSpecification",
                .enable_primary_ipv6 = "EnablePrimaryIpv6",
                .connection_tracking_specification = "ConnectionTrackingSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_network_interface_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_network_interface_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_private_dns_name_options: struct {
    action_name: []const u8 = "ModifyPrivateDnsNameOptions",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_id: []const u8,
        private_dns_hostname_type: ?[]const u8 = null,
        enable_resource_name_dns_a_record: ?bool = null,
        enable_resource_name_dns_aaaa_record: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_id = "InstanceId",
                .private_dns_hostname_type = "PrivateDnsHostnameType",
                .enable_resource_name_dns_a_record = "EnableResourceNameDnsARecord",
                .enable_resource_name_dns_aaaa_record = "EnableResourceNameDnsAAAARecord",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_private_dns_name_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_private_dns_name_options };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_reserved_instances: struct {
    action_name: []const u8 = "ModifyReservedInstances",
    Request: type = struct {
        reserved_instances_ids: [][]const u8,
        client_token: ?[]const u8 = null,
        target_configurations: []ReservedInstancesConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_ids = "ReservedInstancesId",
                .client_token = "clientToken",
                .target_configurations = "ReservedInstancesConfigurationSetItemType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_reserved_instances) } {
            return .{ .service_metadata = service_metadata, .action = modify_reserved_instances };
        }
    },
    Response: type = struct {
        reserved_instances_modification_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_modification_id = "reservedInstancesModificationId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_security_group_rules: struct {
    action_name: []const u8 = "ModifySecurityGroupRules",
    Request: type = struct {
        group_id: []const u8,
        security_group_rules: []struct {
            security_group_rule_id: []const u8,
            security_group_rule: ?struct {
                ip_protocol: ?[]const u8 = null,
                from_port: ?i64 = null,
                to_port: ?i64 = null,
                cidr_ipv4: ?[]const u8 = null,
                cidr_ipv6: ?[]const u8 = null,
                prefix_list_id: ?[]const u8 = null,
                referenced_group_id: ?[]const u8 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ip_protocol = "IpProtocol",
                        .from_port = "FromPort",
                        .to_port = "ToPort",
                        .cidr_ipv4 = "CidrIpv4",
                        .cidr_ipv6 = "CidrIpv6",
                        .prefix_list_id = "PrefixListId",
                        .referenced_group_id = "ReferencedGroupId",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_group_rule_id = "SecurityGroupRuleId",
                    .security_group_rule = "SecurityGroupRule",
                };
                return @field(mappings, field_name);
            }
        },
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .security_group_rules = "SecurityGroupRule",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_security_group_rules) } {
            return .{ .service_metadata = service_metadata, .action = modify_security_group_rules };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_snapshot_attribute: struct {
    action_name: []const u8 = "ModifySnapshotAttribute",
    Request: type = struct {
        attribute: ?[]const u8 = null,
        create_volume_permission: ?struct {
            add: ?[]CreateVolumePermission = null,
            remove: ?[]CreateVolumePermission = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add = "Add",
                    .remove = "Remove",
                };
                return @field(mappings, field_name);
            }
        } = null,
        group_names: ?[][]const u8 = null,
        operation_type: ?[]const u8 = null,
        snapshot_id: []const u8,
        user_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .create_volume_permission = "CreateVolumePermission",
                .group_names = "UserGroup",
                .operation_type = "OperationType",
                .snapshot_id = "SnapshotId",
                .user_ids = "UserId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_snapshot_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_snapshot_tier: struct {
    action_name: []const u8 = "ModifySnapshotTier",
    Request: type = struct {
        snapshot_id: []const u8,
        storage_tier: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .storage_tier = "StorageTier",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_snapshot_tier) } {
            return .{ .service_metadata = service_metadata, .action = modify_snapshot_tier };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        tiering_start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
                .tiering_start_time = "tieringStartTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_spot_fleet_request: struct {
    action_name: []const u8 = "ModifySpotFleetRequest",
    Request: type = struct {
        excess_capacity_termination_policy: ?[]const u8 = null,
        launch_template_configs: ?[]LaunchTemplateConfig = null,
        spot_fleet_request_id: []const u8,
        target_capacity: ?i64 = null,
        on_demand_target_capacity: ?i64 = null,
        context: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .excess_capacity_termination_policy = "excessCapacityTerminationPolicy",
                .launch_template_configs = "LaunchTemplateConfig",
                .spot_fleet_request_id = "spotFleetRequestId",
                .target_capacity = "targetCapacity",
                .on_demand_target_capacity = "OnDemandTargetCapacity",
                .context = "Context",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_spot_fleet_request) } {
            return .{ .service_metadata = service_metadata, .action = modify_spot_fleet_request };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_subnet_attribute: struct {
    action_name: []const u8 = "ModifySubnetAttribute",
    Request: type = struct {
        assign_ipv6_address_on_creation: ?AttributeBooleanValue = null,
        map_public_ip_on_launch: ?AttributeBooleanValue = null,
        subnet_id: []const u8,
        map_customer_owned_ip_on_launch: ?AttributeBooleanValue = null,
        customer_owned_ipv4_pool: ?[]const u8 = null,
        enable_dns64: ?AttributeBooleanValue = null,
        private_dns_hostname_type_on_launch: ?[]const u8 = null,
        enable_resource_name_dns_a_record_on_launch: ?AttributeBooleanValue = null,
        enable_resource_name_dns_aaaa_record_on_launch: ?AttributeBooleanValue = null,
        enable_lni_at_device_index: ?i64 = null,
        disable_lni_at_device_index: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assign_ipv6_address_on_creation = "AssignIpv6AddressOnCreation",
                .map_public_ip_on_launch = "MapPublicIpOnLaunch",
                .subnet_id = "subnetId",
                .map_customer_owned_ip_on_launch = "MapCustomerOwnedIpOnLaunch",
                .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
                .enable_dns64 = "EnableDns64",
                .private_dns_hostname_type_on_launch = "PrivateDnsHostnameTypeOnLaunch",
                .enable_resource_name_dns_a_record_on_launch = "EnableResourceNameDnsARecordOnLaunch",
                .enable_resource_name_dns_aaaa_record_on_launch = "EnableResourceNameDnsAAAARecordOnLaunch",
                .enable_lni_at_device_index = "EnableLniAtDeviceIndex",
                .disable_lni_at_device_index = "DisableLniAtDeviceIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_subnet_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_subnet_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_traffic_mirror_filter_network_services: struct {
    action_name: []const u8 = "ModifyTrafficMirrorFilterNetworkServices",
    Request: type = struct {
        traffic_mirror_filter_id: []const u8,
        add_network_services: ?[][]const u8 = null,
        remove_network_services: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_id = "TrafficMirrorFilterId",
                .add_network_services = "AddNetworkService",
                .remove_network_services = "RemoveNetworkService",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_traffic_mirror_filter_network_services) } {
            return .{ .service_metadata = service_metadata, .action = modify_traffic_mirror_filter_network_services };
        }
    },
    Response: type = struct {
        traffic_mirror_filter: ?TrafficMirrorFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter = "trafficMirrorFilter",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_traffic_mirror_filter_rule: struct {
    action_name: []const u8 = "ModifyTrafficMirrorFilterRule",
    Request: type = struct {
        traffic_mirror_filter_rule_id: []const u8,
        traffic_direction: ?[]const u8 = null,
        rule_number: ?i64 = null,
        rule_action: ?[]const u8 = null,
        destination_port_range: ?TrafficMirrorPortRangeRequest = null,
        source_port_range: ?TrafficMirrorPortRangeRequest = null,
        protocol: ?i64 = null,
        destination_cidr_block: ?[]const u8 = null,
        source_cidr_block: ?[]const u8 = null,
        description: ?[]const u8 = null,
        remove_fields: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_rule_id = "TrafficMirrorFilterRuleId",
                .traffic_direction = "TrafficDirection",
                .rule_number = "RuleNumber",
                .rule_action = "RuleAction",
                .destination_port_range = "DestinationPortRange",
                .source_port_range = "SourcePortRange",
                .protocol = "Protocol",
                .destination_cidr_block = "DestinationCidrBlock",
                .source_cidr_block = "SourceCidrBlock",
                .description = "Description",
                .remove_fields = "RemoveField",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_traffic_mirror_filter_rule) } {
            return .{ .service_metadata = service_metadata, .action = modify_traffic_mirror_filter_rule };
        }
    },
    Response: type = struct {
        traffic_mirror_filter_rule: ?TrafficMirrorFilterRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_filter_rule = "trafficMirrorFilterRule",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_traffic_mirror_session: struct {
    action_name: []const u8 = "ModifyTrafficMirrorSession",
    Request: type = struct {
        traffic_mirror_session_id: []const u8,
        traffic_mirror_target_id: ?[]const u8 = null,
        traffic_mirror_filter_id: ?[]const u8 = null,
        packet_length: ?i64 = null,
        session_number: ?i64 = null,
        virtual_network_id: ?i64 = null,
        description: ?[]const u8 = null,
        remove_fields: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session_id = "TrafficMirrorSessionId",
                .traffic_mirror_target_id = "TrafficMirrorTargetId",
                .traffic_mirror_filter_id = "TrafficMirrorFilterId",
                .packet_length = "PacketLength",
                .session_number = "SessionNumber",
                .virtual_network_id = "VirtualNetworkId",
                .description = "Description",
                .remove_fields = "RemoveField",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_traffic_mirror_session) } {
            return .{ .service_metadata = service_metadata, .action = modify_traffic_mirror_session };
        }
    },
    Response: type = struct {
        traffic_mirror_session: ?TrafficMirrorSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_mirror_session = "trafficMirrorSession",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_transit_gateway: struct {
    action_name: []const u8 = "ModifyTransitGateway",
    Request: type = struct {
        transit_gateway_id: []const u8,
        description: ?[]const u8 = null,
        options: ?struct {
            add_transit_gateway_cidr_blocks: ?[][]const u8 = null,
            remove_transit_gateway_cidr_blocks: ?[][]const u8 = null,
            vpn_ecmp_support: ?[]const u8 = null,
            dns_support: ?[]const u8 = null,
            security_group_referencing_support: ?[]const u8 = null,
            auto_accept_shared_attachments: ?[]const u8 = null,
            default_route_table_association: ?[]const u8 = null,
            association_default_route_table_id: ?[]const u8 = null,
            default_route_table_propagation: ?[]const u8 = null,
            propagation_default_route_table_id: ?[]const u8 = null,
            amazon_side_asn: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_transit_gateway_cidr_blocks = "AddTransitGatewayCidrBlocks",
                    .remove_transit_gateway_cidr_blocks = "RemoveTransitGatewayCidrBlocks",
                    .vpn_ecmp_support = "VpnEcmpSupport",
                    .dns_support = "DnsSupport",
                    .security_group_referencing_support = "SecurityGroupReferencingSupport",
                    .auto_accept_shared_attachments = "AutoAcceptSharedAttachments",
                    .default_route_table_association = "DefaultRouteTableAssociation",
                    .association_default_route_table_id = "AssociationDefaultRouteTableId",
                    .default_route_table_propagation = "DefaultRouteTablePropagation",
                    .propagation_default_route_table_id = "PropagationDefaultRouteTableId",
                    .amazon_side_asn = "AmazonSideAsn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_id = "TransitGatewayId",
                .description = "Description",
                .options = "Options",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = modify_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway: ?TransitGateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway = "transitGateway",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_transit_gateway_prefix_list_reference: struct {
    action_name: []const u8 = "ModifyTransitGatewayPrefixListReference",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        prefix_list_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        blackhole: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .prefix_list_id = "PrefixListId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .blackhole = "Blackhole",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_transit_gateway_prefix_list_reference) } {
            return .{ .service_metadata = service_metadata, .action = modify_transit_gateway_prefix_list_reference };
        }
    },
    Response: type = struct {
        transit_gateway_prefix_list_reference: ?TransitGatewayPrefixListReference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_prefix_list_reference = "transitGatewayPrefixListReference",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_transit_gateway_vpc_attachment: struct {
    action_name: []const u8 = "ModifyTransitGatewayVpcAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        add_subnet_ids: ?[][]const u8 = null,
        remove_subnet_ids: ?[][]const u8 = null,
        options: ?struct {
            dns_support: ?[]const u8 = null,
            security_group_referencing_support: ?[]const u8 = null,
            ipv6_support: ?[]const u8 = null,
            appliance_mode_support: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dns_support = "DnsSupport",
                    .security_group_referencing_support = "SecurityGroupReferencingSupport",
                    .ipv6_support = "Ipv6Support",
                    .appliance_mode_support = "ApplianceModeSupport",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .add_subnet_ids = "AddSubnetIds",
                .remove_subnet_ids = "RemoveSubnetIds",
                .options = "Options",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_transit_gateway_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = modify_transit_gateway_vpc_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachment: ?TransitGatewayVpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachment = "transitGatewayVpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_endpoint: struct {
    action_name: []const u8 = "ModifyVerifiedAccessEndpoint",
    Request: type = struct {
        verified_access_endpoint_id: []const u8,
        verified_access_group_id: ?[]const u8 = null,
        load_balancer_options: ?struct {
            subnet_ids: ?[][]const u8 = null,
            protocol: ?[]const u8 = null,
            port: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .subnet_ids = "SubnetId",
                    .protocol = "Protocol",
                    .port = "Port",
                };
                return @field(mappings, field_name);
            }
        } = null,
        network_interface_options: ?struct {
            protocol: ?[]const u8 = null,
            port: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .protocol = "Protocol",
                    .port = "Port",
                };
                return @field(mappings, field_name);
            }
        } = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint_id = "VerifiedAccessEndpointId",
                .verified_access_group_id = "VerifiedAccessGroupId",
                .load_balancer_options = "LoadBalancerOptions",
                .network_interface_options = "NetworkInterfaceOptions",
                .description = "Description",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_endpoint };
        }
    },
    Response: type = struct {
        verified_access_endpoint: ?VerifiedAccessEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint = "verifiedAccessEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_endpoint_policy: struct {
    action_name: []const u8 = "ModifyVerifiedAccessEndpointPolicy",
    Request: type = struct {
        verified_access_endpoint_id: []const u8,
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_endpoint_id = "VerifiedAccessEndpointId",
                .policy_enabled = "PolicyEnabled",
                .policy_document = "PolicyDocument",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_endpoint_policy) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_endpoint_policy };
        }
    },
    Response: type = struct {
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,
        sse_specification: ?VerifiedAccessSseSpecificationResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_enabled = "policyEnabled",
                .policy_document = "policyDocument",
                .sse_specification = "sseSpecification",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_group: struct {
    action_name: []const u8 = "ModifyVerifiedAccessGroup",
    Request: type = struct {
        verified_access_group_id: []const u8,
        verified_access_instance_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_id = "VerifiedAccessGroupId",
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .description = "Description",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_group };
        }
    },
    Response: type = struct {
        verified_access_group: ?VerifiedAccessGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group = "verifiedAccessGroup",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_group_policy: struct {
    action_name: []const u8 = "ModifyVerifiedAccessGroupPolicy",
    Request: type = struct {
        verified_access_group_id: []const u8,
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_group_id = "VerifiedAccessGroupId",
                .policy_enabled = "PolicyEnabled",
                .policy_document = "PolicyDocument",
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_group_policy) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_group_policy };
        }
    },
    Response: type = struct {
        policy_enabled: ?bool = null,
        policy_document: ?[]const u8 = null,
        sse_specification: ?VerifiedAccessSseSpecificationResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_enabled = "policyEnabled",
                .policy_document = "policyDocument",
                .sse_specification = "sseSpecification",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_instance: struct {
    action_name: []const u8 = "ModifyVerifiedAccessInstance",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .description = "Description",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_instance) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_instance };
        }
    },
    Response: type = struct {
        verified_access_instance: ?VerifiedAccessInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance = "verifiedAccessInstance",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_instance_logging_configuration: struct {
    action_name: []const u8 = "ModifyVerifiedAccessInstanceLoggingConfiguration",
    Request: type = struct {
        verified_access_instance_id: []const u8,
        access_logs: struct {
            s3: ?struct {
                enabled: bool,
                bucket_name: ?[]const u8 = null,
                prefix: ?[]const u8 = null,
                bucket_owner: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "Enabled",
                        .bucket_name = "BucketName",
                        .prefix = "Prefix",
                        .bucket_owner = "BucketOwner",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cloud_watch_logs: ?struct {
                enabled: bool,
                log_group: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "Enabled",
                        .log_group = "LogGroup",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            kinesis_data_firehose: ?struct {
                enabled: bool,
                delivery_stream: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "Enabled",
                        .delivery_stream = "DeliveryStream",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            log_version: ?[]const u8 = null,
            include_trust_context: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3 = "S3",
                    .cloud_watch_logs = "CloudWatchLogs",
                    .kinesis_data_firehose = "KinesisDataFirehose",
                    .log_version = "LogVersion",
                    .include_trust_context = "IncludeTrustContext",
                };
                return @field(mappings, field_name);
            }
        },
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_instance_id = "VerifiedAccessInstanceId",
                .access_logs = "AccessLogs",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_instance_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_instance_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?VerifiedAccessInstanceLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "loggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_verified_access_trust_provider: struct {
    action_name: []const u8 = "ModifyVerifiedAccessTrustProvider",
    Request: type = struct {
        verified_access_trust_provider_id: []const u8,
        oidc_options: ?struct {
            issuer: ?[]const u8 = null,
            authorization_endpoint: ?[]const u8 = null,
            token_endpoint: ?[]const u8 = null,
            user_info_endpoint: ?[]const u8 = null,
            client_id: ?[]const u8 = null,
            client_secret: ?[]const u8 = null,
            scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .issuer = "Issuer",
                    .authorization_endpoint = "AuthorizationEndpoint",
                    .token_endpoint = "TokenEndpoint",
                    .user_info_endpoint = "UserInfoEndpoint",
                    .client_id = "ClientId",
                    .client_secret = "ClientSecret",
                    .scope = "Scope",
                };
                return @field(mappings, field_name);
            }
        } = null,
        device_options: ?struct {
            public_signing_key_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .public_signing_key_url = "PublicSigningKeyUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,
        sse_specification: ?VerifiedAccessSseSpecificationRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider_id = "VerifiedAccessTrustProviderId",
                .oidc_options = "OidcOptions",
                .device_options = "DeviceOptions",
                .description = "Description",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
                .sse_specification = "SseSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_verified_access_trust_provider) } {
            return .{ .service_metadata = service_metadata, .action = modify_verified_access_trust_provider };
        }
    },
    Response: type = struct {
        verified_access_trust_provider: ?VerifiedAccessTrustProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_access_trust_provider = "verifiedAccessTrustProvider",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_volume: struct {
    action_name: []const u8 = "ModifyVolume",
    Request: type = struct {
        dry_run: ?bool = null,
        volume_id: []const u8,
        size: ?i64 = null,
        volume_type: ?[]const u8 = null,
        iops: ?i64 = null,
        throughput: ?i64 = null,
        multi_attach_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .volume_id = "VolumeId",
                .size = "Size",
                .volume_type = "VolumeType",
                .iops = "Iops",
                .throughput = "Throughput",
                .multi_attach_enabled = "MultiAttachEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_volume) } {
            return .{ .service_metadata = service_metadata, .action = modify_volume };
        }
    },
    Response: type = struct {
        volume_modification: ?VolumeModification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_modification = "volumeModification",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_volume_attribute: struct {
    action_name: []const u8 = "ModifyVolumeAttribute",
    Request: type = struct {
        auto_enable_io: ?AttributeBooleanValue = null,
        volume_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable_io = "AutoEnableIO",
                .volume_id = "VolumeId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_volume_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_volume_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_vpc_attribute: struct {
    action_name: []const u8 = "ModifyVpcAttribute",
    Request: type = struct {
        enable_dns_hostnames: ?AttributeBooleanValue = null,
        enable_dns_support: ?AttributeBooleanValue = null,
        vpc_id: []const u8,
        enable_network_address_usage_metrics: ?AttributeBooleanValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enable_dns_hostnames = "EnableDnsHostnames",
                .enable_dns_support = "EnableDnsSupport",
                .vpc_id = "vpcId",
                .enable_network_address_usage_metrics = "EnableNetworkAddressUsageMetrics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_attribute) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const modify_vpc_endpoint: struct {
    action_name: []const u8 = "ModifyVpcEndpoint",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_endpoint_id: []const u8,
        reset_policy: ?bool = null,
        policy_document: ?[]const u8 = null,
        add_route_table_ids: ?[][]const u8 = null,
        remove_route_table_ids: ?[][]const u8 = null,
        add_subnet_ids: ?[][]const u8 = null,
        remove_subnet_ids: ?[][]const u8 = null,
        add_security_group_ids: ?[][]const u8 = null,
        remove_security_group_ids: ?[][]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        dns_options: ?DnsOptionsSpecification = null,
        private_dns_enabled: ?bool = null,
        subnet_configurations: ?[]SubnetConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .vpc_endpoint_id = "VpcEndpointId",
                .reset_policy = "ResetPolicy",
                .policy_document = "PolicyDocument",
                .add_route_table_ids = "AddRouteTableId",
                .remove_route_table_ids = "RemoveRouteTableId",
                .add_subnet_ids = "AddSubnetId",
                .remove_subnet_ids = "RemoveSubnetId",
                .add_security_group_ids = "AddSecurityGroupId",
                .remove_security_group_ids = "RemoveSecurityGroupId",
                .ip_address_type = "IpAddressType",
                .dns_options = "DnsOptions",
                .private_dns_enabled = "PrivateDnsEnabled",
                .subnet_configurations = "SubnetConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_endpoint };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_endpoint_connection_notification: struct {
    action_name: []const u8 = "ModifyVpcEndpointConnectionNotification",
    Request: type = struct {
        dry_run: ?bool = null,
        connection_notification_id: []const u8,
        connection_notification_arn: ?[]const u8 = null,
        connection_events: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .connection_notification_id = "ConnectionNotificationId",
                .connection_notification_arn = "ConnectionNotificationArn",
                .connection_events = "ConnectionEvents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_endpoint_connection_notification) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_endpoint_connection_notification };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_endpoint_service_configuration: struct {
    action_name: []const u8 = "ModifyVpcEndpointServiceConfiguration",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        private_dns_name: ?[]const u8 = null,
        remove_private_dns_name: ?bool = null,
        acceptance_required: ?bool = null,
        add_network_load_balancer_arns: ?[][]const u8 = null,
        remove_network_load_balancer_arns: ?[][]const u8 = null,
        add_gateway_load_balancer_arns: ?[][]const u8 = null,
        remove_gateway_load_balancer_arns: ?[][]const u8 = null,
        add_supported_ip_address_types: ?[][]const u8 = null,
        remove_supported_ip_address_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .private_dns_name = "PrivateDnsName",
                .remove_private_dns_name = "RemovePrivateDnsName",
                .acceptance_required = "AcceptanceRequired",
                .add_network_load_balancer_arns = "AddNetworkLoadBalancerArn",
                .remove_network_load_balancer_arns = "RemoveNetworkLoadBalancerArn",
                .add_gateway_load_balancer_arns = "AddGatewayLoadBalancerArn",
                .remove_gateway_load_balancer_arns = "RemoveGatewayLoadBalancerArn",
                .add_supported_ip_address_types = "AddSupportedIpAddressType",
                .remove_supported_ip_address_types = "RemoveSupportedIpAddressType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_endpoint_service_configuration) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_endpoint_service_configuration };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_endpoint_service_payer_responsibility: struct {
    action_name: []const u8 = "ModifyVpcEndpointServicePayerResponsibility",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        payer_responsibility: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .payer_responsibility = "PayerResponsibility",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_endpoint_service_payer_responsibility) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_endpoint_service_payer_responsibility };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_endpoint_service_permissions: struct {
    action_name: []const u8 = "ModifyVpcEndpointServicePermissions",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        add_allowed_principals: ?[][]const u8 = null,
        remove_allowed_principals: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .add_allowed_principals = "AddAllowedPrincipals",
                .remove_allowed_principals = "RemoveAllowedPrincipals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_endpoint_service_permissions) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_endpoint_service_permissions };
        }
    },
    Response: type = struct {
        added_principals: ?[]struct {
            principal_type: ?[]const u8 = null,
            principal: ?[]const u8 = null,
            service_permission_id: ?[]const u8 = null,
            service_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_type = "principalType",
                    .principal = "principal",
                    .service_permission_id = "servicePermissionId",
                    .service_id = "serviceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .added_principals = "addedPrincipalSet",
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_peering_connection_options: struct {
    action_name: []const u8 = "ModifyVpcPeeringConnectionOptions",
    Request: type = struct {
        accepter_peering_connection_options: ?PeeringConnectionOptionsRequest = null,
        dry_run: ?bool = null,
        requester_peering_connection_options: ?PeeringConnectionOptionsRequest = null,
        vpc_peering_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accepter_peering_connection_options = "AccepterPeeringConnectionOptions",
                .dry_run = "DryRun",
                .requester_peering_connection_options = "RequesterPeeringConnectionOptions",
                .vpc_peering_connection_id = "VpcPeeringConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_peering_connection_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_peering_connection_options };
        }
    },
    Response: type = struct {
        accepter_peering_connection_options: ?PeeringConnectionOptions = null,
        requester_peering_connection_options: ?PeeringConnectionOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accepter_peering_connection_options = "accepterPeeringConnectionOptions",
                .requester_peering_connection_options = "requesterPeeringConnectionOptions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpc_tenancy: struct {
    action_name: []const u8 = "ModifyVpcTenancy",
    Request: type = struct {
        vpc_id: []const u8,
        instance_tenancy: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .instance_tenancy = "InstanceTenancy",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpc_tenancy) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpc_tenancy };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpn_connection: struct {
    action_name: []const u8 = "ModifyVpnConnection",
    Request: type = struct {
        vpn_connection_id: []const u8,
        transit_gateway_id: ?[]const u8 = null,
        customer_gateway_id: ?[]const u8 = null,
        vpn_gateway_id: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .transit_gateway_id = "TransitGatewayId",
                .customer_gateway_id = "CustomerGatewayId",
                .vpn_gateway_id = "VpnGatewayId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpn_connection) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpn_connection };
        }
    },
    Response: type = struct {
        vpn_connection: ?VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection = "vpnConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpn_connection_options: struct {
    action_name: []const u8 = "ModifyVpnConnectionOptions",
    Request: type = struct {
        vpn_connection_id: []const u8,
        local_ipv4_network_cidr: ?[]const u8 = null,
        remote_ipv4_network_cidr: ?[]const u8 = null,
        local_ipv6_network_cidr: ?[]const u8 = null,
        remote_ipv6_network_cidr: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .local_ipv4_network_cidr = "LocalIpv4NetworkCidr",
                .remote_ipv4_network_cidr = "RemoteIpv4NetworkCidr",
                .local_ipv6_network_cidr = "LocalIpv6NetworkCidr",
                .remote_ipv6_network_cidr = "RemoteIpv6NetworkCidr",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpn_connection_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpn_connection_options };
        }
    },
    Response: type = struct {
        vpn_connection: ?VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection = "vpnConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpn_tunnel_certificate: struct {
    action_name: []const u8 = "ModifyVpnTunnelCertificate",
    Request: type = struct {
        vpn_connection_id: []const u8,
        vpn_tunnel_outside_ip_address: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .vpn_tunnel_outside_ip_address = "VpnTunnelOutsideIpAddress",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpn_tunnel_certificate) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpn_tunnel_certificate };
        }
    },
    Response: type = struct {
        vpn_connection: ?VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection = "vpnConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const modify_vpn_tunnel_options: struct {
    action_name: []const u8 = "ModifyVpnTunnelOptions",
    Request: type = struct {
        vpn_connection_id: []const u8,
        vpn_tunnel_outside_ip_address: []const u8,
        tunnel_options: struct {
            tunnel_inside_cidr: ?[]const u8 = null,
            tunnel_inside_ipv6_cidr: ?[]const u8 = null,
            pre_shared_key: ?[]const u8 = null,
            phase1_lifetime_seconds: ?i64 = null,
            phase2_lifetime_seconds: ?i64 = null,
            rekey_margin_time_seconds: ?i64 = null,
            rekey_fuzz_percentage: ?i64 = null,
            replay_window_size: ?i64 = null,
            dpd_timeout_seconds: ?i64 = null,
            dpd_timeout_action: ?[]const u8 = null,
            phase1_encryption_algorithms: ?[]Phase1EncryptionAlgorithmsRequestListValue = null,
            phase2_encryption_algorithms: ?[]Phase2EncryptionAlgorithmsRequestListValue = null,
            phase1_integrity_algorithms: ?[]Phase1IntegrityAlgorithmsRequestListValue = null,
            phase2_integrity_algorithms: ?[]Phase2IntegrityAlgorithmsRequestListValue = null,
            phase1dh_group_numbers: ?[]Phase1DHGroupNumbersRequestListValue = null,
            phase2dh_group_numbers: ?[]Phase2DHGroupNumbersRequestListValue = null,
            ike_versions: ?[]IKEVersionsRequestListValue = null,
            startup_action: ?[]const u8 = null,
            log_options: ?VpnTunnelLogOptionsSpecification = null,
            enable_tunnel_lifecycle_control: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tunnel_inside_cidr = "TunnelInsideCidr",
                    .tunnel_inside_ipv6_cidr = "TunnelInsideIpv6Cidr",
                    .pre_shared_key = "PreSharedKey",
                    .phase1_lifetime_seconds = "Phase1LifetimeSeconds",
                    .phase2_lifetime_seconds = "Phase2LifetimeSeconds",
                    .rekey_margin_time_seconds = "RekeyMarginTimeSeconds",
                    .rekey_fuzz_percentage = "RekeyFuzzPercentage",
                    .replay_window_size = "ReplayWindowSize",
                    .dpd_timeout_seconds = "DPDTimeoutSeconds",
                    .dpd_timeout_action = "DPDTimeoutAction",
                    .phase1_encryption_algorithms = "Phase1EncryptionAlgorithm",
                    .phase2_encryption_algorithms = "Phase2EncryptionAlgorithm",
                    .phase1_integrity_algorithms = "Phase1IntegrityAlgorithm",
                    .phase2_integrity_algorithms = "Phase2IntegrityAlgorithm",
                    .phase1dh_group_numbers = "Phase1DHGroupNumber",
                    .phase2dh_group_numbers = "Phase2DHGroupNumber",
                    .ike_versions = "IKEVersion",
                    .startup_action = "StartupAction",
                    .log_options = "LogOptions",
                    .enable_tunnel_lifecycle_control = "EnableTunnelLifecycleControl",
                };
                return @field(mappings, field_name);
            }
        },
        dry_run: ?bool = null,
        skip_tunnel_replacement: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .vpn_tunnel_outside_ip_address = "VpnTunnelOutsideIpAddress",
                .tunnel_options = "TunnelOptions",
                .dry_run = "DryRun",
                .skip_tunnel_replacement = "SkipTunnelReplacement",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_vpn_tunnel_options) } {
            return .{ .service_metadata = service_metadata, .action = modify_vpn_tunnel_options };
        }
    },
    Response: type = struct {
        vpn_connection: ?VpnConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection = "vpnConnection",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const monitor_instances: struct {
    action_name: []const u8 = "MonitorInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(monitor_instances) } {
            return .{ .service_metadata = service_metadata, .action = monitor_instances };
        }
    },
    Response: type = struct {
        instance_monitorings: ?[]InstanceMonitoring = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_monitorings = "instancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const move_address_to_vpc: struct {
    action_name: []const u8 = "MoveAddressToVpc",
    Request: type = struct {
        dry_run: ?bool = null,
        public_ip: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .public_ip = "publicIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(move_address_to_vpc) } {
            return .{ .service_metadata = service_metadata, .action = move_address_to_vpc };
        }
    },
    Response: type = struct {
        allocation_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "allocationId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const move_byoip_cidr_to_ipam: struct {
    action_name: []const u8 = "MoveByoipCidrToIpam",
    Request: type = struct {
        dry_run: ?bool = null,
        cidr: []const u8,
        ipam_pool_id: []const u8,
        ipam_pool_owner: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .cidr = "Cidr",
                .ipam_pool_id = "IpamPoolId",
                .ipam_pool_owner = "IpamPoolOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(move_byoip_cidr_to_ipam) } {
            return .{ .service_metadata = service_metadata, .action = move_byoip_cidr_to_ipam };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "byoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const provision_byoip_cidr: struct {
    action_name: []const u8 = "ProvisionByoipCidr",
    Request: type = struct {
        cidr: []const u8,
        cidr_authorization_context: ?struct {
            message: []const u8,
            signature: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .signature = "Signature",
                };
                return @field(mappings, field_name);
            }
        } = null,
        publicly_advertisable: ?bool = null,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        pool_tag_specifications: ?[]TagSpecification = null,
        multi_region: ?bool = null,
        network_border_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .cidr_authorization_context = "CidrAuthorizationContext",
                .publicly_advertisable = "PubliclyAdvertisable",
                .description = "Description",
                .dry_run = "DryRun",
                .pool_tag_specifications = "PoolTagSpecification",
                .multi_region = "MultiRegion",
                .network_border_group = "NetworkBorderGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = provision_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "byoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const provision_ipam_byoasn: struct {
    action_name: []const u8 = "ProvisionIpamByoasn",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_id: []const u8,
        asn: []const u8,
        asn_authorization_context: struct {
            message: []const u8,
            signature: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .signature = "Signature",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_id = "IpamId",
                .asn = "Asn",
                .asn_authorization_context = "AsnAuthorizationContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_ipam_byoasn) } {
            return .{ .service_metadata = service_metadata, .action = provision_ipam_byoasn };
        }
    },
    Response: type = struct {
        byoasn: ?Byoasn = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoasn = "byoasn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const provision_ipam_pool_cidr: struct {
    action_name: []const u8 = "ProvisionIpamPoolCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        cidr: ?[]const u8 = null,
        cidr_authorization_context: ?struct {
            message: ?[]const u8 = null,
            signature: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                    .signature = "Signature",
                };
                return @field(mappings, field_name);
            }
        } = null,
        netmask_length: ?i64 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .cidr = "Cidr",
                .cidr_authorization_context = "CidrAuthorizationContext",
                .netmask_length = "NetmaskLength",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_ipam_pool_cidr) } {
            return .{ .service_metadata = service_metadata, .action = provision_ipam_pool_cidr };
        }
    },
    Response: type = struct {
        ipam_pool_cidr: ?IpamPoolCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipam_pool_cidr = "ipamPoolCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const provision_public_ipv4_pool_cidr: struct {
    action_name: []const u8 = "ProvisionPublicIpv4PoolCidr",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        pool_id: []const u8,
        netmask_length: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .pool_id = "PoolId",
                .netmask_length = "NetmaskLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_public_ipv4_pool_cidr) } {
            return .{ .service_metadata = service_metadata, .action = provision_public_ipv4_pool_cidr };
        }
    },
    Response: type = struct {
        pool_id: ?[]const u8 = null,
        pool_address_range: ?PublicIpv4PoolRange = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "poolId",
                .pool_address_range = "poolAddressRange",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const purchase_capacity_block: struct {
    action_name: []const u8 = "PurchaseCapacityBlock",
    Request: type = struct {
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        capacity_block_offering_id: []const u8,
        instance_platform: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
                .capacity_block_offering_id = "CapacityBlockOfferingId",
                .instance_platform = "InstancePlatform",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_capacity_block) } {
            return .{ .service_metadata = service_metadata, .action = purchase_capacity_block };
        }
    },
    Response: type = struct {
        capacity_reservation: ?CapacityReservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_reservation = "capacityReservation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const purchase_host_reservation: struct {
    action_name: []const u8 = "PurchaseHostReservation",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        currency_code: ?[]const u8 = null,
        host_id_set: [][]const u8,
        limit_price: ?[]const u8 = null,
        offering_id: []const u8,
        tag_specifications: ?[]TagSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .currency_code = "CurrencyCode",
                .host_id_set = "HostIdSet",
                .limit_price = "LimitPrice",
                .offering_id = "OfferingId",
                .tag_specifications = "TagSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_host_reservation) } {
            return .{ .service_metadata = service_metadata, .action = purchase_host_reservation };
        }
    },
    Response: type = struct {
        client_token: ?[]const u8 = null,
        currency_code: ?[]const u8 = null,
        purchase: ?[]Purchase = null,
        total_hourly_price: ?[]const u8 = null,
        total_upfront_price: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .currency_code = "currencyCode",
                .purchase = "purchase",
                .total_hourly_price = "totalHourlyPrice",
                .total_upfront_price = "totalUpfrontPrice",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const purchase_reserved_instances_offering: struct {
    action_name: []const u8 = "PurchaseReservedInstancesOffering",
    Request: type = struct {
        instance_count: i64,
        reserved_instances_offering_id: []const u8,
        dry_run: ?bool = null,
        limit_price: ?struct {
            amount: ?f64 = null,
            currency_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amount = "amount",
                    .currency_code = "currencyCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        purchase_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_count = "InstanceCount",
                .reserved_instances_offering_id = "ReservedInstancesOfferingId",
                .dry_run = "dryRun",
                .limit_price = "limitPrice",
                .purchase_time = "PurchaseTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_instances_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_instances_offering };
        }
    },
    Response: type = struct {
        reserved_instances_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instances_id = "reservedInstancesId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const purchase_scheduled_instances: struct {
    action_name: []const u8 = "PurchaseScheduledInstances",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        purchase_requests: []struct {
            instance_count: i64,
            purchase_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_count = "InstanceCount",
                    .purchase_token = "PurchaseToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .purchase_requests = "PurchaseRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_scheduled_instances) } {
            return .{ .service_metadata = service_metadata, .action = purchase_scheduled_instances };
        }
    },
    Response: type = struct {
        scheduled_instance_set: ?[]ScheduledInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_instance_set = "scheduledInstanceSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reboot_instances: struct {
    action_name: []const u8 = "RebootInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_instances) } {
            return .{ .service_metadata = service_metadata, .action = reboot_instances };
        }
    },
    Response: type = struct {},
} = .{};
pub const register_image: struct {
    action_name: []const u8 = "RegisterImage",
    Request: type = struct {
        image_location: ?[]const u8 = null,
        architecture: ?[]const u8 = null,
        block_device_mappings: ?[]BlockDeviceMapping = null,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        ena_support: ?bool = null,
        kernel_id: ?[]const u8 = null,
        name: []const u8,
        billing_products: ?[][]const u8 = null,
        ramdisk_id: ?[]const u8 = null,
        root_device_name: ?[]const u8 = null,
        sriov_net_support: ?[]const u8 = null,
        virtualization_type: ?[]const u8 = null,
        boot_mode: ?[]const u8 = null,
        tpm_support: ?[]const u8 = null,
        uefi_data: ?[]const u8 = null,
        imds_support: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_location = "ImageLocation",
                .architecture = "architecture",
                .block_device_mappings = "BlockDeviceMapping",
                .description = "description",
                .dry_run = "dryRun",
                .ena_support = "enaSupport",
                .kernel_id = "kernelId",
                .name = "name",
                .billing_products = "BillingProduct",
                .ramdisk_id = "ramdiskId",
                .root_device_name = "rootDeviceName",
                .sriov_net_support = "sriovNetSupport",
                .virtualization_type = "virtualizationType",
                .boot_mode = "BootMode",
                .tpm_support = "TpmSupport",
                .uefi_data = "UefiData",
                .imds_support = "ImdsSupport",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_image) } {
            return .{ .service_metadata = service_metadata, .action = register_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "imageId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const register_instance_event_notification_attributes: struct {
    action_name: []const u8 = "RegisterInstanceEventNotificationAttributes",
    Request: type = struct {
        dry_run: ?bool = null,
        instance_tag_attribute: struct {
            include_all_tags_of_instance: ?bool = null,
            instance_tag_keys: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .include_all_tags_of_instance = "IncludeAllTagsOfInstance",
                    .instance_tag_keys = "InstanceTagKey",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .instance_tag_attribute = "InstanceTagAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_instance_event_notification_attributes) } {
            return .{ .service_metadata = service_metadata, .action = register_instance_event_notification_attributes };
        }
    },
    Response: type = struct {
        instance_tag_attribute: ?InstanceTagNotificationAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_tag_attribute = "instanceTagAttribute",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const register_transit_gateway_multicast_group_members: struct {
    action_name: []const u8 = "RegisterTransitGatewayMulticastGroupMembers",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        group_ip_address: ?[]const u8 = null,
        network_interface_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .group_ip_address = "GroupIpAddress",
                .network_interface_ids = "NetworkInterfaceIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_transit_gateway_multicast_group_members) } {
            return .{ .service_metadata = service_metadata, .action = register_transit_gateway_multicast_group_members };
        }
    },
    Response: type = struct {
        registered_multicast_group_members: ?struct {
            transit_gateway_multicast_domain_id: ?[]const u8 = null,
            registered_network_interface_ids: ?[][]const u8 = null,
            group_ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
                    .registered_network_interface_ids = "registeredNetworkInterfaceIds",
                    .group_ip_address = "groupIpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registered_multicast_group_members = "registeredMulticastGroupMembers",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const register_transit_gateway_multicast_group_sources: struct {
    action_name: []const u8 = "RegisterTransitGatewayMulticastGroupSources",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        group_ip_address: ?[]const u8 = null,
        network_interface_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .group_ip_address = "GroupIpAddress",
                .network_interface_ids = "NetworkInterfaceIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_transit_gateway_multicast_group_sources) } {
            return .{ .service_metadata = service_metadata, .action = register_transit_gateway_multicast_group_sources };
        }
    },
    Response: type = struct {
        registered_multicast_group_sources: ?struct {
            transit_gateway_multicast_domain_id: ?[]const u8 = null,
            registered_network_interface_ids: ?[][]const u8 = null,
            group_ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
                    .registered_network_interface_ids = "registeredNetworkInterfaceIds",
                    .group_ip_address = "groupIpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registered_multicast_group_sources = "registeredMulticastGroupSources",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reject_transit_gateway_multicast_domain_associations: struct {
    action_name: []const u8 = "RejectTransitGatewayMulticastDomainAssociations",
    Request: type = struct {
        transit_gateway_multicast_domain_id: ?[]const u8 = null,
        transit_gateway_attachment_id: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .subnet_ids = "SubnetIds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_transit_gateway_multicast_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = reject_transit_gateway_multicast_domain_associations };
        }
    },
    Response: type = struct {
        associations: ?TransitGatewayMulticastDomainAssociations = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "associations",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reject_transit_gateway_peering_attachment: struct {
    action_name: []const u8 = "RejectTransitGatewayPeeringAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_transit_gateway_peering_attachment) } {
            return .{ .service_metadata = service_metadata, .action = reject_transit_gateway_peering_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_peering_attachment: ?TransitGatewayPeeringAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering_attachment = "transitGatewayPeeringAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reject_transit_gateway_vpc_attachment: struct {
    action_name: []const u8 = "RejectTransitGatewayVpcAttachment",
    Request: type = struct {
        transit_gateway_attachment_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_transit_gateway_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = reject_transit_gateway_vpc_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_vpc_attachment: ?TransitGatewayVpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_vpc_attachment = "transitGatewayVpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reject_vpc_endpoint_connections: struct {
    action_name: []const u8 = "RejectVpcEndpointConnections",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,
        vpc_endpoint_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
                .vpc_endpoint_ids = "VpcEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_vpc_endpoint_connections) } {
            return .{ .service_metadata = service_metadata, .action = reject_vpc_endpoint_connections };
        }
    },
    Response: type = struct {
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reject_vpc_peering_connection: struct {
    action_name: []const u8 = "RejectVpcPeeringConnection",
    Request: type = struct {
        dry_run: ?bool = null,
        vpc_peering_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .vpc_peering_connection_id = "vpcPeeringConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_vpc_peering_connection) } {
            return .{ .service_metadata = service_metadata, .action = reject_vpc_peering_connection };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const release_address: struct {
    action_name: []const u8 = "ReleaseAddress",
    Request: type = struct {
        allocation_id: ?[]const u8 = null,
        public_ip: ?[]const u8 = null,
        network_border_group: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .public_ip = "PublicIp",
                .network_border_group = "NetworkBorderGroup",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_address) } {
            return .{ .service_metadata = service_metadata, .action = release_address };
        }
    },
    Response: type = struct {},
} = .{};
pub const release_hosts: struct {
    action_name: []const u8 = "ReleaseHosts",
    Request: type = struct {
        host_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_ids = "hostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_hosts) } {
            return .{ .service_metadata = service_metadata, .action = release_hosts };
        }
    },
    Response: type = struct {
        successful: ?[][]const u8 = null,
        unsuccessful: ?[]UnsuccessfulItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const release_ipam_pool_allocation: struct {
    action_name: []const u8 = "ReleaseIpamPoolAllocation",
    Request: type = struct {
        dry_run: ?bool = null,
        ipam_pool_id: []const u8,
        cidr: []const u8,
        ipam_pool_allocation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .ipam_pool_id = "IpamPoolId",
                .cidr = "Cidr",
                .ipam_pool_allocation_id = "IpamPoolAllocationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_ipam_pool_allocation) } {
            return .{ .service_metadata = service_metadata, .action = release_ipam_pool_allocation };
        }
    },
    Response: type = struct {
        success: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .success = "success",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const replace_iam_instance_profile_association: struct {
    action_name: []const u8 = "ReplaceIamInstanceProfileAssociation",
    Request: type = struct {
        iam_instance_profile: IamInstanceProfileSpecification,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile = "IamInstanceProfile",
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_iam_instance_profile_association) } {
            return .{ .service_metadata = service_metadata, .action = replace_iam_instance_profile_association };
        }
    },
    Response: type = struct {
        iam_instance_profile_association: ?IamInstanceProfileAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_instance_profile_association = "iamInstanceProfileAssociation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const replace_network_acl_association: struct {
    action_name: []const u8 = "ReplaceNetworkAclAssociation",
    Request: type = struct {
        association_id: []const u8,
        dry_run: ?bool = null,
        network_acl_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .dry_run = "dryRun",
                .network_acl_id = "networkAclId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_network_acl_association) } {
            return .{ .service_metadata = service_metadata, .action = replace_network_acl_association };
        }
    },
    Response: type = struct {
        new_association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .new_association_id = "newAssociationId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const replace_network_acl_entry: struct {
    action_name: []const u8 = "ReplaceNetworkAclEntry",
    Request: type = struct {
        cidr_block: ?[]const u8 = null,
        dry_run: ?bool = null,
        egress: bool,
        icmp_type_code: ?IcmpTypeCode = null,
        ipv6_cidr_block: ?[]const u8 = null,
        network_acl_id: []const u8,
        port_range: ?PortRange = null,
        protocol: []const u8,
        rule_action: []const u8,
        rule_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_block = "cidrBlock",
                .dry_run = "dryRun",
                .egress = "egress",
                .icmp_type_code = "Icmp",
                .ipv6_cidr_block = "ipv6CidrBlock",
                .network_acl_id = "networkAclId",
                .port_range = "portRange",
                .protocol = "protocol",
                .rule_action = "ruleAction",
                .rule_number = "ruleNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_network_acl_entry) } {
            return .{ .service_metadata = service_metadata, .action = replace_network_acl_entry };
        }
    },
    Response: type = struct {},
} = .{};
pub const replace_route: struct {
    action_name: []const u8 = "ReplaceRoute",
    Request: type = struct {
        destination_cidr_block: ?[]const u8 = null,
        destination_ipv6_cidr_block: ?[]const u8 = null,
        destination_prefix_list_id: ?[]const u8 = null,
        dry_run: ?bool = null,
        vpc_endpoint_id: ?[]const u8 = null,
        egress_only_internet_gateway_id: ?[]const u8 = null,
        gateway_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        local_target: ?bool = null,
        nat_gateway_id: ?[]const u8 = null,
        transit_gateway_id: ?[]const u8 = null,
        local_gateway_id: ?[]const u8 = null,
        carrier_gateway_id: ?[]const u8 = null,
        network_interface_id: ?[]const u8 = null,
        route_table_id: []const u8,
        vpc_peering_connection_id: ?[]const u8 = null,
        core_network_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "destinationCidrBlock",
                .destination_ipv6_cidr_block = "destinationIpv6CidrBlock",
                .destination_prefix_list_id = "DestinationPrefixListId",
                .dry_run = "dryRun",
                .vpc_endpoint_id = "VpcEndpointId",
                .egress_only_internet_gateway_id = "egressOnlyInternetGatewayId",
                .gateway_id = "gatewayId",
                .instance_id = "instanceId",
                .local_target = "LocalTarget",
                .nat_gateway_id = "natGatewayId",
                .transit_gateway_id = "TransitGatewayId",
                .local_gateway_id = "LocalGatewayId",
                .carrier_gateway_id = "CarrierGatewayId",
                .network_interface_id = "networkInterfaceId",
                .route_table_id = "routeTableId",
                .vpc_peering_connection_id = "vpcPeeringConnectionId",
                .core_network_arn = "CoreNetworkArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_route) } {
            return .{ .service_metadata = service_metadata, .action = replace_route };
        }
    },
    Response: type = struct {},
} = .{};
pub const replace_route_table_association: struct {
    action_name: []const u8 = "ReplaceRouteTableAssociation",
    Request: type = struct {
        association_id: []const u8,
        dry_run: ?bool = null,
        route_table_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "associationId",
                .dry_run = "dryRun",
                .route_table_id = "routeTableId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_route_table_association) } {
            return .{ .service_metadata = service_metadata, .action = replace_route_table_association };
        }
    },
    Response: type = struct {
        new_association_id: ?[]const u8 = null,
        association_state: ?RouteTableAssociationState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .new_association_id = "newAssociationId",
                .association_state = "associationState",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const replace_transit_gateway_route: struct {
    action_name: []const u8 = "ReplaceTransitGatewayRoute",
    Request: type = struct {
        destination_cidr_block: []const u8,
        transit_gateway_route_table_id: []const u8,
        transit_gateway_attachment_id: ?[]const u8 = null,
        blackhole: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_cidr_block = "DestinationCidrBlock",
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                .blackhole = "Blackhole",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_transit_gateway_route) } {
            return .{ .service_metadata = service_metadata, .action = replace_transit_gateway_route };
        }
    },
    Response: type = struct {
        route: ?TransitGatewayRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route = "route",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const replace_vpn_tunnel: struct {
    action_name: []const u8 = "ReplaceVpnTunnel",
    Request: type = struct {
        vpn_connection_id: []const u8,
        vpn_tunnel_outside_ip_address: []const u8,
        apply_pending_maintenance: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpn_connection_id = "VpnConnectionId",
                .vpn_tunnel_outside_ip_address = "VpnTunnelOutsideIpAddress",
                .apply_pending_maintenance = "ApplyPendingMaintenance",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_vpn_tunnel) } {
            return .{ .service_metadata = service_metadata, .action = replace_vpn_tunnel };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const report_instance_status: struct {
    action_name: []const u8 = "ReportInstanceStatus",
    Request: type = struct {
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        end_time: ?i64 = null,
        instances: [][]const u8,
        reason_codes: [][]const u8,
        start_time: ?i64 = null,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .dry_run = "dryRun",
                .end_time = "endTime",
                .instances = "instanceId",
                .reason_codes = "reasonCode",
                .start_time = "startTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(report_instance_status) } {
            return .{ .service_metadata = service_metadata, .action = report_instance_status };
        }
    },
    Response: type = struct {},
} = .{};
pub const request_spot_fleet: struct {
    action_name: []const u8 = "RequestSpotFleet",
    Request: type = struct {
        dry_run: ?bool = null,
        spot_fleet_request_config: SpotFleetRequestConfigData,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .spot_fleet_request_config = "spotFleetRequestConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_spot_fleet) } {
            return .{ .service_metadata = service_metadata, .action = request_spot_fleet };
        }
    },
    Response: type = struct {
        spot_fleet_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_fleet_request_id = "spotFleetRequestId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const request_spot_instances: struct {
    action_name: []const u8 = "RequestSpotInstances",
    Request: type = struct {
        availability_zone_group: ?[]const u8 = null,
        block_duration_minutes: ?i64 = null,
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        instance_count: ?i64 = null,
        launch_group: ?[]const u8 = null,
        launch_specification: ?struct {
            security_group_ids: ?[][]const u8 = null,
            security_groups: ?[][]const u8 = null,
            addressing_type: ?[]const u8 = null,
            block_device_mappings: ?[]BlockDeviceMapping = null,
            ebs_optimized: ?bool = null,
            iam_instance_profile: ?IamInstanceProfileSpecification = null,
            image_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            kernel_id: ?[]const u8 = null,
            key_name: ?[]const u8 = null,
            monitoring: ?RunInstancesMonitoringEnabled = null,
            network_interfaces: ?[]InstanceNetworkInterfaceSpecification = null,
            placement: ?SpotPlacement = null,
            ramdisk_id: ?[]const u8 = null,
            subnet_id: ?[]const u8 = null,
            user_data: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_group_ids = "SecurityGroupId",
                    .security_groups = "SecurityGroup",
                    .addressing_type = "addressingType",
                    .block_device_mappings = "blockDeviceMapping",
                    .ebs_optimized = "ebsOptimized",
                    .iam_instance_profile = "iamInstanceProfile",
                    .image_id = "imageId",
                    .instance_type = "instanceType",
                    .kernel_id = "kernelId",
                    .key_name = "keyName",
                    .monitoring = "monitoring",
                    .network_interfaces = "NetworkInterface",
                    .placement = "placement",
                    .ramdisk_id = "ramdiskId",
                    .subnet_id = "subnetId",
                    .user_data = "userData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        spot_price: ?[]const u8 = null,
        type: ?[]const u8 = null,
        valid_from: ?i64 = null,
        valid_until: ?i64 = null,
        tag_specifications: ?[]TagSpecification = null,
        instance_interruption_behavior: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone_group = "availabilityZoneGroup",
                .block_duration_minutes = "blockDurationMinutes",
                .client_token = "clientToken",
                .dry_run = "dryRun",
                .instance_count = "instanceCount",
                .launch_group = "launchGroup",
                .launch_specification = "LaunchSpecification",
                .spot_price = "spotPrice",
                .type = "type",
                .valid_from = "validFrom",
                .valid_until = "validUntil",
                .tag_specifications = "TagSpecification",
                .instance_interruption_behavior = "InstanceInterruptionBehavior",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_spot_instances) } {
            return .{ .service_metadata = service_metadata, .action = request_spot_instances };
        }
    },
    Response: type = struct {
        spot_instance_requests: ?[]SpotInstanceRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spot_instance_requests = "spotInstanceRequestSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reset_address_attribute: struct {
    action_name: []const u8 = "ResetAddressAttribute",
    Request: type = struct {
        allocation_id: []const u8,
        attribute: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allocation_id = "AllocationId",
                .attribute = "Attribute",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_address_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_address_attribute };
        }
    },
    Response: type = struct {
        address: ?AddressAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "address",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reset_ebs_default_kms_key_id: struct {
    action_name: []const u8 = "ResetEbsDefaultKmsKeyId",
    Request: type = struct {
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_ebs_default_kms_key_id) } {
            return .{ .service_metadata = service_metadata, .action = reset_ebs_default_kms_key_id };
        }
    },
    Response: type = struct {
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reset_fpga_image_attribute: struct {
    action_name: []const u8 = "ResetFpgaImageAttribute",
    Request: type = struct {
        dry_run: ?bool = null,
        fpga_image_id: []const u8,
        attribute: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .fpga_image_id = "FpgaImageId",
                .attribute = "Attribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_fpga_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_fpga_image_attribute };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const reset_image_attribute: struct {
    action_name: []const u8 = "ResetImageAttribute",
    Request: type = struct {
        attribute: []const u8,
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .image_id = "ImageId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_image_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_image_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const reset_instance_attribute: struct {
    action_name: []const u8 = "ResetInstanceAttribute",
    Request: type = struct {
        attribute: []const u8,
        dry_run: ?bool = null,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "attribute",
                .dry_run = "dryRun",
                .instance_id = "instanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_instance_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const reset_network_interface_attribute: struct {
    action_name: []const u8 = "ResetNetworkInterfaceAttribute",
    Request: type = struct {
        dry_run: ?bool = null,
        network_interface_id: []const u8,
        source_dest_check: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .network_interface_id = "networkInterfaceId",
                .source_dest_check = "sourceDestCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_network_interface_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_network_interface_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const reset_snapshot_attribute: struct {
    action_name: []const u8 = "ResetSnapshotAttribute",
    Request: type = struct {
        attribute: []const u8,
        snapshot_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
                .snapshot_id = "SnapshotId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_snapshot_attribute) } {
            return .{ .service_metadata = service_metadata, .action = reset_snapshot_attribute };
        }
    },
    Response: type = struct {},
} = .{};
pub const restore_address_to_classic: struct {
    action_name: []const u8 = "RestoreAddressToClassic",
    Request: type = struct {
        dry_run: ?bool = null,
        public_ip: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .public_ip = "publicIp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_address_to_classic) } {
            return .{ .service_metadata = service_metadata, .action = restore_address_to_classic };
        }
    },
    Response: type = struct {
        public_ip: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_ip = "publicIp",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const restore_image_from_recycle_bin: struct {
    action_name: []const u8 = "RestoreImageFromRecycleBin",
    Request: type = struct {
        image_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_image_from_recycle_bin) } {
            return .{ .service_metadata = service_metadata, .action = restore_image_from_recycle_bin };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const restore_managed_prefix_list_version: struct {
    action_name: []const u8 = "RestoreManagedPrefixListVersion",
    Request: type = struct {
        dry_run: ?bool = null,
        prefix_list_id: []const u8,
        previous_version: i64,
        current_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .prefix_list_id = "PrefixListId",
                .previous_version = "PreviousVersion",
                .current_version = "CurrentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_managed_prefix_list_version) } {
            return .{ .service_metadata = service_metadata, .action = restore_managed_prefix_list_version };
        }
    },
    Response: type = struct {
        prefix_list: ?ManagedPrefixList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prefix_list = "prefixList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const restore_snapshot_from_recycle_bin: struct {
    action_name: []const u8 = "RestoreSnapshotFromRecycleBin",
    Request: type = struct {
        snapshot_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_snapshot_from_recycle_bin) } {
            return .{ .service_metadata = service_metadata, .action = restore_snapshot_from_recycle_bin };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        encrypted: ?bool = null,
        owner_id: ?[]const u8 = null,
        progress: ?[]const u8 = null,
        start_time: ?i64 = null,
        state: ?[]const u8 = null,
        volume_id: ?[]const u8 = null,
        volume_size: ?i64 = null,
        sse_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
                .outpost_arn = "outpostArn",
                .description = "description",
                .encrypted = "encrypted",
                .owner_id = "ownerId",
                .progress = "progress",
                .start_time = "startTime",
                .state = "status",
                .volume_id = "volumeId",
                .volume_size = "volumeSize",
                .sse_type = "sseType",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const restore_snapshot_tier: struct {
    action_name: []const u8 = "RestoreSnapshotTier",
    Request: type = struct {
        snapshot_id: []const u8,
        temporary_restore_days: ?i64 = null,
        permanent_restore: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .temporary_restore_days = "TemporaryRestoreDays",
                .permanent_restore = "PermanentRestore",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_snapshot_tier) } {
            return .{ .service_metadata = service_metadata, .action = restore_snapshot_tier };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        restore_start_time: ?i64 = null,
        restore_duration: ?i64 = null,
        is_permanent_restore: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
                .restore_start_time = "restoreStartTime",
                .restore_duration = "restoreDuration",
                .is_permanent_restore = "isPermanentRestore",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const revoke_client_vpn_ingress: struct {
    action_name: []const u8 = "RevokeClientVpnIngress",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        target_network_cidr: []const u8,
        access_group_id: ?[]const u8 = null,
        revoke_all_groups: ?bool = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .target_network_cidr = "TargetNetworkCidr",
                .access_group_id = "AccessGroupId",
                .revoke_all_groups = "RevokeAllGroups",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_client_vpn_ingress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_client_vpn_ingress };
        }
    },
    Response: type = struct {
        status: ?ClientVpnAuthorizationRuleStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const revoke_security_group_egress: struct {
    action_name: []const u8 = "RevokeSecurityGroupEgress",
    Request: type = struct {
        dry_run: ?bool = null,
        group_id: []const u8,
        ip_permissions: ?[]IpPermission = null,
        security_group_rule_ids: ?[][]const u8 = null,
        cidr_ip: ?[]const u8 = null,
        from_port: ?i64 = null,
        ip_protocol: ?[]const u8 = null,
        to_port: ?i64 = null,
        source_security_group_name: ?[]const u8 = null,
        source_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "dryRun",
                .group_id = "groupId",
                .ip_permissions = "ipPermissions",
                .security_group_rule_ids = "SecurityGroupRuleId",
                .cidr_ip = "cidrIp",
                .from_port = "fromPort",
                .ip_protocol = "ipProtocol",
                .to_port = "toPort",
                .source_security_group_name = "sourceSecurityGroupName",
                .source_security_group_owner_id = "sourceSecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_security_group_egress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_security_group_egress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        unknown_ip_permissions: ?[]IpPermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .unknown_ip_permissions = "unknownIpPermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const revoke_security_group_ingress: struct {
    action_name: []const u8 = "RevokeSecurityGroupIngress",
    Request: type = struct {
        cidr_ip: ?[]const u8 = null,
        from_port: ?i64 = null,
        group_id: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        ip_permissions: ?[]IpPermission = null,
        ip_protocol: ?[]const u8 = null,
        source_security_group_name: ?[]const u8 = null,
        source_security_group_owner_id: ?[]const u8 = null,
        to_port: ?i64 = null,
        dry_run: ?bool = null,
        security_group_rule_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_ip = "CidrIp",
                .from_port = "FromPort",
                .group_id = "GroupId",
                .group_name = "GroupName",
                .ip_permissions = "IpPermissions",
                .ip_protocol = "IpProtocol",
                .source_security_group_name = "SourceSecurityGroupName",
                .source_security_group_owner_id = "SourceSecurityGroupOwnerId",
                .to_port = "ToPort",
                .dry_run = "dryRun",
                .security_group_rule_ids = "SecurityGroupRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_security_group_ingress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,
        unknown_ip_permissions: ?[]IpPermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
                .unknown_ip_permissions = "unknownIpPermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const run_instances: struct {
    action_name: []const u8 = "RunInstances",
    Request: type = struct {
        block_device_mappings: ?[]BlockDeviceMapping = null,
        image_id: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        ipv6_address_count: ?i64 = null,
        ipv6_addresses: ?[]InstanceIpv6Address = null,
        kernel_id: ?[]const u8 = null,
        key_name: ?[]const u8 = null,
        max_count: i64,
        min_count: i64,
        monitoring: ?RunInstancesMonitoringEnabled = null,
        placement: ?Placement = null,
        ramdisk_id: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        security_groups: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        user_data: ?[]const u8 = null,
        additional_info: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        disable_api_termination: ?bool = null,
        dry_run: ?bool = null,
        ebs_optimized: ?bool = null,
        iam_instance_profile: ?IamInstanceProfileSpecification = null,
        instance_initiated_shutdown_behavior: ?[]const u8 = null,
        network_interfaces: ?[]InstanceNetworkInterfaceSpecification = null,
        private_ip_address: ?[]const u8 = null,
        elastic_gpu_specification: ?[]ElasticGpuSpecification = null,
        elastic_inference_accelerators: ?[]struct {
            type: []const u8,
            count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .count = "Count",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_specifications: ?[]TagSpecification = null,
        launch_template: ?struct {
            launch_template_id: ?[]const u8 = null,
            launch_template_name: ?[]const u8 = null,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .launch_template_id = "LaunchTemplateId",
                    .launch_template_name = "LaunchTemplateName",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        instance_market_options: ?struct {
            market_type: ?[]const u8 = null,
            spot_options: ?struct {
                max_price: ?[]const u8 = null,
                spot_instance_type: ?[]const u8 = null,
                block_duration_minutes: ?i64 = null,
                valid_until: ?i64 = null,
                instance_interruption_behavior: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_price = "MaxPrice",
                        .spot_instance_type = "SpotInstanceType",
                        .block_duration_minutes = "BlockDurationMinutes",
                        .valid_until = "ValidUntil",
                        .instance_interruption_behavior = "InstanceInterruptionBehavior",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .market_type = "MarketType",
                    .spot_options = "SpotOptions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        credit_specification: ?CreditSpecificationRequest = null,
        cpu_options: ?struct {
            core_count: ?i64 = null,
            threads_per_core: ?i64 = null,
            amd_sev_snp: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .core_count = "CoreCount",
                    .threads_per_core = "ThreadsPerCore",
                    .amd_sev_snp = "AmdSevSnp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        capacity_reservation_specification: ?CapacityReservationSpecification = null,
        hibernation_options: ?struct {
            configured: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configured = "Configured",
                };
                return @field(mappings, field_name);
            }
        } = null,
        license_specifications: ?[]struct {
            license_configuration_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .license_configuration_arn = "LicenseConfigurationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        metadata_options: ?struct {
            http_tokens: ?[]const u8 = null,
            http_put_response_hop_limit: ?i64 = null,
            http_endpoint: ?[]const u8 = null,
            http_protocol_ipv6: ?[]const u8 = null,
            instance_metadata_tags: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .http_tokens = "HttpTokens",
                    .http_put_response_hop_limit = "HttpPutResponseHopLimit",
                    .http_endpoint = "HttpEndpoint",
                    .http_protocol_ipv6 = "HttpProtocolIpv6",
                    .instance_metadata_tags = "InstanceMetadataTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        enclave_options: ?struct {
            enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        private_dns_name_options: ?struct {
            hostname_type: ?[]const u8 = null,
            enable_resource_name_dns_a_record: ?bool = null,
            enable_resource_name_dns_aaaa_record: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hostname_type = "HostnameType",
                    .enable_resource_name_dns_a_record = "EnableResourceNameDnsARecord",
                    .enable_resource_name_dns_aaaa_record = "EnableResourceNameDnsAAAARecord",
                };
                return @field(mappings, field_name);
            }
        } = null,
        maintenance_options: ?struct {
            auto_recovery: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_recovery = "AutoRecovery",
                };
                return @field(mappings, field_name);
            }
        } = null,
        disable_api_stop: ?bool = null,
        enable_primary_ipv6: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block_device_mappings = "BlockDeviceMapping",
                .image_id = "ImageId",
                .instance_type = "InstanceType",
                .ipv6_address_count = "Ipv6AddressCount",
                .ipv6_addresses = "Ipv6Address",
                .kernel_id = "KernelId",
                .key_name = "KeyName",
                .max_count = "MaxCount",
                .min_count = "MinCount",
                .monitoring = "Monitoring",
                .placement = "Placement",
                .ramdisk_id = "RamdiskId",
                .security_group_ids = "SecurityGroupId",
                .security_groups = "SecurityGroup",
                .subnet_id = "SubnetId",
                .user_data = "UserData",
                .additional_info = "additionalInfo",
                .client_token = "clientToken",
                .disable_api_termination = "disableApiTermination",
                .dry_run = "dryRun",
                .ebs_optimized = "ebsOptimized",
                .iam_instance_profile = "iamInstanceProfile",
                .instance_initiated_shutdown_behavior = "instanceInitiatedShutdownBehavior",
                .network_interfaces = "networkInterface",
                .private_ip_address = "privateIpAddress",
                .elastic_gpu_specification = "ElasticGpuSpecification",
                .elastic_inference_accelerators = "ElasticInferenceAccelerator",
                .tag_specifications = "TagSpecification",
                .launch_template = "LaunchTemplate",
                .instance_market_options = "InstanceMarketOptions",
                .credit_specification = "CreditSpecification",
                .cpu_options = "CpuOptions",
                .capacity_reservation_specification = "CapacityReservationSpecification",
                .hibernation_options = "HibernationOptions",
                .license_specifications = "LicenseSpecification",
                .metadata_options = "MetadataOptions",
                .enclave_options = "EnclaveOptions",
                .private_dns_name_options = "PrivateDnsNameOptions",
                .maintenance_options = "MaintenanceOptions",
                .disable_api_stop = "DisableApiStop",
                .enable_primary_ipv6 = "EnablePrimaryIpv6",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_instances) } {
            return .{ .service_metadata = service_metadata, .action = run_instances };
        }
    },
    Response: type = struct {
        groups: ?[]GroupIdentifier = null,
        instances: ?[]Instance = null,
        owner_id: ?[]const u8 = null,
        requester_id: ?[]const u8 = null,
        reservation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "groupSet",
                .instances = "instancesSet",
                .owner_id = "ownerId",
                .requester_id = "requesterId",
                .reservation_id = "reservationId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const run_scheduled_instances: struct {
    action_name: []const u8 = "RunScheduledInstances",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        dry_run: ?bool = null,
        instance_count: ?i64 = null,
        launch_specification: struct {
            block_device_mappings: ?[]struct {
                device_name: ?[]const u8 = null,
                ebs: ?struct {
                    delete_on_termination: ?bool = null,
                    encrypted: ?bool = null,
                    iops: ?i64 = null,
                    snapshot_id: ?[]const u8 = null,
                    volume_size: ?i64 = null,
                    volume_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .delete_on_termination = "DeleteOnTermination",
                            .encrypted = "Encrypted",
                            .iops = "Iops",
                            .snapshot_id = "SnapshotId",
                            .volume_size = "VolumeSize",
                            .volume_type = "VolumeType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                no_device: ?[]const u8 = null,
                virtual_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .device_name = "DeviceName",
                        .ebs = "Ebs",
                        .no_device = "NoDevice",
                        .virtual_name = "VirtualName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ebs_optimized: ?bool = null,
            iam_instance_profile: ?struct {
                arn: ?[]const u8 = null,
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "Arn",
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            image_id: []const u8,
            instance_type: ?[]const u8 = null,
            kernel_id: ?[]const u8 = null,
            key_name: ?[]const u8 = null,
            monitoring: ?struct {
                enabled: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enabled = "Enabled",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            network_interfaces: ?[]struct {
                associate_public_ip_address: ?bool = null,
                delete_on_termination: ?bool = null,
                description: ?[]const u8 = null,
                device_index: ?i64 = null,
                groups: ?[][]const u8 = null,
                ipv6_address_count: ?i64 = null,
                ipv6_addresses: ?[]struct {
                    ipv6_address: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ipv6_address = "Ipv6Address",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                network_interface_id: ?[]const u8 = null,
                private_ip_address: ?[]const u8 = null,
                private_ip_address_configs: ?[]struct {
                    primary: ?bool = null,
                    private_ip_address: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .primary = "Primary",
                            .private_ip_address = "PrivateIpAddress",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                secondary_private_ip_address_count: ?i64 = null,
                subnet_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .associate_public_ip_address = "AssociatePublicIpAddress",
                        .delete_on_termination = "DeleteOnTermination",
                        .description = "Description",
                        .device_index = "DeviceIndex",
                        .groups = "Group",
                        .ipv6_address_count = "Ipv6AddressCount",
                        .ipv6_addresses = "Ipv6Address",
                        .network_interface_id = "NetworkInterfaceId",
                        .private_ip_address = "PrivateIpAddress",
                        .private_ip_address_configs = "PrivateIpAddressConfig",
                        .secondary_private_ip_address_count = "SecondaryPrivateIpAddressCount",
                        .subnet_id = "SubnetId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            placement: ?struct {
                availability_zone: ?[]const u8 = null,
                group_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .availability_zone = "AvailabilityZone",
                        .group_name = "GroupName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ramdisk_id: ?[]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            subnet_id: ?[]const u8 = null,
            user_data: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .block_device_mappings = "BlockDeviceMapping",
                    .ebs_optimized = "EbsOptimized",
                    .iam_instance_profile = "IamInstanceProfile",
                    .image_id = "ImageId",
                    .instance_type = "InstanceType",
                    .kernel_id = "KernelId",
                    .key_name = "KeyName",
                    .monitoring = "Monitoring",
                    .network_interfaces = "NetworkInterface",
                    .placement = "Placement",
                    .ramdisk_id = "RamdiskId",
                    .security_group_ids = "SecurityGroupId",
                    .subnet_id = "SubnetId",
                    .user_data = "UserData",
                };
                return @field(mappings, field_name);
            }
        },
        scheduled_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .dry_run = "DryRun",
                .instance_count = "InstanceCount",
                .launch_specification = "LaunchSpecification",
                .scheduled_instance_id = "ScheduledInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_scheduled_instances) } {
            return .{ .service_metadata = service_metadata, .action = run_scheduled_instances };
        }
    },
    Response: type = struct {
        instance_id_set: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id_set = "instanceIdSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const search_local_gateway_routes: struct {
    action_name: []const u8 = "SearchLocalGatewayRoutes",
    Request: type = struct {
        local_gateway_route_table_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_gateway_route_table_id = "LocalGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_local_gateway_routes) } {
            return .{ .service_metadata = service_metadata, .action = search_local_gateway_routes };
        }
    },
    Response: type = struct {
        routes: ?[]LocalGatewayRoute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routes = "routeSet",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const search_transit_gateway_multicast_groups: struct {
    action_name: []const u8 = "SearchTransitGatewayMulticastGroups",
    Request: type = struct {
        transit_gateway_multicast_domain_id: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_multicast_domain_id = "TransitGatewayMulticastDomainId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_transit_gateway_multicast_groups) } {
            return .{ .service_metadata = service_metadata, .action = search_transit_gateway_multicast_groups };
        }
    },
    Response: type = struct {
        multicast_groups: ?[]struct {
            group_ip_address: ?[]const u8 = null,
            transit_gateway_attachment_id: ?[]const u8 = null,
            subnet_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            network_interface_id: ?[]const u8 = null,
            group_member: ?bool = null,
            group_source: ?bool = null,
            member_type: ?[]const u8 = null,
            source_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_ip_address = "groupIpAddress",
                    .transit_gateway_attachment_id = "transitGatewayAttachmentId",
                    .subnet_id = "subnetId",
                    .resource_id = "resourceId",
                    .resource_type = "resourceType",
                    .resource_owner_id = "resourceOwnerId",
                    .network_interface_id = "networkInterfaceId",
                    .group_member = "groupMember",
                    .group_source = "groupSource",
                    .member_type = "memberType",
                    .source_type = "sourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multicast_groups = "multicastGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const search_transit_gateway_routes: struct {
    action_name: []const u8 = "SearchTransitGatewayRoutes",
    Request: type = struct {
        transit_gateway_route_table_id: []const u8,
        filters: []Filter,
        max_results: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_id = "TransitGatewayRouteTableId",
                .filters = "Filter",
                .max_results = "MaxResults",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_transit_gateway_routes) } {
            return .{ .service_metadata = service_metadata, .action = search_transit_gateway_routes };
        }
    },
    Response: type = struct {
        routes: ?[]TransitGatewayRoute = null,
        additional_routes_available: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routes = "routeSet",
                .additional_routes_available = "additionalRoutesAvailable",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const send_diagnostic_interrupt: struct {
    action_name: []const u8 = "SendDiagnosticInterrupt",
    Request: type = struct {
        instance_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_diagnostic_interrupt) } {
            return .{ .service_metadata = service_metadata, .action = send_diagnostic_interrupt };
        }
    },
    Response: type = struct {},
} = .{};
pub const start_instances: struct {
    action_name: []const u8 = "StartInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        additional_info: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .additional_info = "additionalInfo",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_instances) } {
            return .{ .service_metadata = service_metadata, .action = start_instances };
        }
    },
    Response: type = struct {
        starting_instances: ?[]InstanceStateChange = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .starting_instances = "instancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const start_network_insights_access_scope_analysis: struct {
    action_name: []const u8 = "StartNetworkInsightsAccessScopeAnalysis",
    Request: type = struct {
        network_insights_access_scope_id: []const u8,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_id = "NetworkInsightsAccessScopeId",
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_network_insights_access_scope_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_network_insights_access_scope_analysis };
        }
    },
    Response: type = struct {
        network_insights_access_scope_analysis: ?NetworkInsightsAccessScopeAnalysis = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_access_scope_analysis = "networkInsightsAccessScopeAnalysis",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const start_network_insights_analysis: struct {
    action_name: []const u8 = "StartNetworkInsightsAnalysis",
    Request: type = struct {
        network_insights_path_id: []const u8,
        additional_accounts: ?[][]const u8 = null,
        filter_in_arns: ?[][]const u8 = null,
        dry_run: ?bool = null,
        tag_specifications: ?[]TagSpecification = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_path_id = "NetworkInsightsPathId",
                .additional_accounts = "AdditionalAccount",
                .filter_in_arns = "FilterInArn",
                .dry_run = "DryRun",
                .tag_specifications = "TagSpecification",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_network_insights_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_network_insights_analysis };
        }
    },
    Response: type = struct {
        network_insights_analysis: ?NetworkInsightsAnalysis = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_insights_analysis = "networkInsightsAnalysis",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const start_vpc_endpoint_service_private_dns_verification: struct {
    action_name: []const u8 = "StartVpcEndpointServicePrivateDnsVerification",
    Request: type = struct {
        dry_run: ?bool = null,
        service_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .service_id = "ServiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_vpc_endpoint_service_private_dns_verification) } {
            return .{ .service_metadata = service_metadata, .action = start_vpc_endpoint_service_private_dns_verification };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const stop_instances: struct {
    action_name: []const u8 = "StopInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        hibernate: ?bool = null,
        dry_run: ?bool = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .hibernate = "Hibernate",
                .dry_run = "dryRun",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_instances) } {
            return .{ .service_metadata = service_metadata, .action = stop_instances };
        }
    },
    Response: type = struct {
        stopping_instances: ?[]InstanceStateChange = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stopping_instances = "instancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const terminate_client_vpn_connections: struct {
    action_name: []const u8 = "TerminateClientVpnConnections",
    Request: type = struct {
        client_vpn_endpoint_id: []const u8,
        connection_id: ?[]const u8 = null,
        username: ?[]const u8 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "ClientVpnEndpointId",
                .connection_id = "ConnectionId",
                .username = "Username",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_client_vpn_connections) } {
            return .{ .service_metadata = service_metadata, .action = terminate_client_vpn_connections };
        }
    },
    Response: type = struct {
        client_vpn_endpoint_id: ?[]const u8 = null,
        username: ?[]const u8 = null,
        connection_statuses: ?[]struct {
            connection_id: ?[]const u8 = null,
            previous_status: ?ClientVpnConnectionStatus = null,
            current_status: ?ClientVpnConnectionStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_id = "connectionId",
                    .previous_status = "previousStatus",
                    .current_status = "currentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_vpn_endpoint_id = "clientVpnEndpointId",
                .username = "username",
                .connection_statuses = "connectionStatuses",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const terminate_instances: struct {
    action_name: []const u8 = "TerminateInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_instances) } {
            return .{ .service_metadata = service_metadata, .action = terminate_instances };
        }
    },
    Response: type = struct {
        terminating_instances: ?[]InstanceStateChange = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .terminating_instances = "instancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const unassign_ipv6_addresses: struct {
    action_name: []const u8 = "UnassignIpv6Addresses",
    Request: type = struct {
        ipv6_addresses: ?[][]const u8 = null,
        ipv6_prefixes: ?[][]const u8 = null,
        network_interface_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ipv6_addresses = "ipv6Addresses",
                .ipv6_prefixes = "Ipv6Prefix",
                .network_interface_id = "networkInterfaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unassign_ipv6_addresses) } {
            return .{ .service_metadata = service_metadata, .action = unassign_ipv6_addresses };
        }
    },
    Response: type = struct {
        network_interface_id: ?[]const u8 = null,
        unassigned_ipv6_addresses: ?[][]const u8 = null,
        unassigned_ipv6_prefixes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "networkInterfaceId",
                .unassigned_ipv6_addresses = "unassignedIpv6Addresses",
                .unassigned_ipv6_prefixes = "unassignedIpv6PrefixSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const unassign_private_ip_addresses: struct {
    action_name: []const u8 = "UnassignPrivateIpAddresses",
    Request: type = struct {
        network_interface_id: []const u8,
        private_ip_addresses: ?[][]const u8 = null,
        ipv4_prefixes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_interface_id = "networkInterfaceId",
                .private_ip_addresses = "privateIpAddress",
                .ipv4_prefixes = "Ipv4Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unassign_private_ip_addresses) } {
            return .{ .service_metadata = service_metadata, .action = unassign_private_ip_addresses };
        }
    },
    Response: type = struct {},
} = .{};
pub const unassign_private_nat_gateway_address: struct {
    action_name: []const u8 = "UnassignPrivateNatGatewayAddress",
    Request: type = struct {
        nat_gateway_id: []const u8,
        private_ip_addresses: [][]const u8,
        max_drain_duration_seconds: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "NatGatewayId",
                .private_ip_addresses = "PrivateIpAddress",
                .max_drain_duration_seconds = "MaxDrainDurationSeconds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unassign_private_nat_gateway_address) } {
            return .{ .service_metadata = service_metadata, .action = unassign_private_nat_gateway_address };
        }
    },
    Response: type = struct {
        nat_gateway_id: ?[]const u8 = null,
        nat_gateway_addresses: ?[]NatGatewayAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nat_gateway_id = "natGatewayId",
                .nat_gateway_addresses = "natGatewayAddressSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const unlock_snapshot: struct {
    action_name: []const u8 = "UnlockSnapshot",
    Request: type = struct {
        snapshot_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unlock_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = unlock_snapshot };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "snapshotId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const unmonitor_instances: struct {
    action_name: []const u8 = "UnmonitorInstances",
    Request: type = struct {
        instance_ids: [][]const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceId",
                .dry_run = "dryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unmonitor_instances) } {
            return .{ .service_metadata = service_metadata, .action = unmonitor_instances };
        }
    },
    Response: type = struct {
        instance_monitorings: ?[]InstanceMonitoring = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_monitorings = "instancesSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_security_group_rule_descriptions_egress: struct {
    action_name: []const u8 = "UpdateSecurityGroupRuleDescriptionsEgress",
    Request: type = struct {
        dry_run: ?bool = null,
        group_id: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        ip_permissions: ?[]IpPermission = null,
        security_group_rule_descriptions: ?[]SecurityGroupRuleDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .group_id = "GroupId",
                .group_name = "GroupName",
                .ip_permissions = "IpPermissions",
                .security_group_rule_descriptions = "SecurityGroupRuleDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_group_rule_descriptions_egress) } {
            return .{ .service_metadata = service_metadata, .action = update_security_group_rule_descriptions_egress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_security_group_rule_descriptions_ingress: struct {
    action_name: []const u8 = "UpdateSecurityGroupRuleDescriptionsIngress",
    Request: type = struct {
        dry_run: ?bool = null,
        group_id: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        ip_permissions: ?[]IpPermission = null,
        security_group_rule_descriptions: ?[]SecurityGroupRuleDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run = "DryRun",
                .group_id = "GroupId",
                .group_name = "GroupName",
                .ip_permissions = "IpPermissions",
                .security_group_rule_descriptions = "SecurityGroupRuleDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_group_rule_descriptions_ingress) } {
            return .{ .service_metadata = service_metadata, .action = update_security_group_rule_descriptions_ingress };
        }
    },
    Response: type = struct {
        @"return": ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"return" = "return",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const withdraw_byoip_cidr: struct {
    action_name: []const u8 = "WithdrawByoipCidr",
    Request: type = struct {
        cidr: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr = "Cidr",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(withdraw_byoip_cidr) } {
            return .{ .service_metadata = service_metadata, .action = withdraw_byoip_cidr };
        }
    },
    Response: type = struct {
        byoip_cidr: ?ByoipCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byoip_cidr = "byoipCidr",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};

pub const ByoipCidr = struct {
    cidr: ?[]const u8 = null,
    description: ?[]const u8 = null,
    asn_associations: ?[]AsnAssociation = null,
    status_message: ?[]const u8 = null,
    state: ?[]const u8 = null,
    network_border_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .description = "description",
            .asn_associations = "asnAssociationSet",
            .status_message = "statusMessage",
            .state = "state",
            .network_border_group = "networkBorderGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AsnAssociation = struct {
    asn: ?[]const u8 = null,
    cidr: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asn = "asn",
            .cidr = "cidr",
            .status_message = "statusMessage",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupRuleDescription = struct {
    security_group_rule_id: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_rule_id = "SecurityGroupRuleId",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const IpPermission = struct {
    from_port: ?i64 = null,
    ip_protocol: ?[]const u8 = null,
    ip_ranges: ?[]IpRange = null,
    ipv6_ranges: ?[]Ipv6Range = null,
    prefix_list_ids: ?[]PrefixListId = null,
    to_port: ?i64 = null,
    user_id_group_pairs: ?[]UserIdGroupPair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "fromPort",
            .ip_protocol = "ipProtocol",
            .ip_ranges = "ipRanges",
            .ipv6_ranges = "ipv6Ranges",
            .prefix_list_ids = "prefixListIds",
            .to_port = "toPort",
            .user_id_group_pairs = "groups",
        };
        return @field(mappings, field_name);
    }
};

pub const UserIdGroupPair = struct {
    description: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    peering_status: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .group_id = "groupId",
            .group_name = "groupName",
            .peering_status = "peeringStatus",
            .user_id = "userId",
            .vpc_id = "vpcId",
            .vpc_peering_connection_id = "vpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixListId = struct {
    description: ?[]const u8 = null,
    prefix_list_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .prefix_list_id = "prefixListId",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6Range = struct {
    cidr_ipv6: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ipv6 = "cidrIpv6",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const IpRange = struct {
    cidr_ip: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ip = "cidrIp",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceMonitoring = struct {
    instance_id: ?[]const u8 = null,
    monitoring: ?Monitoring = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "instanceId",
            .monitoring = "monitoring",
        };
        return @field(mappings, field_name);
    }
};

pub const Monitoring = struct {
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const NatGatewayAddress = struct {
    allocation_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    private_ip: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,
    association_id: ?[]const u8 = null,
    is_primary: ?bool = null,
    failure_message: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocation_id = "allocationId",
            .network_interface_id = "networkInterfaceId",
            .private_ip = "privateIp",
            .public_ip = "publicIp",
            .association_id = "associationId",
            .is_primary = "isPrimary",
            .failure_message = "failureMessage",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStateChange = struct {
    current_state: ?InstanceState = null,
    instance_id: ?[]const u8 = null,
    previous_state: ?InstanceState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_state = "currentState",
            .instance_id = "instanceId",
            .previous_state = "previousState",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceState = struct {
    code: ?i64 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientVpnConnectionStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInsightsAnalysis = struct {
    network_insights_analysis_id: ?[]const u8 = null,
    network_insights_analysis_arn: ?[]const u8 = null,
    network_insights_path_id: ?[]const u8 = null,
    additional_accounts: ?[][]const u8 = null,
    filter_in_arns: ?[][]const u8 = null,
    start_date: ?i64 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    warning_message: ?[]const u8 = null,
    network_path_found: ?bool = null,
    forward_path_components: ?[]PathComponent = null,
    return_path_components: ?[]PathComponent = null,
    explanations: ?[]Explanation = null,
    alternate_path_hints: ?[]AlternatePathHint = null,
    suggested_accounts: ?[][]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_insights_analysis_id = "networkInsightsAnalysisId",
            .network_insights_analysis_arn = "networkInsightsAnalysisArn",
            .network_insights_path_id = "networkInsightsPathId",
            .additional_accounts = "additionalAccountSet",
            .filter_in_arns = "filterInArnSet",
            .start_date = "startDate",
            .status = "status",
            .status_message = "statusMessage",
            .warning_message = "warningMessage",
            .network_path_found = "networkPathFound",
            .forward_path_components = "forwardPathComponentSet",
            .return_path_components = "returnPathComponentSet",
            .explanations = "explanationSet",
            .alternate_path_hints = "alternatePathHintSet",
            .suggested_accounts = "suggestedAccountSet",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const AlternatePathHint = struct {
    component_id: ?[]const u8 = null,
    component_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_id = "componentId",
            .component_arn = "componentArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Explanation = struct {
    acl: ?AnalysisComponent = null,
    acl_rule: ?AnalysisAclRule = null,
    address: ?[]const u8 = null,
    addresses: ?[][]const u8 = null,
    attached_to: ?AnalysisComponent = null,
    availability_zones: ?[][]const u8 = null,
    cidrs: ?[][]const u8 = null,
    component: ?AnalysisComponent = null,
    customer_gateway: ?AnalysisComponent = null,
    destination: ?AnalysisComponent = null,
    destination_vpc: ?AnalysisComponent = null,
    direction: ?[]const u8 = null,
    explanation_code: ?[]const u8 = null,
    ingress_route_table: ?AnalysisComponent = null,
    internet_gateway: ?AnalysisComponent = null,
    load_balancer_arn: ?[]const u8 = null,
    classic_load_balancer_listener: ?AnalysisLoadBalancerListener = null,
    load_balancer_listener_port: ?i64 = null,
    load_balancer_target: ?AnalysisLoadBalancerTarget = null,
    load_balancer_target_group: ?AnalysisComponent = null,
    load_balancer_target_groups: ?[]AnalysisComponent = null,
    load_balancer_target_port: ?i64 = null,
    elastic_load_balancer_listener: ?AnalysisComponent = null,
    missing_component: ?[]const u8 = null,
    nat_gateway: ?AnalysisComponent = null,
    network_interface: ?AnalysisComponent = null,
    packet_field: ?[]const u8 = null,
    vpc_peering_connection: ?AnalysisComponent = null,
    port: ?i64 = null,
    port_ranges: ?[]PortRange = null,
    prefix_list: ?AnalysisComponent = null,
    protocols: ?[][]const u8 = null,
    route_table_route: ?AnalysisRouteTableRoute = null,
    route_table: ?AnalysisComponent = null,
    security_group: ?AnalysisComponent = null,
    security_group_rule: ?AnalysisSecurityGroupRule = null,
    security_groups: ?[]AnalysisComponent = null,
    source_vpc: ?AnalysisComponent = null,
    state: ?[]const u8 = null,
    subnet: ?AnalysisComponent = null,
    subnet_route_table: ?AnalysisComponent = null,
    vpc: ?AnalysisComponent = null,
    vpc_endpoint: ?AnalysisComponent = null,
    vpn_connection: ?AnalysisComponent = null,
    vpn_gateway: ?AnalysisComponent = null,
    transit_gateway: ?AnalysisComponent = null,
    transit_gateway_route_table: ?AnalysisComponent = null,
    transit_gateway_route_table_route: ?TransitGatewayRouteTableRoute = null,
    transit_gateway_attachment: ?AnalysisComponent = null,
    component_account: ?[]const u8 = null,
    component_region: ?[]const u8 = null,
    firewall_stateless_rule: ?FirewallStatelessRule = null,
    firewall_stateful_rule: ?FirewallStatefulRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acl = "acl",
            .acl_rule = "aclRule",
            .address = "address",
            .addresses = "addressSet",
            .attached_to = "attachedTo",
            .availability_zones = "availabilityZoneSet",
            .cidrs = "cidrSet",
            .component = "component",
            .customer_gateway = "customerGateway",
            .destination = "destination",
            .destination_vpc = "destinationVpc",
            .direction = "direction",
            .explanation_code = "explanationCode",
            .ingress_route_table = "ingressRouteTable",
            .internet_gateway = "internetGateway",
            .load_balancer_arn = "loadBalancerArn",
            .classic_load_balancer_listener = "classicLoadBalancerListener",
            .load_balancer_listener_port = "loadBalancerListenerPort",
            .load_balancer_target = "loadBalancerTarget",
            .load_balancer_target_group = "loadBalancerTargetGroup",
            .load_balancer_target_groups = "loadBalancerTargetGroupSet",
            .load_balancer_target_port = "loadBalancerTargetPort",
            .elastic_load_balancer_listener = "elasticLoadBalancerListener",
            .missing_component = "missingComponent",
            .nat_gateway = "natGateway",
            .network_interface = "networkInterface",
            .packet_field = "packetField",
            .vpc_peering_connection = "vpcPeeringConnection",
            .port = "port",
            .port_ranges = "portRangeSet",
            .prefix_list = "prefixList",
            .protocols = "protocolSet",
            .route_table_route = "routeTableRoute",
            .route_table = "routeTable",
            .security_group = "securityGroup",
            .security_group_rule = "securityGroupRule",
            .security_groups = "securityGroupSet",
            .source_vpc = "sourceVpc",
            .state = "state",
            .subnet = "subnet",
            .subnet_route_table = "subnetRouteTable",
            .vpc = "vpc",
            .vpc_endpoint = "vpcEndpoint",
            .vpn_connection = "vpnConnection",
            .vpn_gateway = "vpnGateway",
            .transit_gateway = "transitGateway",
            .transit_gateway_route_table = "transitGatewayRouteTable",
            .transit_gateway_route_table_route = "transitGatewayRouteTableRoute",
            .transit_gateway_attachment = "transitGatewayAttachment",
            .component_account = "componentAccount",
            .component_region = "componentRegion",
            .firewall_stateless_rule = "firewallStatelessRule",
            .firewall_stateful_rule = "firewallStatefulRule",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallStatefulRule = struct {
    rule_group_arn: ?[]const u8 = null,
    sources: ?[][]const u8 = null,
    destinations: ?[][]const u8 = null,
    source_ports: ?[]PortRange = null,
    destination_ports: ?[]PortRange = null,
    protocol: ?[]const u8 = null,
    rule_action: ?[]const u8 = null,
    direction: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_arn = "ruleGroupArn",
            .sources = "sourceSet",
            .destinations = "destinationSet",
            .source_ports = "sourcePortSet",
            .destination_ports = "destinationPortSet",
            .protocol = "protocol",
            .rule_action = "ruleAction",
            .direction = "direction",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    from: ?i64 = null,
    to: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "from",
            .to = "to",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallStatelessRule = struct {
    rule_group_arn: ?[]const u8 = null,
    sources: ?[][]const u8 = null,
    destinations: ?[][]const u8 = null,
    source_ports: ?[]PortRange = null,
    destination_ports: ?[]PortRange = null,
    protocols: ?[]i64 = null,
    rule_action: ?[]const u8 = null,
    priority: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_arn = "ruleGroupArn",
            .sources = "sourceSet",
            .destinations = "destinationSet",
            .source_ports = "sourcePortSet",
            .destination_ports = "destinationPortSet",
            .protocols = "protocolSet",
            .rule_action = "ruleAction",
            .priority = "priority",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisComponent = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRouteTableRoute = struct {
    destination_cidr: ?[]const u8 = null,
    state: ?[]const u8 = null,
    route_origin: ?[]const u8 = null,
    prefix_list_id: ?[]const u8 = null,
    attachment_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr = "destinationCidr",
            .state = "state",
            .route_origin = "routeOrigin",
            .prefix_list_id = "prefixListId",
            .attachment_id = "attachmentId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSecurityGroupRule = struct {
    cidr: ?[]const u8 = null,
    direction: ?[]const u8 = null,
    security_group_id: ?[]const u8 = null,
    port_range: ?PortRange = null,
    prefix_list_id: ?[]const u8 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .direction = "direction",
            .security_group_id = "securityGroupId",
            .port_range = "portRange",
            .prefix_list_id = "prefixListId",
            .protocol = "protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisRouteTableRoute = struct {
    destination_cidr: ?[]const u8 = null,
    destination_prefix_list_id: ?[]const u8 = null,
    egress_only_internet_gateway_id: ?[]const u8 = null,
    gateway_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    nat_gateway_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    origin: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    carrier_gateway_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr = "destinationCidr",
            .destination_prefix_list_id = "destinationPrefixListId",
            .egress_only_internet_gateway_id = "egressOnlyInternetGatewayId",
            .gateway_id = "gatewayId",
            .instance_id = "instanceId",
            .nat_gateway_id = "natGatewayId",
            .network_interface_id = "networkInterfaceId",
            .origin = "origin",
            .transit_gateway_id = "transitGatewayId",
            .vpc_peering_connection_id = "vpcPeeringConnectionId",
            .state = "state",
            .carrier_gateway_id = "carrierGatewayId",
            .core_network_arn = "coreNetworkArn",
            .local_gateway_id = "localGatewayId",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisLoadBalancerTarget = struct {
    address: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    instance: ?AnalysisComponent = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "address",
            .availability_zone = "availabilityZone",
            .instance = "instance",
            .port = "port",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisLoadBalancerListener = struct {
    load_balancer_port: ?i64 = null,
    instance_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .load_balancer_port = "loadBalancerPort",
            .instance_port = "instancePort",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisAclRule = struct {
    cidr: ?[]const u8 = null,
    egress: ?bool = null,
    port_range: ?PortRange = null,
    protocol: ?[]const u8 = null,
    rule_action: ?[]const u8 = null,
    rule_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .egress = "egress",
            .port_range = "portRange",
            .protocol = "protocol",
            .rule_action = "ruleAction",
            .rule_number = "ruleNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PathComponent = struct {
    sequence_number: ?i64 = null,
    acl_rule: ?AnalysisAclRule = null,
    attached_to: ?AnalysisComponent = null,
    component: ?AnalysisComponent = null,
    destination_vpc: ?AnalysisComponent = null,
    outbound_header: ?AnalysisPacketHeader = null,
    inbound_header: ?AnalysisPacketHeader = null,
    route_table_route: ?AnalysisRouteTableRoute = null,
    security_group_rule: ?AnalysisSecurityGroupRule = null,
    source_vpc: ?AnalysisComponent = null,
    subnet: ?AnalysisComponent = null,
    vpc: ?AnalysisComponent = null,
    additional_details: ?[]AdditionalDetail = null,
    transit_gateway: ?AnalysisComponent = null,
    transit_gateway_route_table_route: ?TransitGatewayRouteTableRoute = null,
    explanations: ?[]Explanation = null,
    elastic_load_balancer_listener: ?AnalysisComponent = null,
    firewall_stateless_rule: ?FirewallStatelessRule = null,
    firewall_stateful_rule: ?FirewallStatefulRule = null,
    service_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sequence_number = "sequenceNumber",
            .acl_rule = "aclRule",
            .attached_to = "attachedTo",
            .component = "component",
            .destination_vpc = "destinationVpc",
            .outbound_header = "outboundHeader",
            .inbound_header = "inboundHeader",
            .route_table_route = "routeTableRoute",
            .security_group_rule = "securityGroupRule",
            .source_vpc = "sourceVpc",
            .subnet = "subnet",
            .vpc = "vpc",
            .additional_details = "additionalDetailSet",
            .transit_gateway = "transitGateway",
            .transit_gateway_route_table_route = "transitGatewayRouteTableRoute",
            .explanations = "explanationSet",
            .elastic_load_balancer_listener = "elasticLoadBalancerListener",
            .firewall_stateless_rule = "firewallStatelessRule",
            .firewall_stateful_rule = "firewallStatefulRule",
            .service_name = "serviceName",
        };
        return @field(mappings, field_name);
    }
};

pub const AdditionalDetail = struct {
    additional_detail_type: ?[]const u8 = null,
    component: ?AnalysisComponent = null,
    vpc_endpoint_service: ?AnalysisComponent = null,
    rule_options: ?[]RuleOption = null,
    rule_group_type_pairs: ?[]RuleGroupTypePair = null,
    rule_group_rule_options_pairs: ?[]RuleGroupRuleOptionsPair = null,
    service_name: ?[]const u8 = null,
    load_balancers: ?[]AnalysisComponent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_detail_type = "additionalDetailType",
            .component = "component",
            .vpc_endpoint_service = "vpcEndpointService",
            .rule_options = "ruleOptionSet",
            .rule_group_type_pairs = "ruleGroupTypePairSet",
            .rule_group_rule_options_pairs = "ruleGroupRuleOptionsPairSet",
            .service_name = "serviceName",
            .load_balancers = "loadBalancerSet",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupRuleOptionsPair = struct {
    rule_group_arn: ?[]const u8 = null,
    rule_options: ?[]RuleOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_arn = "ruleGroupArn",
            .rule_options = "ruleOptionSet",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleOption = struct {
    keyword: ?[]const u8 = null,
    settings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keyword = "keyword",
            .settings = "settingSet",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupTypePair = struct {
    rule_group_arn: ?[]const u8 = null,
    rule_group_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_arn = "ruleGroupArn",
            .rule_group_type = "ruleGroupType",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisPacketHeader = struct {
    destination_addresses: ?[][]const u8 = null,
    destination_port_ranges: ?[]PortRange = null,
    protocol: ?[]const u8 = null,
    source_addresses: ?[][]const u8 = null,
    source_port_ranges: ?[]PortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_addresses = "destinationAddressSet",
            .destination_port_ranges = "destinationPortRangeSet",
            .protocol = "protocol",
            .source_addresses = "sourceAddressSet",
            .source_port_ranges = "sourcePortRangeSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TagSpecification = struct {
    resource_type: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .tags = "Tag",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInsightsAccessScopeAnalysis = struct {
    network_insights_access_scope_analysis_id: ?[]const u8 = null,
    network_insights_access_scope_analysis_arn: ?[]const u8 = null,
    network_insights_access_scope_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    warning_message: ?[]const u8 = null,
    start_date: ?i64 = null,
    end_date: ?i64 = null,
    findings_found: ?[]const u8 = null,
    analyzed_eni_count: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_insights_access_scope_analysis_id = "networkInsightsAccessScopeAnalysisId",
            .network_insights_access_scope_analysis_arn = "networkInsightsAccessScopeAnalysisArn",
            .network_insights_access_scope_id = "networkInsightsAccessScopeId",
            .status = "status",
            .status_message = "statusMessage",
            .warning_message = "warningMessage",
            .start_date = "startDate",
            .end_date = "endDate",
            .findings_found = "findingsFound",
            .analyzed_eni_count = "analyzedEniCount",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRoute = struct {
    destination_cidr_block: ?[]const u8 = null,
    prefix_list_id: ?[]const u8 = null,
    transit_gateway_route_table_announcement_id: ?[]const u8 = null,
    transit_gateway_attachments: ?[]TransitGatewayRouteAttachment = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr_block = "destinationCidrBlock",
            .prefix_list_id = "prefixListId",
            .transit_gateway_route_table_announcement_id = "transitGatewayRouteTableAnnouncementId",
            .transit_gateway_attachments = "transitGatewayAttachments",
            .type = "type",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRouteAttachment = struct {
    resource_id: ?[]const u8 = null,
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "resourceId",
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_type = "resourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalGatewayRoute = struct {
    destination_cidr_block: ?[]const u8 = null,
    local_gateway_virtual_interface_group_id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    local_gateway_route_table_id: ?[]const u8 = null,
    local_gateway_route_table_arn: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    coip_pool_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    destination_prefix_list_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr_block = "destinationCidrBlock",
            .local_gateway_virtual_interface_group_id = "localGatewayVirtualInterfaceGroupId",
            .type = "type",
            .state = "state",
            .local_gateway_route_table_id = "localGatewayRouteTableId",
            .local_gateway_route_table_arn = "localGatewayRouteTableArn",
            .owner_id = "ownerId",
            .subnet_id = "subnetId",
            .coip_pool_id = "coipPoolId",
            .network_interface_id = "networkInterfaceId",
            .destination_prefix_list_id = "destinationPrefixListId",
        };
        return @field(mappings, field_name);
    }
};

pub const Instance = struct {
    ami_launch_index: ?i64 = null,
    image_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    kernel_id: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    launch_time: ?i64 = null,
    monitoring: ?Monitoring = null,
    placement: ?Placement = null,
    platform: ?[]const u8 = null,
    private_dns_name: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    product_codes: ?[]ProductCode = null,
    public_dns_name: ?[]const u8 = null,
    public_ip_address: ?[]const u8 = null,
    ramdisk_id: ?[]const u8 = null,
    state: ?InstanceState = null,
    state_transition_reason: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    architecture: ?[]const u8 = null,
    block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
    client_token: ?[]const u8 = null,
    ebs_optimized: ?bool = null,
    ena_support: ?bool = null,
    hypervisor: ?[]const u8 = null,
    iam_instance_profile: ?IamInstanceProfile = null,
    instance_lifecycle: ?[]const u8 = null,
    elastic_gpu_associations: ?[]ElasticGpuAssociation = null,
    elastic_inference_accelerator_associations: ?[]ElasticInferenceAcceleratorAssociation = null,
    network_interfaces: ?[]InstanceNetworkInterface = null,
    outpost_arn: ?[]const u8 = null,
    root_device_name: ?[]const u8 = null,
    root_device_type: ?[]const u8 = null,
    security_groups: ?[]GroupIdentifier = null,
    source_dest_check: ?bool = null,
    spot_instance_request_id: ?[]const u8 = null,
    sriov_net_support: ?[]const u8 = null,
    state_reason: ?StateReason = null,
    tags: ?[]Tag = null,
    virtualization_type: ?[]const u8 = null,
    cpu_options: ?CpuOptions = null,
    capacity_reservation_id: ?[]const u8 = null,
    capacity_reservation_specification: ?CapacityReservationSpecificationResponse = null,
    hibernation_options: ?HibernationOptions = null,
    licenses: ?[]LicenseConfiguration = null,
    metadata_options: ?InstanceMetadataOptionsResponse = null,
    enclave_options: ?EnclaveOptions = null,
    boot_mode: ?[]const u8 = null,
    platform_details: ?[]const u8 = null,
    usage_operation: ?[]const u8 = null,
    usage_operation_update_time: ?i64 = null,
    private_dns_name_options: ?PrivateDnsNameOptionsResponse = null,
    ipv6_address: ?[]const u8 = null,
    tpm_support: ?[]const u8 = null,
    maintenance_options: ?InstanceMaintenanceOptions = null,
    current_instance_boot_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ami_launch_index = "amiLaunchIndex",
            .image_id = "imageId",
            .instance_id = "instanceId",
            .instance_type = "instanceType",
            .kernel_id = "kernelId",
            .key_name = "keyName",
            .launch_time = "launchTime",
            .monitoring = "monitoring",
            .placement = "placement",
            .platform = "platform",
            .private_dns_name = "privateDnsName",
            .private_ip_address = "privateIpAddress",
            .product_codes = "productCodes",
            .public_dns_name = "dnsName",
            .public_ip_address = "ipAddress",
            .ramdisk_id = "ramdiskId",
            .state = "instanceState",
            .state_transition_reason = "reason",
            .subnet_id = "subnetId",
            .vpc_id = "vpcId",
            .architecture = "architecture",
            .block_device_mappings = "blockDeviceMapping",
            .client_token = "clientToken",
            .ebs_optimized = "ebsOptimized",
            .ena_support = "enaSupport",
            .hypervisor = "hypervisor",
            .iam_instance_profile = "iamInstanceProfile",
            .instance_lifecycle = "instanceLifecycle",
            .elastic_gpu_associations = "elasticGpuAssociationSet",
            .elastic_inference_accelerator_associations = "elasticInferenceAcceleratorAssociationSet",
            .network_interfaces = "networkInterfaceSet",
            .outpost_arn = "outpostArn",
            .root_device_name = "rootDeviceName",
            .root_device_type = "rootDeviceType",
            .security_groups = "groupSet",
            .source_dest_check = "sourceDestCheck",
            .spot_instance_request_id = "spotInstanceRequestId",
            .sriov_net_support = "sriovNetSupport",
            .state_reason = "stateReason",
            .tags = "tagSet",
            .virtualization_type = "virtualizationType",
            .cpu_options = "cpuOptions",
            .capacity_reservation_id = "capacityReservationId",
            .capacity_reservation_specification = "capacityReservationSpecification",
            .hibernation_options = "hibernationOptions",
            .licenses = "licenseSet",
            .metadata_options = "metadataOptions",
            .enclave_options = "enclaveOptions",
            .boot_mode = "bootMode",
            .platform_details = "platformDetails",
            .usage_operation = "usageOperation",
            .usage_operation_update_time = "usageOperationUpdateTime",
            .private_dns_name_options = "privateDnsNameOptions",
            .ipv6_address = "ipv6Address",
            .tpm_support = "tpmSupport",
            .maintenance_options = "maintenanceOptions",
            .current_instance_boot_mode = "currentInstanceBootMode",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceMaintenanceOptions = struct {
    auto_recovery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_recovery = "autoRecovery",
        };
        return @field(mappings, field_name);
    }
};

pub const PrivateDnsNameOptionsResponse = struct {
    hostname_type: ?[]const u8 = null,
    enable_resource_name_dns_a_record: ?bool = null,
    enable_resource_name_dns_aaaa_record: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname_type = "hostnameType",
            .enable_resource_name_dns_a_record = "enableResourceNameDnsARecord",
            .enable_resource_name_dns_aaaa_record = "enableResourceNameDnsAAAARecord",
        };
        return @field(mappings, field_name);
    }
};

pub const EnclaveOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceMetadataOptionsResponse = struct {
    state: ?[]const u8 = null,
    http_tokens: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    http_endpoint: ?[]const u8 = null,
    http_protocol_ipv6: ?[]const u8 = null,
    instance_metadata_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .http_tokens = "httpTokens",
            .http_put_response_hop_limit = "httpPutResponseHopLimit",
            .http_endpoint = "httpEndpoint",
            .http_protocol_ipv6 = "httpProtocolIpv6",
            .instance_metadata_tags = "instanceMetadataTags",
        };
        return @field(mappings, field_name);
    }
};

pub const LicenseConfiguration = struct {
    license_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "licenseConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HibernationOptions = struct {
    configured: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configured = "configured",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityReservationSpecificationResponse = struct {
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_target: ?CapacityReservationTargetResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_preference = "capacityReservationPreference",
            .capacity_reservation_target = "capacityReservationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityReservationTargetResponse = struct {
    capacity_reservation_id: ?[]const u8 = null,
    capacity_reservation_resource_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_id = "capacityReservationId",
            .capacity_reservation_resource_group_arn = "capacityReservationResourceGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CpuOptions = struct {
    core_count: ?i64 = null,
    threads_per_core: ?i64 = null,
    amd_sev_snp: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_count = "coreCount",
            .threads_per_core = "threadsPerCore",
            .amd_sev_snp = "amdSevSnp",
        };
        return @field(mappings, field_name);
    }
};

pub const StateReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupIdentifier = struct {
    group_name: ?[]const u8 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "groupName",
            .group_id = "groupId",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceNetworkInterface = struct {
    association: ?InstanceNetworkInterfaceAssociation = null,
    attachment: ?InstanceNetworkInterfaceAttachment = null,
    description: ?[]const u8 = null,
    groups: ?[]GroupIdentifier = null,
    ipv6_addresses: ?[]InstanceIpv6Address = null,
    mac_address: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    private_dns_name: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]InstancePrivateIpAddress = null,
    source_dest_check: ?bool = null,
    status: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    interface_type: ?[]const u8 = null,
    ipv4_prefixes: ?[]InstanceIpv4Prefix = null,
    ipv6_prefixes: ?[]InstanceIpv6Prefix = null,
    connection_tracking_configuration: ?ConnectionTrackingSpecificationResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association = "association",
            .attachment = "attachment",
            .description = "description",
            .groups = "groupSet",
            .ipv6_addresses = "ipv6AddressesSet",
            .mac_address = "macAddress",
            .network_interface_id = "networkInterfaceId",
            .owner_id = "ownerId",
            .private_dns_name = "privateDnsName",
            .private_ip_address = "privateIpAddress",
            .private_ip_addresses = "privateIpAddressesSet",
            .source_dest_check = "sourceDestCheck",
            .status = "status",
            .subnet_id = "subnetId",
            .vpc_id = "vpcId",
            .interface_type = "interfaceType",
            .ipv4_prefixes = "ipv4PrefixSet",
            .ipv6_prefixes = "ipv6PrefixSet",
            .connection_tracking_configuration = "connectionTrackingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionTrackingSpecificationResponse = struct {
    tcp_established_timeout: ?i64 = null,
    udp_stream_timeout: ?i64 = null,
    udp_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tcp_established_timeout = "tcpEstablishedTimeout",
            .udp_stream_timeout = "udpStreamTimeout",
            .udp_timeout = "udpTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceIpv6Prefix = struct {
    ipv6_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_prefix = "ipv6Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceIpv4Prefix = struct {
    ipv4_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv4_prefix = "ipv4Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InstancePrivateIpAddress = struct {
    association: ?InstanceNetworkInterfaceAssociation = null,
    primary: ?bool = null,
    private_dns_name: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association = "association",
            .primary = "primary",
            .private_dns_name = "privateDnsName",
            .private_ip_address = "privateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceNetworkInterfaceAssociation = struct {
    carrier_ip: ?[]const u8 = null,
    customer_owned_ip: ?[]const u8 = null,
    ip_owner_id: ?[]const u8 = null,
    public_dns_name: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .carrier_ip = "carrierIp",
            .customer_owned_ip = "customerOwnedIp",
            .ip_owner_id = "ipOwnerId",
            .public_dns_name = "publicDnsName",
            .public_ip = "publicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceIpv6Address = struct {
    ipv6_address: ?[]const u8 = null,
    is_primary_ipv6: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_address = "ipv6Address",
            .is_primary_ipv6 = "isPrimaryIpv6",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceNetworkInterfaceAttachment = struct {
    attach_time: ?i64 = null,
    attachment_id: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    device_index: ?i64 = null,
    status: ?[]const u8 = null,
    network_card_index: ?i64 = null,
    ena_srd_specification: ?InstanceAttachmentEnaSrdSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "attachTime",
            .attachment_id = "attachmentId",
            .delete_on_termination = "deleteOnTermination",
            .device_index = "deviceIndex",
            .status = "status",
            .network_card_index = "networkCardIndex",
            .ena_srd_specification = "enaSrdSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceAttachmentEnaSrdSpecification = struct {
    ena_srd_enabled: ?bool = null,
    ena_srd_udp_specification: ?InstanceAttachmentEnaSrdUdpSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_enabled = "enaSrdEnabled",
            .ena_srd_udp_specification = "enaSrdUdpSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceAttachmentEnaSrdUdpSpecification = struct {
    ena_srd_udp_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_udp_enabled = "enaSrdUdpEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticInferenceAcceleratorAssociation = struct {
    elastic_inference_accelerator_arn: ?[]const u8 = null,
    elastic_inference_accelerator_association_id: ?[]const u8 = null,
    elastic_inference_accelerator_association_state: ?[]const u8 = null,
    elastic_inference_accelerator_association_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elastic_inference_accelerator_arn = "elasticInferenceAcceleratorArn",
            .elastic_inference_accelerator_association_id = "elasticInferenceAcceleratorAssociationId",
            .elastic_inference_accelerator_association_state = "elasticInferenceAcceleratorAssociationState",
            .elastic_inference_accelerator_association_time = "elasticInferenceAcceleratorAssociationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticGpuAssociation = struct {
    elastic_gpu_id: ?[]const u8 = null,
    elastic_gpu_association_id: ?[]const u8 = null,
    elastic_gpu_association_state: ?[]const u8 = null,
    elastic_gpu_association_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elastic_gpu_id = "elasticGpuId",
            .elastic_gpu_association_id = "elasticGpuAssociationId",
            .elastic_gpu_association_state = "elasticGpuAssociationState",
            .elastic_gpu_association_time = "elasticGpuAssociationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const IamInstanceProfile = struct {
    arn: ?[]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceBlockDeviceMapping = struct {
    device_name: ?[]const u8 = null,
    ebs: ?EbsInstanceBlockDevice = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .ebs = "ebs",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsInstanceBlockDevice = struct {
    attach_time: ?i64 = null,
    delete_on_termination: ?bool = null,
    status: ?[]const u8 = null,
    volume_id: ?[]const u8 = null,
    associated_resource: ?[]const u8 = null,
    volume_owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "attachTime",
            .delete_on_termination = "deleteOnTermination",
            .status = "status",
            .volume_id = "volumeId",
            .associated_resource = "associatedResource",
            .volume_owner_id = "volumeOwnerId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductCode = struct {
    product_code_id: ?[]const u8 = null,
    product_code_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_code_id = "productCode",
            .product_code_type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const Placement = struct {
    availability_zone: ?[]const u8 = null,
    affinity: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    partition_number: ?i64 = null,
    host_id: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,
    spread_domain: ?[]const u8 = null,
    host_resource_group_arn: ?[]const u8 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .affinity = "affinity",
            .group_name = "groupName",
            .partition_number = "partitionNumber",
            .host_id = "hostId",
            .tenancy = "tenancy",
            .spread_domain = "spreadDomain",
            .host_resource_group_arn = "hostResourceGroupArn",
            .group_id = "groupId",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityReservationSpecification = struct {
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_target: ?CapacityReservationTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_preference = "CapacityReservationPreference",
            .capacity_reservation_target = "CapacityReservationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityReservationTarget = struct {
    capacity_reservation_id: ?[]const u8 = null,
    capacity_reservation_resource_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_id = "CapacityReservationId",
            .capacity_reservation_resource_group_arn = "CapacityReservationResourceGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CreditSpecificationRequest = struct {
    cpu_credits: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_credits = "CpuCredits",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticGpuSpecification = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceNetworkInterfaceSpecification = struct {
    associate_public_ip_address: ?bool = null,
    delete_on_termination: ?bool = null,
    description: ?[]const u8 = null,
    device_index: ?i64 = null,
    groups: ?[][]const u8 = null,
    ipv6_address_count: ?i64 = null,
    ipv6_addresses: ?[]InstanceIpv6Address = null,
    network_interface_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]PrivateIpAddressSpecification = null,
    secondary_private_ip_address_count: ?i64 = null,
    subnet_id: ?[]const u8 = null,
    associate_carrier_ip_address: ?bool = null,
    interface_type: ?[]const u8 = null,
    network_card_index: ?i64 = null,
    ipv4_prefixes: ?[]Ipv4PrefixSpecificationRequest = null,
    ipv4_prefix_count: ?i64 = null,
    ipv6_prefixes: ?[]Ipv6PrefixSpecificationRequest = null,
    ipv6_prefix_count: ?i64 = null,
    primary_ipv6: ?bool = null,
    ena_srd_specification: ?EnaSrdSpecificationRequest = null,
    connection_tracking_specification: ?ConnectionTrackingSpecificationRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_public_ip_address = "associatePublicIpAddress",
            .delete_on_termination = "deleteOnTermination",
            .description = "description",
            .device_index = "deviceIndex",
            .groups = "SecurityGroupId",
            .ipv6_address_count = "ipv6AddressCount",
            .ipv6_addresses = "ipv6AddressesSet",
            .network_interface_id = "networkInterfaceId",
            .private_ip_address = "privateIpAddress",
            .private_ip_addresses = "privateIpAddressesSet",
            .secondary_private_ip_address_count = "secondaryPrivateIpAddressCount",
            .subnet_id = "subnetId",
            .associate_carrier_ip_address = "AssociateCarrierIpAddress",
            .interface_type = "InterfaceType",
            .network_card_index = "NetworkCardIndex",
            .ipv4_prefixes = "Ipv4Prefix",
            .ipv4_prefix_count = "Ipv4PrefixCount",
            .ipv6_prefixes = "Ipv6Prefix",
            .ipv6_prefix_count = "Ipv6PrefixCount",
            .primary_ipv6 = "PrimaryIpv6",
            .ena_srd_specification = "EnaSrdSpecification",
            .connection_tracking_specification = "ConnectionTrackingSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionTrackingSpecificationRequest = struct {
    tcp_established_timeout: ?i64 = null,
    udp_stream_timeout: ?i64 = null,
    udp_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tcp_established_timeout = "TcpEstablishedTimeout",
            .udp_stream_timeout = "UdpStreamTimeout",
            .udp_timeout = "UdpTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const EnaSrdSpecificationRequest = struct {
    ena_srd_enabled: ?bool = null,
    ena_srd_udp_specification: ?EnaSrdUdpSpecificationRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_enabled = "EnaSrdEnabled",
            .ena_srd_udp_specification = "EnaSrdUdpSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const EnaSrdUdpSpecificationRequest = struct {
    ena_srd_udp_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_udp_enabled = "EnaSrdUdpEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6PrefixSpecificationRequest = struct {
    ipv6_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_prefix = "Ipv6Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv4PrefixSpecificationRequest = struct {
    ipv4_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv4_prefix = "Ipv4Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const PrivateIpAddressSpecification = struct {
    primary: ?bool = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary = "primary",
            .private_ip_address = "privateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const IamInstanceProfileSpecification = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const RunInstancesMonitoringEnabled = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockDeviceMapping = struct {
    device_name: ?[]const u8 = null,
    virtual_name: ?[]const u8 = null,
    ebs: ?EbsBlockDevice = null,
    no_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .virtual_name = "virtualName",
            .ebs = "ebs",
            .no_device = "noDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsBlockDevice = struct {
    delete_on_termination: ?bool = null,
    iops: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    throughput: ?i64 = null,
    outpost_arn: ?[]const u8 = null,
    encrypted: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_on_termination = "deleteOnTermination",
            .iops = "iops",
            .snapshot_id = "snapshotId",
            .volume_size = "volumeSize",
            .volume_type = "volumeType",
            .kms_key_id = "kmsKeyId",
            .throughput = "throughput",
            .outpost_arn = "outpostArn",
            .encrypted = "encrypted",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientVpnAuthorizationRuleStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedPrefixList = struct {
    prefix_list_id: ?[]const u8 = null,
    address_family: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,
    prefix_list_arn: ?[]const u8 = null,
    prefix_list_name: ?[]const u8 = null,
    max_entries: ?i64 = null,
    version: ?i64 = null,
    tags: ?[]Tag = null,
    owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_list_id = "prefixListId",
            .address_family = "addressFamily",
            .state = "state",
            .state_message = "stateMessage",
            .prefix_list_arn = "prefixListArn",
            .prefix_list_name = "prefixListName",
            .max_entries = "maxEntries",
            .version = "version",
            .tags = "tagSet",
            .owner_id = "ownerId",
        };
        return @field(mappings, field_name);
    }
};

pub const AddressAttribute = struct {
    public_ip: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    ptr_record: ?[]const u8 = null,
    ptr_record_update: ?PtrUpdateStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .public_ip = "publicIp",
            .allocation_id = "allocationId",
            .ptr_record = "ptrRecord",
            .ptr_record_update = "ptrRecordUpdate",
        };
        return @field(mappings, field_name);
    }
};

pub const PtrUpdateStatus = struct {
    value: ?[]const u8 = null,
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotInstanceRequest = struct {
    actual_block_hourly_price: ?[]const u8 = null,
    availability_zone_group: ?[]const u8 = null,
    block_duration_minutes: ?i64 = null,
    create_time: ?i64 = null,
    fault: ?SpotInstanceStateFault = null,
    instance_id: ?[]const u8 = null,
    launch_group: ?[]const u8 = null,
    launch_specification: ?LaunchSpecification = null,
    launched_availability_zone: ?[]const u8 = null,
    product_description: ?[]const u8 = null,
    spot_instance_request_id: ?[]const u8 = null,
    spot_price: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status: ?SpotInstanceStatus = null,
    tags: ?[]Tag = null,
    type: ?[]const u8 = null,
    valid_from: ?i64 = null,
    valid_until: ?i64 = null,
    instance_interruption_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actual_block_hourly_price = "actualBlockHourlyPrice",
            .availability_zone_group = "availabilityZoneGroup",
            .block_duration_minutes = "blockDurationMinutes",
            .create_time = "createTime",
            .fault = "fault",
            .instance_id = "instanceId",
            .launch_group = "launchGroup",
            .launch_specification = "launchSpecification",
            .launched_availability_zone = "launchedAvailabilityZone",
            .product_description = "productDescription",
            .spot_instance_request_id = "spotInstanceRequestId",
            .spot_price = "spotPrice",
            .state = "state",
            .status = "status",
            .tags = "tagSet",
            .type = "type",
            .valid_from = "validFrom",
            .valid_until = "validUntil",
            .instance_interruption_behavior = "instanceInterruptionBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotInstanceStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,
    update_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .update_time = "updateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchSpecification = struct {
    user_data: ?[]const u8 = null,
    security_groups: ?[]GroupIdentifier = null,
    addressing_type: ?[]const u8 = null,
    block_device_mappings: ?[]BlockDeviceMapping = null,
    ebs_optimized: ?bool = null,
    iam_instance_profile: ?IamInstanceProfileSpecification = null,
    image_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    kernel_id: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    network_interfaces: ?[]InstanceNetworkInterfaceSpecification = null,
    placement: ?SpotPlacement = null,
    ramdisk_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    monitoring: ?RunInstancesMonitoringEnabled = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_data = "userData",
            .security_groups = "groupSet",
            .addressing_type = "addressingType",
            .block_device_mappings = "blockDeviceMapping",
            .ebs_optimized = "ebsOptimized",
            .iam_instance_profile = "iamInstanceProfile",
            .image_id = "imageId",
            .instance_type = "instanceType",
            .kernel_id = "kernelId",
            .key_name = "keyName",
            .network_interfaces = "networkInterfaceSet",
            .placement = "placement",
            .ramdisk_id = "ramdiskId",
            .subnet_id = "subnetId",
            .monitoring = "monitoring",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotPlacement = struct {
    availability_zone: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .group_name = "groupName",
            .tenancy = "tenancy",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotInstanceStateFault = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotFleetRequestConfigData = struct {
    allocation_strategy: ?[]const u8 = null,
    on_demand_allocation_strategy: ?[]const u8 = null,
    spot_maintenance_strategies: ?SpotMaintenanceStrategies = null,
    client_token: ?[]const u8 = null,
    excess_capacity_termination_policy: ?[]const u8 = null,
    fulfilled_capacity: ?f64 = null,
    on_demand_fulfilled_capacity: ?f64 = null,
    iam_fleet_role: []const u8,
    launch_specifications: ?[]SpotFleetLaunchSpecification = null,
    launch_template_configs: ?[]LaunchTemplateConfig = null,
    spot_price: ?[]const u8 = null,
    target_capacity: i64,
    on_demand_target_capacity: ?i64 = null,
    on_demand_max_total_price: ?[]const u8 = null,
    spot_max_total_price: ?[]const u8 = null,
    terminate_instances_with_expiration: ?bool = null,
    type: ?[]const u8 = null,
    valid_from: ?i64 = null,
    valid_until: ?i64 = null,
    replace_unhealthy_instances: ?bool = null,
    instance_interruption_behavior: ?[]const u8 = null,
    load_balancers_config: ?LoadBalancersConfig = null,
    instance_pools_to_use_count: ?i64 = null,
    context: ?[]const u8 = null,
    target_capacity_unit_type: ?[]const u8 = null,
    tag_specifications: ?[]TagSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocation_strategy = "allocationStrategy",
            .on_demand_allocation_strategy = "onDemandAllocationStrategy",
            .spot_maintenance_strategies = "spotMaintenanceStrategies",
            .client_token = "clientToken",
            .excess_capacity_termination_policy = "excessCapacityTerminationPolicy",
            .fulfilled_capacity = "fulfilledCapacity",
            .on_demand_fulfilled_capacity = "onDemandFulfilledCapacity",
            .iam_fleet_role = "iamFleetRole",
            .launch_specifications = "launchSpecifications",
            .launch_template_configs = "launchTemplateConfigs",
            .spot_price = "spotPrice",
            .target_capacity = "targetCapacity",
            .on_demand_target_capacity = "onDemandTargetCapacity",
            .on_demand_max_total_price = "onDemandMaxTotalPrice",
            .spot_max_total_price = "spotMaxTotalPrice",
            .terminate_instances_with_expiration = "terminateInstancesWithExpiration",
            .type = "type",
            .valid_from = "validFrom",
            .valid_until = "validUntil",
            .replace_unhealthy_instances = "replaceUnhealthyInstances",
            .instance_interruption_behavior = "instanceInterruptionBehavior",
            .load_balancers_config = "loadBalancersConfig",
            .instance_pools_to_use_count = "instancePoolsToUseCount",
            .context = "context",
            .target_capacity_unit_type = "targetCapacityUnitType",
            .tag_specifications = "TagSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancersConfig = struct {
    classic_load_balancers_config: ?ClassicLoadBalancersConfig = null,
    target_groups_config: ?TargetGroupsConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .classic_load_balancers_config = "classicLoadBalancersConfig",
            .target_groups_config = "targetGroupsConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroupsConfig = struct {
    target_groups: ?[]TargetGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_groups = "targetGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetGroup = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassicLoadBalancersConfig = struct {
    classic_load_balancers: ?[]ClassicLoadBalancer = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .classic_load_balancers = "classicLoadBalancers",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassicLoadBalancer = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateConfig = struct {
    launch_template_specification: ?FleetLaunchTemplateSpecification = null,
    overrides: ?[]LaunchTemplateOverrides = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_specification = "launchTemplateSpecification",
            .overrides = "overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateOverrides = struct {
    instance_type: ?[]const u8 = null,
    spot_price: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    weighted_capacity: ?f64 = null,
    priority: ?f64 = null,
    instance_requirements: ?InstanceRequirements = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "instanceType",
            .spot_price = "spotPrice",
            .subnet_id = "subnetId",
            .availability_zone = "availabilityZone",
            .weighted_capacity = "weightedCapacity",
            .priority = "priority",
            .instance_requirements = "instanceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceRequirements = struct {
    v_cpu_count: ?VCpuCountRange = null,
    memory_mib: ?MemoryMiB = null,
    cpu_manufacturers: ?[][]const u8 = null,
    memory_gi_b_per_v_cpu: ?MemoryGiBPerVCpu = null,
    excluded_instance_types: ?[][]const u8 = null,
    instance_generations: ?[][]const u8 = null,
    spot_max_price_percentage_over_lowest_price: ?i64 = null,
    on_demand_max_price_percentage_over_lowest_price: ?i64 = null,
    bare_metal: ?[]const u8 = null,
    burstable_performance: ?[]const u8 = null,
    require_hibernate_support: ?bool = null,
    network_interface_count: ?NetworkInterfaceCount = null,
    local_storage: ?[]const u8 = null,
    local_storage_types: ?[][]const u8 = null,
    total_local_storage_gb: ?TotalLocalStorageGB = null,
    baseline_ebs_bandwidth_mbps: ?BaselineEbsBandwidthMbps = null,
    accelerator_types: ?[][]const u8 = null,
    accelerator_count: ?AcceleratorCount = null,
    accelerator_manufacturers: ?[][]const u8 = null,
    accelerator_names: ?[][]const u8 = null,
    accelerator_total_memory_mib: ?AcceleratorTotalMemoryMiB = null,
    network_bandwidth_gbps: ?NetworkBandwidthGbps = null,
    allowed_instance_types: ?[][]const u8 = null,
    max_spot_price_as_percentage_of_optimal_on_demand_price: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .v_cpu_count = "vCpuCount",
            .memory_mib = "memoryMiB",
            .cpu_manufacturers = "cpuManufacturerSet",
            .memory_gi_b_per_v_cpu = "memoryGiBPerVCpu",
            .excluded_instance_types = "excludedInstanceTypeSet",
            .instance_generations = "instanceGenerationSet",
            .spot_max_price_percentage_over_lowest_price = "spotMaxPricePercentageOverLowestPrice",
            .on_demand_max_price_percentage_over_lowest_price = "onDemandMaxPricePercentageOverLowestPrice",
            .bare_metal = "bareMetal",
            .burstable_performance = "burstablePerformance",
            .require_hibernate_support = "requireHibernateSupport",
            .network_interface_count = "networkInterfaceCount",
            .local_storage = "localStorage",
            .local_storage_types = "localStorageTypeSet",
            .total_local_storage_gb = "totalLocalStorageGB",
            .baseline_ebs_bandwidth_mbps = "baselineEbsBandwidthMbps",
            .accelerator_types = "acceleratorTypeSet",
            .accelerator_count = "acceleratorCount",
            .accelerator_manufacturers = "acceleratorManufacturerSet",
            .accelerator_names = "acceleratorNameSet",
            .accelerator_total_memory_mib = "acceleratorTotalMemoryMiB",
            .network_bandwidth_gbps = "networkBandwidthGbps",
            .allowed_instance_types = "allowedInstanceTypeSet",
            .max_spot_price_as_percentage_of_optimal_on_demand_price = "maxSpotPriceAsPercentageOfOptimalOnDemandPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkBandwidthGbps = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorTotalMemoryMiB = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorCount = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const BaselineEbsBandwidthMbps = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalLocalStorageGB = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfaceCount = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const MemoryGiBPerVCpu = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const MemoryMiB = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const VCpuCountRange = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "min",
            .max = "max",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetLaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotFleetLaunchSpecification = struct {
    security_groups: ?[]GroupIdentifier = null,
    addressing_type: ?[]const u8 = null,
    block_device_mappings: ?[]BlockDeviceMapping = null,
    ebs_optimized: ?bool = null,
    iam_instance_profile: ?IamInstanceProfileSpecification = null,
    image_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    kernel_id: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    monitoring: ?SpotFleetMonitoring = null,
    network_interfaces: ?[]InstanceNetworkInterfaceSpecification = null,
    placement: ?SpotPlacement = null,
    ramdisk_id: ?[]const u8 = null,
    spot_price: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    user_data: ?[]const u8 = null,
    weighted_capacity: ?f64 = null,
    tag_specifications: ?[]SpotFleetTagSpecification = null,
    instance_requirements: ?InstanceRequirements = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_groups = "groupSet",
            .addressing_type = "addressingType",
            .block_device_mappings = "blockDeviceMapping",
            .ebs_optimized = "ebsOptimized",
            .iam_instance_profile = "iamInstanceProfile",
            .image_id = "imageId",
            .instance_type = "instanceType",
            .kernel_id = "kernelId",
            .key_name = "keyName",
            .monitoring = "monitoring",
            .network_interfaces = "networkInterfaceSet",
            .placement = "placement",
            .ramdisk_id = "ramdiskId",
            .spot_price = "spotPrice",
            .subnet_id = "subnetId",
            .user_data = "userData",
            .weighted_capacity = "weightedCapacity",
            .tag_specifications = "tagSpecificationSet",
            .instance_requirements = "instanceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotFleetTagSpecification = struct {
    resource_type: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .tags = "tag",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotFleetMonitoring = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotMaintenanceStrategies = struct {
    capacity_rebalance: ?SpotCapacityRebalance = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_rebalance = "capacityRebalance",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotCapacityRebalance = struct {
    replacement_strategy: ?[]const u8 = null,
    termination_delay: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replacement_strategy = "replacementStrategy",
            .termination_delay = "terminationDelay",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteTableAssociationState = struct {
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .status_message = "statusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const IcmpTypeCode = struct {
    code: ?i64 = null,
    type: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const IamInstanceProfileAssociation = struct {
    association_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    iam_instance_profile: ?IamInstanceProfile = null,
    state: ?[]const u8 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "associationId",
            .instance_id = "instanceId",
            .iam_instance_profile = "iamInstanceProfile",
            .state = "state",
            .timestamp = "timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const UnsuccessfulItem = struct {
    @"error": ?UnsuccessfulItemError = null,
    resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"error" = "error",
            .resource_id = "resourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const UnsuccessfulItemError = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayVpcAttachment = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    creation_time: ?i64 = null,
    options: ?TransitGatewayVpcAttachmentOptions = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .transit_gateway_id = "transitGatewayId",
            .vpc_id = "vpcId",
            .vpc_owner_id = "vpcOwnerId",
            .state = "state",
            .subnet_ids = "subnetIds",
            .creation_time = "creationTime",
            .options = "options",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayVpcAttachmentOptions = struct {
    dns_support: ?[]const u8 = null,
    security_group_referencing_support: ?[]const u8 = null,
    ipv6_support: ?[]const u8 = null,
    appliance_mode_support: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_support = "dnsSupport",
            .security_group_referencing_support = "securityGroupReferencingSupport",
            .ipv6_support = "ipv6Support",
            .appliance_mode_support = "applianceModeSupport",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPeeringAttachment = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    accepter_transit_gateway_attachment_id: ?[]const u8 = null,
    requester_tgw_info: ?PeeringTgwInfo = null,
    accepter_tgw_info: ?PeeringTgwInfo = null,
    options: ?TransitGatewayPeeringAttachmentOptions = null,
    status: ?PeeringAttachmentStatus = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .accepter_transit_gateway_attachment_id = "accepterTransitGatewayAttachmentId",
            .requester_tgw_info = "requesterTgwInfo",
            .accepter_tgw_info = "accepterTgwInfo",
            .options = "options",
            .status = "status",
            .state = "state",
            .creation_time = "creationTime",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const PeeringAttachmentStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPeeringAttachmentOptions = struct {
    dynamic_routing: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_routing = "dynamicRouting",
        };
        return @field(mappings, field_name);
    }
};

pub const PeeringTgwInfo = struct {
    transit_gateway_id: ?[]const u8 = null,
    core_network_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_id = "transitGatewayId",
            .core_network_id = "coreNetworkId",
            .owner_id = "ownerId",
            .region = "region",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayMulticastDomainAssociations = struct {
    transit_gateway_multicast_domain_id: ?[]const u8 = null,
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_owner_id: ?[]const u8 = null,
    subnets: ?[]SubnetAssociation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .resource_owner_id = "resourceOwnerId",
            .subnets = "subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetAssociation = struct {
    subnet_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "subnetId",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceTagNotificationAttribute = struct {
    instance_tag_keys: ?[][]const u8 = null,
    include_all_tags_of_instance: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_tag_keys = "instanceTagKeySet",
            .include_all_tags_of_instance = "includeAllTagsOfInstance",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledInstance = struct {
    availability_zone: ?[]const u8 = null,
    create_date: ?i64 = null,
    hourly_price: ?[]const u8 = null,
    instance_count: ?i64 = null,
    instance_type: ?[]const u8 = null,
    network_platform: ?[]const u8 = null,
    next_slot_start_time: ?i64 = null,
    platform: ?[]const u8 = null,
    previous_slot_end_time: ?i64 = null,
    recurrence: ?ScheduledInstanceRecurrence = null,
    scheduled_instance_id: ?[]const u8 = null,
    slot_duration_in_hours: ?i64 = null,
    term_end_date: ?i64 = null,
    term_start_date: ?i64 = null,
    total_scheduled_instance_hours: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .create_date = "createDate",
            .hourly_price = "hourlyPrice",
            .instance_count = "instanceCount",
            .instance_type = "instanceType",
            .network_platform = "networkPlatform",
            .next_slot_start_time = "nextSlotStartTime",
            .platform = "platform",
            .previous_slot_end_time = "previousSlotEndTime",
            .recurrence = "recurrence",
            .scheduled_instance_id = "scheduledInstanceId",
            .slot_duration_in_hours = "slotDurationInHours",
            .term_end_date = "termEndDate",
            .term_start_date = "termStartDate",
            .total_scheduled_instance_hours = "totalScheduledInstanceHours",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledInstanceRecurrence = struct {
    frequency: ?[]const u8 = null,
    interval: ?i64 = null,
    occurrence_day_set: ?[]i64 = null,
    occurrence_relative_to_end: ?bool = null,
    occurrence_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frequency = "frequency",
            .interval = "interval",
            .occurrence_day_set = "occurrenceDaySet",
            .occurrence_relative_to_end = "occurrenceRelativeToEnd",
            .occurrence_unit = "occurrenceUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const Purchase = struct {
    currency_code: ?[]const u8 = null,
    duration: ?i64 = null,
    host_id_set: ?[][]const u8 = null,
    host_reservation_id: ?[]const u8 = null,
    hourly_price: ?[]const u8 = null,
    instance_family: ?[]const u8 = null,
    payment_option: ?[]const u8 = null,
    upfront_price: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .currency_code = "currencyCode",
            .duration = "duration",
            .host_id_set = "hostIdSet",
            .host_reservation_id = "hostReservationId",
            .hourly_price = "hourlyPrice",
            .instance_family = "instanceFamily",
            .payment_option = "paymentOption",
            .upfront_price = "upfrontPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityReservation = struct {
    capacity_reservation_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    capacity_reservation_arn: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    instance_platform: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,
    total_instance_count: ?i64 = null,
    available_instance_count: ?i64 = null,
    ebs_optimized: ?bool = null,
    ephemeral_storage: ?bool = null,
    state: ?[]const u8 = null,
    start_date: ?i64 = null,
    end_date: ?i64 = null,
    end_date_type: ?[]const u8 = null,
    instance_match_criteria: ?[]const u8 = null,
    create_date: ?i64 = null,
    tags: ?[]Tag = null,
    outpost_arn: ?[]const u8 = null,
    capacity_reservation_fleet_id: ?[]const u8 = null,
    placement_group_arn: ?[]const u8 = null,
    capacity_allocations: ?[]CapacityAllocation = null,
    reservation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_id = "capacityReservationId",
            .owner_id = "ownerId",
            .capacity_reservation_arn = "capacityReservationArn",
            .availability_zone_id = "availabilityZoneId",
            .instance_type = "instanceType",
            .instance_platform = "instancePlatform",
            .availability_zone = "availabilityZone",
            .tenancy = "tenancy",
            .total_instance_count = "totalInstanceCount",
            .available_instance_count = "availableInstanceCount",
            .ebs_optimized = "ebsOptimized",
            .ephemeral_storage = "ephemeralStorage",
            .state = "state",
            .start_date = "startDate",
            .end_date = "endDate",
            .end_date_type = "endDateType",
            .instance_match_criteria = "instanceMatchCriteria",
            .create_date = "createDate",
            .tags = "tagSet",
            .outpost_arn = "outpostArn",
            .capacity_reservation_fleet_id = "capacityReservationFleetId",
            .placement_group_arn = "placementGroupArn",
            .capacity_allocations = "capacityAllocationSet",
            .reservation_type = "reservationType",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityAllocation = struct {
    allocation_type: ?[]const u8 = null,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocation_type = "allocationType",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicIpv4PoolRange = struct {
    first_address: ?[]const u8 = null,
    last_address: ?[]const u8 = null,
    address_count: ?i64 = null,
    available_address_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .first_address = "firstAddress",
            .last_address = "lastAddress",
            .address_count = "addressCount",
            .available_address_count = "availableAddressCount",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamPoolCidr = struct {
    cidr: ?[]const u8 = null,
    state: ?[]const u8 = null,
    failure_reason: ?IpamPoolCidrFailureReason = null,
    ipam_pool_cidr_id: ?[]const u8 = null,
    netmask_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .state = "state",
            .failure_reason = "failureReason",
            .ipam_pool_cidr_id = "ipamPoolCidrId",
            .netmask_length = "netmaskLength",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamPoolCidrFailureReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const Byoasn = struct {
    asn: ?[]const u8 = null,
    ipam_id: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asn = "asn",
            .ipam_id = "ipamId",
            .status_message = "statusMessage",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnConnection = struct {
    customer_gateway_configuration: ?[]const u8 = null,
    customer_gateway_id: ?[]const u8 = null,
    category: ?[]const u8 = null,
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,
    vpn_connection_id: ?[]const u8 = null,
    vpn_gateway_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    core_network_attachment_arn: ?[]const u8 = null,
    gateway_association_state: ?[]const u8 = null,
    options: ?VpnConnectionOptions = null,
    routes: ?[]VpnStaticRoute = null,
    tags: ?[]Tag = null,
    vgw_telemetry: ?[]VgwTelemetry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_gateway_configuration = "customerGatewayConfiguration",
            .customer_gateway_id = "customerGatewayId",
            .category = "category",
            .state = "state",
            .type = "type",
            .vpn_connection_id = "vpnConnectionId",
            .vpn_gateway_id = "vpnGatewayId",
            .transit_gateway_id = "transitGatewayId",
            .core_network_arn = "coreNetworkArn",
            .core_network_attachment_arn = "coreNetworkAttachmentArn",
            .gateway_association_state = "gatewayAssociationState",
            .options = "options",
            .routes = "routes",
            .tags = "tagSet",
            .vgw_telemetry = "vgwTelemetry",
        };
        return @field(mappings, field_name);
    }
};

pub const VgwTelemetry = struct {
    accepted_route_count: ?i64 = null,
    last_status_change: ?i64 = null,
    outside_ip_address: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accepted_route_count = "acceptedRouteCount",
            .last_status_change = "lastStatusChange",
            .outside_ip_address = "outsideIpAddress",
            .status = "status",
            .status_message = "statusMessage",
            .certificate_arn = "certificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnStaticRoute = struct {
    destination_cidr_block: ?[]const u8 = null,
    source: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr_block = "destinationCidrBlock",
            .source = "source",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnConnectionOptions = struct {
    enable_acceleration: ?bool = null,
    static_routes_only: ?bool = null,
    local_ipv4_network_cidr: ?[]const u8 = null,
    remote_ipv4_network_cidr: ?[]const u8 = null,
    local_ipv6_network_cidr: ?[]const u8 = null,
    remote_ipv6_network_cidr: ?[]const u8 = null,
    outside_ip_address_type: ?[]const u8 = null,
    transport_transit_gateway_attachment_id: ?[]const u8 = null,
    tunnel_inside_ip_version: ?[]const u8 = null,
    tunnel_options: ?[]TunnelOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_acceleration = "enableAcceleration",
            .static_routes_only = "staticRoutesOnly",
            .local_ipv4_network_cidr = "localIpv4NetworkCidr",
            .remote_ipv4_network_cidr = "remoteIpv4NetworkCidr",
            .local_ipv6_network_cidr = "localIpv6NetworkCidr",
            .remote_ipv6_network_cidr = "remoteIpv6NetworkCidr",
            .outside_ip_address_type = "outsideIpAddressType",
            .transport_transit_gateway_attachment_id = "transportTransitGatewayAttachmentId",
            .tunnel_inside_ip_version = "tunnelInsideIpVersion",
            .tunnel_options = "tunnelOptionSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TunnelOption = struct {
    outside_ip_address: ?[]const u8 = null,
    tunnel_inside_cidr: ?[]const u8 = null,
    tunnel_inside_ipv6_cidr: ?[]const u8 = null,
    pre_shared_key: ?[]const u8 = null,
    phase1_lifetime_seconds: ?i64 = null,
    phase2_lifetime_seconds: ?i64 = null,
    rekey_margin_time_seconds: ?i64 = null,
    rekey_fuzz_percentage: ?i64 = null,
    replay_window_size: ?i64 = null,
    dpd_timeout_seconds: ?i64 = null,
    dpd_timeout_action: ?[]const u8 = null,
    phase1_encryption_algorithms: ?[]Phase1EncryptionAlgorithmsListValue = null,
    phase2_encryption_algorithms: ?[]Phase2EncryptionAlgorithmsListValue = null,
    phase1_integrity_algorithms: ?[]Phase1IntegrityAlgorithmsListValue = null,
    phase2_integrity_algorithms: ?[]Phase2IntegrityAlgorithmsListValue = null,
    phase1dh_group_numbers: ?[]Phase1DHGroupNumbersListValue = null,
    phase2dh_group_numbers: ?[]Phase2DHGroupNumbersListValue = null,
    ike_versions: ?[]IKEVersionsListValue = null,
    startup_action: ?[]const u8 = null,
    log_options: ?VpnTunnelLogOptions = null,
    enable_tunnel_lifecycle_control: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outside_ip_address = "outsideIpAddress",
            .tunnel_inside_cidr = "tunnelInsideCidr",
            .tunnel_inside_ipv6_cidr = "tunnelInsideIpv6Cidr",
            .pre_shared_key = "preSharedKey",
            .phase1_lifetime_seconds = "phase1LifetimeSeconds",
            .phase2_lifetime_seconds = "phase2LifetimeSeconds",
            .rekey_margin_time_seconds = "rekeyMarginTimeSeconds",
            .rekey_fuzz_percentage = "rekeyFuzzPercentage",
            .replay_window_size = "replayWindowSize",
            .dpd_timeout_seconds = "dpdTimeoutSeconds",
            .dpd_timeout_action = "dpdTimeoutAction",
            .phase1_encryption_algorithms = "phase1EncryptionAlgorithmSet",
            .phase2_encryption_algorithms = "phase2EncryptionAlgorithmSet",
            .phase1_integrity_algorithms = "phase1IntegrityAlgorithmSet",
            .phase2_integrity_algorithms = "phase2IntegrityAlgorithmSet",
            .phase1dh_group_numbers = "phase1DHGroupNumberSet",
            .phase2dh_group_numbers = "phase2DHGroupNumberSet",
            .ike_versions = "ikeVersionSet",
            .startup_action = "startupAction",
            .log_options = "logOptions",
            .enable_tunnel_lifecycle_control = "enableTunnelLifecycleControl",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnTunnelLogOptions = struct {
    cloud_watch_log_options: ?CloudWatchLogOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_options = "cloudWatchLogOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogOptions = struct {
    log_enabled: ?bool = null,
    log_group_arn: ?[]const u8 = null,
    log_output_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_enabled = "logEnabled",
            .log_group_arn = "logGroupArn",
            .log_output_format = "logOutputFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const IKEVersionsListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2DHGroupNumbersListValue = struct {
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1DHGroupNumbersListValue = struct {
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2IntegrityAlgorithmsListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1IntegrityAlgorithmsListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2EncryptionAlgorithmsListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1EncryptionAlgorithmsListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnTunnelLogOptionsSpecification = struct {
    cloud_watch_log_options: ?CloudWatchLogOptionsSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_options = "CloudWatchLogOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogOptionsSpecification = struct {
    log_enabled: ?bool = null,
    log_group_arn: ?[]const u8 = null,
    log_output_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_enabled = "LogEnabled",
            .log_group_arn = "LogGroupArn",
            .log_output_format = "LogOutputFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const IKEVersionsRequestListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2DHGroupNumbersRequestListValue = struct {
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1DHGroupNumbersRequestListValue = struct {
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2IntegrityAlgorithmsRequestListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1IntegrityAlgorithmsRequestListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase2EncryptionAlgorithmsRequestListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Phase1EncryptionAlgorithmsRequestListValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PeeringConnectionOptions = struct {
    allow_dns_resolution_from_remote_vpc: ?bool = null,
    allow_egress_from_local_classic_link_to_remote_vpc: ?bool = null,
    allow_egress_from_local_vpc_to_remote_classic_link: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_dns_resolution_from_remote_vpc = "allowDnsResolutionFromRemoteVpc",
            .allow_egress_from_local_classic_link_to_remote_vpc = "allowEgressFromLocalClassicLinkToRemoteVpc",
            .allow_egress_from_local_vpc_to_remote_classic_link = "allowEgressFromLocalVpcToRemoteClassicLink",
        };
        return @field(mappings, field_name);
    }
};

pub const PeeringConnectionOptionsRequest = struct {
    allow_dns_resolution_from_remote_vpc: ?bool = null,
    allow_egress_from_local_classic_link_to_remote_vpc: ?bool = null,
    allow_egress_from_local_vpc_to_remote_classic_link: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_dns_resolution_from_remote_vpc = "AllowDnsResolutionFromRemoteVpc",
            .allow_egress_from_local_classic_link_to_remote_vpc = "AllowEgressFromLocalClassicLinkToRemoteVpc",
            .allow_egress_from_local_vpc_to_remote_classic_link = "AllowEgressFromLocalVpcToRemoteClassicLink",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetConfiguration = struct {
    subnet_id: ?[]const u8 = null,
    ipv4: ?[]const u8 = null,
    ipv6: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .ipv4 = "Ipv4",
            .ipv6 = "Ipv6",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsOptionsSpecification = struct {
    dns_record_ip_type: ?[]const u8 = null,
    private_dns_only_for_inbound_resolver_endpoint: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_record_ip_type = "DnsRecordIpType",
            .private_dns_only_for_inbound_resolver_endpoint = "PrivateDnsOnlyForInboundResolverEndpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeBooleanValue = struct {
    value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeModification = struct {
    volume_id: ?[]const u8 = null,
    modification_state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    target_size: ?i64 = null,
    target_iops: ?i64 = null,
    target_volume_type: ?[]const u8 = null,
    target_throughput: ?i64 = null,
    target_multi_attach_enabled: ?bool = null,
    original_size: ?i64 = null,
    original_iops: ?i64 = null,
    original_volume_type: ?[]const u8 = null,
    original_throughput: ?i64 = null,
    original_multi_attach_enabled: ?bool = null,
    progress: ?i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_id = "volumeId",
            .modification_state = "modificationState",
            .status_message = "statusMessage",
            .target_size = "targetSize",
            .target_iops = "targetIops",
            .target_volume_type = "targetVolumeType",
            .target_throughput = "targetThroughput",
            .target_multi_attach_enabled = "targetMultiAttachEnabled",
            .original_size = "originalSize",
            .original_iops = "originalIops",
            .original_volume_type = "originalVolumeType",
            .original_throughput = "originalThroughput",
            .original_multi_attach_enabled = "originalMultiAttachEnabled",
            .progress = "progress",
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessTrustProvider = struct {
    verified_access_trust_provider_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    trust_provider_type: ?[]const u8 = null,
    user_trust_provider_type: ?[]const u8 = null,
    device_trust_provider_type: ?[]const u8 = null,
    oidc_options: ?OidcOptions = null,
    device_options: ?DeviceOptions = null,
    policy_reference_name: ?[]const u8 = null,
    creation_time: ?[]const u8 = null,
    last_updated_time: ?[]const u8 = null,
    tags: ?[]Tag = null,
    sse_specification: ?VerifiedAccessSseSpecificationResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_trust_provider_id = "verifiedAccessTrustProviderId",
            .description = "description",
            .trust_provider_type = "trustProviderType",
            .user_trust_provider_type = "userTrustProviderType",
            .device_trust_provider_type = "deviceTrustProviderType",
            .oidc_options = "oidcOptions",
            .device_options = "deviceOptions",
            .policy_reference_name = "policyReferenceName",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .tags = "tagSet",
            .sse_specification = "sseSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessSseSpecificationResponse = struct {
    customer_managed_key_enabled: ?bool = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed_key_enabled = "customerManagedKeyEnabled",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceOptions = struct {
    tenant_id: ?[]const u8 = null,
    public_signing_key_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tenant_id = "tenantId",
            .public_signing_key_url = "publicSigningKeyUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const OidcOptions = struct {
    issuer: ?[]const u8 = null,
    authorization_endpoint: ?[]const u8 = null,
    token_endpoint: ?[]const u8 = null,
    user_info_endpoint: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    client_secret: ?[]const u8 = null,
    scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer = "issuer",
            .authorization_endpoint = "authorizationEndpoint",
            .token_endpoint = "tokenEndpoint",
            .user_info_endpoint = "userInfoEndpoint",
            .client_id = "clientId",
            .client_secret = "clientSecret",
            .scope = "scope",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessSseSpecificationRequest = struct {
    customer_managed_key_enabled: ?bool = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed_key_enabled = "CustomerManagedKeyEnabled",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessInstanceLoggingConfiguration = struct {
    verified_access_instance_id: ?[]const u8 = null,
    access_logs: ?VerifiedAccessLogs = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_instance_id = "verifiedAccessInstanceId",
            .access_logs = "accessLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessLogs = struct {
    s3: ?VerifiedAccessLogS3Destination = null,
    cloud_watch_logs: ?VerifiedAccessLogCloudWatchLogsDestination = null,
    kinesis_data_firehose: ?VerifiedAccessLogKinesisDataFirehoseDestination = null,
    log_version: ?[]const u8 = null,
    include_trust_context: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
            .cloud_watch_logs = "cloudWatchLogs",
            .kinesis_data_firehose = "kinesisDataFirehose",
            .log_version = "logVersion",
            .include_trust_context = "includeTrustContext",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessLogKinesisDataFirehoseDestination = struct {
    enabled: ?bool = null,
    delivery_status: ?VerifiedAccessLogDeliveryStatus = null,
    delivery_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .delivery_status = "deliveryStatus",
            .delivery_stream = "deliveryStream",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessLogDeliveryStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessLogCloudWatchLogsDestination = struct {
    enabled: ?bool = null,
    delivery_status: ?VerifiedAccessLogDeliveryStatus = null,
    log_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .delivery_status = "deliveryStatus",
            .log_group = "logGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessLogS3Destination = struct {
    enabled: ?bool = null,
    delivery_status: ?VerifiedAccessLogDeliveryStatus = null,
    bucket_name: ?[]const u8 = null,
    prefix: ?[]const u8 = null,
    bucket_owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .delivery_status = "deliveryStatus",
            .bucket_name = "bucketName",
            .prefix = "prefix",
            .bucket_owner = "bucketOwner",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessInstance = struct {
    verified_access_instance_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    verified_access_trust_providers: ?[]VerifiedAccessTrustProviderCondensed = null,
    creation_time: ?[]const u8 = null,
    last_updated_time: ?[]const u8 = null,
    tags: ?[]Tag = null,
    fips_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_instance_id = "verifiedAccessInstanceId",
            .description = "description",
            .verified_access_trust_providers = "verifiedAccessTrustProviderSet",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .tags = "tagSet",
            .fips_enabled = "fipsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessTrustProviderCondensed = struct {
    verified_access_trust_provider_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    trust_provider_type: ?[]const u8 = null,
    user_trust_provider_type: ?[]const u8 = null,
    device_trust_provider_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_trust_provider_id = "verifiedAccessTrustProviderId",
            .description = "description",
            .trust_provider_type = "trustProviderType",
            .user_trust_provider_type = "userTrustProviderType",
            .device_trust_provider_type = "deviceTrustProviderType",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessGroup = struct {
    verified_access_group_id: ?[]const u8 = null,
    verified_access_instance_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    verified_access_group_arn: ?[]const u8 = null,
    creation_time: ?[]const u8 = null,
    last_updated_time: ?[]const u8 = null,
    deletion_time: ?[]const u8 = null,
    tags: ?[]Tag = null,
    sse_specification: ?VerifiedAccessSseSpecificationResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_group_id = "verifiedAccessGroupId",
            .verified_access_instance_id = "verifiedAccessInstanceId",
            .description = "description",
            .owner = "owner",
            .verified_access_group_arn = "verifiedAccessGroupArn",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .deletion_time = "deletionTime",
            .tags = "tagSet",
            .sse_specification = "sseSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessEndpoint = struct {
    verified_access_instance_id: ?[]const u8 = null,
    verified_access_group_id: ?[]const u8 = null,
    verified_access_endpoint_id: ?[]const u8 = null,
    application_domain: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    attachment_type: ?[]const u8 = null,
    domain_certificate_arn: ?[]const u8 = null,
    endpoint_domain: ?[]const u8 = null,
    device_validation_domain: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    load_balancer_options: ?VerifiedAccessEndpointLoadBalancerOptions = null,
    network_interface_options: ?VerifiedAccessEndpointEniOptions = null,
    status: ?VerifiedAccessEndpointStatus = null,
    description: ?[]const u8 = null,
    creation_time: ?[]const u8 = null,
    last_updated_time: ?[]const u8 = null,
    deletion_time: ?[]const u8 = null,
    tags: ?[]Tag = null,
    sse_specification: ?VerifiedAccessSseSpecificationResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verified_access_instance_id = "verifiedAccessInstanceId",
            .verified_access_group_id = "verifiedAccessGroupId",
            .verified_access_endpoint_id = "verifiedAccessEndpointId",
            .application_domain = "applicationDomain",
            .endpoint_type = "endpointType",
            .attachment_type = "attachmentType",
            .domain_certificate_arn = "domainCertificateArn",
            .endpoint_domain = "endpointDomain",
            .device_validation_domain = "deviceValidationDomain",
            .security_group_ids = "securityGroupIdSet",
            .load_balancer_options = "loadBalancerOptions",
            .network_interface_options = "networkInterfaceOptions",
            .status = "status",
            .description = "description",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .deletion_time = "deletionTime",
            .tags = "tagSet",
            .sse_specification = "sseSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessEndpointStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessEndpointEniOptions = struct {
    network_interface_id: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_id = "networkInterfaceId",
            .protocol = "protocol",
            .port = "port",
        };
        return @field(mappings, field_name);
    }
};

pub const VerifiedAccessEndpointLoadBalancerOptions = struct {
    protocol: ?[]const u8 = null,
    port: ?i64 = null,
    load_balancer_arn: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "protocol",
            .port = "port",
            .load_balancer_arn = "loadBalancerArn",
            .subnet_ids = "subnetIdSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPrefixListReference = struct {
    transit_gateway_route_table_id: ?[]const u8 = null,
    prefix_list_id: ?[]const u8 = null,
    prefix_list_owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    blackhole: ?bool = null,
    transit_gateway_attachment: ?TransitGatewayPrefixListAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_route_table_id = "transitGatewayRouteTableId",
            .prefix_list_id = "prefixListId",
            .prefix_list_owner_id = "prefixListOwnerId",
            .state = "state",
            .blackhole = "blackhole",
            .transit_gateway_attachment = "transitGatewayAttachment",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPrefixListAttachment = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_type = "resourceType",
            .resource_id = "resourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGateway = struct {
    transit_gateway_id: ?[]const u8 = null,
    transit_gateway_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    creation_time: ?i64 = null,
    options: ?TransitGatewayOptions = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_id = "transitGatewayId",
            .transit_gateway_arn = "transitGatewayArn",
            .state = "state",
            .owner_id = "ownerId",
            .description = "description",
            .creation_time = "creationTime",
            .options = "options",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayOptions = struct {
    amazon_side_asn: ?i64 = null,
    transit_gateway_cidr_blocks: ?[][]const u8 = null,
    auto_accept_shared_attachments: ?[]const u8 = null,
    default_route_table_association: ?[]const u8 = null,
    association_default_route_table_id: ?[]const u8 = null,
    default_route_table_propagation: ?[]const u8 = null,
    propagation_default_route_table_id: ?[]const u8 = null,
    vpn_ecmp_support: ?[]const u8 = null,
    dns_support: ?[]const u8 = null,
    security_group_referencing_support: ?[]const u8 = null,
    multicast_support: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_side_asn = "amazonSideAsn",
            .transit_gateway_cidr_blocks = "transitGatewayCidrBlocks",
            .auto_accept_shared_attachments = "autoAcceptSharedAttachments",
            .default_route_table_association = "defaultRouteTableAssociation",
            .association_default_route_table_id = "associationDefaultRouteTableId",
            .default_route_table_propagation = "defaultRouteTablePropagation",
            .propagation_default_route_table_id = "propagationDefaultRouteTableId",
            .vpn_ecmp_support = "vpnEcmpSupport",
            .dns_support = "dnsSupport",
            .security_group_referencing_support = "securityGroupReferencingSupport",
            .multicast_support = "multicastSupport",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorSession = struct {
    traffic_mirror_session_id: ?[]const u8 = null,
    traffic_mirror_target_id: ?[]const u8 = null,
    traffic_mirror_filter_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    packet_length: ?i64 = null,
    session_number: ?i64 = null,
    virtual_network_id: ?i64 = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .traffic_mirror_session_id = "trafficMirrorSessionId",
            .traffic_mirror_target_id = "trafficMirrorTargetId",
            .traffic_mirror_filter_id = "trafficMirrorFilterId",
            .network_interface_id = "networkInterfaceId",
            .owner_id = "ownerId",
            .packet_length = "packetLength",
            .session_number = "sessionNumber",
            .virtual_network_id = "virtualNetworkId",
            .description = "description",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorFilterRule = struct {
    traffic_mirror_filter_rule_id: ?[]const u8 = null,
    traffic_mirror_filter_id: ?[]const u8 = null,
    traffic_direction: ?[]const u8 = null,
    rule_number: ?i64 = null,
    rule_action: ?[]const u8 = null,
    protocol: ?i64 = null,
    destination_port_range: ?TrafficMirrorPortRange = null,
    source_port_range: ?TrafficMirrorPortRange = null,
    destination_cidr_block: ?[]const u8 = null,
    source_cidr_block: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .traffic_mirror_filter_rule_id = "trafficMirrorFilterRuleId",
            .traffic_mirror_filter_id = "trafficMirrorFilterId",
            .traffic_direction = "trafficDirection",
            .rule_number = "ruleNumber",
            .rule_action = "ruleAction",
            .protocol = "protocol",
            .destination_port_range = "destinationPortRange",
            .source_port_range = "sourcePortRange",
            .destination_cidr_block = "destinationCidrBlock",
            .source_cidr_block = "sourceCidrBlock",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorPortRange = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "fromPort",
            .to_port = "toPort",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorPortRangeRequest = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorFilter = struct {
    traffic_mirror_filter_id: ?[]const u8 = null,
    ingress_filter_rules: ?[]TrafficMirrorFilterRule = null,
    egress_filter_rules: ?[]TrafficMirrorFilterRule = null,
    network_services: ?[][]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .traffic_mirror_filter_id = "trafficMirrorFilterId",
            .ingress_filter_rules = "ingressFilterRuleSet",
            .egress_filter_rules = "egressFilterRuleSet",
            .network_services = "networkServiceSet",
            .description = "description",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateVolumePermission = struct {
    group: ?[]const u8 = null,
    user_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "group",
            .user_id = "userId",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedInstancesConfiguration = struct {
    availability_zone: ?[]const u8 = null,
    instance_count: ?i64 = null,
    instance_type: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .instance_count = "instanceCount",
            .instance_type = "instanceType",
            .platform = "platform",
            .scope = "scope",
        };
        return @field(mappings, field_name);
    }
};

pub const EnaSrdSpecification = struct {
    ena_srd_enabled: ?bool = null,
    ena_srd_udp_specification: ?EnaSrdUdpSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_enabled = "EnaSrdEnabled",
            .ena_srd_udp_specification = "EnaSrdUdpSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const EnaSrdUdpSpecification = struct {
    ena_srd_udp_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_udp_enabled = "EnaSrdUdpEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const AddPrefixListEntry = struct {
    cidr: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "Cidr",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplate = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    create_time: ?i64 = null,
    created_by: ?[]const u8 = null,
    default_version_number: ?i64 = null,
    latest_version_number: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .create_time = "createTime",
            .created_by = "createdBy",
            .default_version_number = "defaultVersionNumber",
            .latest_version_number = "latestVersionNumber",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamScope = struct {
    owner_id: ?[]const u8 = null,
    ipam_scope_id: ?[]const u8 = null,
    ipam_scope_arn: ?[]const u8 = null,
    ipam_arn: ?[]const u8 = null,
    ipam_region: ?[]const u8 = null,
    ipam_scope_type: ?[]const u8 = null,
    is_default: ?bool = null,
    description: ?[]const u8 = null,
    pool_count: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .ipam_scope_id = "ipamScopeId",
            .ipam_scope_arn = "ipamScopeArn",
            .ipam_arn = "ipamArn",
            .ipam_region = "ipamRegion",
            .ipam_scope_type = "ipamScopeType",
            .is_default = "isDefault",
            .description = "description",
            .pool_count = "poolCount",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamResourceDiscovery = struct {
    owner_id: ?[]const u8 = null,
    ipam_resource_discovery_id: ?[]const u8 = null,
    ipam_resource_discovery_arn: ?[]const u8 = null,
    ipam_resource_discovery_region: ?[]const u8 = null,
    description: ?[]const u8 = null,
    operating_regions: ?[]IpamOperatingRegion = null,
    is_default: ?bool = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .ipam_resource_discovery_id = "ipamResourceDiscoveryId",
            .ipam_resource_discovery_arn = "ipamResourceDiscoveryArn",
            .ipam_resource_discovery_region = "ipamResourceDiscoveryRegion",
            .description = "description",
            .operating_regions = "operatingRegionSet",
            .is_default = "isDefault",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamOperatingRegion = struct {
    region_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "regionName",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoveIpamOperatingRegion = struct {
    region_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
        };
        return @field(mappings, field_name);
    }
};

pub const AddIpamOperatingRegion = struct {
    region_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region_name = "RegionName",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamResourceCidr = struct {
    ipam_id: ?[]const u8 = null,
    ipam_scope_id: ?[]const u8 = null,
    ipam_pool_id: ?[]const u8 = null,
    resource_region: ?[]const u8 = null,
    resource_owner_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    resource_cidr: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_tags: ?[]IpamResourceTag = null,
    ip_usage: ?f64 = null,
    compliance_status: ?[]const u8 = null,
    management_state: ?[]const u8 = null,
    overlap_status: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipam_id = "ipamId",
            .ipam_scope_id = "ipamScopeId",
            .ipam_pool_id = "ipamPoolId",
            .resource_region = "resourceRegion",
            .resource_owner_id = "resourceOwnerId",
            .resource_id = "resourceId",
            .resource_name = "resourceName",
            .resource_cidr = "resourceCidr",
            .resource_type = "resourceType",
            .resource_tags = "resourceTagSet",
            .ip_usage = "ipUsage",
            .compliance_status = "complianceStatus",
            .management_state = "managementState",
            .overlap_status = "overlapStatus",
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamResourceTag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamPool = struct {
    owner_id: ?[]const u8 = null,
    ipam_pool_id: ?[]const u8 = null,
    source_ipam_pool_id: ?[]const u8 = null,
    ipam_pool_arn: ?[]const u8 = null,
    ipam_scope_arn: ?[]const u8 = null,
    ipam_scope_type: ?[]const u8 = null,
    ipam_arn: ?[]const u8 = null,
    ipam_region: ?[]const u8 = null,
    locale: ?[]const u8 = null,
    pool_depth: ?i64 = null,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,
    description: ?[]const u8 = null,
    auto_import: ?bool = null,
    publicly_advertisable: ?bool = null,
    address_family: ?[]const u8 = null,
    allocation_min_netmask_length: ?i64 = null,
    allocation_max_netmask_length: ?i64 = null,
    allocation_default_netmask_length: ?i64 = null,
    allocation_resource_tags: ?[]IpamResourceTag = null,
    tags: ?[]Tag = null,
    aws_service: ?[]const u8 = null,
    public_ip_source: ?[]const u8 = null,
    source_resource: ?IpamPoolSourceResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .ipam_pool_id = "ipamPoolId",
            .source_ipam_pool_id = "sourceIpamPoolId",
            .ipam_pool_arn = "ipamPoolArn",
            .ipam_scope_arn = "ipamScopeArn",
            .ipam_scope_type = "ipamScopeType",
            .ipam_arn = "ipamArn",
            .ipam_region = "ipamRegion",
            .locale = "locale",
            .pool_depth = "poolDepth",
            .state = "state",
            .state_message = "stateMessage",
            .description = "description",
            .auto_import = "autoImport",
            .publicly_advertisable = "publiclyAdvertisable",
            .address_family = "addressFamily",
            .allocation_min_netmask_length = "allocationMinNetmaskLength",
            .allocation_max_netmask_length = "allocationMaxNetmaskLength",
            .allocation_default_netmask_length = "allocationDefaultNetmaskLength",
            .allocation_resource_tags = "allocationResourceTagSet",
            .tags = "tagSet",
            .aws_service = "awsService",
            .public_ip_source = "publicIpSource",
            .source_resource = "sourceResource",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamPoolSourceResource = struct {
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_region: ?[]const u8 = null,
    resource_owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .resource_region = "resourceRegion",
            .resource_owner = "resourceOwner",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestIpamResourceTag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipam = struct {
    owner_id: ?[]const u8 = null,
    ipam_id: ?[]const u8 = null,
    ipam_arn: ?[]const u8 = null,
    ipam_region: ?[]const u8 = null,
    public_default_scope_id: ?[]const u8 = null,
    private_default_scope_id: ?[]const u8 = null,
    scope_count: ?i64 = null,
    description: ?[]const u8 = null,
    operating_regions: ?[]IpamOperatingRegion = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,
    default_resource_discovery_id: ?[]const u8 = null,
    default_resource_discovery_association_id: ?[]const u8 = null,
    resource_discovery_association_count: ?i64 = null,
    state_message: ?[]const u8 = null,
    tier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .ipam_id = "ipamId",
            .ipam_arn = "ipamArn",
            .ipam_region = "ipamRegion",
            .public_default_scope_id = "publicDefaultScopeId",
            .private_default_scope_id = "privateDefaultScopeId",
            .scope_count = "scopeCount",
            .description = "description",
            .operating_regions = "operatingRegionSet",
            .state = "state",
            .tags = "tagSet",
            .default_resource_discovery_id = "defaultResourceDiscoveryId",
            .default_resource_discovery_association_id = "defaultResourceDiscoveryAssociationId",
            .resource_discovery_association_count = "resourceDiscoveryAssociationCount",
            .state_message = "stateMessage",
            .tier = "tier",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceEventWindow = struct {
    instance_event_window_id: ?[]const u8 = null,
    time_ranges: ?[]InstanceEventWindowTimeRange = null,
    name: ?[]const u8 = null,
    cron_expression: ?[]const u8 = null,
    association_target: ?InstanceEventWindowAssociationTarget = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_event_window_id = "instanceEventWindowId",
            .time_ranges = "timeRangeSet",
            .name = "name",
            .cron_expression = "cronExpression",
            .association_target = "associationTarget",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceEventWindowAssociationTarget = struct {
    instance_ids: ?[][]const u8 = null,
    tags: ?[]Tag = null,
    dedicated_host_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_ids = "instanceIdSet",
            .tags = "tagSet",
            .dedicated_host_ids = "dedicatedHostIdSet",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceEventWindowTimeRange = struct {
    start_week_day: ?[]const u8 = null,
    start_hour: ?i64 = null,
    end_week_day: ?[]const u8 = null,
    end_hour: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_week_day = "startWeekDay",
            .start_hour = "startHour",
            .end_week_day = "endWeekDay",
            .end_hour = "endHour",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceEventWindowTimeRangeRequest = struct {
    start_week_day: ?[]const u8 = null,
    start_hour: ?i64 = null,
    end_week_day: ?[]const u8 = null,
    end_hour: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_week_day = "StartWeekDay",
            .start_hour = "StartHour",
            .end_week_day = "EndWeekDay",
            .end_hour = "EndHour",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStatusEvent = struct {
    instance_event_id: ?[]const u8 = null,
    code: ?[]const u8 = null,
    description: ?[]const u8 = null,
    not_after: ?i64 = null,
    not_before: ?i64 = null,
    not_before_deadline: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_event_id = "instanceEventId",
            .code = "code",
            .description = "description",
            .not_after = "notAfter",
            .not_before = "notBefore",
            .not_before_deadline = "notBeforeDeadline",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchPermission = struct {
    group: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    organization_arn: ?[]const u8 = null,
    organizational_unit_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "group",
            .user_id = "userId",
            .organization_arn = "organizationArn",
            .organizational_unit_arn = "organizationalUnitArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FpgaImageAttribute = struct {
    fpga_image_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    load_permissions: ?[]LoadPermission = null,
    product_codes: ?[]ProductCode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fpga_image_id = "fpgaImageId",
            .name = "name",
            .description = "description",
            .load_permissions = "loadPermissions",
            .product_codes = "productCodes",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadPermission = struct {
    user_id: ?[]const u8 = null,
    group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "userId",
            .group = "group",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadPermissionRequest = struct {
    group: ?[]const u8 = null,
    user_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "Group",
            .user_id = "UserId",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetCapacitySpecificationRequest = struct {
    total_target_capacity: i64,
    on_demand_target_capacity: ?i64 = null,
    spot_target_capacity: ?i64 = null,
    default_target_capacity_type: ?[]const u8 = null,
    target_capacity_unit_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_target_capacity = "TotalTargetCapacity",
            .on_demand_target_capacity = "OnDemandTargetCapacity",
            .spot_target_capacity = "SpotTargetCapacity",
            .default_target_capacity_type = "DefaultTargetCapacityType",
            .target_capacity_unit_type = "TargetCapacityUnitType",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetLaunchTemplateConfigRequest = struct {
    launch_template_specification: ?FleetLaunchTemplateSpecificationRequest = null,
    overrides: ?[]FleetLaunchTemplateOverridesRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_specification = "LaunchTemplateSpecification",
            .overrides = "Overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetLaunchTemplateOverridesRequest = struct {
    instance_type: ?[]const u8 = null,
    max_price: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    weighted_capacity: ?f64 = null,
    priority: ?f64 = null,
    placement: ?Placement = null,
    instance_requirements: ?InstanceRequirementsRequest = null,
    image_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .max_price = "MaxPrice",
            .subnet_id = "SubnetId",
            .availability_zone = "AvailabilityZone",
            .weighted_capacity = "WeightedCapacity",
            .priority = "Priority",
            .placement = "Placement",
            .instance_requirements = "InstanceRequirements",
            .image_id = "ImageId",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceRequirementsRequest = struct {
    v_cpu_count: VCpuCountRangeRequest,
    memory_mib: MemoryMiBRequest,
    cpu_manufacturers: ?[][]const u8 = null,
    memory_gi_b_per_v_cpu: ?MemoryGiBPerVCpuRequest = null,
    excluded_instance_types: ?[][]const u8 = null,
    instance_generations: ?[][]const u8 = null,
    spot_max_price_percentage_over_lowest_price: ?i64 = null,
    on_demand_max_price_percentage_over_lowest_price: ?i64 = null,
    bare_metal: ?[]const u8 = null,
    burstable_performance: ?[]const u8 = null,
    require_hibernate_support: ?bool = null,
    network_interface_count: ?NetworkInterfaceCountRequest = null,
    local_storage: ?[]const u8 = null,
    local_storage_types: ?[][]const u8 = null,
    total_local_storage_gb: ?TotalLocalStorageGBRequest = null,
    baseline_ebs_bandwidth_mbps: ?BaselineEbsBandwidthMbpsRequest = null,
    accelerator_types: ?[][]const u8 = null,
    accelerator_count: ?AcceleratorCountRequest = null,
    accelerator_manufacturers: ?[][]const u8 = null,
    accelerator_names: ?[][]const u8 = null,
    accelerator_total_memory_mib: ?AcceleratorTotalMemoryMiBRequest = null,
    network_bandwidth_gbps: ?NetworkBandwidthGbpsRequest = null,
    allowed_instance_types: ?[][]const u8 = null,
    max_spot_price_as_percentage_of_optimal_on_demand_price: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .v_cpu_count = "VCpuCount",
            .memory_mib = "MemoryMiB",
            .cpu_manufacturers = "CpuManufacturer",
            .memory_gi_b_per_v_cpu = "MemoryGiBPerVCpu",
            .excluded_instance_types = "ExcludedInstanceType",
            .instance_generations = "InstanceGeneration",
            .spot_max_price_percentage_over_lowest_price = "SpotMaxPricePercentageOverLowestPrice",
            .on_demand_max_price_percentage_over_lowest_price = "OnDemandMaxPricePercentageOverLowestPrice",
            .bare_metal = "BareMetal",
            .burstable_performance = "BurstablePerformance",
            .require_hibernate_support = "RequireHibernateSupport",
            .network_interface_count = "NetworkInterfaceCount",
            .local_storage = "LocalStorage",
            .local_storage_types = "LocalStorageType",
            .total_local_storage_gb = "TotalLocalStorageGB",
            .baseline_ebs_bandwidth_mbps = "BaselineEbsBandwidthMbps",
            .accelerator_types = "AcceleratorType",
            .accelerator_count = "AcceleratorCount",
            .accelerator_manufacturers = "AcceleratorManufacturer",
            .accelerator_names = "AcceleratorName",
            .accelerator_total_memory_mib = "AcceleratorTotalMemoryMiB",
            .network_bandwidth_gbps = "NetworkBandwidthGbps",
            .allowed_instance_types = "AllowedInstanceType",
            .max_spot_price_as_percentage_of_optimal_on_demand_price = "MaxSpotPriceAsPercentageOfOptimalOnDemandPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkBandwidthGbpsRequest = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorTotalMemoryMiBRequest = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const AcceleratorCountRequest = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const BaselineEbsBandwidthMbpsRequest = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalLocalStorageGBRequest = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfaceCountRequest = struct {
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const MemoryGiBPerVCpuRequest = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const MemoryMiBRequest = struct {
    min: i64,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const VCpuCountRangeRequest = struct {
    min: i64,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetLaunchTemplateSpecificationRequest = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "LaunchTemplateId",
            .launch_template_name = "LaunchTemplateName",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceFamilyCreditSpecification = struct {
    instance_family: ?[]const u8 = null,
    cpu_credits: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_family = "instanceFamily",
            .cpu_credits = "cpuCredits",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientLoginBannerOptions = struct {
    enabled: ?bool = null,
    banner_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .banner_text = "BannerText",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientConnectOptions = struct {
    enabled: ?bool = null,
    lambda_function_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .lambda_function_arn = "LambdaFunctionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionLogOptions = struct {
    enabled: ?bool = null,
    cloudwatch_log_group: ?[]const u8 = null,
    cloudwatch_log_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .cloudwatch_log_group = "CloudwatchLogGroup",
            .cloudwatch_log_stream = "CloudwatchLogStream",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversionTask = struct {
    conversion_task_id: ?[]const u8 = null,
    expiration_time: ?[]const u8 = null,
    import_instance: ?ImportInstanceTaskDetails = null,
    import_volume: ?ImportVolumeTaskDetails = null,
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conversion_task_id = "conversionTaskId",
            .expiration_time = "expirationTime",
            .import_instance = "importInstance",
            .import_volume = "importVolume",
            .state = "state",
            .status_message = "statusMessage",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportVolumeTaskDetails = struct {
    availability_zone: ?[]const u8 = null,
    bytes_converted: ?i64 = null,
    description: ?[]const u8 = null,
    image: ?DiskImageDescription = null,
    volume: ?DiskImageVolumeDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .bytes_converted = "bytesConverted",
            .description = "description",
            .image = "image",
            .volume = "volume",
        };
        return @field(mappings, field_name);
    }
};

pub const DiskImageVolumeDescription = struct {
    id: ?[]const u8 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .size = "size",
        };
        return @field(mappings, field_name);
    }
};

pub const DiskImageDescription = struct {
    checksum: ?[]const u8 = null,
    format: ?[]const u8 = null,
    import_manifest_url: ?[]const u8 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .checksum = "checksum",
            .format = "format",
            .import_manifest_url = "importManifestUrl",
            .size = "size",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportInstanceTaskDetails = struct {
    description: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    volumes: ?[]ImportInstanceVolumeDetailItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .instance_id = "instanceId",
            .platform = "platform",
            .volumes = "volumes",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportInstanceVolumeDetailItem = struct {
    availability_zone: ?[]const u8 = null,
    bytes_converted: ?i64 = null,
    description: ?[]const u8 = null,
    image: ?DiskImageDescription = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    volume: ?DiskImageVolumeDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .bytes_converted = "bytesConverted",
            .description = "description",
            .image = "image",
            .status = "status",
            .status_message = "statusMessage",
            .volume = "volume",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeDetail = struct {
    size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size = "size",
        };
        return @field(mappings, field_name);
    }
};

pub const DiskImageDetail = struct {
    bytes: i64,
    format: []const u8,
    import_manifest_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "bytes",
            .format = "format",
            .import_manifest_url = "importManifestUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotTaskDetail = struct {
    description: ?[]const u8 = null,
    disk_image_size: ?f64 = null,
    encrypted: ?bool = null,
    format: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    progress: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    url: ?[]const u8 = null,
    user_bucket: ?UserBucketDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .disk_image_size = "diskImageSize",
            .encrypted = "encrypted",
            .format = "format",
            .kms_key_id = "kmsKeyId",
            .progress = "progress",
            .snapshot_id = "snapshotId",
            .status = "status",
            .status_message = "statusMessage",
            .url = "url",
            .user_bucket = "userBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const UserBucketDetails = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const UserBucket = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientData = struct {
    comment: ?[]const u8 = null,
    upload_end: ?i64 = null,
    upload_size: ?f64 = null,
    upload_start: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .upload_end = "UploadEnd",
            .upload_size = "UploadSize",
            .upload_start = "UploadStart",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportImageLicenseConfigurationResponse = struct {
    license_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "licenseConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotDetail = struct {
    description: ?[]const u8 = null,
    device_name: ?[]const u8 = null,
    disk_image_size: ?f64 = null,
    format: ?[]const u8 = null,
    progress: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    url: ?[]const u8 = null,
    user_bucket: ?UserBucketDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .device_name = "deviceName",
            .disk_image_size = "diskImageSize",
            .format = "format",
            .progress = "progress",
            .snapshot_id = "snapshotId",
            .status = "status",
            .status_message = "statusMessage",
            .url = "url",
            .user_bucket = "userBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPolicyTableAssociation = struct {
    transit_gateway_policy_table_id: ?[]const u8 = null,
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_policy_table_id = "transitGatewayPolicyTableId",
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetCidrReservation = struct {
    subnet_cidr_reservation_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    cidr: ?[]const u8 = null,
    reservation_type: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_cidr_reservation_id = "subnetCidrReservationId",
            .subnet_id = "subnetId",
            .cidr = "cidr",
            .reservation_type = "reservationType",
            .owner_id = "ownerId",
            .description = "description",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservationValue = struct {
    hourly_price: ?[]const u8 = null,
    remaining_total_value: ?[]const u8 = null,
    remaining_upfront_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hourly_price = "hourlyPrice",
            .remaining_total_value = "remainingTotalValue",
            .remaining_upfront_value = "remainingUpfrontValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetConfigurationRequest = struct {
    instance_count: ?i64 = null,
    offering_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_count = "InstanceCount",
            .offering_id = "OfferingId",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInsightsAccessScopeContent = struct {
    network_insights_access_scope_id: ?[]const u8 = null,
    match_paths: ?[]AccessScopePath = null,
    exclude_paths: ?[]AccessScopePath = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_insights_access_scope_id = "networkInsightsAccessScopeId",
            .match_paths = "matchPathSet",
            .exclude_paths = "excludePathSet",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessScopePath = struct {
    source: ?PathStatement = null,
    destination: ?PathStatement = null,
    through_resources: ?[]ThroughResourcesStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .destination = "destination",
            .through_resources = "throughResourceSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ThroughResourcesStatement = struct {
    resource_statement: ?ResourceStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_statement = "resourceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceStatement = struct {
    resources: ?[][]const u8 = null,
    resource_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources = "resourceSet",
            .resource_types = "resourceTypeSet",
        };
        return @field(mappings, field_name);
    }
};

pub const PathStatement = struct {
    packet_header_statement: ?PacketHeaderStatement = null,
    resource_statement: ?ResourceStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .packet_header_statement = "packetHeaderStatement",
            .resource_statement = "resourceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const PacketHeaderStatement = struct {
    source_addresses: ?[][]const u8 = null,
    destination_addresses: ?[][]const u8 = null,
    source_ports: ?[][]const u8 = null,
    destination_ports: ?[][]const u8 = null,
    source_prefix_lists: ?[][]const u8 = null,
    destination_prefix_lists: ?[][]const u8 = null,
    protocols: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_addresses = "sourceAddressSet",
            .destination_addresses = "destinationAddressSet",
            .source_ports = "sourcePortSet",
            .destination_ports = "destinationPortSet",
            .source_prefix_lists = "sourcePrefixListSet",
            .destination_prefix_lists = "destinationPrefixListSet",
            .protocols = "protocolSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseLaunchTemplateData = struct {
    kernel_id: ?[]const u8 = null,
    ebs_optimized: ?bool = null,
    iam_instance_profile: ?LaunchTemplateIamInstanceProfileSpecification = null,
    block_device_mappings: ?[]LaunchTemplateBlockDeviceMapping = null,
    network_interfaces: ?[]LaunchTemplateInstanceNetworkInterfaceSpecification = null,
    image_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    monitoring: ?LaunchTemplatesMonitoring = null,
    placement: ?LaunchTemplatePlacement = null,
    ram_disk_id: ?[]const u8 = null,
    disable_api_termination: ?bool = null,
    instance_initiated_shutdown_behavior: ?[]const u8 = null,
    user_data: ?[]const u8 = null,
    tag_specifications: ?[]LaunchTemplateTagSpecification = null,
    elastic_gpu_specifications: ?[]ElasticGpuSpecificationResponse = null,
    elastic_inference_accelerators: ?[]LaunchTemplateElasticInferenceAcceleratorResponse = null,
    security_group_ids: ?[][]const u8 = null,
    security_groups: ?[][]const u8 = null,
    instance_market_options: ?LaunchTemplateInstanceMarketOptions = null,
    credit_specification: ?CreditSpecification = null,
    cpu_options: ?LaunchTemplateCpuOptions = null,
    capacity_reservation_specification: ?LaunchTemplateCapacityReservationSpecificationResponse = null,
    license_specifications: ?[]LaunchTemplateLicenseConfiguration = null,
    hibernation_options: ?LaunchTemplateHibernationOptions = null,
    metadata_options: ?LaunchTemplateInstanceMetadataOptions = null,
    enclave_options: ?LaunchTemplateEnclaveOptions = null,
    instance_requirements: ?InstanceRequirements = null,
    private_dns_name_options: ?LaunchTemplatePrivateDnsNameOptions = null,
    maintenance_options: ?LaunchTemplateInstanceMaintenanceOptions = null,
    disable_api_stop: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kernel_id = "kernelId",
            .ebs_optimized = "ebsOptimized",
            .iam_instance_profile = "iamInstanceProfile",
            .block_device_mappings = "blockDeviceMappingSet",
            .network_interfaces = "networkInterfaceSet",
            .image_id = "imageId",
            .instance_type = "instanceType",
            .key_name = "keyName",
            .monitoring = "monitoring",
            .placement = "placement",
            .ram_disk_id = "ramDiskId",
            .disable_api_termination = "disableApiTermination",
            .instance_initiated_shutdown_behavior = "instanceInitiatedShutdownBehavior",
            .user_data = "userData",
            .tag_specifications = "tagSpecificationSet",
            .elastic_gpu_specifications = "elasticGpuSpecificationSet",
            .elastic_inference_accelerators = "elasticInferenceAcceleratorSet",
            .security_group_ids = "securityGroupIdSet",
            .security_groups = "securityGroupSet",
            .instance_market_options = "instanceMarketOptions",
            .credit_specification = "creditSpecification",
            .cpu_options = "cpuOptions",
            .capacity_reservation_specification = "capacityReservationSpecification",
            .license_specifications = "licenseSet",
            .hibernation_options = "hibernationOptions",
            .metadata_options = "metadataOptions",
            .enclave_options = "enclaveOptions",
            .instance_requirements = "instanceRequirements",
            .private_dns_name_options = "privateDnsNameOptions",
            .maintenance_options = "maintenanceOptions",
            .disable_api_stop = "disableApiStop",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMaintenanceOptions = struct {
    auto_recovery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_recovery = "autoRecovery",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatePrivateDnsNameOptions = struct {
    hostname_type: ?[]const u8 = null,
    enable_resource_name_dns_a_record: ?bool = null,
    enable_resource_name_dns_aaaa_record: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname_type = "hostnameType",
            .enable_resource_name_dns_a_record = "enableResourceNameDnsARecord",
            .enable_resource_name_dns_aaaa_record = "enableResourceNameDnsAAAARecord",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEnclaveOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMetadataOptions = struct {
    state: ?[]const u8 = null,
    http_tokens: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    http_endpoint: ?[]const u8 = null,
    http_protocol_ipv6: ?[]const u8 = null,
    instance_metadata_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .http_tokens = "httpTokens",
            .http_put_response_hop_limit = "httpPutResponseHopLimit",
            .http_endpoint = "httpEndpoint",
            .http_protocol_ipv6 = "httpProtocolIpv6",
            .instance_metadata_tags = "instanceMetadataTags",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateHibernationOptions = struct {
    configured: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configured = "configured",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateLicenseConfiguration = struct {
    license_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "licenseConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateCapacityReservationSpecificationResponse = struct {
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_target: ?CapacityReservationTargetResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_preference = "capacityReservationPreference",
            .capacity_reservation_target = "capacityReservationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateCpuOptions = struct {
    core_count: ?i64 = null,
    threads_per_core: ?i64 = null,
    amd_sev_snp: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_count = "coreCount",
            .threads_per_core = "threadsPerCore",
            .amd_sev_snp = "amdSevSnp",
        };
        return @field(mappings, field_name);
    }
};

pub const CreditSpecification = struct {
    cpu_credits: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_credits = "cpuCredits",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMarketOptions = struct {
    market_type: ?[]const u8 = null,
    spot_options: ?LaunchTemplateSpotMarketOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .market_type = "marketType",
            .spot_options = "spotOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateSpotMarketOptions = struct {
    max_price: ?[]const u8 = null,
    spot_instance_type: ?[]const u8 = null,
    block_duration_minutes: ?i64 = null,
    valid_until: ?i64 = null,
    instance_interruption_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_price = "maxPrice",
            .spot_instance_type = "spotInstanceType",
            .block_duration_minutes = "blockDurationMinutes",
            .valid_until = "validUntil",
            .instance_interruption_behavior = "instanceInterruptionBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateElasticInferenceAcceleratorResponse = struct {
    type: ?[]const u8 = null,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticGpuSpecificationResponse = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateTagSpecification = struct {
    resource_type: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatePlacement = struct {
    availability_zone: ?[]const u8 = null,
    affinity: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    host_id: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,
    spread_domain: ?[]const u8 = null,
    host_resource_group_arn: ?[]const u8 = null,
    partition_number: ?i64 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .affinity = "affinity",
            .group_name = "groupName",
            .host_id = "hostId",
            .tenancy = "tenancy",
            .spread_domain = "spreadDomain",
            .host_resource_group_arn = "hostResourceGroupArn",
            .partition_number = "partitionNumber",
            .group_id = "groupId",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatesMonitoring = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceNetworkInterfaceSpecification = struct {
    associate_carrier_ip_address: ?bool = null,
    associate_public_ip_address: ?bool = null,
    delete_on_termination: ?bool = null,
    description: ?[]const u8 = null,
    device_index: ?i64 = null,
    groups: ?[][]const u8 = null,
    interface_type: ?[]const u8 = null,
    ipv6_address_count: ?i64 = null,
    ipv6_addresses: ?[]InstanceIpv6Address = null,
    network_interface_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]PrivateIpAddressSpecification = null,
    secondary_private_ip_address_count: ?i64 = null,
    subnet_id: ?[]const u8 = null,
    network_card_index: ?i64 = null,
    ipv4_prefixes: ?[]Ipv4PrefixSpecificationResponse = null,
    ipv4_prefix_count: ?i64 = null,
    ipv6_prefixes: ?[]Ipv6PrefixSpecificationResponse = null,
    ipv6_prefix_count: ?i64 = null,
    primary_ipv6: ?bool = null,
    ena_srd_specification: ?LaunchTemplateEnaSrdSpecification = null,
    connection_tracking_specification: ?ConnectionTrackingSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_carrier_ip_address = "associateCarrierIpAddress",
            .associate_public_ip_address = "associatePublicIpAddress",
            .delete_on_termination = "deleteOnTermination",
            .description = "description",
            .device_index = "deviceIndex",
            .groups = "groupSet",
            .interface_type = "interfaceType",
            .ipv6_address_count = "ipv6AddressCount",
            .ipv6_addresses = "ipv6AddressesSet",
            .network_interface_id = "networkInterfaceId",
            .private_ip_address = "privateIpAddress",
            .private_ip_addresses = "privateIpAddressesSet",
            .secondary_private_ip_address_count = "secondaryPrivateIpAddressCount",
            .subnet_id = "subnetId",
            .network_card_index = "networkCardIndex",
            .ipv4_prefixes = "ipv4PrefixSet",
            .ipv4_prefix_count = "ipv4PrefixCount",
            .ipv6_prefixes = "ipv6PrefixSet",
            .ipv6_prefix_count = "ipv6PrefixCount",
            .primary_ipv6 = "primaryIpv6",
            .ena_srd_specification = "enaSrdSpecification",
            .connection_tracking_specification = "connectionTrackingSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionTrackingSpecification = struct {
    tcp_established_timeout: ?i64 = null,
    udp_timeout: ?i64 = null,
    udp_stream_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tcp_established_timeout = "tcpEstablishedTimeout",
            .udp_timeout = "udpTimeout",
            .udp_stream_timeout = "udpStreamTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEnaSrdSpecification = struct {
    ena_srd_enabled: ?bool = null,
    ena_srd_udp_specification: ?LaunchTemplateEnaSrdUdpSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_enabled = "enaSrdEnabled",
            .ena_srd_udp_specification = "enaSrdUdpSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEnaSrdUdpSpecification = struct {
    ena_srd_udp_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_udp_enabled = "enaSrdUdpEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6PrefixSpecificationResponse = struct {
    ipv6_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_prefix = "ipv6Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv4PrefixSpecificationResponse = struct {
    ipv4_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv4_prefix = "ipv4Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateBlockDeviceMapping = struct {
    device_name: ?[]const u8 = null,
    virtual_name: ?[]const u8 = null,
    ebs: ?LaunchTemplateEbsBlockDevice = null,
    no_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .virtual_name = "virtualName",
            .ebs = "ebs",
            .no_device = "noDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEbsBlockDevice = struct {
    encrypted: ?bool = null,
    delete_on_termination: ?bool = null,
    iops: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "encrypted",
            .delete_on_termination = "deleteOnTermination",
            .iops = "iops",
            .kms_key_id = "kmsKeyId",
            .snapshot_id = "snapshotId",
            .volume_size = "volumeSize",
            .volume_type = "volumeType",
            .throughput = "throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateIamInstanceProfileSpecification = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamPoolAllocation = struct {
    cidr: ?[]const u8 = null,
    ipam_pool_allocation_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    resource_region: ?[]const u8 = null,
    resource_owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .ipam_pool_allocation_id = "ipamPoolAllocationId",
            .description = "description",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .resource_region = "resourceRegion",
            .resource_owner = "resourceOwner",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportTaskS3Location = struct {
    s3_bucket: ?[]const u8 = null,
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_prefix = "s3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPropagation = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    transit_gateway_route_table_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    transit_gateway_route_table_announcement_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .transit_gateway_route_table_id = "transitGatewayRouteTableId",
            .state = "state",
            .transit_gateway_route_table_announcement_id = "transitGatewayRouteTableAnnouncementId",
        };
        return @field(mappings, field_name);
    }
};

pub const FastLaunchLaunchTemplateSpecificationResponse = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const FastLaunchSnapshotConfigurationResponse = struct {
    target_resource_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_resource_count = "targetResourceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AddressTransfer = struct {
    public_ip: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    transfer_account_id: ?[]const u8 = null,
    transfer_offer_expiration_timestamp: ?i64 = null,
    transfer_offer_accepted_timestamp: ?i64 = null,
    address_transfer_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .public_ip = "publicIp",
            .allocation_id = "allocationId",
            .transfer_account_id = "transferAccountId",
            .transfer_offer_expiration_timestamp = "transferOfferExpirationTimestamp",
            .transfer_offer_accepted_timestamp = "transferOfferAcceptedTimestamp",
            .address_transfer_status = "addressTransferStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcCidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    cidr_block: ?[]const u8 = null,
    cidr_block_state: ?VpcCidrBlockState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "associationId",
            .cidr_block = "cidrBlock",
            .cidr_block_state = "cidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcCidrBlockState = struct {
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .status_message = "statusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcIpv6CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    ipv6_cidr_block: ?[]const u8 = null,
    ipv6_cidr_block_state: ?VpcCidrBlockState = null,
    network_border_group: ?[]const u8 = null,
    ipv6_pool: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "associationId",
            .ipv6_cidr_block = "ipv6CidrBlock",
            .ipv6_cidr_block_state = "ipv6CidrBlockState",
            .network_border_group = "networkBorderGroup",
            .ipv6_pool = "ipv6Pool",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayAssociation = struct {
    transit_gateway_route_table_id: ?[]const u8 = null,
    transit_gateway_attachment_id: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_route_table_id = "transitGatewayRouteTableId",
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .resource_id = "resourceId",
            .resource_type = "resourceType",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetIpv6CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    ipv6_cidr_block: ?[]const u8 = null,
    ipv6_cidr_block_state: ?SubnetCidrBlockState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "associationId",
            .ipv6_cidr_block = "ipv6CidrBlock",
            .ipv6_cidr_block_state = "ipv6CidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetCidrBlockState = struct {
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .status_message = "statusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const IpamResourceDiscoveryAssociation = struct {
    owner_id: ?[]const u8 = null,
    ipam_resource_discovery_association_id: ?[]const u8 = null,
    ipam_resource_discovery_association_arn: ?[]const u8 = null,
    ipam_resource_discovery_id: ?[]const u8 = null,
    ipam_id: ?[]const u8 = null,
    ipam_arn: ?[]const u8 = null,
    ipam_region: ?[]const u8 = null,
    is_default: ?bool = null,
    resource_discovery_status: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .ipam_resource_discovery_association_id = "ipamResourceDiscoveryAssociationId",
            .ipam_resource_discovery_association_arn = "ipamResourceDiscoveryAssociationArn",
            .ipam_resource_discovery_id = "ipamResourceDiscoveryId",
            .ipam_id = "ipamId",
            .ipam_arn = "ipamArn",
            .ipam_region = "ipamRegion",
            .is_default = "isDefault",
            .resource_discovery_status = "resourceDiscoveryStatus",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const VpnGateway = struct {
    availability_zone: ?[]const u8 = null,
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,
    vpc_attachments: ?[]VpcAttachment = null,
    vpn_gateway_id: ?[]const u8 = null,
    amazon_side_asn: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .state = "state",
            .type = "type",
            .vpc_attachments = "attachments",
            .vpn_gateway_id = "vpnGatewayId",
            .amazon_side_asn = "amazonSideAsn",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcAttachment = struct {
    state: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const Vpc = struct {
    cidr_block: ?[]const u8 = null,
    dhcp_options_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    instance_tenancy: ?[]const u8 = null,
    ipv6_cidr_block_association_set: ?[]VpcIpv6CidrBlockAssociation = null,
    cidr_block_association_set: ?[]VpcCidrBlockAssociation = null,
    is_default: ?bool = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "cidrBlock",
            .dhcp_options_id = "dhcpOptionsId",
            .state = "state",
            .vpc_id = "vpcId",
            .owner_id = "ownerId",
            .instance_tenancy = "instanceTenancy",
            .ipv6_cidr_block_association_set = "ipv6CidrBlockAssociationSet",
            .cidr_block_association_set = "cidrBlockAssociationSet",
            .is_default = "isDefault",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcPeeringConnection = struct {
    accepter_vpc_info: ?VpcPeeringConnectionVpcInfo = null,
    expiration_time: ?i64 = null,
    requester_vpc_info: ?VpcPeeringConnectionVpcInfo = null,
    status: ?VpcPeeringConnectionStateReason = null,
    tags: ?[]Tag = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accepter_vpc_info = "accepterVpcInfo",
            .expiration_time = "expirationTime",
            .requester_vpc_info = "requesterVpcInfo",
            .status = "status",
            .tags = "tagSet",
            .vpc_peering_connection_id = "vpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcPeeringConnectionStateReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcPeeringConnectionVpcInfo = struct {
    cidr_block: ?[]const u8 = null,
    ipv6_cidr_block_set: ?[]Ipv6CidrBlock = null,
    cidr_block_set: ?[]CidrBlock = null,
    owner_id: ?[]const u8 = null,
    peering_options: ?VpcPeeringConnectionOptionsDescription = null,
    vpc_id: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "cidrBlock",
            .ipv6_cidr_block_set = "ipv6CidrBlockSet",
            .cidr_block_set = "cidrBlockSet",
            .owner_id = "ownerId",
            .peering_options = "peeringOptions",
            .vpc_id = "vpcId",
            .region = "region",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcPeeringConnectionOptionsDescription = struct {
    allow_dns_resolution_from_remote_vpc: ?bool = null,
    allow_egress_from_local_classic_link_to_remote_vpc: ?bool = null,
    allow_egress_from_local_vpc_to_remote_classic_link: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_dns_resolution_from_remote_vpc = "allowDnsResolutionFromRemoteVpc",
            .allow_egress_from_local_classic_link_to_remote_vpc = "allowEgressFromLocalClassicLinkToRemoteVpc",
            .allow_egress_from_local_vpc_to_remote_classic_link = "allowEgressFromLocalVpcToRemoteClassicLink",
        };
        return @field(mappings, field_name);
    }
};

pub const CidrBlock = struct {
    cidr_block: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "cidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6CidrBlock = struct {
    ipv6_cidr_block: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_cidr_block = "ipv6CidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceTypeDetail = struct {
    service_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_type = "serviceType",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceConfiguration = struct {
    service_type: ?[]ServiceTypeDetail = null,
    service_id: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    service_state: ?[]const u8 = null,
    availability_zones: ?[][]const u8 = null,
    acceptance_required: ?bool = null,
    manages_vpc_endpoints: ?bool = null,
    network_load_balancer_arns: ?[][]const u8 = null,
    gateway_load_balancer_arns: ?[][]const u8 = null,
    supported_ip_address_types: ?[][]const u8 = null,
    base_endpoint_dns_names: ?[][]const u8 = null,
    private_dns_name: ?[]const u8 = null,
    private_dns_name_configuration: ?PrivateDnsNameConfiguration = null,
    payer_responsibility: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_type = "serviceType",
            .service_id = "serviceId",
            .service_name = "serviceName",
            .service_state = "serviceState",
            .availability_zones = "availabilityZoneSet",
            .acceptance_required = "acceptanceRequired",
            .manages_vpc_endpoints = "managesVpcEndpoints",
            .network_load_balancer_arns = "networkLoadBalancerArnSet",
            .gateway_load_balancer_arns = "gatewayLoadBalancerArnSet",
            .supported_ip_address_types = "supportedIpAddressTypeSet",
            .base_endpoint_dns_names = "baseEndpointDnsNameSet",
            .private_dns_name = "privateDnsName",
            .private_dns_name_configuration = "privateDnsNameConfiguration",
            .payer_responsibility = "payerResponsibility",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const PrivateDnsNameConfiguration = struct {
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .type = "type",
            .value = "value",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpoint = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_endpoint_type: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    policy_document: ?[]const u8 = null,
    route_table_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    groups: ?[]SecurityGroupIdentifier = null,
    ip_address_type: ?[]const u8 = null,
    dns_options: ?DnsOptions = null,
    private_dns_enabled: ?bool = null,
    requester_managed: ?bool = null,
    network_interface_ids: ?[][]const u8 = null,
    dns_entries: ?[]DnsEntry = null,
    creation_timestamp: ?i64 = null,
    tags: ?[]Tag = null,
    owner_id: ?[]const u8 = null,
    last_error: ?LastError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "vpcEndpointId",
            .vpc_endpoint_type = "vpcEndpointType",
            .vpc_id = "vpcId",
            .service_name = "serviceName",
            .state = "state",
            .policy_document = "policyDocument",
            .route_table_ids = "routeTableIdSet",
            .subnet_ids = "subnetIdSet",
            .groups = "groupSet",
            .ip_address_type = "ipAddressType",
            .dns_options = "dnsOptions",
            .private_dns_enabled = "privateDnsEnabled",
            .requester_managed = "requesterManaged",
            .network_interface_ids = "networkInterfaceIdSet",
            .dns_entries = "dnsEntrySet",
            .creation_timestamp = "creationTimestamp",
            .tags = "tagSet",
            .owner_id = "ownerId",
            .last_error = "lastError",
        };
        return @field(mappings, field_name);
    }
};

pub const LastError = struct {
    message: ?[]const u8 = null,
    code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
            .code = "code",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsEntry = struct {
    dns_name: ?[]const u8 = null,
    hosted_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_name = "dnsName",
            .hosted_zone_id = "hostedZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsOptions = struct {
    dns_record_ip_type: ?[]const u8 = null,
    private_dns_only_for_inbound_resolver_endpoint: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_record_ip_type = "dnsRecordIpType",
            .private_dns_only_for_inbound_resolver_endpoint = "privateDnsOnlyForInboundResolverEndpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupIdentifier = struct {
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "groupId",
            .group_name = "groupName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionNotification = struct {
    connection_notification_id: ?[]const u8 = null,
    service_id: ?[]const u8 = null,
    vpc_endpoint_id: ?[]const u8 = null,
    connection_notification_type: ?[]const u8 = null,
    connection_notification_arn: ?[]const u8 = null,
    connection_events: ?[][]const u8 = null,
    connection_notification_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_notification_id = "connectionNotificationId",
            .service_id = "serviceId",
            .vpc_endpoint_id = "vpcEndpointId",
            .connection_notification_type = "connectionNotificationType",
            .connection_notification_arn = "connectionNotificationArn",
            .connection_events = "connectionEvents",
            .connection_notification_state = "connectionNotificationState",
        };
        return @field(mappings, field_name);
    }
};

pub const Volume = struct {
    attachments: ?[]VolumeAttachment = null,
    availability_zone: ?[]const u8 = null,
    create_time: ?i64 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    size: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    volume_id: ?[]const u8 = null,
    iops: ?i64 = null,
    tags: ?[]Tag = null,
    volume_type: ?[]const u8 = null,
    fast_restored: ?bool = null,
    multi_attach_enabled: ?bool = null,
    throughput: ?i64 = null,
    sse_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachments = "attachmentSet",
            .availability_zone = "availabilityZone",
            .create_time = "createTime",
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
            .outpost_arn = "outpostArn",
            .size = "size",
            .snapshot_id = "snapshotId",
            .state = "status",
            .volume_id = "volumeId",
            .iops = "iops",
            .tags = "tagSet",
            .volume_type = "volumeType",
            .fast_restored = "fastRestored",
            .multi_attach_enabled = "multiAttachEnabled",
            .throughput = "throughput",
            .sse_type = "sseType",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeAttachment = struct {
    attach_time: ?i64 = null,
    device: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    volume_id: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    associated_resource: ?[]const u8 = null,
    instance_owning_service: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "attachTime",
            .device = "device",
            .instance_id = "instanceId",
            .state = "status",
            .volume_id = "volumeId",
            .delete_on_termination = "deleteOnTermination",
            .associated_resource = "associatedResource",
            .instance_owning_service = "instanceOwningService",
        };
        return @field(mappings, field_name);
    }
};

pub const TrunkInterfaceAssociation = struct {
    association_id: ?[]const u8 = null,
    branch_interface_id: ?[]const u8 = null,
    trunk_interface_id: ?[]const u8 = null,
    interface_protocol: ?[]const u8 = null,
    vlan_id: ?i64 = null,
    gre_key: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "associationId",
            .branch_interface_id = "branchInterfaceId",
            .trunk_interface_id = "trunkInterfaceId",
            .interface_protocol = "interfaceProtocol",
            .vlan_id = "vlanId",
            .gre_key = "greKey",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRouteTable = struct {
    transit_gateway_route_table_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    default_association_route_table: ?bool = null,
    default_propagation_route_table: ?bool = null,
    creation_time: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_route_table_id = "transitGatewayRouteTableId",
            .transit_gateway_id = "transitGatewayId",
            .state = "state",
            .default_association_route_table = "defaultAssociationRouteTable",
            .default_propagation_route_table = "defaultPropagationRouteTable",
            .creation_time = "creationTime",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRouteTableAnnouncement = struct {
    transit_gateway_route_table_announcement_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    core_network_id: ?[]const u8 = null,
    peer_transit_gateway_id: ?[]const u8 = null,
    peer_core_network_id: ?[]const u8 = null,
    peering_attachment_id: ?[]const u8 = null,
    announcement_direction: ?[]const u8 = null,
    transit_gateway_route_table_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_route_table_announcement_id = "transitGatewayRouteTableAnnouncementId",
            .transit_gateway_id = "transitGatewayId",
            .core_network_id = "coreNetworkId",
            .peer_transit_gateway_id = "peerTransitGatewayId",
            .peer_core_network_id = "peerCoreNetworkId",
            .peering_attachment_id = "peeringAttachmentId",
            .announcement_direction = "announcementDirection",
            .transit_gateway_route_table_id = "transitGatewayRouteTableId",
            .state = "state",
            .creation_time = "creationTime",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPolicyTable = struct {
    transit_gateway_policy_table_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_policy_table_id = "transitGatewayPolicyTableId",
            .transit_gateway_id = "transitGatewayId",
            .state = "state",
            .creation_time = "creationTime",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayMulticastDomain = struct {
    transit_gateway_multicast_domain_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    transit_gateway_multicast_domain_arn: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    options: ?TransitGatewayMulticastDomainOptions = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_multicast_domain_id = "transitGatewayMulticastDomainId",
            .transit_gateway_id = "transitGatewayId",
            .transit_gateway_multicast_domain_arn = "transitGatewayMulticastDomainArn",
            .owner_id = "ownerId",
            .options = "options",
            .state = "state",
            .creation_time = "creationTime",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayMulticastDomainOptions = struct {
    igmpv2_support: ?[]const u8 = null,
    static_sources_support: ?[]const u8 = null,
    auto_accept_shared_associations: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .igmpv2_support = "igmpv2Support",
            .static_sources_support = "staticSourcesSupport",
            .auto_accept_shared_associations = "autoAcceptSharedAssociations",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnect = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    transport_transit_gateway_attachment_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    options: ?TransitGatewayConnectOptions = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .transport_transit_gateway_attachment_id = "transportTransitGatewayAttachmentId",
            .transit_gateway_id = "transitGatewayId",
            .state = "state",
            .creation_time = "creationTime",
            .options = "options",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnectOptions = struct {
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnectPeer = struct {
    transit_gateway_attachment_id: ?[]const u8 = null,
    transit_gateway_connect_peer_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    creation_time: ?i64 = null,
    connect_peer_configuration: ?TransitGatewayConnectPeerConfiguration = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_id = "transitGatewayAttachmentId",
            .transit_gateway_connect_peer_id = "transitGatewayConnectPeerId",
            .state = "state",
            .creation_time = "creationTime",
            .connect_peer_configuration = "connectPeerConfiguration",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnectPeerConfiguration = struct {
    transit_gateway_address: ?[]const u8 = null,
    peer_address: ?[]const u8 = null,
    inside_cidr_blocks: ?[][]const u8 = null,
    protocol: ?[]const u8 = null,
    bgp_configurations: ?[]TransitGatewayAttachmentBgpConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_address = "transitGatewayAddress",
            .peer_address = "peerAddress",
            .inside_cidr_blocks = "insideCidrBlocks",
            .protocol = "protocol",
            .bgp_configurations = "bgpConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayAttachmentBgpConfiguration = struct {
    transit_gateway_asn: ?i64 = null,
    peer_asn: ?i64 = null,
    transit_gateway_address: ?[]const u8 = null,
    peer_address: ?[]const u8 = null,
    bgp_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_asn = "transitGatewayAsn",
            .peer_asn = "peerAsn",
            .transit_gateway_address = "transitGatewayAddress",
            .peer_address = "peerAddress",
            .bgp_status = "bgpStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficMirrorTarget = struct {
    traffic_mirror_target_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    network_load_balancer_arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    gateway_load_balancer_endpoint_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .traffic_mirror_target_id = "trafficMirrorTargetId",
            .network_interface_id = "networkInterfaceId",
            .network_load_balancer_arn = "networkLoadBalancerArn",
            .type = "type",
            .description = "description",
            .owner_id = "ownerId",
            .tags = "tagSet",
            .gateway_load_balancer_endpoint_id = "gatewayLoadBalancerEndpointId",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    availability_zone: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    available_ip_address_count: ?i64 = null,
    cidr_block: ?[]const u8 = null,
    default_for_az: ?bool = null,
    enable_lni_at_device_index: ?i64 = null,
    map_public_ip_on_launch: ?bool = null,
    map_customer_owned_ip_on_launch: ?bool = null,
    customer_owned_ipv4_pool: ?[]const u8 = null,
    state: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    assign_ipv6_address_on_creation: ?bool = null,
    ipv6_cidr_block_association_set: ?[]SubnetIpv6CidrBlockAssociation = null,
    tags: ?[]Tag = null,
    subnet_arn: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    enable_dns64: ?bool = null,
    ipv6_native: ?bool = null,
    private_dns_name_options_on_launch: ?PrivateDnsNameOptionsOnLaunch = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .availability_zone_id = "availabilityZoneId",
            .available_ip_address_count = "availableIpAddressCount",
            .cidr_block = "cidrBlock",
            .default_for_az = "defaultForAz",
            .enable_lni_at_device_index = "enableLniAtDeviceIndex",
            .map_public_ip_on_launch = "mapPublicIpOnLaunch",
            .map_customer_owned_ip_on_launch = "mapCustomerOwnedIpOnLaunch",
            .customer_owned_ipv4_pool = "customerOwnedIpv4Pool",
            .state = "state",
            .subnet_id = "subnetId",
            .vpc_id = "vpcId",
            .owner_id = "ownerId",
            .assign_ipv6_address_on_creation = "assignIpv6AddressOnCreation",
            .ipv6_cidr_block_association_set = "ipv6CidrBlockAssociationSet",
            .tags = "tagSet",
            .subnet_arn = "subnetArn",
            .outpost_arn = "outpostArn",
            .enable_dns64 = "enableDns64",
            .ipv6_native = "ipv6Native",
            .private_dns_name_options_on_launch = "privateDnsNameOptionsOnLaunch",
        };
        return @field(mappings, field_name);
    }
};

pub const PrivateDnsNameOptionsOnLaunch = struct {
    hostname_type: ?[]const u8 = null,
    enable_resource_name_dns_a_record: ?bool = null,
    enable_resource_name_dns_aaaa_record: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname_type = "hostnameType",
            .enable_resource_name_dns_a_record = "enableResourceNameDnsARecord",
            .enable_resource_name_dns_aaaa_record = "enableResourceNameDnsAAAARecord",
        };
        return @field(mappings, field_name);
    }
};

pub const StaleIpPermission = struct {
    from_port: ?i64 = null,
    ip_protocol: ?[]const u8 = null,
    ip_ranges: ?[][]const u8 = null,
    prefix_list_ids: ?[][]const u8 = null,
    to_port: ?i64 = null,
    user_id_group_pairs: ?[]UserIdGroupPair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "fromPort",
            .ip_protocol = "ipProtocol",
            .ip_ranges = "ipRanges",
            .prefix_list_ids = "prefixListIds",
            .to_port = "toPort",
            .user_id_group_pairs = "groups",
        };
        return @field(mappings, field_name);
    }
};

pub const EventInformation = struct {
    event_description: ?[]const u8 = null,
    event_sub_type: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_description = "eventDescription",
            .event_sub_type = "eventSubType",
            .instance_id = "instanceId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveInstance = struct {
    instance_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    spot_instance_request_id: ?[]const u8 = null,
    instance_health: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "instanceId",
            .instance_type = "instanceType",
            .spot_instance_request_id = "spotInstanceRequestId",
            .instance_health = "instanceHealth",
        };
        return @field(mappings, field_name);
    }
};

pub const SpotDatafeedSubscription = struct {
    bucket: ?[]const u8 = null,
    fault: ?SpotInstanceStateFault = null,
    owner_id: ?[]const u8 = null,
    prefix: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .fault = "fault",
            .owner_id = "ownerId",
            .prefix = "prefix",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    data_encryption_key_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    progress: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    start_time: ?i64 = null,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,
    volume_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    owner_alias: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    storage_tier: ?[]const u8 = null,
    restore_expiry_time: ?i64 = null,
    sse_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_encryption_key_id = "dataEncryptionKeyId",
            .description = "description",
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
            .owner_id = "ownerId",
            .progress = "progress",
            .snapshot_id = "snapshotId",
            .start_time = "startTime",
            .state = "status",
            .state_message = "statusMessage",
            .volume_id = "volumeId",
            .volume_size = "volumeSize",
            .owner_alias = "ownerAlias",
            .outpost_arn = "outpostArn",
            .tags = "tagSet",
            .storage_tier = "storageTier",
            .restore_expiry_time = "restoreExpiryTime",
            .sse_type = "sseType",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupRule = struct {
    security_group_rule_id: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    group_owner_id: ?[]const u8 = null,
    is_egress: ?bool = null,
    ip_protocol: ?[]const u8 = null,
    from_port: ?i64 = null,
    to_port: ?i64 = null,
    cidr_ipv4: ?[]const u8 = null,
    cidr_ipv6: ?[]const u8 = null,
    prefix_list_id: ?[]const u8 = null,
    referenced_group_info: ?ReferencedSecurityGroup = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_rule_id = "securityGroupRuleId",
            .group_id = "groupId",
            .group_owner_id = "groupOwnerId",
            .is_egress = "isEgress",
            .ip_protocol = "ipProtocol",
            .from_port = "fromPort",
            .to_port = "toPort",
            .cidr_ipv4 = "cidrIpv4",
            .cidr_ipv6 = "cidrIpv6",
            .prefix_list_id = "prefixListId",
            .referenced_group_info = "referencedGroupInfo",
            .description = "description",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferencedSecurityGroup = struct {
    group_id: ?[]const u8 = null,
    peering_status: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "groupId",
            .peering_status = "peeringStatus",
            .user_id = "userId",
            .vpc_id = "vpcId",
            .vpc_peering_connection_id = "vpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteTable = struct {
    associations: ?[]RouteTableAssociation = null,
    propagating_vgws: ?[]PropagatingVgw = null,
    route_table_id: ?[]const u8 = null,
    routes: ?[]Route = null,
    tags: ?[]Tag = null,
    vpc_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associations = "associationSet",
            .propagating_vgws = "propagatingVgwSet",
            .route_table_id = "routeTableId",
            .routes = "routeSet",
            .tags = "tagSet",
            .vpc_id = "vpcId",
            .owner_id = "ownerId",
        };
        return @field(mappings, field_name);
    }
};

pub const Route = struct {
    destination_cidr_block: ?[]const u8 = null,
    destination_ipv6_cidr_block: ?[]const u8 = null,
    destination_prefix_list_id: ?[]const u8 = null,
    egress_only_internet_gateway_id: ?[]const u8 = null,
    gateway_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    instance_owner_id: ?[]const u8 = null,
    nat_gateway_id: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,
    carrier_gateway_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    origin: ?[]const u8 = null,
    state: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr_block = "destinationCidrBlock",
            .destination_ipv6_cidr_block = "destinationIpv6CidrBlock",
            .destination_prefix_list_id = "destinationPrefixListId",
            .egress_only_internet_gateway_id = "egressOnlyInternetGatewayId",
            .gateway_id = "gatewayId",
            .instance_id = "instanceId",
            .instance_owner_id = "instanceOwnerId",
            .nat_gateway_id = "natGatewayId",
            .transit_gateway_id = "transitGatewayId",
            .local_gateway_id = "localGatewayId",
            .carrier_gateway_id = "carrierGatewayId",
            .network_interface_id = "networkInterfaceId",
            .origin = "origin",
            .state = "state",
            .vpc_peering_connection_id = "vpcPeeringConnectionId",
            .core_network_arn = "coreNetworkArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PropagatingVgw = struct {
    gateway_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_id = "gatewayId",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteTableAssociation = struct {
    main: ?bool = null,
    route_table_association_id: ?[]const u8 = null,
    route_table_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    gateway_id: ?[]const u8 = null,
    association_state: ?RouteTableAssociationState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .main = "main",
            .route_table_association_id = "routeTableAssociationId",
            .route_table_id = "routeTableId",
            .subnet_id = "subnetId",
            .gateway_id = "gatewayId",
            .association_state = "associationState",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    amount: ?f64 = null,
    frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "amount",
            .frequency = "frequency",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedInstancesListing = struct {
    client_token: ?[]const u8 = null,
    create_date: ?i64 = null,
    instance_counts: ?[]InstanceCount = null,
    price_schedules: ?[]PriceSchedule = null,
    reserved_instances_id: ?[]const u8 = null,
    reserved_instances_listing_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    tags: ?[]Tag = null,
    update_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_token = "clientToken",
            .create_date = "createDate",
            .instance_counts = "instanceCounts",
            .price_schedules = "priceSchedules",
            .reserved_instances_id = "reservedInstancesId",
            .reserved_instances_listing_id = "reservedInstancesListingId",
            .status = "status",
            .status_message = "statusMessage",
            .tags = "tagSet",
            .update_date = "updateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const PriceSchedule = struct {
    active: ?bool = null,
    currency_code: ?[]const u8 = null,
    price: ?f64 = null,
    term: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active = "active",
            .currency_code = "currencyCode",
            .price = "price",
            .term = "term",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceCount = struct {
    instance_count: ?i64 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_count = "instanceCount",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplaceRootVolumeTask = struct {
    replace_root_volume_task_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    task_state: ?[]const u8 = null,
    start_time: ?[]const u8 = null,
    complete_time: ?[]const u8 = null,
    tags: ?[]Tag = null,
    image_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    delete_replaced_root_volume: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replace_root_volume_task_id = "replaceRootVolumeTaskId",
            .instance_id = "instanceId",
            .task_state = "taskState",
            .start_time = "startTime",
            .complete_time = "completeTime",
            .tags = "tagSet",
            .image_id = "imageId",
            .snapshot_id = "snapshotId",
            .delete_replaced_root_volume = "deleteReplacedRootVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const IdFormat = struct {
    deadline: ?i64 = null,
    resource: ?[]const u8 = null,
    use_long_ids: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deadline = "deadline",
            .resource = "resource",
            .use_long_ids = "useLongIds",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementGroup = struct {
    group_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    strategy: ?[]const u8 = null,
    partition_count: ?i64 = null,
    group_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    group_arn: ?[]const u8 = null,
    spread_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "groupName",
            .state = "state",
            .strategy = "strategy",
            .partition_count = "partitionCount",
            .group_id = "groupId",
            .tags = "tagSet",
            .group_arn = "groupArn",
            .spread_level = "spreadLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    association: ?NetworkInterfaceAssociation = null,
    attachment: ?NetworkInterfaceAttachment = null,
    availability_zone: ?[]const u8 = null,
    connection_tracking_configuration: ?ConnectionTrackingConfiguration = null,
    description: ?[]const u8 = null,
    groups: ?[]GroupIdentifier = null,
    interface_type: ?[]const u8 = null,
    ipv6_addresses: ?[]NetworkInterfaceIpv6Address = null,
    mac_address: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    private_dns_name: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]NetworkInterfacePrivateIpAddress = null,
    ipv4_prefixes: ?[]Ipv4PrefixSpecification = null,
    ipv6_prefixes: ?[]Ipv6PrefixSpecification = null,
    requester_id: ?[]const u8 = null,
    requester_managed: ?bool = null,
    source_dest_check: ?bool = null,
    status: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    tag_set: ?[]Tag = null,
    vpc_id: ?[]const u8 = null,
    deny_all_igw_traffic: ?bool = null,
    ipv6_native: ?bool = null,
    ipv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association = "association",
            .attachment = "attachment",
            .availability_zone = "availabilityZone",
            .connection_tracking_configuration = "connectionTrackingConfiguration",
            .description = "description",
            .groups = "groupSet",
            .interface_type = "interfaceType",
            .ipv6_addresses = "ipv6AddressesSet",
            .mac_address = "macAddress",
            .network_interface_id = "networkInterfaceId",
            .outpost_arn = "outpostArn",
            .owner_id = "ownerId",
            .private_dns_name = "privateDnsName",
            .private_ip_address = "privateIpAddress",
            .private_ip_addresses = "privateIpAddressesSet",
            .ipv4_prefixes = "ipv4PrefixSet",
            .ipv6_prefixes = "ipv6PrefixSet",
            .requester_id = "requesterId",
            .requester_managed = "requesterManaged",
            .source_dest_check = "sourceDestCheck",
            .status = "status",
            .subnet_id = "subnetId",
            .tag_set = "tagSet",
            .vpc_id = "vpcId",
            .deny_all_igw_traffic = "denyAllIgwTraffic",
            .ipv6_native = "ipv6Native",
            .ipv6_address = "ipv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6PrefixSpecification = struct {
    ipv6_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_prefix = "ipv6Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv4PrefixSpecification = struct {
    ipv4_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv4_prefix = "ipv4Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfacePrivateIpAddress = struct {
    association: ?NetworkInterfaceAssociation = null,
    primary: ?bool = null,
    private_dns_name: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association = "association",
            .primary = "primary",
            .private_dns_name = "privateDnsName",
            .private_ip_address = "privateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfaceAssociation = struct {
    allocation_id: ?[]const u8 = null,
    association_id: ?[]const u8 = null,
    ip_owner_id: ?[]const u8 = null,
    public_dns_name: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,
    customer_owned_ip: ?[]const u8 = null,
    carrier_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocation_id = "allocationId",
            .association_id = "associationId",
            .ip_owner_id = "ipOwnerId",
            .public_dns_name = "publicDnsName",
            .public_ip = "publicIp",
            .customer_owned_ip = "customerOwnedIp",
            .carrier_ip = "carrierIp",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfaceIpv6Address = struct {
    ipv6_address: ?[]const u8 = null,
    is_primary_ipv6: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_address = "ipv6Address",
            .is_primary_ipv6 = "isPrimaryIpv6",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionTrackingConfiguration = struct {
    tcp_established_timeout: ?i64 = null,
    udp_stream_timeout: ?i64 = null,
    udp_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tcp_established_timeout = "tcpEstablishedTimeout",
            .udp_stream_timeout = "udpStreamTimeout",
            .udp_timeout = "udpTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfaceAttachment = struct {
    attach_time: ?i64 = null,
    attachment_id: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    device_index: ?i64 = null,
    network_card_index: ?i64 = null,
    instance_id: ?[]const u8 = null,
    instance_owner_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    ena_srd_specification: ?AttachmentEnaSrdSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "attachTime",
            .attachment_id = "attachmentId",
            .delete_on_termination = "deleteOnTermination",
            .device_index = "deviceIndex",
            .network_card_index = "networkCardIndex",
            .instance_id = "instanceId",
            .instance_owner_id = "instanceOwnerId",
            .status = "status",
            .ena_srd_specification = "enaSrdSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentEnaSrdSpecification = struct {
    ena_srd_enabled: ?bool = null,
    ena_srd_udp_specification: ?AttachmentEnaSrdUdpSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_enabled = "enaSrdEnabled",
            .ena_srd_udp_specification = "enaSrdUdpSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentEnaSrdUdpSpecification = struct {
    ena_srd_udp_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ena_srd_udp_enabled = "enaSrdUdpEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfacePermission = struct {
    network_interface_permission_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,
    aws_service: ?[]const u8 = null,
    permission: ?[]const u8 = null,
    permission_state: ?NetworkInterfacePermissionState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_permission_id = "networkInterfacePermissionId",
            .network_interface_id = "networkInterfaceId",
            .aws_account_id = "awsAccountId",
            .aws_service = "awsService",
            .permission = "permission",
            .permission_state = "permissionState",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterfacePermissionState = struct {
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .status_message = "statusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInsightsPath = struct {
    network_insights_path_id: ?[]const u8 = null,
    network_insights_path_arn: ?[]const u8 = null,
    created_date: ?i64 = null,
    source: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    destination_arn: ?[]const u8 = null,
    source_ip: ?[]const u8 = null,
    destination_ip: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    destination_port: ?i64 = null,
    tags: ?[]Tag = null,
    filter_at_source: ?PathFilter = null,
    filter_at_destination: ?PathFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_insights_path_id = "networkInsightsPathId",
            .network_insights_path_arn = "networkInsightsPathArn",
            .created_date = "createdDate",
            .source = "source",
            .destination = "destination",
            .source_arn = "sourceArn",
            .destination_arn = "destinationArn",
            .source_ip = "sourceIp",
            .destination_ip = "destinationIp",
            .protocol = "protocol",
            .destination_port = "destinationPort",
            .tags = "tagSet",
            .filter_at_source = "filterAtSource",
            .filter_at_destination = "filterAtDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const PathFilter = struct {
    source_address: ?[]const u8 = null,
    source_port_range: ?FilterPortRange = null,
    destination_address: ?[]const u8 = null,
    destination_port_range: ?FilterPortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_address = "sourceAddress",
            .source_port_range = "sourcePortRange",
            .destination_address = "destinationAddress",
            .destination_port_range = "destinationPortRange",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterPortRange = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "fromPort",
            .to_port = "toPort",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInsightsAccessScope = struct {
    network_insights_access_scope_id: ?[]const u8 = null,
    network_insights_access_scope_arn: ?[]const u8 = null,
    created_date: ?i64 = null,
    updated_date: ?i64 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_insights_access_scope_id = "networkInsightsAccessScopeId",
            .network_insights_access_scope_arn = "networkInsightsAccessScopeArn",
            .created_date = "createdDate",
            .updated_date = "updatedDate",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkAcl = struct {
    associations: ?[]NetworkAclAssociation = null,
    entries: ?[]NetworkAclEntry = null,
    is_default: ?bool = null,
    network_acl_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    vpc_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associations = "associationSet",
            .entries = "entrySet",
            .is_default = "default",
            .network_acl_id = "networkAclId",
            .tags = "tagSet",
            .vpc_id = "vpcId",
            .owner_id = "ownerId",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkAclEntry = struct {
    cidr_block: ?[]const u8 = null,
    egress: ?bool = null,
    icmp_type_code: ?IcmpTypeCode = null,
    ipv6_cidr_block: ?[]const u8 = null,
    port_range: ?PortRange = null,
    protocol: ?[]const u8 = null,
    rule_action: ?[]const u8 = null,
    rule_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "cidrBlock",
            .egress = "egress",
            .icmp_type_code = "icmpTypeCode",
            .ipv6_cidr_block = "ipv6CidrBlock",
            .port_range = "portRange",
            .protocol = "protocol",
            .rule_action = "ruleAction",
            .rule_number = "ruleNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkAclAssociation = struct {
    network_acl_association_id: ?[]const u8 = null,
    network_acl_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_acl_association_id = "networkAclAssociationId",
            .network_acl_id = "networkAclId",
            .subnet_id = "subnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const NatGateway = struct {
    create_time: ?i64 = null,
    delete_time: ?i64 = null,
    failure_code: ?[]const u8 = null,
    failure_message: ?[]const u8 = null,
    nat_gateway_addresses: ?[]NatGatewayAddress = null,
    nat_gateway_id: ?[]const u8 = null,
    provisioned_bandwidth: ?ProvisionedBandwidth = null,
    state: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    connectivity_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .create_time = "createTime",
            .delete_time = "deleteTime",
            .failure_code = "failureCode",
            .failure_message = "failureMessage",
            .nat_gateway_addresses = "natGatewayAddressSet",
            .nat_gateway_id = "natGatewayId",
            .provisioned_bandwidth = "provisionedBandwidth",
            .state = "state",
            .subnet_id = "subnetId",
            .vpc_id = "vpcId",
            .tags = "tagSet",
            .connectivity_type = "connectivityType",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedBandwidth = struct {
    provision_time: ?i64 = null,
    provisioned: ?[]const u8 = null,
    request_time: ?i64 = null,
    requested: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provision_time = "provisionTime",
            .provisioned = "provisioned",
            .request_time = "requestTime",
            .requested = "requested",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalGatewayRouteTableVpcAssociation = struct {
    local_gateway_route_table_vpc_association_id: ?[]const u8 = null,
    local_gateway_route_table_id: ?[]const u8 = null,
    local_gateway_route_table_arn: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_gateway_route_table_vpc_association_id = "localGatewayRouteTableVpcAssociationId",
            .local_gateway_route_table_id = "localGatewayRouteTableId",
            .local_gateway_route_table_arn = "localGatewayRouteTableArn",
            .local_gateway_id = "localGatewayId",
            .vpc_id = "vpcId",
            .owner_id = "ownerId",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalGatewayRouteTableVirtualInterfaceGroupAssociation = struct {
    local_gateway_route_table_virtual_interface_group_association_id: ?[]const u8 = null,
    local_gateway_virtual_interface_group_id: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,
    local_gateway_route_table_id: ?[]const u8 = null,
    local_gateway_route_table_arn: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_gateway_route_table_virtual_interface_group_association_id = "localGatewayRouteTableVirtualInterfaceGroupAssociationId",
            .local_gateway_virtual_interface_group_id = "localGatewayVirtualInterfaceGroupId",
            .local_gateway_id = "localGatewayId",
            .local_gateway_route_table_id = "localGatewayRouteTableId",
            .local_gateway_route_table_arn = "localGatewayRouteTableArn",
            .owner_id = "ownerId",
            .state = "state",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalGatewayRouteTable = struct {
    local_gateway_route_table_id: ?[]const u8 = null,
    local_gateway_route_table_arn: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,
    mode: ?[]const u8 = null,
    state_reason: ?StateReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_gateway_route_table_id = "localGatewayRouteTableId",
            .local_gateway_route_table_arn = "localGatewayRouteTableArn",
            .local_gateway_id = "localGatewayId",
            .outpost_arn = "outpostArn",
            .owner_id = "ownerId",
            .state = "state",
            .tags = "tagSet",
            .mode = "mode",
            .state_reason = "stateReason",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateVersion = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version_number: ?i64 = null,
    version_description: ?[]const u8 = null,
    create_time: ?i64 = null,
    created_by: ?[]const u8 = null,
    default_version: ?bool = null,
    launch_template_data: ?ResponseLaunchTemplateData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .version_number = "versionNumber",
            .version_description = "versionDescription",
            .create_time = "createTime",
            .created_by = "createdBy",
            .default_version = "defaultVersion",
            .launch_template_data = "launchTemplateData",
        };
        return @field(mappings, field_name);
    }
};

pub const InternetGateway = struct {
    attachments: ?[]InternetGatewayAttachment = null,
    internet_gateway_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachments = "attachmentSet",
            .internet_gateway_id = "internetGatewayId",
            .owner_id = "ownerId",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const InternetGatewayAttachment = struct {
    state: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .vpc_id = "vpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStatusSummary = struct {
    details: ?[]InstanceStatusDetails = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .details = "details",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStatusDetails = struct {
    impaired_since: ?i64 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .impaired_since = "impairedSince",
            .name = "name",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const Reservation = struct {
    groups: ?[]GroupIdentifier = null,
    instances: ?[]Instance = null,
    owner_id: ?[]const u8 = null,
    requester_id: ?[]const u8 = null,
    reservation_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .groups = "groupSet",
            .instances = "instancesSet",
            .owner_id = "ownerId",
            .requester_id = "requesterId",
            .reservation_id = "reservationId",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2InstanceConnectEndpoint = struct {
    owner_id: ?[]const u8 = null,
    instance_connect_endpoint_id: ?[]const u8 = null,
    instance_connect_endpoint_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_message: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    fips_dns_name: ?[]const u8 = null,
    network_interface_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    created_at: ?i64 = null,
    subnet_id: ?[]const u8 = null,
    preserve_client_ip: ?bool = null,
    security_group_ids: ?[][]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "ownerId",
            .instance_connect_endpoint_id = "instanceConnectEndpointId",
            .instance_connect_endpoint_arn = "instanceConnectEndpointArn",
            .state = "state",
            .state_message = "stateMessage",
            .dns_name = "dnsName",
            .fips_dns_name = "fipsDnsName",
            .network_interface_ids = "networkInterfaceIdSet",
            .vpc_id = "vpcId",
            .availability_zone = "availabilityZone",
            .created_at = "createdAt",
            .subnet_id = "subnetId",
            .preserve_client_ip = "preserveClientIp",
            .security_group_ids = "securityGroupIdSet",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateAndOverridesResponse = struct {
    launch_template_specification: ?FleetLaunchTemplateSpecification = null,
    overrides: ?FleetLaunchTemplateOverrides = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_specification = "launchTemplateSpecification",
            .overrides = "overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetLaunchTemplateOverrides = struct {
    instance_type: ?[]const u8 = null,
    max_price: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    weighted_capacity: ?f64 = null,
    priority: ?f64 = null,
    placement: ?PlacementResponse = null,
    instance_requirements: ?InstanceRequirements = null,
    image_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "instanceType",
            .max_price = "maxPrice",
            .subnet_id = "subnetId",
            .availability_zone = "availabilityZone",
            .weighted_capacity = "weightedCapacity",
            .priority = "priority",
            .placement = "placement",
            .instance_requirements = "instanceRequirements",
            .image_id = "imageId",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementResponse = struct {
    group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "groupName",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportTask = struct {
    description: ?[]const u8 = null,
    export_task_id: ?[]const u8 = null,
    export_to_s3_task: ?ExportToS3Task = null,
    instance_export_details: ?InstanceExportDetails = null,
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .export_task_id = "exportTaskId",
            .export_to_s3_task = "exportToS3",
            .instance_export_details = "instanceExport",
            .state = "state",
            .status_message = "statusMessage",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceExportDetails = struct {
    instance_id: ?[]const u8 = null,
    target_environment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "instanceId",
            .target_environment = "targetEnvironment",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportToS3Task = struct {
    container_format: ?[]const u8 = null,
    disk_image_format: ?[]const u8 = null,
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_format = "containerFormat",
            .disk_image_format = "diskImageFormat",
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const EgressOnlyInternetGateway = struct {
    attachments: ?[]InternetGatewayAttachment = null,
    egress_only_internet_gateway_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachments = "attachmentSet",
            .egress_only_internet_gateway_id = "egressOnlyInternetGatewayId",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const DhcpOptions = struct {
    dhcp_configurations: ?[]DhcpConfiguration = null,
    dhcp_options_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dhcp_configurations = "dhcpConfigurationSet",
            .dhcp_options_id = "dhcpOptionsId",
            .owner_id = "ownerId",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const DhcpConfiguration = struct {
    key: ?[]const u8 = null,
    values: ?[]AttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .values = "valueSet",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerGateway = struct {
    bgp_asn: ?[]const u8 = null,
    customer_gateway_id: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,
    device_name: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bgp_asn = "bgpAsn",
            .customer_gateway_id = "customerGatewayId",
            .ip_address = "ipAddress",
            .certificate_arn = "certificateArn",
            .state = "state",
            .type = "type",
            .device_name = "deviceName",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const CoipPool = struct {
    pool_id: ?[]const u8 = null,
    pool_cidrs: ?[][]const u8 = null,
    local_gateway_route_table_id: ?[]const u8 = null,
    tags: ?[]Tag = null,
    pool_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pool_id = "poolId",
            .pool_cidrs = "poolCidrSet",
            .local_gateway_route_table_id = "localGatewayRouteTableId",
            .tags = "tagSet",
            .pool_arn = "poolArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientVpnRouteStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientVpnEndpointStatus = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const CarrierGateway = struct {
    carrier_gateway_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .carrier_gateway_id = "carrierGatewayId",
            .vpc_id = "vpcId",
            .state = "state",
            .owner_id = "ownerId",
            .tags = "tagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const FleetCapacityReservation = struct {
    capacity_reservation_id: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    instance_platform: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    total_instance_count: ?i64 = null,
    fulfilled_capacity: ?f64 = null,
    ebs_optimized: ?bool = null,
    create_date: ?i64 = null,
    weight: ?f64 = null,
    priority: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_id = "capacityReservationId",
            .availability_zone_id = "availabilityZoneId",
            .instance_type = "instanceType",
            .instance_platform = "instancePlatform",
            .availability_zone = "availabilityZone",
            .total_instance_count = "totalInstanceCount",
            .fulfilled_capacity = "fulfilledCapacity",
            .ebs_optimized = "ebsOptimized",
            .create_date = "createDate",
            .weight = "weight",
            .priority = "priority",
        };
        return @field(mappings, field_name);
    }
};

pub const BundleTask = struct {
    bundle_id: ?[]const u8 = null,
    bundle_task_error: ?BundleTaskError = null,
    instance_id: ?[]const u8 = null,
    progress: ?[]const u8 = null,
    start_time: ?i64 = null,
    state: ?[]const u8 = null,
    storage: ?Storage = null,
    update_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bundle_id = "bundleId",
            .bundle_task_error = "error",
            .instance_id = "instanceId",
            .progress = "progress",
            .start_time = "startTime",
            .state = "state",
            .storage = "storage",
            .update_time = "updateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Storage = struct {
    s3: ?S3Storage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "S3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Storage = struct {
    aws_access_key_id: ?[]const u8 = null,
    bucket: ?[]const u8 = null,
    prefix: ?[]const u8 = null,
    upload_policy: ?[]const u8 = null,
    upload_policy_signature: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_access_key_id = "AWSAccessKeyId",
            .bucket = "bucket",
            .prefix = "prefix",
            .upload_policy = "uploadPolicy",
            .upload_policy_signature = "uploadPolicySignature",
        };
        return @field(mappings, field_name);
    }
};

pub const BundleTaskError = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const CoipCidr = struct {
    cidr: ?[]const u8 = null,
    coip_pool_id: ?[]const u8 = null,
    local_gateway_route_table_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
            .coip_pool_id = "coipPoolId",
            .local_gateway_route_table_id = "localGatewayRouteTableId",
        };
        return @field(mappings, field_name);
    }
};

pub const PathRequestFilter = struct {
    source_address: ?[]const u8 = null,
    source_port_range: ?RequestFilterPortRange = null,
    destination_address: ?[]const u8 = null,
    destination_port_range: ?RequestFilterPortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_address = "SourceAddress",
            .source_port_range = "SourcePortRange",
            .destination_address = "DestinationAddress",
            .destination_port_range = "DestinationPortRange",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestFilterPortRange = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessScopePathRequest = struct {
    source: ?PathStatementRequest = null,
    destination: ?PathStatementRequest = null,
    through_resources: ?[]ThroughResourcesStatementRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .destination = "Destination",
            .through_resources = "ThroughResource",
        };
        return @field(mappings, field_name);
    }
};

pub const ThroughResourcesStatementRequest = struct {
    resource_statement: ?ResourceStatementRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_statement = "ResourceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceStatementRequest = struct {
    resources: ?[][]const u8 = null,
    resource_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources = "Resource",
            .resource_types = "ResourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const PathStatementRequest = struct {
    packet_header_statement: ?PacketHeaderStatementRequest = null,
    resource_statement: ?ResourceStatementRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .packet_header_statement = "PacketHeaderStatement",
            .resource_statement = "ResourceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const PacketHeaderStatementRequest = struct {
    source_addresses: ?[][]const u8 = null,
    destination_addresses: ?[][]const u8 = null,
    source_ports: ?[][]const u8 = null,
    destination_ports: ?[][]const u8 = null,
    source_prefix_lists: ?[][]const u8 = null,
    destination_prefix_lists: ?[][]const u8 = null,
    protocols: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_addresses = "SourceAddress",
            .destination_addresses = "DestinationAddress",
            .source_ports = "SourcePort",
            .destination_ports = "DestinationPort",
            .source_prefix_lists = "SourcePrefixList",
            .destination_prefix_lists = "DestinationPrefixList",
            .protocols = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationWarning = struct {
    errors: ?[]ValidationError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .errors = "errorSet",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationError = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestLaunchTemplateData = struct {
    kernel_id: ?[]const u8 = null,
    ebs_optimized: ?bool = null,
    iam_instance_profile: ?LaunchTemplateIamInstanceProfileSpecificationRequest = null,
    block_device_mappings: ?[]LaunchTemplateBlockDeviceMappingRequest = null,
    network_interfaces: ?[]LaunchTemplateInstanceNetworkInterfaceSpecificationRequest = null,
    image_id: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    monitoring: ?LaunchTemplatesMonitoringRequest = null,
    placement: ?LaunchTemplatePlacementRequest = null,
    ram_disk_id: ?[]const u8 = null,
    disable_api_termination: ?bool = null,
    instance_initiated_shutdown_behavior: ?[]const u8 = null,
    user_data: ?[]const u8 = null,
    tag_specifications: ?[]LaunchTemplateTagSpecificationRequest = null,
    elastic_gpu_specifications: ?[]ElasticGpuSpecification = null,
    elastic_inference_accelerators: ?[]LaunchTemplateElasticInferenceAccelerator = null,
    security_group_ids: ?[][]const u8 = null,
    security_groups: ?[][]const u8 = null,
    instance_market_options: ?LaunchTemplateInstanceMarketOptionsRequest = null,
    credit_specification: ?CreditSpecificationRequest = null,
    cpu_options: ?LaunchTemplateCpuOptionsRequest = null,
    capacity_reservation_specification: ?LaunchTemplateCapacityReservationSpecificationRequest = null,
    license_specifications: ?[]LaunchTemplateLicenseConfigurationRequest = null,
    hibernation_options: ?LaunchTemplateHibernationOptionsRequest = null,
    metadata_options: ?LaunchTemplateInstanceMetadataOptionsRequest = null,
    enclave_options: ?LaunchTemplateEnclaveOptionsRequest = null,
    instance_requirements: ?InstanceRequirementsRequest = null,
    private_dns_name_options: ?LaunchTemplatePrivateDnsNameOptionsRequest = null,
    maintenance_options: ?LaunchTemplateInstanceMaintenanceOptionsRequest = null,
    disable_api_stop: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kernel_id = "KernelId",
            .ebs_optimized = "EbsOptimized",
            .iam_instance_profile = "IamInstanceProfile",
            .block_device_mappings = "BlockDeviceMapping",
            .network_interfaces = "NetworkInterface",
            .image_id = "ImageId",
            .instance_type = "InstanceType",
            .key_name = "KeyName",
            .monitoring = "Monitoring",
            .placement = "Placement",
            .ram_disk_id = "RamDiskId",
            .disable_api_termination = "DisableApiTermination",
            .instance_initiated_shutdown_behavior = "InstanceInitiatedShutdownBehavior",
            .user_data = "UserData",
            .tag_specifications = "TagSpecification",
            .elastic_gpu_specifications = "ElasticGpuSpecification",
            .elastic_inference_accelerators = "ElasticInferenceAccelerator",
            .security_group_ids = "SecurityGroupId",
            .security_groups = "SecurityGroup",
            .instance_market_options = "InstanceMarketOptions",
            .credit_specification = "CreditSpecification",
            .cpu_options = "CpuOptions",
            .capacity_reservation_specification = "CapacityReservationSpecification",
            .license_specifications = "LicenseSpecification",
            .hibernation_options = "HibernationOptions",
            .metadata_options = "MetadataOptions",
            .enclave_options = "EnclaveOptions",
            .instance_requirements = "InstanceRequirements",
            .private_dns_name_options = "PrivateDnsNameOptions",
            .maintenance_options = "MaintenanceOptions",
            .disable_api_stop = "DisableApiStop",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMaintenanceOptionsRequest = struct {
    auto_recovery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_recovery = "AutoRecovery",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatePrivateDnsNameOptionsRequest = struct {
    hostname_type: ?[]const u8 = null,
    enable_resource_name_dns_a_record: ?bool = null,
    enable_resource_name_dns_aaaa_record: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname_type = "HostnameType",
            .enable_resource_name_dns_a_record = "EnableResourceNameDnsARecord",
            .enable_resource_name_dns_aaaa_record = "EnableResourceNameDnsAAAARecord",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEnclaveOptionsRequest = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMetadataOptionsRequest = struct {
    http_tokens: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    http_endpoint: ?[]const u8 = null,
    http_protocol_ipv6: ?[]const u8 = null,
    instance_metadata_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_tokens = "HttpTokens",
            .http_put_response_hop_limit = "HttpPutResponseHopLimit",
            .http_endpoint = "HttpEndpoint",
            .http_protocol_ipv6 = "HttpProtocolIpv6",
            .instance_metadata_tags = "InstanceMetadataTags",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateHibernationOptionsRequest = struct {
    configured: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configured = "Configured",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateLicenseConfigurationRequest = struct {
    license_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "LicenseConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateCapacityReservationSpecificationRequest = struct {
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_target: ?CapacityReservationTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_preference = "CapacityReservationPreference",
            .capacity_reservation_target = "CapacityReservationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateCpuOptionsRequest = struct {
    core_count: ?i64 = null,
    threads_per_core: ?i64 = null,
    amd_sev_snp: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_count = "CoreCount",
            .threads_per_core = "ThreadsPerCore",
            .amd_sev_snp = "AmdSevSnp",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceMarketOptionsRequest = struct {
    market_type: ?[]const u8 = null,
    spot_options: ?LaunchTemplateSpotMarketOptionsRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .market_type = "MarketType",
            .spot_options = "SpotOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateSpotMarketOptionsRequest = struct {
    max_price: ?[]const u8 = null,
    spot_instance_type: ?[]const u8 = null,
    block_duration_minutes: ?i64 = null,
    valid_until: ?i64 = null,
    instance_interruption_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_price = "MaxPrice",
            .spot_instance_type = "SpotInstanceType",
            .block_duration_minutes = "BlockDurationMinutes",
            .valid_until = "ValidUntil",
            .instance_interruption_behavior = "InstanceInterruptionBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateElasticInferenceAccelerator = struct {
    type: []const u8,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .count = "Count",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateTagSpecificationRequest = struct {
    resource_type: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .tags = "Tag",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatePlacementRequest = struct {
    availability_zone: ?[]const u8 = null,
    affinity: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    host_id: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,
    spread_domain: ?[]const u8 = null,
    host_resource_group_arn: ?[]const u8 = null,
    partition_number: ?i64 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "AvailabilityZone",
            .affinity = "Affinity",
            .group_name = "GroupName",
            .host_id = "HostId",
            .tenancy = "Tenancy",
            .spread_domain = "SpreadDomain",
            .host_resource_group_arn = "HostResourceGroupArn",
            .partition_number = "PartitionNumber",
            .group_id = "GroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplatesMonitoringRequest = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateInstanceNetworkInterfaceSpecificationRequest = struct {
    associate_carrier_ip_address: ?bool = null,
    associate_public_ip_address: ?bool = null,
    delete_on_termination: ?bool = null,
    description: ?[]const u8 = null,
    device_index: ?i64 = null,
    groups: ?[][]const u8 = null,
    interface_type: ?[]const u8 = null,
    ipv6_address_count: ?i64 = null,
    ipv6_addresses: ?[]InstanceIpv6AddressRequest = null,
    network_interface_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]PrivateIpAddressSpecification = null,
    secondary_private_ip_address_count: ?i64 = null,
    subnet_id: ?[]const u8 = null,
    network_card_index: ?i64 = null,
    ipv4_prefixes: ?[]Ipv4PrefixSpecificationRequest = null,
    ipv4_prefix_count: ?i64 = null,
    ipv6_prefixes: ?[]Ipv6PrefixSpecificationRequest = null,
    ipv6_prefix_count: ?i64 = null,
    primary_ipv6: ?bool = null,
    ena_srd_specification: ?EnaSrdSpecificationRequest = null,
    connection_tracking_specification: ?ConnectionTrackingSpecificationRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_carrier_ip_address = "AssociateCarrierIpAddress",
            .associate_public_ip_address = "AssociatePublicIpAddress",
            .delete_on_termination = "DeleteOnTermination",
            .description = "Description",
            .device_index = "DeviceIndex",
            .groups = "SecurityGroupId",
            .interface_type = "InterfaceType",
            .ipv6_address_count = "Ipv6AddressCount",
            .ipv6_addresses = "Ipv6Addresses",
            .network_interface_id = "NetworkInterfaceId",
            .private_ip_address = "PrivateIpAddress",
            .private_ip_addresses = "PrivateIpAddresses",
            .secondary_private_ip_address_count = "SecondaryPrivateIpAddressCount",
            .subnet_id = "SubnetId",
            .network_card_index = "NetworkCardIndex",
            .ipv4_prefixes = "Ipv4Prefix",
            .ipv4_prefix_count = "Ipv4PrefixCount",
            .ipv6_prefixes = "Ipv6Prefix",
            .ipv6_prefix_count = "Ipv6PrefixCount",
            .primary_ipv6 = "PrimaryIpv6",
            .ena_srd_specification = "EnaSrdSpecification",
            .connection_tracking_specification = "ConnectionTrackingSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceIpv6AddressRequest = struct {
    ipv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_address = "Ipv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateBlockDeviceMappingRequest = struct {
    device_name: ?[]const u8 = null,
    virtual_name: ?[]const u8 = null,
    ebs: ?LaunchTemplateEbsBlockDeviceRequest = null,
    no_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .virtual_name = "VirtualName",
            .ebs = "Ebs",
            .no_device = "NoDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateEbsBlockDeviceRequest = struct {
    encrypted: ?bool = null,
    delete_on_termination: ?bool = null,
    iops: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "Encrypted",
            .delete_on_termination = "DeleteOnTermination",
            .iops = "Iops",
            .kms_key_id = "KmsKeyId",
            .snapshot_id = "SnapshotId",
            .volume_size = "VolumeSize",
            .volume_type = "VolumeType",
            .throughput = "Throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateIamInstanceProfileSpecificationRequest = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLocation = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};
