const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-03-31";
pub const sdk_id: []const u8 = "Glue";
pub const arn_namespace: ?[]const u8 = "glue";
pub const endpoint_prefix: []const u8 = "glue";
pub const sigv4_name: []const u8 = "glue";
pub const name: []const u8 = "AWSGlue";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-03-31",
    sdk_id: []const u8 = "Glue",
    arn_namespace: ?[]const u8 = "glue",
    endpoint_prefix: []const u8 = "glue",
    sigv4_name: []const u8 = "glue",
    name: []const u8 = "AWSGlue",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_create_partition: struct {
    action_name: []const u8 = "BatchCreatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_input_list: []PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_input_list = "PartitionInputList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_partition };
        }
    },
    Response: type = struct {
        errors: ?[]PartitionError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const batch_delete_connection: struct {
    action_name: []const u8 = "BatchDeleteConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_name_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_name_list = "ConnectionNameList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_connection };
        }
    },
    Response: type = struct {
        succeeded: ?[][]const u8 = null,
        errors: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ErrorDetail = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .succeeded = "Succeeded",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "errors", field_name))
                return try serializeMap(self.errors, self.fieldNameFor("errors"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const batch_delete_partition: struct {
    action_name: []const u8 = "BatchDeletePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partitions_to_delete: []PartitionValueList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partitions_to_delete = "PartitionsToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_partition };
        }
    },
    Response: type = struct {
        errors: ?[]PartitionError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_delete_table: struct {
    action_name: []const u8 = "BatchDeleteTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        tables_to_delete: [][]const u8,
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .tables_to_delete = "TablesToDelete",
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_table) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_table };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            table_name: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
    },
} = .{};
pub const batch_delete_table_version: struct {
    action_name: []const u8 = "BatchDeleteTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_ids = "VersionIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_table_version) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_table_version };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            table_name: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .version_id = "VersionId",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_blueprints: struct {
    action_name: []const u8 = "BatchGetBlueprints",
    Request: type = struct {
        names: [][]const u8,
        include_blueprint: ?bool = null,
        include_parameter_spec: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .include_blueprint = "IncludeBlueprint",
                .include_parameter_spec = "IncludeParameterSpec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_blueprints) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_blueprints };
        }
    },
    Response: type = struct {
        blueprints: ?[]Blueprint = null,
        missing_blueprints: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprints = "Blueprints",
                .missing_blueprints = "MissingBlueprints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_crawlers: struct {
    action_name: []const u8 = "BatchGetCrawlers",
    Request: type = struct {
        crawler_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_names = "CrawlerNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_crawlers };
        }
    },
    Response: type = struct {
        crawlers: ?[]Crawler = null,
        crawlers_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawlers = "Crawlers",
                .crawlers_not_found = "CrawlersNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_custom_entity_types: struct {
    action_name: []const u8 = "BatchGetCustomEntityTypes",
    Request: type = struct {
        names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_custom_entity_types) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_custom_entity_types };
        }
    },
    Response: type = struct {
        custom_entity_types: ?[]CustomEntityType = null,
        custom_entity_types_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_entity_types = "CustomEntityTypes",
                .custom_entity_types_not_found = "CustomEntityTypesNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_data_quality_result: struct {
    action_name: []const u8 = "BatchGetDataQualityResult",
    Request: type = struct {
        result_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result_ids = "ResultIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_data_quality_result) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_data_quality_result };
        }
    },
    Response: type = struct {
        results: []struct {
            result_id: ?[]const u8 = null,
            score: ?f64 = null,
            data_source: ?DataSource = null,
            ruleset_name: ?[]const u8 = null,
            evaluation_context: ?[]const u8 = null,
            started_on: ?i64 = null,
            completed_on: ?i64 = null,
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,
            ruleset_evaluation_run_id: ?[]const u8 = null,
            rule_results: ?[]DataQualityRuleResult = null,
            analyzer_results: ?[]DataQualityAnalyzerResult = null,
            observations: ?[]DataQualityObservation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .score = "Score",
                    .data_source = "DataSource",
                    .ruleset_name = "RulesetName",
                    .evaluation_context = "EvaluationContext",
                    .started_on = "StartedOn",
                    .completed_on = "CompletedOn",
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                    .ruleset_evaluation_run_id = "RulesetEvaluationRunId",
                    .rule_results = "RuleResults",
                    .analyzer_results = "AnalyzerResults",
                    .observations = "Observations",
                };
                return @field(mappings, field_name);
            }
        },
        results_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .results_not_found = "ResultsNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_dev_endpoints: struct {
    action_name: []const u8 = "BatchGetDevEndpoints",
    Request: type = struct {
        dev_endpoint_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint_names = "DevEndpointNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoints: ?[]DevEndpoint = null,
        dev_endpoints_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoints = "DevEndpoints",
                .dev_endpoints_not_found = "DevEndpointsNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_jobs: struct {
    action_name: []const u8 = "BatchGetJobs",
    Request: type = struct {
        job_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_jobs) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        jobs_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .jobs_not_found = "JobsNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_partition: struct {
    action_name: []const u8 = "BatchGetPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partitions_to_get: []PartitionValueList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partitions_to_get = "PartitionsToGet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_partition };
        }
    },
    Response: type = struct {
        partitions: ?[]Partition = null,
        unprocessed_keys: ?[]PartitionValueList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partitions = "Partitions",
                .unprocessed_keys = "UnprocessedKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        InvalidState,
        OperationTimeout,
    },
} = .{};
pub const batch_get_table_optimizer: struct {
    action_name: []const u8 = "BatchGetTableOptimizer",
    Request: type = struct {
        entries: []struct {
            catalog_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_id = "catalogId",
                    .database_name = "databaseName",
                    .table_name = "tableName",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_table_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_table_optimizer };
        }
    },
    Response: type = struct {
        table_optimizers: ?[]struct {
            catalog_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            table_optimizer: ?TableOptimizer = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_id = "catalogId",
                    .database_name = "databaseName",
                    .table_name = "tableName",
                    .table_optimizer = "tableOptimizer",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failures: ?[]struct {
            @"error": ?ErrorDetail = null,
            catalog_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .@"error" = "error",
                    .catalog_id = "catalogId",
                    .database_name = "databaseName",
                    .table_name = "tableName",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_optimizers = "TableOptimizers",
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
    },
} = .{};
pub const batch_get_triggers: struct {
    action_name: []const u8 = "BatchGetTriggers",
    Request: type = struct {
        trigger_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger_names = "TriggerNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_triggers) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_triggers };
        }
    },
    Response: type = struct {
        triggers: ?[]Trigger = null,
        triggers_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .triggers = "Triggers",
                .triggers_not_found = "TriggersNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_workflows: struct {
    action_name: []const u8 = "BatchGetWorkflows",
    Request: type = struct {
        names: [][]const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_workflows) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_workflows };
        }
    },
    Response: type = struct {
        workflows: ?[]Workflow = null,
        missing_workflows: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflows = "Workflows",
                .missing_workflows = "MissingWorkflows",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_stop_job_run: struct {
    action_name: []const u8 = "BatchStopJobRun",
    Request: type = struct {
        job_name: []const u8,
        job_run_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_run_ids = "JobRunIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_stop_job_run) } {
            return .{ .service_metadata = service_metadata, .action = batch_stop_job_run };
        }
    },
    Response: type = struct {
        successful_submissions: ?[]struct {
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_submissions = "SuccessfulSubmissions",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_update_partition: struct {
    action_name: []const u8 = "BatchUpdatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        entries: []struct {
            partition_value_list: [][]const u8,
            partition_input: PartitionInput,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition_value_list = "PartitionValueList",
                    .partition_input = "PartitionInput",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_partition };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            partition_value_list: ?[][]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition_value_list = "PartitionValueList",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_data_quality_rule_recommendation_run: struct {
    action_name: []const u8 = "CancelDataQualityRuleRecommendationRun",
    Request: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_data_quality_rule_recommendation_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_data_quality_rule_recommendation_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_data_quality_ruleset_evaluation_run: struct {
    action_name: []const u8 = "CancelDataQualityRulesetEvaluationRun",
    Request: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_data_quality_ruleset_evaluation_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_data_quality_ruleset_evaluation_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_ml_task_run: struct {
    action_name: []const u8 = "CancelMLTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        task_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ml_task_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ml_task_run };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        task_run_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_statement: struct {
    action_name: []const u8 = "CancelStatement",
    Request: type = struct {
        session_id: []const u8,
        id: i64,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .id = "Id",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_statement) } {
            return .{ .service_metadata = service_metadata, .action = cancel_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const check_schema_version_validity: struct {
    action_name: []const u8 = "CheckSchemaVersionValidity",
    Request: type = struct {
        data_format: []const u8,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_format = "DataFormat",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_schema_version_validity) } {
            return .{ .service_metadata = service_metadata, .action = check_schema_version_validity };
        }
    },
    Response: type = struct {
        valid: ?bool = null,
        @"error": ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .valid = "Valid",
                .@"error" = "Error",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const create_blueprint: struct {
    action_name: []const u8 = "CreateBlueprint",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        blueprint_location: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .blueprint_location = "BlueprintLocation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = create_blueprint };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_classifier: struct {
    action_name: []const u8 = "CreateClassifier",
    Request: type = struct {
        grok_classifier: ?struct {
            classification: []const u8,
            name: []const u8,
            grok_pattern: []const u8,
            custom_patterns: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classification = "Classification",
                    .name = "Name",
                    .grok_pattern = "GrokPattern",
                    .custom_patterns = "CustomPatterns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        xml_classifier: ?struct {
            classification: []const u8,
            name: []const u8,
            row_tag: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classification = "Classification",
                    .name = "Name",
                    .row_tag = "RowTag",
                };
                return @field(mappings, field_name);
            }
        } = null,
        json_classifier: ?struct {
            name: []const u8,
            json_path: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .json_path = "JsonPath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        csv_classifier: ?struct {
            name: []const u8,
            delimiter: ?[]const u8 = null,
            quote_symbol: ?[]const u8 = null,
            contains_header: ?[]const u8 = null,
            header: ?[][]const u8 = null,
            disable_value_trimming: ?bool = null,
            allow_single_column: ?bool = null,
            custom_datatype_configured: ?bool = null,
            custom_datatypes: ?[][]const u8 = null,
            serde: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .delimiter = "Delimiter",
                    .quote_symbol = "QuoteSymbol",
                    .contains_header = "ContainsHeader",
                    .header = "Header",
                    .disable_value_trimming = "DisableValueTrimming",
                    .allow_single_column = "AllowSingleColumn",
                    .custom_datatype_configured = "CustomDatatypeConfigured",
                    .custom_datatypes = "CustomDatatypes",
                    .serde = "Serde",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grok_classifier = "GrokClassifier",
                .xml_classifier = "XMLClassifier",
                .json_classifier = "JsonClassifier",
                .csv_classifier = "CsvClassifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_classifier) } {
            return .{ .service_metadata = service_metadata, .action = create_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_input: ConnectionInput,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_input = "ConnectionInput",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_crawler: struct {
    action_name: []const u8 = "CreateCrawler",
    Request: type = struct {
        name: []const u8,
        role: []const u8,
        database_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        targets: CrawlerTargets,
        schedule: ?[]const u8 = null,
        classifiers: ?[][]const u8 = null,
        table_prefix: ?[]const u8 = null,
        schema_change_policy: ?SchemaChangePolicy = null,
        recrawl_policy: ?RecrawlPolicy = null,
        lineage_configuration: ?LineageConfiguration = null,
        lake_formation_configuration: ?LakeFormationConfiguration = null,
        configuration: ?[]const u8 = null,
        crawler_security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .role = "Role",
                .database_name = "DatabaseName",
                .description = "Description",
                .targets = "Targets",
                .schedule = "Schedule",
                .classifiers = "Classifiers",
                .table_prefix = "TablePrefix",
                .schema_change_policy = "SchemaChangePolicy",
                .recrawl_policy = "RecrawlPolicy",
                .lineage_configuration = "LineageConfiguration",
                .lake_formation_configuration = "LakeFormationConfiguration",
                .configuration = "Configuration",
                .crawler_security_configuration = "CrawlerSecurityConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_crawler) } {
            return .{ .service_metadata = service_metadata, .action = create_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_custom_entity_type: struct {
    action_name: []const u8 = "CreateCustomEntityType",
    Request: type = struct {
        name: []const u8,
        regex_string: []const u8,
        context_words: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .regex_string = "RegexString",
                .context_words = "ContextWords",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_entity_type) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_entity_type };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_database: struct {
    action_name: []const u8 = "CreateDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_input: DatabaseInput,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_input = "DatabaseInput",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_database) } {
            return .{ .service_metadata = service_metadata, .action = create_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        FederatedResourceAlreadyExists,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_data_quality_ruleset: struct {
    action_name: []const u8 = "CreateDataQualityRuleset",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        ruleset: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        target_table: ?DataQualityTargetTable = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .ruleset = "Ruleset",
                .tags = "Tags",
                .target_table = "TargetTable",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_quality_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = create_data_quality_ruleset };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_dev_endpoint: struct {
    action_name: []const u8 = "CreateDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        role_arn: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        public_keys: ?[][]const u8 = null,
        number_of_nodes: ?i64 = null,
        worker_type: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        extra_python_libs_s3_path: ?[]const u8 = null,
        extra_jars_s3_path: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .role_arn = "RoleArn",
                .security_group_ids = "SecurityGroupIds",
                .subnet_id = "SubnetId",
                .public_key = "PublicKey",
                .public_keys = "PublicKeys",
                .number_of_nodes = "NumberOfNodes",
                .worker_type = "WorkerType",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                .extra_jars_s3_path = "ExtraJarsS3Path",
                .security_configuration = "SecurityConfiguration",
                .tags = "Tags",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_dev_endpoint };
        }
    },
    Response: type = struct {
        endpoint_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        yarn_endpoint_address: ?[]const u8 = null,
        zeppelin_remote_spark_interpreter_port: ?i64 = null,
        number_of_nodes: ?i64 = null,
        worker_type: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        availability_zone: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        extra_python_libs_s3_path: ?[]const u8 = null,
        extra_jars_s3_path: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .status = "Status",
                .security_group_ids = "SecurityGroupIds",
                .subnet_id = "SubnetId",
                .role_arn = "RoleArn",
                .yarn_endpoint_address = "YarnEndpointAddress",
                .zeppelin_remote_spark_interpreter_port = "ZeppelinRemoteSparkInterpreterPort",
                .number_of_nodes = "NumberOfNodes",
                .worker_type = "WorkerType",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .availability_zone = "AvailabilityZone",
                .vpc_id = "VpcId",
                .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                .extra_jars_s3_path = "ExtraJarsS3Path",
                .failure_reason = "FailureReason",
                .security_configuration = "SecurityConfiguration",
                .created_timestamp = "CreatedTimestamp",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
        Validation,
    },
} = .{};
pub const create_job: struct {
    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        log_uri: ?[]const u8 = null,
        role: []const u8,
        execution_property: ?ExecutionProperty = null,
        command: JobCommand,
        default_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        non_overridable_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        connections: ?ConnectionsList = null,
        max_retries: ?i64 = null,
        allocated_capacity: ?i64 = null,
        timeout: ?i64 = null,
        max_capacity: ?f64 = null,
        security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        notification_property: ?NotificationProperty = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        worker_type: ?[]const u8 = null,
        code_gen_configuration_nodes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CodeGenConfigurationNode = null,
        } = null,
        execution_class: ?[]const u8 = null,
        source_control_details: ?SourceControlDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .log_uri = "LogUri",
                .role = "Role",
                .execution_property = "ExecutionProperty",
                .command = "Command",
                .default_arguments = "DefaultArguments",
                .non_overridable_arguments = "NonOverridableArguments",
                .connections = "Connections",
                .max_retries = "MaxRetries",
                .allocated_capacity = "AllocatedCapacity",
                .timeout = "Timeout",
                .max_capacity = "MaxCapacity",
                .security_configuration = "SecurityConfiguration",
                .tags = "Tags",
                .notification_property = "NotificationProperty",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .worker_type = "WorkerType",
                .code_gen_configuration_nodes = "CodeGenConfigurationNodes",
                .execution_class = "ExecutionClass",
                .source_control_details = "SourceControlDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_arguments", field_name))
                return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
            if (std.mem.eql(u8, "non_overridable_arguments", field_name))
                return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "code_gen_configuration_nodes", field_name))
                return try serializeMap(self.code_gen_configuration_nodes, self.fieldNameFor("code_gen_configuration_nodes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_ml_transform: struct {
    action_name: []const u8 = "CreateMLTransform",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        input_record_tables: []GlueTable,
        parameters: TransformParameters,
        role: []const u8,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transform_encryption: ?TransformEncryption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .input_record_tables = "InputRecordTables",
                .parameters = "Parameters",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
                .tags = "Tags",
                .transform_encryption = "TransformEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = create_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_partition: struct {
    action_name: []const u8 = "CreatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_input: PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_input = "PartitionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partition) } {
            return .{ .service_metadata = service_metadata, .action = create_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_partition_index: struct {
    action_name: []const u8 = "CreatePartitionIndex",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_index: PartitionIndex,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_index = "PartitionIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partition_index) } {
            return .{ .service_metadata = service_metadata, .action = create_partition_index };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_registry: struct {
    action_name: []const u8 = "CreateRegistry",
    Request: type = struct {
        registry_name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registry) } {
            return .{ .service_metadata = service_metadata, .action = create_registry };
        }
    },
    Response: type = struct {
        registry_arn: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_arn = "RegistryArn",
                .registry_name = "RegistryName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        ConcurrentModification,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_schema: struct {
    action_name: []const u8 = "CreateSchema",
    Request: type = struct {
        registry_id: ?RegistryId = null,
        schema_name: []const u8,
        data_format: []const u8,
        compatibility: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        schema_definition: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .schema_name = "SchemaName",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .description = "Description",
                .tags = "Tags",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema) } {
            return .{ .service_metadata = service_metadata, .action = create_schema };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        compatibility: ?[]const u8 = null,
        schema_checkpoint: ?i64 = null,
        latest_schema_version: ?i64 = null,
        next_schema_version: ?i64 = null,
        schema_status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        schema_version_id: ?[]const u8 = null,
        schema_version_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .schema_name = "SchemaName",
                .schema_arn = "SchemaArn",
                .description = "Description",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .schema_checkpoint = "SchemaCheckpoint",
                .latest_schema_version = "LatestSchemaVersion",
                .next_schema_version = "NextSchemaVersion",
                .schema_status = "SchemaStatus",
                .tags = "Tags",
                .schema_version_id = "SchemaVersionId",
                .schema_version_status = "SchemaVersionStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_script: struct {
    action_name: []const u8 = "CreateScript",
    Request: type = struct {
        dag_nodes: ?[]CodeGenNode = null,
        dag_edges: ?[]CodeGenEdge = null,
        language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dag_nodes = "DagNodes",
                .dag_edges = "DagEdges",
                .language = "Language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_script) } {
            return .{ .service_metadata = service_metadata, .action = create_script };
        }
    },
    Response: type = struct {
        python_script: ?[]const u8 = null,
        scala_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
                .scala_code = "ScalaCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_security_configuration: struct {
    action_name: []const u8 = "CreateSecurityConfiguration",
    Request: type = struct {
        name: []const u8,
        encryption_configuration: EncryptionConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_security_configuration };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_session: struct {
    action_name: []const u8 = "CreateSession",
    Request: type = struct {
        id: []const u8,
        description: ?[]const u8 = null,
        role: []const u8,
        command: SessionCommand,
        timeout: ?i64 = null,
        idle_timeout: ?i64 = null,
        default_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        connections: ?ConnectionsList = null,
        max_capacity: ?f64 = null,
        number_of_workers: ?i64 = null,
        worker_type: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .description = "Description",
                .role = "Role",
                .command = "Command",
                .timeout = "Timeout",
                .idle_timeout = "IdleTimeout",
                .default_arguments = "DefaultArguments",
                .connections = "Connections",
                .max_capacity = "MaxCapacity",
                .number_of_workers = "NumberOfWorkers",
                .worker_type = "WorkerType",
                .security_configuration = "SecurityConfiguration",
                .glue_version = "GlueVersion",
                .tags = "Tags",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_arguments", field_name))
                return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_session) } {
            return .{ .service_metadata = service_metadata, .action = create_session };
        }
    },
    Response: type = struct {
        session: ?Session = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session = "Session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
        Validation,
    },
} = .{};
pub const create_table: struct {
    action_name: []const u8 = "CreateTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_input: TableInput,
        partition_indexes: ?[]PartitionIndex = null,
        transaction_id: ?[]const u8 = null,
        open_table_format_input: ?struct {
            iceberg_input: ?struct {
                metadata_operation: []const u8,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metadata_operation = "MetadataOperation",
                        .version = "Version",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iceberg_input = "IcebergInput",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_input = "TableInput",
                .partition_indexes = "PartitionIndexes",
                .transaction_id = "TransactionId",
                .open_table_format_input = "OpenTableFormatInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table) } {
            return .{ .service_metadata = service_metadata, .action = create_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_table_optimizer: struct {
    action_name: []const u8 = "CreateTableOptimizer",
    Request: type = struct {
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        type: []const u8,
        table_optimizer_configuration: TableOptimizerConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .type = "Type",
                .table_optimizer_configuration = "TableOptimizerConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = create_table_optimizer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const create_trigger: struct {
    action_name: []const u8 = "CreateTrigger",
    Request: type = struct {
        name: []const u8,
        workflow_name: ?[]const u8 = null,
        type: []const u8,
        schedule: ?[]const u8 = null,
        predicate: ?Predicate = null,
        actions: []Action,
        description: ?[]const u8 = null,
        start_on_creation: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        event_batching_condition: ?EventBatchingCondition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .workflow_name = "WorkflowName",
                .type = "Type",
                .schedule = "Schedule",
                .predicate = "Predicate",
                .actions = "Actions",
                .description = "Description",
                .start_on_creation = "StartOnCreation",
                .tags = "Tags",
                .event_batching_condition = "EventBatchingCondition",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trigger) } {
            return .{ .service_metadata = service_metadata, .action = create_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_user_defined_function: struct {
    action_name: []const u8 = "CreateUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_input: UserDefinedFunctionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_input = "FunctionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = create_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_workflow: struct {
    action_name: []const u8 = "CreateWorkflow",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        default_run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_concurrent_runs: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_run_properties = "DefaultRunProperties",
                .tags = "Tags",
                .max_concurrent_runs = "MaxConcurrentRuns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_run_properties", field_name))
                return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const delete_blueprint: struct {
    action_name: []const u8 = "DeleteBlueprint",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = delete_blueprint };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_classifier: struct {
    action_name: []const u8 = "DeleteClassifier",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_classifier) } {
            return .{ .service_metadata = service_metadata, .action = delete_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const delete_column_statistics_for_partition: struct {
    action_name: []const u8 = "DeleteColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_name = "ColumnName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = delete_column_statistics_for_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_column_statistics_for_table: struct {
    action_name: []const u8 = "DeleteColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_name = "ColumnName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_column_statistics_for_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_name = "ConnectionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const delete_crawler: struct {
    action_name: []const u8 = "DeleteCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_crawler) } {
            return .{ .service_metadata = service_metadata, .action = delete_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        OperationTimeout,
        SchedulerTransitioning,
    },
} = .{};
pub const delete_custom_entity_type: struct {
    action_name: []const u8 = "DeleteCustomEntityType",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_entity_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_entity_type };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_database: struct {
    action_name: []const u8 = "DeleteDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_database) } {
            return .{ .service_metadata = service_metadata, .action = delete_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_data_quality_ruleset: struct {
    action_name: []const u8 = "DeleteDataQualityRuleset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_quality_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_quality_ruleset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_dev_endpoint: struct {
    action_name: []const u8 = "DeleteDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_dev_endpoint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_job: struct {
    action_name: []const u8 = "DeleteJob",
    Request: type = struct {
        job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_ml_transform: struct {
    action_name: []const u8 = "DeleteMLTransform",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = delete_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_partition: struct {
    action_name: []const u8 = "DeletePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partition) } {
            return .{ .service_metadata = service_metadata, .action = delete_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_partition_index: struct {
    action_name: []const u8 = "DeletePartitionIndex",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        index_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .index_name = "IndexName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partition_index) } {
            return .{ .service_metadata = service_metadata, .action = delete_partition_index };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_registry: struct {
    action_name: []const u8 = "DeleteRegistry",
    Request: type = struct {
        registry_id: RegistryId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registry) } {
            return .{ .service_metadata = service_metadata, .action = delete_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        policy_hash_condition: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_hash_condition = "PolicyHashCondition",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConditionCheckFailure,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_schema: struct {
    action_name: []const u8 = "DeleteSchema",
    Request: type = struct {
        schema_id: SchemaId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_schema_versions: struct {
    action_name: []const u8 = "DeleteSchemaVersions",
    Request: type = struct {
        schema_id: SchemaId,
        versions: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema_versions) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema_versions };
        }
    },
    Response: type = struct {
        schema_version_errors: ?[]struct {
            version_number: ?i64 = null,
            error_details: ?struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_number = "VersionNumber",
                    .error_details = "ErrorDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_errors = "SchemaVersionErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_security_configuration: struct {
    action_name: []const u8 = "DeleteSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_session: struct {
    action_name: []const u8 = "DeleteSession",
    Request: type = struct {
        id: []const u8,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_session };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_table: struct {
    action_name: []const u8 = "DeleteTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        name: []const u8,
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .name = "Name",
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
    },
} = .{};
pub const delete_table_optimizer: struct {
    action_name: []const u8 = "DeleteTableOptimizer",
    Request: type = struct {
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = delete_table_optimizer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const delete_table_version: struct {
    action_name: []const u8 = "DeleteTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_table_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_trigger: struct {
    action_name: []const u8 = "DeleteTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trigger) } {
            return .{ .service_metadata = service_metadata, .action = delete_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_user_defined_function: struct {
    action_name: []const u8 = "DeleteUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_workflow: struct {
    action_name: []const u8 = "DeleteWorkflow",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_blueprint: struct {
    action_name: []const u8 = "GetBlueprint",
    Request: type = struct {
        name: []const u8,
        include_blueprint: ?bool = null,
        include_parameter_spec: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .include_blueprint = "IncludeBlueprint",
                .include_parameter_spec = "IncludeParameterSpec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = get_blueprint };
        }
    },
    Response: type = struct {
        blueprint: ?Blueprint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint = "Blueprint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_blueprint_run: struct {
    action_name: []const u8 = "GetBlueprintRun",
    Request: type = struct {
        blueprint_name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_name = "BlueprintName",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blueprint_run) } {
            return .{ .service_metadata = service_metadata, .action = get_blueprint_run };
        }
    },
    Response: type = struct {
        blueprint_run: ?BlueprintRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_run = "BlueprintRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const get_blueprint_runs: struct {
    action_name: []const u8 = "GetBlueprintRuns",
    Request: type = struct {
        blueprint_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_name = "BlueprintName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blueprint_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_blueprint_runs };
        }
    },
    Response: type = struct {
        blueprint_runs: ?[]BlueprintRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_runs = "BlueprintRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_catalog_import_status: struct {
    action_name: []const u8 = "GetCatalogImportStatus",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_catalog_import_status) } {
            return .{ .service_metadata = service_metadata, .action = get_catalog_import_status };
        }
    },
    Response: type = struct {
        import_status: ?struct {
            import_completed: ?bool = null,
            import_time: ?i64 = null,
            imported_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_completed = "ImportCompleted",
                    .import_time = "ImportTime",
                    .imported_by = "ImportedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_status = "ImportStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const get_classifier: struct {
    action_name: []const u8 = "GetClassifier",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classifier) } {
            return .{ .service_metadata = service_metadata, .action = get_classifier };
        }
    },
    Response: type = struct {
        classifier: ?Classifier = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classifier = "Classifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const get_classifiers: struct {
    action_name: []const u8 = "GetClassifiers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classifiers) } {
            return .{ .service_metadata = service_metadata, .action = get_classifiers };
        }
    },
    Response: type = struct {
        classifiers: ?[]Classifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classifiers = "Classifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_for_partition: struct {
    action_name: []const u8 = "GetColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_names = "ColumnNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_for_partition };
        }
    },
    Response: type = struct {
        column_statistics_list: ?[]ColumnStatistics = null,
        errors: ?[]ColumnError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_list = "ColumnStatisticsList",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_for_table: struct {
    action_name: []const u8 = "GetColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_names = "ColumnNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_for_table };
        }
    },
    Response: type = struct {
        column_statistics_list: ?[]ColumnStatistics = null,
        errors: ?[]ColumnError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_list = "ColumnStatisticsList",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_task_run: struct {
    action_name: []const u8 = "GetColumnStatisticsTaskRun",
    Request: type = struct {
        column_statistics_task_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_task_run_id = "ColumnStatisticsTaskRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_task_run) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_task_run };
        }
    },
    Response: type = struct {
        column_statistics_task_run: ?ColumnStatisticsTaskRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_task_run = "ColumnStatisticsTaskRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_task_runs: struct {
    action_name: []const u8 = "GetColumnStatisticsTaskRuns",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_task_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_task_runs };
        }
    },
    Response: type = struct {
        column_statistics_task_runs: ?[]ColumnStatisticsTaskRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_task_runs = "ColumnStatisticsTaskRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_connection: struct {
    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        hide_password: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .hide_password = "HidePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_connections: struct {
    action_name: []const u8 = "GetConnections",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        filter: ?struct {
            match_criteria: ?[][]const u8 = null,
            connection_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .match_criteria = "MatchCriteria",
                    .connection_type = "ConnectionType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        hide_password: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .filter = "Filter",
                .hide_password = "HidePassword",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connections) } {
            return .{ .service_metadata = service_metadata, .action = get_connections };
        }
    },
    Response: type = struct {
        connection_list: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_list = "ConnectionList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_crawler: struct {
    action_name: []const u8 = "GetCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawler) } {
            return .{ .service_metadata = service_metadata, .action = get_crawler };
        }
    },
    Response: type = struct {
        crawler: ?Crawler = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler = "Crawler",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const get_crawler_metrics: struct {
    action_name: []const u8 = "GetCrawlerMetrics",
    Request: type = struct {
        crawler_name_list: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name_list = "CrawlerNameList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawler_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_crawler_metrics };
        }
    },
    Response: type = struct {
        crawler_metrics_list: ?[]struct {
            crawler_name: ?[]const u8 = null,
            time_left_seconds: ?f64 = null,
            still_estimating: ?bool = null,
            last_runtime_seconds: ?f64 = null,
            median_runtime_seconds: ?f64 = null,
            tables_created: ?i64 = null,
            tables_updated: ?i64 = null,
            tables_deleted: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .crawler_name = "CrawlerName",
                    .time_left_seconds = "TimeLeftSeconds",
                    .still_estimating = "StillEstimating",
                    .last_runtime_seconds = "LastRuntimeSeconds",
                    .median_runtime_seconds = "MedianRuntimeSeconds",
                    .tables_created = "TablesCreated",
                    .tables_updated = "TablesUpdated",
                    .tables_deleted = "TablesDeleted",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_metrics_list = "CrawlerMetricsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_crawlers: struct {
    action_name: []const u8 = "GetCrawlers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = get_crawlers };
        }
    },
    Response: type = struct {
        crawlers: ?[]Crawler = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawlers = "Crawlers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_custom_entity_type: struct {
    action_name: []const u8 = "GetCustomEntityType",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_entity_type) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_entity_type };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        regex_string: ?[]const u8 = null,
        context_words: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .regex_string = "RegexString",
                .context_words = "ContextWords",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_database: struct {
    action_name: []const u8 = "GetDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_database) } {
            return .{ .service_metadata = service_metadata, .action = get_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_databases: struct {
    action_name: []const u8 = "GetDatabases",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_share_type = "ResourceShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_databases) } {
            return .{ .service_metadata = service_metadata, .action = get_databases };
        }
    },
    Response: type = struct {
        database_list: []Database,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_list = "DatabaseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_catalog_encryption_settings: struct {
    action_name: []const u8 = "GetDataCatalogEncryptionSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_catalog_encryption_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_data_catalog_encryption_settings };
        }
    },
    Response: type = struct {
        data_catalog_encryption_settings: ?DataCatalogEncryptionSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalog_encryption_settings = "DataCatalogEncryptionSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dataflow_graph: struct {
    action_name: []const u8 = "GetDataflowGraph",
    Request: type = struct {
        python_script: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dataflow_graph) } {
            return .{ .service_metadata = service_metadata, .action = get_dataflow_graph };
        }
    },
    Response: type = struct {
        dag_nodes: ?[]CodeGenNode = null,
        dag_edges: ?[]CodeGenEdge = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dag_nodes = "DagNodes",
                .dag_edges = "DagEdges",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_quality_result: struct {
    action_name: []const u8 = "GetDataQualityResult",
    Request: type = struct {
        result_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result_id = "ResultId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_quality_result) } {
            return .{ .service_metadata = service_metadata, .action = get_data_quality_result };
        }
    },
    Response: type = struct {
        result_id: ?[]const u8 = null,
        score: ?f64 = null,
        data_source: ?DataSource = null,
        ruleset_name: ?[]const u8 = null,
        evaluation_context: ?[]const u8 = null,
        started_on: ?i64 = null,
        completed_on: ?i64 = null,
        job_name: ?[]const u8 = null,
        job_run_id: ?[]const u8 = null,
        ruleset_evaluation_run_id: ?[]const u8 = null,
        rule_results: ?[]DataQualityRuleResult = null,
        analyzer_results: ?[]DataQualityAnalyzerResult = null,
        observations: ?[]DataQualityObservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result_id = "ResultId",
                .score = "Score",
                .data_source = "DataSource",
                .ruleset_name = "RulesetName",
                .evaluation_context = "EvaluationContext",
                .started_on = "StartedOn",
                .completed_on = "CompletedOn",
                .job_name = "JobName",
                .job_run_id = "JobRunId",
                .ruleset_evaluation_run_id = "RulesetEvaluationRunId",
                .rule_results = "RuleResults",
                .analyzer_results = "AnalyzerResults",
                .observations = "Observations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_quality_rule_recommendation_run: struct {
    action_name: []const u8 = "GetDataQualityRuleRecommendationRun",
    Request: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_quality_rule_recommendation_run) } {
            return .{ .service_metadata = service_metadata, .action = get_data_quality_rule_recommendation_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,
        data_source: ?DataSource = null,
        role: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        status: ?[]const u8 = null,
        error_string: ?[]const u8 = null,
        started_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        completed_on: ?i64 = null,
        execution_time: ?i64 = null,
        recommended_ruleset: ?[]const u8 = null,
        created_ruleset_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
                .data_source = "DataSource",
                .role = "Role",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .status = "Status",
                .error_string = "ErrorString",
                .started_on = "StartedOn",
                .last_modified_on = "LastModifiedOn",
                .completed_on = "CompletedOn",
                .execution_time = "ExecutionTime",
                .recommended_ruleset = "RecommendedRuleset",
                .created_ruleset_name = "CreatedRulesetName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_quality_ruleset: struct {
    action_name: []const u8 = "GetDataQualityRuleset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_quality_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = get_data_quality_ruleset };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        ruleset: ?[]const u8 = null,
        target_table: ?DataQualityTargetTable = null,
        created_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        recommendation_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .ruleset = "Ruleset",
                .target_table = "TargetTable",
                .created_on = "CreatedOn",
                .last_modified_on = "LastModifiedOn",
                .recommendation_run_id = "RecommendationRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_quality_ruleset_evaluation_run: struct {
    action_name: []const u8 = "GetDataQualityRulesetEvaluationRun",
    Request: type = struct {
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_quality_ruleset_evaluation_run) } {
            return .{ .service_metadata = service_metadata, .action = get_data_quality_ruleset_evaluation_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,
        data_source: ?DataSource = null,
        role: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        additional_run_options: ?DataQualityEvaluationRunAdditionalRunOptions = null,
        status: ?[]const u8 = null,
        error_string: ?[]const u8 = null,
        started_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        completed_on: ?i64 = null,
        execution_time: ?i64 = null,
        ruleset_names: ?[][]const u8 = null,
        result_ids: ?[][]const u8 = null,
        additional_data_sources: ?[]struct {
            key: ?[]const u8 = null,
            value: ?DataSource = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
                .data_source = "DataSource",
                .role = "Role",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .additional_run_options = "AdditionalRunOptions",
                .status = "Status",
                .error_string = "ErrorString",
                .started_on = "StartedOn",
                .last_modified_on = "LastModifiedOn",
                .completed_on = "CompletedOn",
                .execution_time = "ExecutionTime",
                .ruleset_names = "RulesetNames",
                .result_ids = "ResultIds",
                .additional_data_sources = "AdditionalDataSources",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_data_sources", field_name))
                return try serializeMap(self.additional_data_sources, self.fieldNameFor("additional_data_sources"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dev_endpoint: struct {
    action_name: []const u8 = "GetDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_dev_endpoint };
        }
    },
    Response: type = struct {
        dev_endpoint: ?DevEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint = "DevEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dev_endpoints: struct {
    action_name: []const u8 = "GetDevEndpoints",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = get_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoints: ?[]DevEndpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoints = "DevEndpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job: struct {
    action_name: []const u8 = "GetJob",
    Request: type = struct {
        job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job_bookmark: struct {
    action_name: []const u8 = "GetJobBookmark",
    Request: type = struct {
        job_name: []const u8,
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_bookmark) } {
            return .{ .service_metadata = service_metadata, .action = get_job_bookmark };
        }
    },
    Response: type = struct {
        job_bookmark_entry: ?JobBookmarkEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_bookmark_entry = "JobBookmarkEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const get_job_run: struct {
    action_name: []const u8 = "GetJobRun",
    Request: type = struct {
        job_name: []const u8,
        run_id: []const u8,
        predecessors_included: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
                .predecessors_included = "PredecessorsIncluded",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_run) } {
            return .{ .service_metadata = service_metadata, .action = get_job_run };
        }
    },
    Response: type = struct {
        job_run: ?JobRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_run = "JobRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job_runs: struct {
    action_name: []const u8 = "GetJobRuns",
    Request: type = struct {
        job_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_job_runs };
        }
    },
    Response: type = struct {
        job_runs: ?[]JobRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_runs = "JobRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_jobs: struct {
    action_name: []const u8 = "GetJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_mapping: struct {
    action_name: []const u8 = "GetMapping",
    Request: type = struct {
        source: CatalogEntry,
        sinks: ?[]CatalogEntry = null,
        location: ?Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .sinks = "Sinks",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_mapping };
        }
    },
    Response: type = struct {
        mapping: []MappingEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mapping = "Mapping",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_task_run: struct {
    action_name: []const u8 = "GetMLTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        task_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_task_run) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_task_run };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        task_run_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        log_group_name: ?[]const u8 = null,
        properties: ?TaskRunProperties = null,
        error_string: ?[]const u8 = null,
        started_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        completed_on: ?i64 = null,
        execution_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
                .status = "Status",
                .log_group_name = "LogGroupName",
                .properties = "Properties",
                .error_string = "ErrorString",
                .started_on = "StartedOn",
                .last_modified_on = "LastModifiedOn",
                .completed_on = "CompletedOn",
                .execution_time = "ExecutionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_task_runs: struct {
    action_name: []const u8 = "GetMLTaskRuns",
    Request: type = struct {
        transform_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            task_run_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            started_before: ?i64 = null,
            started_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_run_type = "TaskRunType",
                    .status = "Status",
                    .started_before = "StartedBefore",
                    .started_after = "StartedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort: ?struct {
            column: []const u8,
            sort_direction: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .column = "Column",
                    .sort_direction = "SortDirection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_task_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_task_runs };
        }
    },
    Response: type = struct {
        task_runs: ?[]struct {
            transform_id: ?[]const u8 = null,
            task_run_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            log_group_name: ?[]const u8 = null,
            properties: ?TaskRunProperties = null,
            error_string: ?[]const u8 = null,
            started_on: ?i64 = null,
            last_modified_on: ?i64 = null,
            completed_on: ?i64 = null,
            execution_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transform_id = "TransformId",
                    .task_run_id = "TaskRunId",
                    .status = "Status",
                    .log_group_name = "LogGroupName",
                    .properties = "Properties",
                    .error_string = "ErrorString",
                    .started_on = "StartedOn",
                    .last_modified_on = "LastModifiedOn",
                    .completed_on = "CompletedOn",
                    .execution_time = "ExecutionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_runs = "TaskRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_transform: struct {
    action_name: []const u8 = "GetMLTransform",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        input_record_tables: ?[]GlueTable = null,
        parameters: ?TransformParameters = null,
        evaluation_metrics: ?EvaluationMetrics = null,
        label_count: ?i64 = null,
        schema: ?[]SchemaColumn = null,
        role: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,
        transform_encryption: ?TransformEncryption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .created_on = "CreatedOn",
                .last_modified_on = "LastModifiedOn",
                .input_record_tables = "InputRecordTables",
                .parameters = "Parameters",
                .evaluation_metrics = "EvaluationMetrics",
                .label_count = "LabelCount",
                .schema = "Schema",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
                .transform_encryption = "TransformEncryption",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_transforms: struct {
    action_name: []const u8 = "GetMLTransforms",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?TransformFilterCriteria = null,
        sort: ?TransformSortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_transforms) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_transforms };
        }
    },
    Response: type = struct {
        transforms: []struct {
            transform_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_on: ?i64 = null,
            last_modified_on: ?i64 = null,
            input_record_tables: ?[]GlueTable = null,
            parameters: ?TransformParameters = null,
            evaluation_metrics: ?EvaluationMetrics = null,
            label_count: ?i64 = null,
            schema: ?[]SchemaColumn = null,
            role: ?[]const u8 = null,
            glue_version: ?[]const u8 = null,
            max_capacity: ?f64 = null,
            worker_type: ?[]const u8 = null,
            number_of_workers: ?i64 = null,
            timeout: ?i64 = null,
            max_retries: ?i64 = null,
            transform_encryption: ?TransformEncryption = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transform_id = "TransformId",
                    .name = "Name",
                    .description = "Description",
                    .status = "Status",
                    .created_on = "CreatedOn",
                    .last_modified_on = "LastModifiedOn",
                    .input_record_tables = "InputRecordTables",
                    .parameters = "Parameters",
                    .evaluation_metrics = "EvaluationMetrics",
                    .label_count = "LabelCount",
                    .schema = "Schema",
                    .role = "Role",
                    .glue_version = "GlueVersion",
                    .max_capacity = "MaxCapacity",
                    .worker_type = "WorkerType",
                    .number_of_workers = "NumberOfWorkers",
                    .timeout = "Timeout",
                    .max_retries = "MaxRetries",
                    .transform_encryption = "TransformEncryption",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transforms = "Transforms",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partition: struct {
    action_name: []const u8 = "GetPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partition) } {
            return .{ .service_metadata = service_metadata, .action = get_partition };
        }
    },
    Response: type = struct {
        partition: ?Partition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partition = "Partition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partition_indexes: struct {
    action_name: []const u8 = "GetPartitionIndexes",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partition_indexes) } {
            return .{ .service_metadata = service_metadata, .action = get_partition_indexes };
        }
    },
    Response: type = struct {
        partition_index_descriptor_list: ?[]struct {
            index_name: []const u8,
            keys: []struct {
                name: []const u8,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            },
            index_status: []const u8,
            backfill_errors: ?[]struct {
                code: ?[]const u8 = null,
                partitions: ?[]PartitionValueList = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "Code",
                        .partitions = "Partitions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .index_name = "IndexName",
                    .keys = "Keys",
                    .index_status = "IndexStatus",
                    .backfill_errors = "BackfillErrors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partition_index_descriptor_list = "PartitionIndexDescriptorList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partitions: struct {
    action_name: []const u8 = "GetPartitions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        segment: ?Segment = null,
        max_results: ?i64 = null,
        exclude_column_schema: ?bool = null,
        transaction_id: ?[]const u8 = null,
        query_as_of_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .expression = "Expression",
                .next_token = "NextToken",
                .segment = "Segment",
                .max_results = "MaxResults",
                .exclude_column_schema = "ExcludeColumnSchema",
                .transaction_id = "TransactionId",
                .query_as_of_time = "QueryAsOfTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partitions) } {
            return .{ .service_metadata = service_metadata, .action = get_partitions };
        }
    },
    Response: type = struct {
        partitions: ?[]Partition = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partitions = "Partitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        InvalidState,
        OperationTimeout,
        ResourceNotReady,
    },
} = .{};
pub const get_plan: struct {
    action_name: []const u8 = "GetPlan",
    Request: type = struct {
        mapping: []MappingEntry,
        source: CatalogEntry,
        sinks: ?[]CatalogEntry = null,
        location: ?Location = null,
        language: ?[]const u8 = null,
        additional_plan_options_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mapping = "Mapping",
                .source = "Source",
                .sinks = "Sinks",
                .location = "Location",
                .language = "Language",
                .additional_plan_options_map = "AdditionalPlanOptionsMap",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_plan_options_map", field_name))
                return try serializeMap(self.additional_plan_options_map, self.fieldNameFor("additional_plan_options_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_plan };
        }
    },
    Response: type = struct {
        python_script: ?[]const u8 = null,
        scala_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
                .scala_code = "ScalaCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_registry: struct {
    action_name: []const u8 = "GetRegistry",
    Request: type = struct {
        registry_id: RegistryId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_registry) } {
            return .{ .service_metadata = service_metadata, .action = get_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,
        updated_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .description = "Description",
                .status = "Status",
                .created_time = "CreatedTime",
                .updated_time = "UpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_resource_policies: struct {
    action_name: []const u8 = "GetResourcePolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policies };
        }
    },
    Response: type = struct {
        get_resource_policies_response_list: ?[]struct {
            policy_in_json: ?[]const u8 = null,
            policy_hash: ?[]const u8 = null,
            create_time: ?i64 = null,
            update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_in_json = "PolicyInJson",
                    .policy_hash = "PolicyHash",
                    .create_time = "CreateTime",
                    .update_time = "UpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .get_resource_policies_response_list = "GetResourcePoliciesResponseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy_in_json: ?[]const u8 = null,
        policy_hash: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_in_json = "PolicyInJson",
                .policy_hash = "PolicyHash",
                .create_time = "CreateTime",
                .update_time = "UpdateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_schema: struct {
    action_name: []const u8 = "GetSchema",
    Request: type = struct {
        schema_id: SchemaId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema) } {
            return .{ .service_metadata = service_metadata, .action = get_schema };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        compatibility: ?[]const u8 = null,
        schema_checkpoint: ?i64 = null,
        latest_schema_version: ?i64 = null,
        next_schema_version: ?i64 = null,
        schema_status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,
        updated_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .schema_name = "SchemaName",
                .schema_arn = "SchemaArn",
                .description = "Description",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .schema_checkpoint = "SchemaCheckpoint",
                .latest_schema_version = "LatestSchemaVersion",
                .next_schema_version = "NextSchemaVersion",
                .schema_status = "SchemaStatus",
                .created_time = "CreatedTime",
                .updated_time = "UpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_by_definition: struct {
    action_name: []const u8 = "GetSchemaByDefinition",
    Request: type = struct {
        schema_id: SchemaId,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_by_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_by_definition };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .schema_arn = "SchemaArn",
                .data_format = "DataFormat",
                .status = "Status",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_version: struct {
    action_name: []const u8 = "GetSchemaVersion",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_id: ?[]const u8 = null,
        schema_version_number: ?SchemaVersionNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_id = "SchemaVersionId",
                .schema_version_number = "SchemaVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_version };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        schema_definition: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        version_number: ?i64 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .schema_definition = "SchemaDefinition",
                .data_format = "DataFormat",
                .schema_arn = "SchemaArn",
                .version_number = "VersionNumber",
                .status = "Status",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_versions_diff: struct {
    action_name: []const u8 = "GetSchemaVersionsDiff",
    Request: type = struct {
        schema_id: SchemaId,
        first_schema_version_number: SchemaVersionNumber,
        second_schema_version_number: SchemaVersionNumber,
        schema_diff_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .first_schema_version_number = "FirstSchemaVersionNumber",
                .second_schema_version_number = "SecondSchemaVersionNumber",
                .schema_diff_type = "SchemaDiffType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_versions_diff) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_versions_diff };
        }
    },
    Response: type = struct {
        diff: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .diff = "Diff",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_security_configuration: struct {
    action_name: []const u8 = "GetSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_security_configuration };
        }
    },
    Response: type = struct {
        security_configuration: ?SecurityConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_configuration = "SecurityConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_security_configurations: struct {
    action_name: []const u8 = "GetSecurityConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_configurations) } {
            return .{ .service_metadata = service_metadata, .action = get_security_configurations };
        }
    },
    Response: type = struct {
        security_configurations: ?[]SecurityConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_configurations = "SecurityConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_session: struct {
    action_name: []const u8 = "GetSession",
    Request: type = struct {
        id: []const u8,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session) } {
            return .{ .service_metadata = service_metadata, .action = get_session };
        }
    },
    Response: type = struct {
        session: ?Session = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session = "Session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_statement: struct {
    action_name: []const u8 = "GetStatement",
    Request: type = struct {
        session_id: []const u8,
        id: i64,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .id = "Id",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_statement) } {
            return .{ .service_metadata = service_metadata, .action = get_statement };
        }
    },
    Response: type = struct {
        statement: ?Statement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement = "Statement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table: struct {
    action_name: []const u8 = "GetTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        name: []const u8,
        transaction_id: ?[]const u8 = null,
        query_as_of_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .name = "Name",
                .transaction_id = "TransactionId",
                .query_as_of_time = "QueryAsOfTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table) } {
            return .{ .service_metadata = service_metadata, .action = get_table };
        }
    },
    Response: type = struct {
        table: ?Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
    },
} = .{};
pub const get_table_optimizer: struct {
    action_name: []const u8 = "GetTableOptimizer",
    Request: type = struct {
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = get_table_optimizer };
        }
    },
    Response: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        table_name: ?[]const u8 = null,
        table_optimizer: ?TableOptimizer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .table_optimizer = "TableOptimizer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_tables: struct {
    action_name: []const u8 = "GetTables",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        transaction_id: ?[]const u8 = null,
        query_as_of_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .expression = "Expression",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .transaction_id = "TransactionId",
                .query_as_of_time = "QueryAsOfTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tables) } {
            return .{ .service_metadata = service_metadata, .action = get_tables };
        }
    },
    Response: type = struct {
        table_list: ?[]Table = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_list = "TableList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table_version: struct {
    action_name: []const u8 = "GetTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_version) } {
            return .{ .service_metadata = service_metadata, .action = get_table_version };
        }
    },
    Response: type = struct {
        table_version: ?TableVersion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_version = "TableVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table_versions: struct {
    action_name: []const u8 = "GetTableVersions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_table_versions };
        }
    },
    Response: type = struct {
        table_versions: ?[]TableVersion = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_versions = "TableVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_tags: struct {
    action_name: []const u8 = "GetTags",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_trigger: struct {
    action_name: []const u8 = "GetTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trigger) } {
            return .{ .service_metadata = service_metadata, .action = get_trigger };
        }
    },
    Response: type = struct {
        trigger: ?Trigger = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger = "Trigger",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_triggers: struct {
    action_name: []const u8 = "GetTriggers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        dependent_job_name: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dependent_job_name = "DependentJobName",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_triggers) } {
            return .{ .service_metadata = service_metadata, .action = get_triggers };
        }
    },
    Response: type = struct {
        triggers: ?[]Trigger = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .triggers = "Triggers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_unfiltered_partition_metadata: struct {
    action_name: []const u8 = "GetUnfilteredPartitionMetadata",
    Request: type = struct {
        region: ?[]const u8 = null,
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        audit_context: ?AuditContext = null,
        supported_permission_types: [][]const u8,
        query_session_context: ?QuerySessionContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .region = "Region",
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .audit_context = "AuditContext",
                .supported_permission_types = "SupportedPermissionTypes",
                .query_session_context = "QuerySessionContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_unfiltered_partition_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_unfiltered_partition_metadata };
        }
    },
    Response: type = struct {
        partition: ?Partition = null,
        authorized_columns: ?[][]const u8 = null,
        is_registered_with_lake_formation: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partition = "Partition",
                .authorized_columns = "AuthorizedColumns",
                .is_registered_with_lake_formation = "IsRegisteredWithLakeFormation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        PermissionTypeMismatch,
    },
} = .{};
pub const get_unfiltered_partitions_metadata: struct {
    action_name: []const u8 = "GetUnfilteredPartitionsMetadata",
    Request: type = struct {
        region: ?[]const u8 = null,
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        expression: ?[]const u8 = null,
        audit_context: ?AuditContext = null,
        supported_permission_types: [][]const u8,
        next_token: ?[]const u8 = null,
        segment: ?Segment = null,
        max_results: ?i64 = null,
        query_session_context: ?QuerySessionContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .region = "Region",
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .expression = "Expression",
                .audit_context = "AuditContext",
                .supported_permission_types = "SupportedPermissionTypes",
                .next_token = "NextToken",
                .segment = "Segment",
                .max_results = "MaxResults",
                .query_session_context = "QuerySessionContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_unfiltered_partitions_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_unfiltered_partitions_metadata };
        }
    },
    Response: type = struct {
        unfiltered_partitions: ?[]struct {
            partition: ?Partition = null,
            authorized_columns: ?[][]const u8 = null,
            is_registered_with_lake_formation: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition = "Partition",
                    .authorized_columns = "AuthorizedColumns",
                    .is_registered_with_lake_formation = "IsRegisteredWithLakeFormation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unfiltered_partitions = "UnfilteredPartitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        PermissionTypeMismatch,
    },
} = .{};
pub const get_unfiltered_table_metadata: struct {
    action_name: []const u8 = "GetUnfilteredTableMetadata",
    Request: type = struct {
        region: ?[]const u8 = null,
        catalog_id: []const u8,
        database_name: []const u8,
        name: []const u8,
        audit_context: ?AuditContext = null,
        supported_permission_types: [][]const u8,
        supported_dialect: ?struct {
            dialect: ?[]const u8 = null,
            dialect_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dialect = "Dialect",
                    .dialect_version = "DialectVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        permissions: ?[][]const u8 = null,
        query_session_context: ?QuerySessionContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .region = "Region",
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .name = "Name",
                .audit_context = "AuditContext",
                .supported_permission_types = "SupportedPermissionTypes",
                .supported_dialect = "SupportedDialect",
                .permissions = "Permissions",
                .query_session_context = "QuerySessionContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_unfiltered_table_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_unfiltered_table_metadata };
        }
    },
    Response: type = struct {
        table: ?Table = null,
        authorized_columns: ?[][]const u8 = null,
        is_registered_with_lake_formation: ?bool = null,
        cell_filters: ?[]struct {
            column_name: ?[]const u8 = null,
            row_filter_expression: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .column_name = "ColumnName",
                    .row_filter_expression = "RowFilterExpression",
                };
                return @field(mappings, field_name);
            }
        } = null,
        query_authorization_id: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        permissions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
                .authorized_columns = "AuthorizedColumns",
                .is_registered_with_lake_formation = "IsRegisteredWithLakeFormation",
                .cell_filters = "CellFilters",
                .query_authorization_id = "QueryAuthorizationId",
                .resource_arn = "ResourceArn",
                .permissions = "Permissions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        FederationSource,
        FederationSourceRetryable,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        PermissionTypeMismatch,
    },
} = .{};
pub const get_user_defined_function: struct {
    action_name: []const u8 = "GetUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = get_user_defined_function };
        }
    },
    Response: type = struct {
        user_defined_function: ?UserDefinedFunction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_defined_function = "UserDefinedFunction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_user_defined_functions: struct {
    action_name: []const u8 = "GetUserDefinedFunctions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        pattern: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .pattern = "Pattern",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_defined_functions) } {
            return .{ .service_metadata = service_metadata, .action = get_user_defined_functions };
        }
    },
    Response: type = struct {
        user_defined_functions: ?[]UserDefinedFunction = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_defined_functions = "UserDefinedFunctions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow: struct {
    action_name: []const u8 = "GetWorkflow",
    Request: type = struct {
        name: []const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow };
        }
    },
    Response: type = struct {
        workflow: ?Workflow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow = "Workflow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_run: struct {
    action_name: []const u8 = "GetWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_run };
        }
    },
    Response: type = struct {
        run: ?WorkflowRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run = "Run",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_run_properties: struct {
    action_name: []const u8 = "GetWorkflowRunProperties",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_run_properties) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_run_properties };
        }
    },
    Response: type = struct {
        run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_properties = "RunProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "run_properties", field_name))
                return try serializeMap(self.run_properties, self.fieldNameFor("run_properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_runs: struct {
    action_name: []const u8 = "GetWorkflowRuns",
    Request: type = struct {
        name: []const u8,
        include_graph: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .include_graph = "IncludeGraph",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_runs };
        }
    },
    Response: type = struct {
        runs: ?[]WorkflowRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runs = "Runs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const import_catalog_to_glue: struct {
    action_name: []const u8 = "ImportCatalogToGlue",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_catalog_to_glue) } {
            return .{ .service_metadata = service_metadata, .action = import_catalog_to_glue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const list_blueprints: struct {
    action_name: []const u8 = "ListBlueprints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_blueprints) } {
            return .{ .service_metadata = service_metadata, .action = list_blueprints };
        }
    },
    Response: type = struct {
        blueprints: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprints = "Blueprints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_column_statistics_task_runs: struct {
    action_name: []const u8 = "ListColumnStatisticsTaskRuns",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_column_statistics_task_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_column_statistics_task_runs };
        }
    },
    Response: type = struct {
        column_statistics_task_run_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_task_run_ids = "ColumnStatisticsTaskRunIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const list_crawlers: struct {
    action_name: []const u8 = "ListCrawlers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = list_crawlers };
        }
    },
    Response: type = struct {
        crawler_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_names = "CrawlerNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const list_crawls: struct {
    action_name: []const u8 = "ListCrawls",
    Request: type = struct {
        crawler_name: []const u8,
        max_results: ?i64 = null,
        filters: ?[]struct {
            field_name: ?[]const u8 = null,
            filter_operator: ?[]const u8 = null,
            field_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field_name = "FieldName",
                    .filter_operator = "FilterOperator",
                    .field_value = "FieldValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
                .max_results = "MaxResults",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_crawls) } {
            return .{ .service_metadata = service_metadata, .action = list_crawls };
        }
    },
    Response: type = struct {
        crawls: ?[]struct {
            crawl_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            summary: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            log_group: ?[]const u8 = null,
            log_stream: ?[]const u8 = null,
            message_prefix: ?[]const u8 = null,
            dpu_hour: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .crawl_id = "CrawlId",
                    .state = "State",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .summary = "Summary",
                    .error_message = "ErrorMessage",
                    .log_group = "LogGroup",
                    .log_stream = "LogStream",
                    .message_prefix = "MessagePrefix",
                    .dpu_hour = "DPUHour",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawls = "Crawls",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_custom_entity_types: struct {
    action_name: []const u8 = "ListCustomEntityTypes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_entity_types) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_entity_types };
        }
    },
    Response: type = struct {
        custom_entity_types: ?[]CustomEntityType = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_entity_types = "CustomEntityTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_data_quality_results: struct {
    action_name: []const u8 = "ListDataQualityResults",
    Request: type = struct {
        filter: ?struct {
            data_source: ?DataSource = null,
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,
            started_after: ?i64 = null,
            started_before: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source = "DataSource",
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                    .started_after = "StartedAfter",
                    .started_before = "StartedBefore",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_quality_results) } {
            return .{ .service_metadata = service_metadata, .action = list_data_quality_results };
        }
    },
    Response: type = struct {
        results: []struct {
            result_id: ?[]const u8 = null,
            data_source: ?DataSource = null,
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,
            started_on: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_id = "ResultId",
                    .data_source = "DataSource",
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                    .started_on = "StartedOn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_data_quality_rule_recommendation_runs: struct {
    action_name: []const u8 = "ListDataQualityRuleRecommendationRuns",
    Request: type = struct {
        filter: ?struct {
            data_source: DataSource,
            started_before: ?i64 = null,
            started_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source = "DataSource",
                    .started_before = "StartedBefore",
                    .started_after = "StartedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_quality_rule_recommendation_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_quality_rule_recommendation_runs };
        }
    },
    Response: type = struct {
        runs: ?[]struct {
            run_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            started_on: ?i64 = null,
            data_source: ?DataSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .run_id = "RunId",
                    .status = "Status",
                    .started_on = "StartedOn",
                    .data_source = "DataSource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runs = "Runs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_data_quality_ruleset_evaluation_runs: struct {
    action_name: []const u8 = "ListDataQualityRulesetEvaluationRuns",
    Request: type = struct {
        filter: ?struct {
            data_source: DataSource,
            started_before: ?i64 = null,
            started_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source = "DataSource",
                    .started_before = "StartedBefore",
                    .started_after = "StartedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_quality_ruleset_evaluation_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_quality_ruleset_evaluation_runs };
        }
    },
    Response: type = struct {
        runs: ?[]struct {
            run_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            started_on: ?i64 = null,
            data_source: ?DataSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .run_id = "RunId",
                    .status = "Status",
                    .started_on = "StartedOn",
                    .data_source = "DataSource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runs = "Runs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_data_quality_rulesets: struct {
    action_name: []const u8 = "ListDataQualityRulesets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_before: ?i64 = null,
            created_after: ?i64 = null,
            last_modified_before: ?i64 = null,
            last_modified_after: ?i64 = null,
            target_table: ?DataQualityTargetTable = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .created_before = "CreatedBefore",
                    .created_after = "CreatedAfter",
                    .last_modified_before = "LastModifiedBefore",
                    .last_modified_after = "LastModifiedAfter",
                    .target_table = "TargetTable",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_quality_rulesets) } {
            return .{ .service_metadata = service_metadata, .action = list_data_quality_rulesets };
        }
    },
    Response: type = struct {
        rulesets: ?[]struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_on: ?i64 = null,
            last_modified_on: ?i64 = null,
            target_table: ?DataQualityTargetTable = null,
            recommendation_run_id: ?[]const u8 = null,
            rule_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .created_on = "CreatedOn",
                    .last_modified_on = "LastModifiedOn",
                    .target_table = "TargetTable",
                    .recommendation_run_id = "RecommendationRunId",
                    .rule_count = "RuleCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rulesets = "Rulesets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_dev_endpoints: struct {
    action_name: []const u8 = "ListDevEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoint_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint_names = "DevEndpointNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_jobs: struct {
    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_ml_transforms: struct {
    action_name: []const u8 = "ListMLTransforms",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?TransformFilterCriteria = null,
        sort: ?TransformSortCriteria = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_transforms) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_transforms };
        }
    },
    Response: type = struct {
        transform_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_ids = "TransformIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_registries: struct {
    action_name: []const u8 = "ListRegistries",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_registries) } {
            return .{ .service_metadata = service_metadata, .action = list_registries };
        }
    },
    Response: type = struct {
        registries: ?[]struct {
            registry_name: ?[]const u8 = null,
            registry_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,
            updated_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_name = "RegistryName",
                    .registry_arn = "RegistryArn",
                    .description = "Description",
                    .status = "Status",
                    .created_time = "CreatedTime",
                    .updated_time = "UpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registries = "Registries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_schemas: struct {
    action_name: []const u8 = "ListSchemas",
    Request: type = struct {
        registry_id: ?RegistryId = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schemas) } {
            return .{ .service_metadata = service_metadata, .action = list_schemas };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            registry_name: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schema_status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,
            updated_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_name = "RegistryName",
                    .schema_name = "SchemaName",
                    .schema_arn = "SchemaArn",
                    .description = "Description",
                    .schema_status = "SchemaStatus",
                    .created_time = "CreatedTime",
                    .updated_time = "UpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_schema_versions: struct {
    action_name: []const u8 = "ListSchemaVersions",
    Request: type = struct {
        schema_id: SchemaId,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schema_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_schema_versions };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            schema_arn: ?[]const u8 = null,
            schema_version_id: ?[]const u8 = null,
            version_number: ?i64 = null,
            status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_arn = "SchemaArn",
                    .schema_version_id = "SchemaVersionId",
                    .version_number = "VersionNumber",
                    .status = "Status",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_sessions: struct {
    action_name: []const u8 = "ListSessions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_sessions };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,
        sessions: ?[]Session = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "Ids",
                .sessions = "Sessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_statements: struct {
    action_name: []const u8 = "ListStatements",
    Request: type = struct {
        session_id: []const u8,
        request_origin: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .request_origin = "RequestOrigin",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_statements) } {
            return .{ .service_metadata = service_metadata, .action = list_statements };
        }
    },
    Response: type = struct {
        statements: ?[]Statement = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statements = "Statements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_table_optimizer_runs: struct {
    action_name: []const u8 = "ListTableOptimizerRuns",
    Request: type = struct {
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .type = "Type",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_optimizer_runs) } {
            return .{ .service_metadata = service_metadata, .action = list_table_optimizer_runs };
        }
    },
    Response: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        table_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        table_optimizer_runs: ?[]TableOptimizerRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .next_token = "NextToken",
                .table_optimizer_runs = "TableOptimizerRuns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_triggers: struct {
    action_name: []const u8 = "ListTriggers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        dependent_job_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dependent_job_name = "DependentJobName",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_triggers) } {
            return .{ .service_metadata = service_metadata, .action = list_triggers };
        }
    },
    Response: type = struct {
        trigger_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger_names = "TriggerNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_workflows: struct {
    action_name: []const u8 = "ListWorkflows",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_workflows };
        }
    },
    Response: type = struct {
        workflows: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflows = "Workflows",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_data_catalog_encryption_settings: struct {
    action_name: []const u8 = "PutDataCatalogEncryptionSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        data_catalog_encryption_settings: DataCatalogEncryptionSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .data_catalog_encryption_settings = "DataCatalogEncryptionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_catalog_encryption_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_data_catalog_encryption_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        policy_in_json: []const u8,
        resource_arn: ?[]const u8 = null,
        policy_hash_condition: ?[]const u8 = null,
        policy_exists_condition: ?[]const u8 = null,
        enable_hybrid: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_in_json = "PolicyInJson",
                .resource_arn = "ResourceArn",
                .policy_hash_condition = "PolicyHashCondition",
                .policy_exists_condition = "PolicyExistsCondition",
                .enable_hybrid = "EnableHybrid",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        policy_hash: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_hash = "PolicyHash",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConditionCheckFailure,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_schema_version_metadata: struct {
    action_name: []const u8 = "PutSchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key_value: MetadataKeyValuePair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key_value = "MetadataKeyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = put_schema_version_metadata };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        latest_version: ?bool = null,
        version_number: ?i64 = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key: ?[]const u8 = null,
        metadata_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
                .latest_version = "LatestVersion",
                .version_number = "VersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key = "MetadataKey",
                .metadata_value = "MetadataValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const put_workflow_run_properties: struct {
    action_name: []const u8 = "PutWorkflowRunProperties",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        run_properties: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .run_properties = "RunProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "run_properties", field_name))
                return try serializeMap(self.run_properties, self.fieldNameFor("run_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_workflow_run_properties) } {
            return .{ .service_metadata = service_metadata, .action = put_workflow_run_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const query_schema_version_metadata: struct {
    action_name: []const u8 = "QuerySchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_list: ?[]MetadataKeyValuePair = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_list = "MetadataList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = query_schema_version_metadata };
        }
    },
    Response: type = struct {
        metadata_info_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                metadata_value: ?[]const u8 = null,
                created_time: ?[]const u8 = null,
                other_metadata_value_list: ?[]struct {
                    metadata_value: ?[]const u8 = null,
                    created_time: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .metadata_value = "MetadataValue",
                            .created_time = "CreatedTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metadata_value = "MetadataValue",
                        .created_time = "CreatedTime",
                        .other_metadata_value_list = "OtherMetadataValueList",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        schema_version_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_info_map = "MetadataInfoMap",
                .schema_version_id = "SchemaVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata_info_map", field_name))
                return try serializeMap(self.metadata_info_map, self.fieldNameFor("metadata_info_map"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const register_schema_version: struct {
    action_name: []const u8 = "RegisterSchemaVersion",
    Request: type = struct {
        schema_id: SchemaId,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = register_schema_version };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        version_number: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .version_number = "VersionNumber",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const remove_schema_version_metadata: struct {
    action_name: []const u8 = "RemoveSchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key_value: MetadataKeyValuePair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key_value = "MetadataKeyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = remove_schema_version_metadata };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        latest_version: ?bool = null,
        version_number: ?i64 = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key: ?[]const u8 = null,
        metadata_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
                .latest_version = "LatestVersion",
                .version_number = "VersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key = "MetadataKey",
                .metadata_value = "MetadataValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const reset_job_bookmark: struct {
    action_name: []const u8 = "ResetJobBookmark",
    Request: type = struct {
        job_name: []const u8,
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_job_bookmark) } {
            return .{ .service_metadata = service_metadata, .action = reset_job_bookmark };
        }
    },
    Response: type = struct {
        job_bookmark_entry: ?JobBookmarkEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_bookmark_entry = "JobBookmarkEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const resume_workflow_run: struct {
    action_name: []const u8 = "ResumeWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        node_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .node_ids = "NodeIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = resume_workflow_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,
        node_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
                .node_ids = "NodeIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        IllegalWorkflowState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const run_statement: struct {
    action_name: []const u8 = "RunStatement",
    Request: type = struct {
        session_id: []const u8,
        code: []const u8,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .code = "Code",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_statement) } {
            return .{ .service_metadata = service_metadata, .action = run_statement };
        }
    },
    Response: type = struct {
        id: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
        Validation,
    },
} = .{};
pub const search_tables: struct {
    action_name: []const u8 = "SearchTables",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
            comparator: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                    .comparator = "Comparator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_text: ?[]const u8 = null,
        sort_criteria: ?[]struct {
            field_name: ?[]const u8 = null,
            sort: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field_name = "FieldName",
                    .sort = "Sort",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        resource_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .next_token = "NextToken",
                .filters = "Filters",
                .search_text = "SearchText",
                .sort_criteria = "SortCriteria",
                .max_results = "MaxResults",
                .resource_share_type = "ResourceShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_tables) } {
            return .{ .service_metadata = service_metadata, .action = search_tables };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        table_list: ?[]Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .table_list = "TableList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_blueprint_run: struct {
    action_name: []const u8 = "StartBlueprintRun",
    Request: type = struct {
        blueprint_name: []const u8,
        parameters: ?[]const u8 = null,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_name = "BlueprintName",
                .parameters = "Parameters",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_blueprint_run) } {
            return .{ .service_metadata = service_metadata, .action = start_blueprint_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        IllegalBlueprintState,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_column_statistics_task_run: struct {
    action_name: []const u8 = "StartColumnStatisticsTaskRun",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,
        column_name_list: ?[][]const u8 = null,
        role: []const u8,
        sample_size: ?f64 = null,
        catalog_id: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_name_list = "ColumnNameList",
                .role = "Role",
                .sample_size = "SampleSize",
                .catalog_id = "CatalogID",
                .security_configuration = "SecurityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_column_statistics_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_column_statistics_task_run };
        }
    },
    Response: type = struct {
        column_statistics_task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_task_run_id = "ColumnStatisticsTaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ColumnStatisticsTaskRunning,
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_crawler: struct {
    action_name: []const u8 = "StartCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_crawler) } {
            return .{ .service_metadata = service_metadata, .action = start_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const start_crawler_schedule: struct {
    action_name: []const u8 = "StartCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = start_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        NoSchedule,
        OperationTimeout,
        SchedulerRunning,
        SchedulerTransitioning,
    },
} = .{};
pub const start_data_quality_rule_recommendation_run: struct {
    action_name: []const u8 = "StartDataQualityRuleRecommendationRun",
    Request: type = struct {
        data_source: DataSource,
        role: []const u8,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        created_ruleset_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "DataSource",
                .role = "Role",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .created_ruleset_name = "CreatedRulesetName",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_quality_rule_recommendation_run) } {
            return .{ .service_metadata = service_metadata, .action = start_data_quality_rule_recommendation_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_data_quality_ruleset_evaluation_run: struct {
    action_name: []const u8 = "StartDataQualityRulesetEvaluationRun",
    Request: type = struct {
        data_source: DataSource,
        role: []const u8,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        client_token: ?[]const u8 = null,
        additional_run_options: ?DataQualityEvaluationRunAdditionalRunOptions = null,
        ruleset_names: [][]const u8,
        additional_data_sources: ?[]struct {
            key: ?[]const u8 = null,
            value: ?DataSource = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "DataSource",
                .role = "Role",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .client_token = "ClientToken",
                .additional_run_options = "AdditionalRunOptions",
                .ruleset_names = "RulesetNames",
                .additional_data_sources = "AdditionalDataSources",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_data_sources", field_name))
                return try serializeMap(self.additional_data_sources, self.fieldNameFor("additional_data_sources"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_quality_ruleset_evaluation_run) } {
            return .{ .service_metadata = service_metadata, .action = start_data_quality_ruleset_evaluation_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_export_labels_task_run: struct {
    action_name: []const u8 = "StartExportLabelsTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        output_s3_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .output_s3_path = "OutputS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_export_labels_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_export_labels_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_import_labels_task_run: struct {
    action_name: []const u8 = "StartImportLabelsTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        input_s3_path: []const u8,
        replace_all_labels: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .input_s3_path = "InputS3Path",
                .replace_all_labels = "ReplaceAllLabels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import_labels_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_import_labels_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_job_run: struct {
    action_name: []const u8 = "StartJobRun",
    Request: type = struct {
        job_name: []const u8,
        job_run_id: ?[]const u8 = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        allocated_capacity: ?i64 = null,
        timeout: ?i64 = null,
        max_capacity: ?f64 = null,
        security_configuration: ?[]const u8 = null,
        notification_property: ?NotificationProperty = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        execution_class: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_run_id = "JobRunId",
                .arguments = "Arguments",
                .allocated_capacity = "AllocatedCapacity",
                .timeout = "Timeout",
                .max_capacity = "MaxCapacity",
                .security_configuration = "SecurityConfiguration",
                .notification_property = "NotificationProperty",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .execution_class = "ExecutionClass",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job_run) } {
            return .{ .service_metadata = service_metadata, .action = start_job_run };
        }
    },
    Response: type = struct {
        job_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_run_id = "JobRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_ml_evaluation_task_run: struct {
    action_name: []const u8 = "StartMLEvaluationTaskRun",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_evaluation_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_evaluation_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        MLTransformNotReady,
        OperationTimeout,
    },
} = .{};
pub const start_ml_labeling_set_generation_task_run: struct {
    action_name: []const u8 = "StartMLLabelingSetGenerationTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        output_s3_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .output_s3_path = "OutputS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_labeling_set_generation_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_labeling_set_generation_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_trigger: struct {
    action_name: []const u8 = "StartTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_trigger) } {
            return .{ .service_metadata = service_metadata, .action = start_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_workflow_run: struct {
    action_name: []const u8 = "StartWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_properties = "RunProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "run_properties", field_name))
                return try serializeMap(self.run_properties, self.fieldNameFor("run_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = start_workflow_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const stop_column_statistics_task_run: struct {
    action_name: []const u8 = "StopColumnStatisticsTaskRun",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_column_statistics_task_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_column_statistics_task_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ColumnStatisticsTaskNotRunning,
        ColumnStatisticsTaskStopping,
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const stop_crawler: struct {
    action_name: []const u8 = "StopCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_crawler) } {
            return .{ .service_metadata = service_metadata, .action = stop_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerNotRunning,
        CrawlerStopping,
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const stop_crawler_schedule: struct {
    action_name: []const u8 = "StopCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = stop_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
        SchedulerNotRunning,
        SchedulerTransitioning,
    },
} = .{};
pub const stop_session: struct {
    action_name: []const u8 = "StopSession",
    Request: type = struct {
        id: []const u8,
        request_origin: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .request_origin = "RequestOrigin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_session) } {
            return .{ .service_metadata = service_metadata, .action = stop_session };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        IllegalSessionState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const stop_trigger: struct {
    action_name: []const u8 = "StopTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_trigger) } {
            return .{ .service_metadata = service_metadata, .action = stop_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const stop_workflow_run: struct {
    action_name: []const u8 = "StopWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_workflow_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        IllegalWorkflowState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_to_add: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_to_add = "TagsToAdd",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags_to_add", field_name))
                return try serializeMap(self.tags_to_add, self.fieldNameFor("tags_to_add"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_to_remove: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_to_remove = "TagsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_blueprint: struct {
    action_name: []const u8 = "UpdateBlueprint",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        blueprint_location: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .blueprint_location = "BlueprintLocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = update_blueprint };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        IllegalBlueprintState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_classifier: struct {
    action_name: []const u8 = "UpdateClassifier",
    Request: type = struct {
        grok_classifier: ?struct {
            name: []const u8,
            classification: ?[]const u8 = null,
            grok_pattern: ?[]const u8 = null,
            custom_patterns: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .classification = "Classification",
                    .grok_pattern = "GrokPattern",
                    .custom_patterns = "CustomPatterns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        xml_classifier: ?struct {
            name: []const u8,
            classification: ?[]const u8 = null,
            row_tag: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .classification = "Classification",
                    .row_tag = "RowTag",
                };
                return @field(mappings, field_name);
            }
        } = null,
        json_classifier: ?struct {
            name: []const u8,
            json_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .json_path = "JsonPath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        csv_classifier: ?struct {
            name: []const u8,
            delimiter: ?[]const u8 = null,
            quote_symbol: ?[]const u8 = null,
            contains_header: ?[]const u8 = null,
            header: ?[][]const u8 = null,
            disable_value_trimming: ?bool = null,
            allow_single_column: ?bool = null,
            custom_datatype_configured: ?bool = null,
            custom_datatypes: ?[][]const u8 = null,
            serde: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .delimiter = "Delimiter",
                    .quote_symbol = "QuoteSymbol",
                    .contains_header = "ContainsHeader",
                    .header = "Header",
                    .disable_value_trimming = "DisableValueTrimming",
                    .allow_single_column = "AllowSingleColumn",
                    .custom_datatype_configured = "CustomDatatypeConfigured",
                    .custom_datatypes = "CustomDatatypes",
                    .serde = "Serde",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grok_classifier = "GrokClassifier",
                .xml_classifier = "XMLClassifier",
                .json_classifier = "JsonClassifier",
                .csv_classifier = "CsvClassifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_classifier) } {
            return .{ .service_metadata = service_metadata, .action = update_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        VersionMismatch,
    },
} = .{};
pub const update_column_statistics_for_partition: struct {
    action_name: []const u8 = "UpdateColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_statistics_list: []ColumnStatistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_statistics_list = "ColumnStatisticsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = update_column_statistics_for_partition };
        }
    },
    Response: type = struct {
        errors: ?[]ColumnStatisticsError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_column_statistics_for_table: struct {
    action_name: []const u8 = "UpdateColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_statistics_list: []ColumnStatistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_statistics_list = "ColumnStatisticsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = update_column_statistics_for_table };
        }
    },
    Response: type = struct {
        errors: ?[]ColumnStatisticsError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_connection: struct {
    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        connection_input: ConnectionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .connection_input = "ConnectionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_crawler: struct {
    action_name: []const u8 = "UpdateCrawler",
    Request: type = struct {
        name: []const u8,
        role: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        targets: ?CrawlerTargets = null,
        schedule: ?[]const u8 = null,
        classifiers: ?[][]const u8 = null,
        table_prefix: ?[]const u8 = null,
        schema_change_policy: ?SchemaChangePolicy = null,
        recrawl_policy: ?RecrawlPolicy = null,
        lineage_configuration: ?LineageConfiguration = null,
        lake_formation_configuration: ?LakeFormationConfiguration = null,
        configuration: ?[]const u8 = null,
        crawler_security_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .role = "Role",
                .database_name = "DatabaseName",
                .description = "Description",
                .targets = "Targets",
                .schedule = "Schedule",
                .classifiers = "Classifiers",
                .table_prefix = "TablePrefix",
                .schema_change_policy = "SchemaChangePolicy",
                .recrawl_policy = "RecrawlPolicy",
                .lineage_configuration = "LineageConfiguration",
                .lake_formation_configuration = "LakeFormationConfiguration",
                .configuration = "Configuration",
                .crawler_security_configuration = "CrawlerSecurityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_crawler) } {
            return .{ .service_metadata = service_metadata, .action = update_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        VersionMismatch,
    },
} = .{};
pub const update_crawler_schedule: struct {
    action_name: []const u8 = "UpdateCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,
        schedule: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
                .schedule = "Schedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        SchedulerTransitioning,
        VersionMismatch,
    },
} = .{};
pub const update_database: struct {
    action_name: []const u8 = "UpdateDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        database_input: DatabaseInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .database_input = "DatabaseInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_database) } {
            return .{ .service_metadata = service_metadata, .action = update_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_data_quality_ruleset: struct {
    action_name: []const u8 = "UpdateDataQualityRuleset",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        ruleset: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .ruleset = "Ruleset",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_quality_ruleset) } {
            return .{ .service_metadata = service_metadata, .action = update_data_quality_ruleset };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        ruleset: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .ruleset = "Ruleset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const update_dev_endpoint: struct {
    action_name: []const u8 = "UpdateDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        public_key: ?[]const u8 = null,
        add_public_keys: ?[][]const u8 = null,
        delete_public_keys: ?[][]const u8 = null,
        custom_libraries: ?struct {
            extra_python_libs_s3_path: ?[]const u8 = null,
            extra_jars_s3_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                    .extra_jars_s3_path = "ExtraJarsS3Path",
                };
                return @field(mappings, field_name);
            }
        } = null,
        update_etl_libraries: ?bool = null,
        delete_arguments: ?[][]const u8 = null,
        add_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .public_key = "PublicKey",
                .add_public_keys = "AddPublicKeys",
                .delete_public_keys = "DeletePublicKeys",
                .custom_libraries = "CustomLibraries",
                .update_etl_libraries = "UpdateEtlLibraries",
                .delete_arguments = "DeleteArguments",
                .add_arguments = "AddArguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "add_arguments", field_name))
                return try serializeMap(self.add_arguments, self.fieldNameFor("add_arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_dev_endpoint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const update_job: struct {
    action_name: []const u8 = "UpdateJob",
    Request: type = struct {
        job_name: []const u8,
        job_update: struct {
            description: ?[]const u8 = null,
            log_uri: ?[]const u8 = null,
            role: ?[]const u8 = null,
            execution_property: ?ExecutionProperty = null,
            command: ?JobCommand = null,
            default_arguments: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            non_overridable_arguments: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            connections: ?ConnectionsList = null,
            max_retries: ?i64 = null,
            allocated_capacity: ?i64 = null,
            timeout: ?i64 = null,
            max_capacity: ?f64 = null,
            worker_type: ?[]const u8 = null,
            number_of_workers: ?i64 = null,
            security_configuration: ?[]const u8 = null,
            notification_property: ?NotificationProperty = null,
            glue_version: ?[]const u8 = null,
            code_gen_configuration_nodes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?CodeGenConfigurationNode = null,
            } = null,
            execution_class: ?[]const u8 = null,
            source_control_details: ?SourceControlDetails = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .log_uri = "LogUri",
                    .role = "Role",
                    .execution_property = "ExecutionProperty",
                    .command = "Command",
                    .default_arguments = "DefaultArguments",
                    .non_overridable_arguments = "NonOverridableArguments",
                    .connections = "Connections",
                    .max_retries = "MaxRetries",
                    .allocated_capacity = "AllocatedCapacity",
                    .timeout = "Timeout",
                    .max_capacity = "MaxCapacity",
                    .worker_type = "WorkerType",
                    .number_of_workers = "NumberOfWorkers",
                    .security_configuration = "SecurityConfiguration",
                    .notification_property = "NotificationProperty",
                    .glue_version = "GlueVersion",
                    .code_gen_configuration_nodes = "CodeGenConfigurationNodes",
                    .execution_class = "ExecutionClass",
                    .source_control_details = "SourceControlDetails",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "default_arguments", field_name))
                    return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
                if (std.mem.eql(u8, "non_overridable_arguments", field_name))
                    return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
                if (std.mem.eql(u8, "code_gen_configuration_nodes", field_name))
                    return try serializeMap(self.code_gen_configuration_nodes, self.fieldNameFor("code_gen_configuration_nodes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_update = "JobUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job) } {
            return .{ .service_metadata = service_metadata, .action = update_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_job_from_source_control: struct {
    action_name: []const u8 = "UpdateJobFromSourceControl",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        provider: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        repository_owner: ?[]const u8 = null,
        branch_name: ?[]const u8 = null,
        folder: ?[]const u8 = null,
        commit_id: ?[]const u8 = null,
        auth_strategy: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .provider = "Provider",
                .repository_name = "RepositoryName",
                .repository_owner = "RepositoryOwner",
                .branch_name = "BranchName",
                .folder = "Folder",
                .commit_id = "CommitId",
                .auth_strategy = "AuthStrategy",
                .auth_token = "AuthToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_from_source_control) } {
            return .{ .service_metadata = service_metadata, .action = update_job_from_source_control };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const update_ml_transform: struct {
    action_name: []const u8 = "UpdateMLTransform",
    Request: type = struct {
        transform_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parameters: ?TransformParameters = null,
        role: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .name = "Name",
                .description = "Description",
                .parameters = "Parameters",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = update_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_partition: struct {
    action_name: []const u8 = "UpdatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_value_list: [][]const u8,
        partition_input: PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_value_list = "PartitionValueList",
                .partition_input = "PartitionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_partition) } {
            return .{ .service_metadata = service_metadata, .action = update_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_registry: struct {
    action_name: []const u8 = "UpdateRegistry",
    Request: type = struct {
        registry_id: RegistryId,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_registry) } {
            return .{ .service_metadata = service_metadata, .action = update_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const update_schema: struct {
    action_name: []const u8 = "UpdateSchema",
    Request: type = struct {
        schema_id: SchemaId,
        schema_version_number: ?SchemaVersionNumber = null,
        compatibility: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .compatibility = "Compatibility",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schema) } {
            return .{ .service_metadata = service_metadata, .action = update_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const update_source_control_from_job: struct {
    action_name: []const u8 = "UpdateSourceControlFromJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        provider: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        repository_owner: ?[]const u8 = null,
        branch_name: ?[]const u8 = null,
        folder: ?[]const u8 = null,
        commit_id: ?[]const u8 = null,
        auth_strategy: ?[]const u8 = null,
        auth_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .provider = "Provider",
                .repository_name = "RepositoryName",
                .repository_owner = "RepositoryOwner",
                .branch_name = "BranchName",
                .folder = "Folder",
                .commit_id = "CommitId",
                .auth_strategy = "AuthStrategy",
                .auth_token = "AuthToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_source_control_from_job) } {
            return .{ .service_metadata = service_metadata, .action = update_source_control_from_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const update_table: struct {
    action_name: []const u8 = "UpdateTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_input: TableInput,
        skip_archive: ?bool = null,
        transaction_id: ?[]const u8 = null,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_input = "TableInput",
                .skip_archive = "SkipArchive",
                .transaction_id = "TransactionId",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table) } {
            return .{ .service_metadata = service_metadata, .action = update_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const update_table_optimizer: struct {
    action_name: []const u8 = "UpdateTableOptimizer",
    Request: type = struct {
        catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        type: []const u8,
        table_optimizer_configuration: TableOptimizerConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .type = "Type",
                .table_optimizer_configuration = "TableOptimizerConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = update_table_optimizer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const update_trigger: struct {
    action_name: []const u8 = "UpdateTrigger",
    Request: type = struct {
        name: []const u8,
        trigger_update: struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schedule: ?[]const u8 = null,
            actions: ?[]Action = null,
            predicate: ?Predicate = null,
            event_batching_condition: ?EventBatchingCondition = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .schedule = "Schedule",
                    .actions = "Actions",
                    .predicate = "Predicate",
                    .event_batching_condition = "EventBatchingCondition",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .trigger_update = "TriggerUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trigger) } {
            return .{ .service_metadata = service_metadata, .action = update_trigger };
        }
    },
    Response: type = struct {
        trigger: ?Trigger = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger = "Trigger",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_user_defined_function: struct {
    action_name: []const u8 = "UpdateUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,
        function_input: UserDefinedFunctionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
                .function_input = "FunctionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = update_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_workflow: struct {
    action_name: []const u8 = "UpdateWorkflow",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        default_run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_concurrent_runs: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_run_properties = "DefaultRunProperties",
                .max_concurrent_runs = "MaxConcurrentRuns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_run_properties", field_name))
                return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workflow) } {
            return .{ .service_metadata = service_metadata, .action = update_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};

pub const UserDefinedFunctionInput = struct {
    function_name: ?[]const u8 = null,
    class_name: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    owner_type: ?[]const u8 = null,
    resource_uris: ?[]ResourceUri = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_name = "FunctionName",
            .class_name = "ClassName",
            .owner_name = "OwnerName",
            .owner_type = "OwnerType",
            .resource_uris = "ResourceUris",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceUri = struct {
    resource_type: ?[]const u8 = null,
    uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .uri = "Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const Trigger = struct {
    name: ?[]const u8 = null,
    workflow_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    description: ?[]const u8 = null,
    schedule: ?[]const u8 = null,
    actions: ?[]Action = null,
    predicate: ?Predicate = null,
    event_batching_condition: ?EventBatchingCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .workflow_name = "WorkflowName",
            .id = "Id",
            .type = "Type",
            .state = "State",
            .description = "Description",
            .schedule = "Schedule",
            .actions = "Actions",
            .predicate = "Predicate",
            .event_batching_condition = "EventBatchingCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const EventBatchingCondition = struct {
    batch_size: i64,
    batch_window: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .batch_size = "BatchSize",
            .batch_window = "BatchWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const Predicate = struct {
    logical: ?[]const u8 = null,
    conditions: ?[]Condition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logical = "Logical",
            .conditions = "Conditions",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    logical_operator: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    crawler_name: ?[]const u8 = null,
    crawl_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logical_operator = "LogicalOperator",
            .job_name = "JobName",
            .state = "State",
            .crawler_name = "CrawlerName",
            .crawl_state = "CrawlState",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    job_name: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    timeout: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    crawler_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .arguments = "Arguments",
            .timeout = "Timeout",
            .security_configuration = "SecurityConfiguration",
            .notification_property = "NotificationProperty",
            .crawler_name = "CrawlerName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const NotificationProperty = struct {
    notify_delay_after: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notify_delay_after = "NotifyDelayAfter",
        };
        return @field(mappings, field_name);
    }
};

pub const TableOptimizerConfiguration = struct {
    role_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TableInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    last_access_time: ?i64 = null,
    last_analyzed_time: ?i64 = null,
    retention: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    partition_keys: ?[]Column = null,
    view_original_text: ?[]const u8 = null,
    view_expanded_text: ?[]const u8 = null,
    table_type: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    target_table: ?TableIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .owner = "Owner",
            .last_access_time = "LastAccessTime",
            .last_analyzed_time = "LastAnalyzedTime",
            .retention = "Retention",
            .storage_descriptor = "StorageDescriptor",
            .partition_keys = "PartitionKeys",
            .view_original_text = "ViewOriginalText",
            .view_expanded_text = "ViewExpandedText",
            .table_type = "TableType",
            .parameters = "Parameters",
            .target_table = "TargetTable",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const TableIdentifier = struct {
    catalog_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const Column = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    comment: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .comment = "Comment",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const StorageDescriptor = struct {
    columns: ?[]Column = null,
    location: ?[]const u8 = null,
    additional_locations: ?[][]const u8 = null,
    input_format: ?[]const u8 = null,
    output_format: ?[]const u8 = null,
    compressed: ?bool = null,
    number_of_buckets: ?i64 = null,
    serde_info: ?SerDeInfo = null,
    bucket_columns: ?[][]const u8 = null,
    sort_columns: ?[]Order = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    skewed_info: ?SkewedInfo = null,
    stored_as_sub_directories: ?bool = null,
    schema_reference: ?SchemaReference = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "Columns",
            .location = "Location",
            .additional_locations = "AdditionalLocations",
            .input_format = "InputFormat",
            .output_format = "OutputFormat",
            .compressed = "Compressed",
            .number_of_buckets = "NumberOfBuckets",
            .serde_info = "SerdeInfo",
            .bucket_columns = "BucketColumns",
            .sort_columns = "SortColumns",
            .parameters = "Parameters",
            .skewed_info = "SkewedInfo",
            .stored_as_sub_directories = "StoredAsSubDirectories",
            .schema_reference = "SchemaReference",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const SchemaReference = struct {
    schema_id: ?SchemaId = null,
    schema_version_id: ?[]const u8 = null,
    schema_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_id = "SchemaId",
            .schema_version_id = "SchemaVersionId",
            .schema_version_number = "SchemaVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaId = struct {
    schema_arn: ?[]const u8 = null,
    schema_name: ?[]const u8 = null,
    registry_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_arn = "SchemaArn",
            .schema_name = "SchemaName",
            .registry_name = "RegistryName",
        };
        return @field(mappings, field_name);
    }
};

pub const SkewedInfo = struct {
    skewed_column_names: ?[][]const u8 = null,
    skewed_column_values: ?[][]const u8 = null,
    skewed_column_value_location_maps: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .skewed_column_names = "SkewedColumnNames",
            .skewed_column_values = "SkewedColumnValues",
            .skewed_column_value_location_maps = "SkewedColumnValueLocationMaps",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "skewed_column_value_location_maps", field_name))
            return try serializeMap(self.skewed_column_value_location_maps, self.fieldNameFor("skewed_column_value_location_maps"), options, out_stream);
        return false;
    }
};

pub const Order = struct {
    column: []const u8,
    sort_order: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const SerDeInfo = struct {
    name: ?[]const u8 = null,
    serialization_library: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .serialization_library = "SerializationLibrary",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const SchemaVersionNumber = struct {
    latest_version: ?bool = null,
    version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latest_version = "LatestVersion",
            .version_number = "VersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistryId = struct {
    registry_name: ?[]const u8 = null,
    registry_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registry_name = "RegistryName",
            .registry_arn = "RegistryArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionInput = struct {
    values: ?[][]const u8 = null,
    last_access_time: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_analyzed_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .last_access_time = "LastAccessTime",
            .storage_descriptor = "StorageDescriptor",
            .parameters = "Parameters",
            .last_analyzed_time = "LastAnalyzedTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const TransformParameters = struct {
    transform_type: []const u8,
    find_matches_parameters: ?FindMatchesParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transform_type = "TransformType",
            .find_matches_parameters = "FindMatchesParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesParameters = struct {
    primary_key_column_name: ?[]const u8 = null,
    precision_recall_tradeoff: ?f64 = null,
    accuracy_cost_tradeoff: ?f64 = null,
    enforce_provided_labels: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_key_column_name = "PrimaryKeyColumnName",
            .precision_recall_tradeoff = "PrecisionRecallTradeoff",
            .accuracy_cost_tradeoff = "AccuracyCostTradeoff",
            .enforce_provided_labels = "EnforceProvidedLabels",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceControlDetails = struct {
    provider: ?[]const u8 = null,
    repository: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    branch: ?[]const u8 = null,
    folder: ?[]const u8 = null,
    last_commit_id: ?[]const u8 = null,
    auth_strategy: ?[]const u8 = null,
    auth_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider = "Provider",
            .repository = "Repository",
            .owner = "Owner",
            .branch = "Branch",
            .folder = "Folder",
            .last_commit_id = "LastCommitId",
            .auth_strategy = "AuthStrategy",
            .auth_token = "AuthToken",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeGenConfigurationNode = struct {
    athena_connector_source: ?AthenaConnectorSource = null,
    jdbc_connector_source: ?JDBCConnectorSource = null,
    spark_connector_source: ?SparkConnectorSource = null,
    catalog_source: ?CatalogSource = null,
    redshift_source: ?RedshiftSource = null,
    s3_catalog_source: ?S3CatalogSource = null,
    s3_csv_source: ?S3CsvSource = null,
    s3_json_source: ?S3JsonSource = null,
    s3_parquet_source: ?S3ParquetSource = null,
    relational_catalog_source: ?RelationalCatalogSource = null,
    dynamo_db_catalog_source: ?DynamoDBCatalogSource = null,
    jdbc_connector_target: ?JDBCConnectorTarget = null,
    spark_connector_target: ?SparkConnectorTarget = null,
    catalog_target: ?BasicCatalogTarget = null,
    redshift_target: ?RedshiftTarget = null,
    s3_catalog_target: ?S3CatalogTarget = null,
    s3_glue_parquet_target: ?S3GlueParquetTarget = null,
    s3_direct_target: ?S3DirectTarget = null,
    apply_mapping: ?ApplyMapping = null,
    select_fields: ?SelectFields = null,
    drop_fields: ?DropFields = null,
    rename_field: ?RenameField = null,
    spigot: ?Spigot = null,
    join: ?Join = null,
    split_fields: ?SplitFields = null,
    select_from_collection: ?SelectFromCollection = null,
    fill_missing_values: ?FillMissingValues = null,
    filter: ?Filter = null,
    custom_code: ?CustomCode = null,
    spark_sql: ?SparkSQL = null,
    direct_kinesis_source: ?DirectKinesisSource = null,
    direct_kafka_source: ?DirectKafkaSource = null,
    catalog_kinesis_source: ?CatalogKinesisSource = null,
    catalog_kafka_source: ?CatalogKafkaSource = null,
    drop_null_fields: ?DropNullFields = null,
    merge: ?Merge = null,
    @"union": ?Union = null,
    pii_detection: ?PIIDetection = null,
    aggregate: ?Aggregate = null,
    drop_duplicates: ?DropDuplicates = null,
    governed_catalog_target: ?GovernedCatalogTarget = null,
    governed_catalog_source: ?GovernedCatalogSource = null,
    microsoft_sql_server_catalog_source: ?MicrosoftSQLServerCatalogSource = null,
    my_sql_catalog_source: ?MySQLCatalogSource = null,
    oracle_sql_catalog_source: ?OracleSQLCatalogSource = null,
    postgre_sql_catalog_source: ?PostgreSQLCatalogSource = null,
    microsoft_sql_server_catalog_target: ?MicrosoftSQLServerCatalogTarget = null,
    my_sql_catalog_target: ?MySQLCatalogTarget = null,
    oracle_sql_catalog_target: ?OracleSQLCatalogTarget = null,
    postgre_sql_catalog_target: ?PostgreSQLCatalogTarget = null,
    dynamic_transform: ?DynamicTransform = null,
    evaluate_data_quality: ?EvaluateDataQuality = null,
    s3_catalog_hudi_source: ?S3CatalogHudiSource = null,
    catalog_hudi_source: ?CatalogHudiSource = null,
    s3_hudi_source: ?S3HudiSource = null,
    s3_hudi_catalog_target: ?S3HudiCatalogTarget = null,
    s3_hudi_direct_target: ?S3HudiDirectTarget = null,
    direct_jdbc_source: ?DirectJDBCSource = null,
    s3_catalog_delta_source: ?S3CatalogDeltaSource = null,
    catalog_delta_source: ?CatalogDeltaSource = null,
    s3_delta_source: ?S3DeltaSource = null,
    s3_delta_catalog_target: ?S3DeltaCatalogTarget = null,
    s3_delta_direct_target: ?S3DeltaDirectTarget = null,
    amazon_redshift_source: ?AmazonRedshiftSource = null,
    amazon_redshift_target: ?AmazonRedshiftTarget = null,
    evaluate_data_quality_multi_frame: ?EvaluateDataQualityMultiFrame = null,
    recipe: ?Recipe = null,
    snowflake_source: ?SnowflakeSource = null,
    snowflake_target: ?SnowflakeTarget = null,
    connector_data_source: ?ConnectorDataSource = null,
    connector_data_target: ?ConnectorDataTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .athena_connector_source = "AthenaConnectorSource",
            .jdbc_connector_source = "JDBCConnectorSource",
            .spark_connector_source = "SparkConnectorSource",
            .catalog_source = "CatalogSource",
            .redshift_source = "RedshiftSource",
            .s3_catalog_source = "S3CatalogSource",
            .s3_csv_source = "S3CsvSource",
            .s3_json_source = "S3JsonSource",
            .s3_parquet_source = "S3ParquetSource",
            .relational_catalog_source = "RelationalCatalogSource",
            .dynamo_db_catalog_source = "DynamoDBCatalogSource",
            .jdbc_connector_target = "JDBCConnectorTarget",
            .spark_connector_target = "SparkConnectorTarget",
            .catalog_target = "CatalogTarget",
            .redshift_target = "RedshiftTarget",
            .s3_catalog_target = "S3CatalogTarget",
            .s3_glue_parquet_target = "S3GlueParquetTarget",
            .s3_direct_target = "S3DirectTarget",
            .apply_mapping = "ApplyMapping",
            .select_fields = "SelectFields",
            .drop_fields = "DropFields",
            .rename_field = "RenameField",
            .spigot = "Spigot",
            .join = "Join",
            .split_fields = "SplitFields",
            .select_from_collection = "SelectFromCollection",
            .fill_missing_values = "FillMissingValues",
            .filter = "Filter",
            .custom_code = "CustomCode",
            .spark_sql = "SparkSQL",
            .direct_kinesis_source = "DirectKinesisSource",
            .direct_kafka_source = "DirectKafkaSource",
            .catalog_kinesis_source = "CatalogKinesisSource",
            .catalog_kafka_source = "CatalogKafkaSource",
            .drop_null_fields = "DropNullFields",
            .merge = "Merge",
            .@"union" = "Union",
            .pii_detection = "PIIDetection",
            .aggregate = "Aggregate",
            .drop_duplicates = "DropDuplicates",
            .governed_catalog_target = "GovernedCatalogTarget",
            .governed_catalog_source = "GovernedCatalogSource",
            .microsoft_sql_server_catalog_source = "MicrosoftSQLServerCatalogSource",
            .my_sql_catalog_source = "MySQLCatalogSource",
            .oracle_sql_catalog_source = "OracleSQLCatalogSource",
            .postgre_sql_catalog_source = "PostgreSQLCatalogSource",
            .microsoft_sql_server_catalog_target = "MicrosoftSQLServerCatalogTarget",
            .my_sql_catalog_target = "MySQLCatalogTarget",
            .oracle_sql_catalog_target = "OracleSQLCatalogTarget",
            .postgre_sql_catalog_target = "PostgreSQLCatalogTarget",
            .dynamic_transform = "DynamicTransform",
            .evaluate_data_quality = "EvaluateDataQuality",
            .s3_catalog_hudi_source = "S3CatalogHudiSource",
            .catalog_hudi_source = "CatalogHudiSource",
            .s3_hudi_source = "S3HudiSource",
            .s3_hudi_catalog_target = "S3HudiCatalogTarget",
            .s3_hudi_direct_target = "S3HudiDirectTarget",
            .direct_jdbc_source = "DirectJDBCSource",
            .s3_catalog_delta_source = "S3CatalogDeltaSource",
            .catalog_delta_source = "CatalogDeltaSource",
            .s3_delta_source = "S3DeltaSource",
            .s3_delta_catalog_target = "S3DeltaCatalogTarget",
            .s3_delta_direct_target = "S3DeltaDirectTarget",
            .amazon_redshift_source = "AmazonRedshiftSource",
            .amazon_redshift_target = "AmazonRedshiftTarget",
            .evaluate_data_quality_multi_frame = "EvaluateDataQualityMultiFrame",
            .recipe = "Recipe",
            .snowflake_source = "SnowflakeSource",
            .snowflake_target = "SnowflakeTarget",
            .connector_data_source = "ConnectorDataSource",
            .connector_data_target = "ConnectorDataTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectorDataTarget = struct {
    name: []const u8,
    connection_type: []const u8,
    data: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    inputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_type = "ConnectionType",
            .data = "Data",
            .inputs = "Inputs",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        return false;
    }
};

pub const ConnectorDataSource = struct {
    name: []const u8,
    connection_type: []const u8,
    data: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_type = "ConnectionType",
            .data = "Data",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        return false;
    }
};

pub const GlueSchema = struct {
    columns: ?[]GlueStudioSchemaColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const GlueStudioSchemaColumn = struct {
    name: []const u8,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeTarget = struct {
    name: []const u8,
    data: SnowflakeNodeData,
    inputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data = "Data",
            .inputs = "Inputs",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeNodeData = struct {
    source_type: ?[]const u8 = null,
    connection: ?Option = null,
    schema: ?[]const u8 = null,
    table: ?[]const u8 = null,
    database: ?[]const u8 = null,
    temp_dir: ?[]const u8 = null,
    iam_role: ?Option = null,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    sample_query: ?[]const u8 = null,
    pre_action: ?[]const u8 = null,
    post_action: ?[]const u8 = null,
    action: ?[]const u8 = null,
    upsert: ?bool = null,
    merge_action: ?[]const u8 = null,
    merge_when_matched: ?[]const u8 = null,
    merge_when_not_matched: ?[]const u8 = null,
    merge_clause: ?[]const u8 = null,
    staging_table: ?[]const u8 = null,
    selected_columns: ?[]Option = null,
    auto_pushdown: ?bool = null,
    table_schema: ?[]Option = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_type = "SourceType",
            .connection = "Connection",
            .schema = "Schema",
            .table = "Table",
            .database = "Database",
            .temp_dir = "TempDir",
            .iam_role = "IamRole",
            .additional_options = "AdditionalOptions",
            .sample_query = "SampleQuery",
            .pre_action = "PreAction",
            .post_action = "PostAction",
            .action = "Action",
            .upsert = "Upsert",
            .merge_action = "MergeAction",
            .merge_when_matched = "MergeWhenMatched",
            .merge_when_not_matched = "MergeWhenNotMatched",
            .merge_clause = "MergeClause",
            .staging_table = "StagingTable",
            .selected_columns = "SelectedColumns",
            .auto_pushdown = "AutoPushdown",
            .table_schema = "TableSchema",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const Option = struct {
    value: ?[]const u8 = null,
    label: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .label = "Label",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeSource = struct {
    name: []const u8,
    data: SnowflakeNodeData,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data = "Data",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const Recipe = struct {
    name: []const u8,
    inputs: [][]const u8,
    recipe_reference: RecipeReference,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .recipe_reference = "RecipeReference",
        };
        return @field(mappings, field_name);
    }
};

pub const RecipeReference = struct {
    recipe_arn: []const u8,
    recipe_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recipe_arn = "RecipeArn",
            .recipe_version = "RecipeVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluateDataQualityMultiFrame = struct {
    name: []const u8,
    inputs: [][]const u8,
    additional_data_sources: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    ruleset: []const u8,
    publishing_options: ?DQResultsPublishingOptions = null,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    stop_job_on_failure_options: ?DQStopJobOnFailureOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .additional_data_sources = "AdditionalDataSources",
            .ruleset = "Ruleset",
            .publishing_options = "PublishingOptions",
            .additional_options = "AdditionalOptions",
            .stop_job_on_failure_options = "StopJobOnFailureOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_data_sources", field_name))
            return try serializeMap(self.additional_data_sources, self.fieldNameFor("additional_data_sources"), options, out_stream);
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const DQStopJobOnFailureOptions = struct {
    stop_job_on_failure_timing: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stop_job_on_failure_timing = "StopJobOnFailureTiming",
        };
        return @field(mappings, field_name);
    }
};

pub const DQResultsPublishingOptions = struct {
    evaluation_context: ?[]const u8 = null,
    results_s3_prefix: ?[]const u8 = null,
    cloud_watch_metrics_enabled: ?bool = null,
    results_publishing_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evaluation_context = "EvaluationContext",
            .results_s3_prefix = "ResultsS3Prefix",
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .results_publishing_enabled = "ResultsPublishingEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonRedshiftTarget = struct {
    name: ?[]const u8 = null,
    data: ?AmazonRedshiftNodeData = null,
    inputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data = "Data",
            .inputs = "Inputs",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonRedshiftNodeData = struct {
    access_type: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    connection: ?Option = null,
    schema: ?Option = null,
    table: ?Option = null,
    catalog_database: ?Option = null,
    catalog_table: ?Option = null,
    catalog_redshift_schema: ?[]const u8 = null,
    catalog_redshift_table: ?[]const u8 = null,
    temp_dir: ?[]const u8 = null,
    iam_role: ?Option = null,
    advanced_options: ?[]AmazonRedshiftAdvancedOption = null,
    sample_query: ?[]const u8 = null,
    pre_action: ?[]const u8 = null,
    post_action: ?[]const u8 = null,
    action: ?[]const u8 = null,
    table_prefix: ?[]const u8 = null,
    upsert: ?bool = null,
    merge_action: ?[]const u8 = null,
    merge_when_matched: ?[]const u8 = null,
    merge_when_not_matched: ?[]const u8 = null,
    merge_clause: ?[]const u8 = null,
    crawler_connection: ?[]const u8 = null,
    table_schema: ?[]Option = null,
    staging_table: ?[]const u8 = null,
    selected_columns: ?[]Option = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_type = "AccessType",
            .source_type = "SourceType",
            .connection = "Connection",
            .schema = "Schema",
            .table = "Table",
            .catalog_database = "CatalogDatabase",
            .catalog_table = "CatalogTable",
            .catalog_redshift_schema = "CatalogRedshiftSchema",
            .catalog_redshift_table = "CatalogRedshiftTable",
            .temp_dir = "TempDir",
            .iam_role = "IamRole",
            .advanced_options = "AdvancedOptions",
            .sample_query = "SampleQuery",
            .pre_action = "PreAction",
            .post_action = "PostAction",
            .action = "Action",
            .table_prefix = "TablePrefix",
            .upsert = "Upsert",
            .merge_action = "MergeAction",
            .merge_when_matched = "MergeWhenMatched",
            .merge_when_not_matched = "MergeWhenNotMatched",
            .merge_clause = "MergeClause",
            .crawler_connection = "CrawlerConnection",
            .table_schema = "TableSchema",
            .staging_table = "StagingTable",
            .selected_columns = "SelectedColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonRedshiftAdvancedOption = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonRedshiftSource = struct {
    name: ?[]const u8 = null,
    data: ?AmazonRedshiftNodeData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DeltaDirectTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    path: []const u8,
    compression: []const u8,
    format: []const u8,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    schema_change_policy: ?DirectSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .path = "Path",
            .compression = "Compression",
            .format = "Format",
            .additional_options = "AdditionalOptions",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const DirectSchemaChangePolicy = struct {
    enable_update_catalog: ?bool = null,
    update_behavior: ?[]const u8 = null,
    table: ?[]const u8 = null,
    database: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_update_catalog = "EnableUpdateCatalog",
            .update_behavior = "UpdateBehavior",
            .table = "Table",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DeltaCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    table: []const u8,
    database: []const u8,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    schema_change_policy: ?CatalogSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .table = "Table",
            .database = "Database",
            .additional_options = "AdditionalOptions",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const CatalogSchemaChangePolicy = struct {
    enable_update_catalog: ?bool = null,
    update_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_update_catalog = "EnableUpdateCatalog",
            .update_behavior = "UpdateBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DeltaSource = struct {
    name: []const u8,
    paths: [][]const u8,
    additional_delta_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    additional_options: ?S3DirectSourceAdditionalOptions = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .paths = "Paths",
            .additional_delta_options = "AdditionalDeltaOptions",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_delta_options", field_name))
            return try serializeMap(self.additional_delta_options, self.fieldNameFor("additional_delta_options"), options, out_stream);
        return false;
    }
};

pub const S3DirectSourceAdditionalOptions = struct {
    bounded_size: ?i64 = null,
    bounded_files: ?i64 = null,
    enable_sample_path: ?bool = null,
    sample_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounded_size = "BoundedSize",
            .bounded_files = "BoundedFiles",
            .enable_sample_path = "EnableSamplePath",
            .sample_path = "SamplePath",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogDeltaSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    additional_delta_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .additional_delta_options = "AdditionalDeltaOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_delta_options", field_name))
            return try serializeMap(self.additional_delta_options, self.fieldNameFor("additional_delta_options"), options, out_stream);
        return false;
    }
};

pub const S3CatalogDeltaSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    additional_delta_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .additional_delta_options = "AdditionalDeltaOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_delta_options", field_name))
            return try serializeMap(self.additional_delta_options, self.fieldNameFor("additional_delta_options"), options, out_stream);
        return false;
    }
};

pub const DirectJDBCSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    connection_name: []const u8,
    connection_type: []const u8,
    redshift_tmp_dir: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .connection_name = "ConnectionName",
            .connection_type = "ConnectionType",
            .redshift_tmp_dir = "RedshiftTmpDir",
        };
        return @field(mappings, field_name);
    }
};

pub const S3HudiDirectTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    path: []const u8,
    compression: []const u8,
    partition_keys: ?[][][]const u8 = null,
    format: []const u8,
    additional_options: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    schema_change_policy: ?DirectSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .path = "Path",
            .compression = "Compression",
            .partition_keys = "PartitionKeys",
            .format = "Format",
            .additional_options = "AdditionalOptions",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const S3HudiCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    table: []const u8,
    database: []const u8,
    additional_options: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    schema_change_policy: ?CatalogSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .table = "Table",
            .database = "Database",
            .additional_options = "AdditionalOptions",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const S3HudiSource = struct {
    name: []const u8,
    paths: [][]const u8,
    additional_hudi_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    additional_options: ?S3DirectSourceAdditionalOptions = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .paths = "Paths",
            .additional_hudi_options = "AdditionalHudiOptions",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_hudi_options", field_name))
            return try serializeMap(self.additional_hudi_options, self.fieldNameFor("additional_hudi_options"), options, out_stream);
        return false;
    }
};

pub const CatalogHudiSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    additional_hudi_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .additional_hudi_options = "AdditionalHudiOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_hudi_options", field_name))
            return try serializeMap(self.additional_hudi_options, self.fieldNameFor("additional_hudi_options"), options, out_stream);
        return false;
    }
};

pub const S3CatalogHudiSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    additional_hudi_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .additional_hudi_options = "AdditionalHudiOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_hudi_options", field_name))
            return try serializeMap(self.additional_hudi_options, self.fieldNameFor("additional_hudi_options"), options, out_stream);
        return false;
    }
};

pub const EvaluateDataQuality = struct {
    name: []const u8,
    inputs: [][]const u8,
    ruleset: []const u8,
    output: ?[]const u8 = null,
    publishing_options: ?DQResultsPublishingOptions = null,
    stop_job_on_failure_options: ?DQStopJobOnFailureOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .ruleset = "Ruleset",
            .output = "Output",
            .publishing_options = "PublishingOptions",
            .stop_job_on_failure_options = "StopJobOnFailureOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamicTransform = struct {
    name: []const u8,
    transform_name: []const u8,
    inputs: [][]const u8,
    parameters: ?[]TransformConfigParameter = null,
    function_name: []const u8,
    path: []const u8,
    version: ?[]const u8 = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .transform_name = "TransformName",
            .inputs = "Inputs",
            .parameters = "Parameters",
            .function_name = "FunctionName",
            .path = "Path",
            .version = "Version",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformConfigParameter = struct {
    name: []const u8,
    type: []const u8,
    validation_rule: ?[]const u8 = null,
    validation_message: ?[]const u8 = null,
    value: ?[][]const u8 = null,
    list_type: ?[]const u8 = null,
    is_optional: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .validation_rule = "ValidationRule",
            .validation_message = "ValidationMessage",
            .value = "Value",
            .list_type = "ListType",
            .is_optional = "IsOptional",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSQLCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleSQLCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const MySQLCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const MicrosoftSQLServerCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSQLCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleSQLCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const MySQLCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const MicrosoftSQLServerCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const GovernedCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    partition_predicate: ?[]const u8 = null,
    additional_options: ?S3SourceAdditionalOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .partition_predicate = "PartitionPredicate",
            .additional_options = "AdditionalOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SourceAdditionalOptions = struct {
    bounded_size: ?i64 = null,
    bounded_files: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounded_size = "BoundedSize",
            .bounded_files = "BoundedFiles",
        };
        return @field(mappings, field_name);
    }
};

pub const GovernedCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    table: []const u8,
    database: []const u8,
    schema_change_policy: ?CatalogSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .table = "Table",
            .database = "Database",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const DropDuplicates = struct {
    name: []const u8,
    inputs: [][]const u8,
    columns: ?[][][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const Aggregate = struct {
    name: []const u8,
    inputs: [][]const u8,
    groups: [][][]const u8,
    aggs: []AggregateOperation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .groups = "Groups",
            .aggs = "Aggs",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregateOperation = struct {
    column: [][]const u8,
    agg_func: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .agg_func = "AggFunc",
        };
        return @field(mappings, field_name);
    }
};

pub const PIIDetection = struct {
    name: []const u8,
    inputs: [][]const u8,
    pii_type: []const u8,
    entity_types_to_detect: [][]const u8,
    output_column_name: ?[]const u8 = null,
    sample_fraction: ?f64 = null,
    threshold_fraction: ?f64 = null,
    mask_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .pii_type = "PiiType",
            .entity_types_to_detect = "EntityTypesToDetect",
            .output_column_name = "OutputColumnName",
            .sample_fraction = "SampleFraction",
            .threshold_fraction = "ThresholdFraction",
            .mask_value = "MaskValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Union = struct {
    name: []const u8,
    inputs: [][]const u8,
    union_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .union_type = "UnionType",
        };
        return @field(mappings, field_name);
    }
};

pub const Merge = struct {
    name: []const u8,
    inputs: [][]const u8,
    source: []const u8,
    primary_keys: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .source = "Source",
            .primary_keys = "PrimaryKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const DropNullFields = struct {
    name: []const u8,
    inputs: [][]const u8,
    null_check_box_list: ?NullCheckBoxList = null,
    null_text_list: ?[]NullValueField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .null_check_box_list = "NullCheckBoxList",
            .null_text_list = "NullTextList",
        };
        return @field(mappings, field_name);
    }
};

pub const NullValueField = struct {
    value: []const u8,
    datatype: Datatype,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .datatype = "Datatype",
        };
        return @field(mappings, field_name);
    }
};

pub const Datatype = struct {
    id: []const u8,
    label: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .label = "Label",
        };
        return @field(mappings, field_name);
    }
};

pub const NullCheckBoxList = struct {
    is_empty: ?bool = null,
    is_null_string: ?bool = null,
    is_neg_one: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_empty = "IsEmpty",
            .is_null_string = "IsNullString",
            .is_neg_one = "IsNegOne",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogKafkaSource = struct {
    name: []const u8,
    window_size: ?i64 = null,
    detect_schema: ?bool = null,
    table: []const u8,
    database: []const u8,
    streaming_options: ?KafkaStreamingSourceOptions = null,
    data_preview_options: ?StreamingDataPreviewOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .window_size = "WindowSize",
            .detect_schema = "DetectSchema",
            .table = "Table",
            .database = "Database",
            .streaming_options = "StreamingOptions",
            .data_preview_options = "DataPreviewOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingDataPreviewOptions = struct {
    polling_time: ?i64 = null,
    record_polling_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .polling_time = "PollingTime",
            .record_polling_limit = "RecordPollingLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaStreamingSourceOptions = struct {
    bootstrap_servers: ?[]const u8 = null,
    security_protocol: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,
    topic_name: ?[]const u8 = null,
    assign: ?[]const u8 = null,
    subscribe_pattern: ?[]const u8 = null,
    classification: ?[]const u8 = null,
    delimiter: ?[]const u8 = null,
    starting_offsets: ?[]const u8 = null,
    ending_offsets: ?[]const u8 = null,
    poll_timeout_ms: ?i64 = null,
    num_retries: ?i64 = null,
    retry_interval_ms: ?i64 = null,
    max_offsets_per_trigger: ?i64 = null,
    min_partitions: ?i64 = null,
    include_headers: ?bool = null,
    add_record_timestamp: ?[]const u8 = null,
    emit_consumer_lag_metrics: ?[]const u8 = null,
    starting_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bootstrap_servers = "BootstrapServers",
            .security_protocol = "SecurityProtocol",
            .connection_name = "ConnectionName",
            .topic_name = "TopicName",
            .assign = "Assign",
            .subscribe_pattern = "SubscribePattern",
            .classification = "Classification",
            .delimiter = "Delimiter",
            .starting_offsets = "StartingOffsets",
            .ending_offsets = "EndingOffsets",
            .poll_timeout_ms = "PollTimeoutMs",
            .num_retries = "NumRetries",
            .retry_interval_ms = "RetryIntervalMs",
            .max_offsets_per_trigger = "MaxOffsetsPerTrigger",
            .min_partitions = "MinPartitions",
            .include_headers = "IncludeHeaders",
            .add_record_timestamp = "AddRecordTimestamp",
            .emit_consumer_lag_metrics = "EmitConsumerLagMetrics",
            .starting_timestamp = "StartingTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogKinesisSource = struct {
    name: []const u8,
    window_size: ?i64 = null,
    detect_schema: ?bool = null,
    table: []const u8,
    database: []const u8,
    streaming_options: ?KinesisStreamingSourceOptions = null,
    data_preview_options: ?StreamingDataPreviewOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .window_size = "WindowSize",
            .detect_schema = "DetectSchema",
            .table = "Table",
            .database = "Database",
            .streaming_options = "StreamingOptions",
            .data_preview_options = "DataPreviewOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisStreamingSourceOptions = struct {
    endpoint_url: ?[]const u8 = null,
    stream_name: ?[]const u8 = null,
    classification: ?[]const u8 = null,
    delimiter: ?[]const u8 = null,
    starting_position: ?[]const u8 = null,
    max_fetch_time_in_ms: ?i64 = null,
    max_fetch_records_per_shard: ?i64 = null,
    max_record_per_read: ?i64 = null,
    add_idle_time_between_reads: ?bool = null,
    idle_time_between_reads_in_ms: ?i64 = null,
    describe_shard_interval: ?i64 = null,
    num_retries: ?i64 = null,
    retry_interval_ms: ?i64 = null,
    max_retry_interval_ms: ?i64 = null,
    avoid_empty_batches: ?bool = null,
    stream_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    role_session_name: ?[]const u8 = null,
    add_record_timestamp: ?[]const u8 = null,
    emit_consumer_lag_metrics: ?[]const u8 = null,
    starting_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_url = "EndpointUrl",
            .stream_name = "StreamName",
            .classification = "Classification",
            .delimiter = "Delimiter",
            .starting_position = "StartingPosition",
            .max_fetch_time_in_ms = "MaxFetchTimeInMs",
            .max_fetch_records_per_shard = "MaxFetchRecordsPerShard",
            .max_record_per_read = "MaxRecordPerRead",
            .add_idle_time_between_reads = "AddIdleTimeBetweenReads",
            .idle_time_between_reads_in_ms = "IdleTimeBetweenReadsInMs",
            .describe_shard_interval = "DescribeShardInterval",
            .num_retries = "NumRetries",
            .retry_interval_ms = "RetryIntervalMs",
            .max_retry_interval_ms = "MaxRetryIntervalMs",
            .avoid_empty_batches = "AvoidEmptyBatches",
            .stream_arn = "StreamArn",
            .role_arn = "RoleArn",
            .role_session_name = "RoleSessionName",
            .add_record_timestamp = "AddRecordTimestamp",
            .emit_consumer_lag_metrics = "EmitConsumerLagMetrics",
            .starting_timestamp = "StartingTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectKafkaSource = struct {
    name: []const u8,
    streaming_options: ?KafkaStreamingSourceOptions = null,
    window_size: ?i64 = null,
    detect_schema: ?bool = null,
    data_preview_options: ?StreamingDataPreviewOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .streaming_options = "StreamingOptions",
            .window_size = "WindowSize",
            .detect_schema = "DetectSchema",
            .data_preview_options = "DataPreviewOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DirectKinesisSource = struct {
    name: []const u8,
    window_size: ?i64 = null,
    detect_schema: ?bool = null,
    streaming_options: ?KinesisStreamingSourceOptions = null,
    data_preview_options: ?StreamingDataPreviewOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .window_size = "WindowSize",
            .detect_schema = "DetectSchema",
            .streaming_options = "StreamingOptions",
            .data_preview_options = "DataPreviewOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkSQL = struct {
    name: []const u8,
    inputs: [][]const u8,
    sql_query: []const u8,
    sql_aliases: []SqlAlias,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .sql_query = "SqlQuery",
            .sql_aliases = "SqlAliases",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlAlias = struct {
    from: []const u8,
    alias: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .alias = "Alias",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomCode = struct {
    name: []const u8,
    inputs: [][]const u8,
    code: []const u8,
    class_name: []const u8,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .code = "Code",
            .class_name = "ClassName",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    inputs: [][]const u8,
    logical_operator: []const u8,
    filters: []FilterExpression,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .logical_operator = "LogicalOperator",
            .filters = "Filters",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterExpression = struct {
    operation: []const u8,
    negated: ?bool = null,
    values: []FilterValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .operation = "Operation",
            .negated = "Negated",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterValue = struct {
    type: []const u8,
    value: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FillMissingValues = struct {
    name: []const u8,
    inputs: [][]const u8,
    imputed_path: []const u8,
    filled_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .imputed_path = "ImputedPath",
            .filled_path = "FilledPath",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectFromCollection = struct {
    name: []const u8,
    inputs: [][]const u8,
    index: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .index = "Index",
        };
        return @field(mappings, field_name);
    }
};

pub const SplitFields = struct {
    name: []const u8,
    inputs: [][]const u8,
    paths: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .paths = "Paths",
        };
        return @field(mappings, field_name);
    }
};

pub const Join = struct {
    name: []const u8,
    inputs: [][]const u8,
    join_type: []const u8,
    columns: []JoinColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .join_type = "JoinType",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinColumn = struct {
    from: []const u8,
    keys: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .keys = "Keys",
        };
        return @field(mappings, field_name);
    }
};

pub const Spigot = struct {
    name: []const u8,
    inputs: [][]const u8,
    path: []const u8,
    topk: ?i64 = null,
    prob: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .path = "Path",
            .topk = "Topk",
            .prob = "Prob",
        };
        return @field(mappings, field_name);
    }
};

pub const RenameField = struct {
    name: []const u8,
    inputs: [][]const u8,
    source_path: [][]const u8,
    target_path: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .source_path = "SourcePath",
            .target_path = "TargetPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DropFields = struct {
    name: []const u8,
    inputs: [][]const u8,
    paths: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .paths = "Paths",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectFields = struct {
    name: []const u8,
    inputs: [][]const u8,
    paths: [][][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .paths = "Paths",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplyMapping = struct {
    name: []const u8,
    inputs: [][]const u8,
    mapping: []Mapping,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .mapping = "Mapping",
        };
        return @field(mappings, field_name);
    }
};

pub const Mapping = struct {
    to_key: ?[]const u8 = null,
    from_path: ?[][]const u8 = null,
    from_type: ?[]const u8 = null,
    to_type: ?[]const u8 = null,
    dropped: ?bool = null,
    children: ?[]Mapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .to_key = "ToKey",
            .from_path = "FromPath",
            .from_type = "FromType",
            .to_type = "ToType",
            .dropped = "Dropped",
            .children = "Children",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DirectTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    path: []const u8,
    compression: ?[]const u8 = null,
    format: []const u8,
    schema_change_policy: ?DirectSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .path = "Path",
            .compression = "Compression",
            .format = "Format",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const S3GlueParquetTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    path: []const u8,
    compression: ?[]const u8 = null,
    schema_change_policy: ?DirectSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .path = "Path",
            .compression = "Compression",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const S3CatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    partition_keys: ?[][][]const u8 = null,
    table: []const u8,
    database: []const u8,
    schema_change_policy: ?CatalogSchemaChangePolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .partition_keys = "PartitionKeys",
            .table = "Table",
            .database = "Database",
            .schema_change_policy = "SchemaChangePolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,
    redshift_tmp_dir: ?[]const u8 = null,
    tmp_dir_iam_role: ?[]const u8 = null,
    upsert_redshift_options: ?UpsertRedshiftTargetOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
            .redshift_tmp_dir = "RedshiftTmpDir",
            .tmp_dir_iam_role = "TmpDirIAMRole",
            .upsert_redshift_options = "UpsertRedshiftOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const UpsertRedshiftTargetOptions = struct {
    table_location: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,
    upsert_keys: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_location = "TableLocation",
            .connection_name = "ConnectionName",
            .upsert_keys = "UpsertKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const BasicCatalogTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkConnectorTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    connection_name: []const u8,
    connector_name: []const u8,
    connection_type: []const u8,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .connection_name = "ConnectionName",
            .connector_name = "ConnectorName",
            .connection_type = "ConnectionType",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const JDBCConnectorTarget = struct {
    name: []const u8,
    inputs: [][]const u8,
    connection_name: []const u8,
    connection_table: []const u8,
    connector_name: []const u8,
    connection_type: []const u8,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .inputs = "Inputs",
            .connection_name = "ConnectionName",
            .connection_table = "ConnectionTable",
            .connector_name = "ConnectorName",
            .connection_type = "ConnectionType",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const DynamoDBCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const RelationalCatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ParquetSource = struct {
    name: []const u8,
    paths: [][]const u8,
    compression_type: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    group_size: ?[]const u8 = null,
    group_files: ?[]const u8 = null,
    recurse: ?bool = null,
    max_band: ?i64 = null,
    max_files_in_band: ?i64 = null,
    additional_options: ?S3DirectSourceAdditionalOptions = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .paths = "Paths",
            .compression_type = "CompressionType",
            .exclusions = "Exclusions",
            .group_size = "GroupSize",
            .group_files = "GroupFiles",
            .recurse = "Recurse",
            .max_band = "MaxBand",
            .max_files_in_band = "MaxFilesInBand",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const S3JsonSource = struct {
    name: []const u8,
    paths: [][]const u8,
    compression_type: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    group_size: ?[]const u8 = null,
    group_files: ?[]const u8 = null,
    recurse: ?bool = null,
    max_band: ?i64 = null,
    max_files_in_band: ?i64 = null,
    additional_options: ?S3DirectSourceAdditionalOptions = null,
    json_path: ?[]const u8 = null,
    multiline: ?bool = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .paths = "Paths",
            .compression_type = "CompressionType",
            .exclusions = "Exclusions",
            .group_size = "GroupSize",
            .group_files = "GroupFiles",
            .recurse = "Recurse",
            .max_band = "MaxBand",
            .max_files_in_band = "MaxFilesInBand",
            .additional_options = "AdditionalOptions",
            .json_path = "JsonPath",
            .multiline = "Multiline",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const S3CsvSource = struct {
    name: []const u8,
    paths: [][]const u8,
    compression_type: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    group_size: ?[]const u8 = null,
    group_files: ?[]const u8 = null,
    recurse: ?bool = null,
    max_band: ?i64 = null,
    max_files_in_band: ?i64 = null,
    additional_options: ?S3DirectSourceAdditionalOptions = null,
    separator: []const u8,
    escaper: ?[]const u8 = null,
    quote_char: []const u8,
    multiline: ?bool = null,
    with_header: ?bool = null,
    write_header: ?bool = null,
    skip_first: ?bool = null,
    optimize_performance: ?bool = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .paths = "Paths",
            .compression_type = "CompressionType",
            .exclusions = "Exclusions",
            .group_size = "GroupSize",
            .group_files = "GroupFiles",
            .recurse = "Recurse",
            .max_band = "MaxBand",
            .max_files_in_band = "MaxFilesInBand",
            .additional_options = "AdditionalOptions",
            .separator = "Separator",
            .escaper = "Escaper",
            .quote_char = "QuoteChar",
            .multiline = "Multiline",
            .with_header = "WithHeader",
            .write_header = "WriteHeader",
            .skip_first = "SkipFirst",
            .optimize_performance = "OptimizePerformance",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const S3CatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    partition_predicate: ?[]const u8 = null,
    additional_options: ?S3SourceAdditionalOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .partition_predicate = "PartitionPredicate",
            .additional_options = "AdditionalOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,
    redshift_tmp_dir: ?[]const u8 = null,
    tmp_dir_iam_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
            .redshift_tmp_dir = "RedshiftTmpDir",
            .tmp_dir_iam_role = "TmpDirIAMRole",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogSource = struct {
    name: []const u8,
    database: []const u8,
    table: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database = "Database",
            .table = "Table",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkConnectorSource = struct {
    name: []const u8,
    connection_name: []const u8,
    connector_name: []const u8,
    connection_type: []const u8,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_name = "ConnectionName",
            .connector_name = "ConnectorName",
            .connection_type = "ConnectionType",
            .additional_options = "AdditionalOptions",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const JDBCConnectorSource = struct {
    name: []const u8,
    connection_name: []const u8,
    connector_name: []const u8,
    connection_type: []const u8,
    additional_options: ?JDBCConnectorOptions = null,
    connection_table: ?[]const u8 = null,
    query: ?[]const u8 = null,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_name = "ConnectionName",
            .connector_name = "ConnectorName",
            .connection_type = "ConnectionType",
            .additional_options = "AdditionalOptions",
            .connection_table = "ConnectionTable",
            .query = "Query",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const JDBCConnectorOptions = struct {
    filter_predicate: ?[]const u8 = null,
    partition_column: ?[]const u8 = null,
    lower_bound: ?i64 = null,
    upper_bound: ?i64 = null,
    num_partitions: ?i64 = null,
    job_bookmark_keys: ?[][]const u8 = null,
    job_bookmark_keys_sort_order: ?[]const u8 = null,
    data_type_mapping: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_predicate = "FilterPredicate",
            .partition_column = "PartitionColumn",
            .lower_bound = "LowerBound",
            .upper_bound = "UpperBound",
            .num_partitions = "NumPartitions",
            .job_bookmark_keys = "JobBookmarkKeys",
            .job_bookmark_keys_sort_order = "JobBookmarkKeysSortOrder",
            .data_type_mapping = "DataTypeMapping",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data_type_mapping", field_name))
            return try serializeMap(self.data_type_mapping, self.fieldNameFor("data_type_mapping"), options, out_stream);
        return false;
    }
};

pub const AthenaConnectorSource = struct {
    name: []const u8,
    connection_name: []const u8,
    connector_name: []const u8,
    connection_type: []const u8,
    connection_table: ?[]const u8 = null,
    schema_name: []const u8,
    output_schemas: ?[]GlueSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .connection_name = "ConnectionName",
            .connector_name = "ConnectorName",
            .connection_type = "ConnectionType",
            .connection_table = "ConnectionTable",
            .schema_name = "SchemaName",
            .output_schemas = "OutputSchemas",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionsList = struct {
    connections: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connections = "Connections",
        };
        return @field(mappings, field_name);
    }
};

pub const JobCommand = struct {
    name: ?[]const u8 = null,
    script_location: ?[]const u8 = null,
    python_version: ?[]const u8 = null,
    runtime: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .script_location = "ScriptLocation",
            .python_version = "PythonVersion",
            .runtime = "Runtime",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionProperty = struct {
    max_concurrent_runs: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_concurrent_runs = "MaxConcurrentRuns",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    location_uri: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    target_database: ?DatabaseIdentifier = null,
    federated_database: ?FederatedDatabase = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .location_uri = "LocationUri",
            .parameters = "Parameters",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .target_database = "TargetDatabase",
            .federated_database = "FederatedDatabase",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const FederatedDatabase = struct {
    identifier: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .connection_name = "ConnectionName",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseIdentifier = struct {
    catalog_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const PrincipalPermissions = struct {
    principal: ?DataLakePrincipal = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLakePrincipal = struct {
    data_lake_principal_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_principal_identifier = "DataLakePrincipalIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const LakeFormationConfiguration = struct {
    use_lake_formation_credentials: ?bool = null,
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .use_lake_formation_credentials = "UseLakeFormationCredentials",
            .account_id = "AccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const LineageConfiguration = struct {
    crawler_lineage_settings: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawler_lineage_settings = "CrawlerLineageSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const RecrawlPolicy = struct {
    recrawl_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recrawl_behavior = "RecrawlBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaChangePolicy = struct {
    update_behavior: ?[]const u8 = null,
    delete_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_behavior = "UpdateBehavior",
            .delete_behavior = "DeleteBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const CrawlerTargets = struct {
    s3_targets: ?[]S3Target = null,
    jdbc_targets: ?[]JdbcTarget = null,
    mongo_db_targets: ?[]MongoDBTarget = null,
    dynamo_db_targets: ?[]DynamoDBTarget = null,
    catalog_targets: ?[]CatalogTarget = null,
    delta_targets: ?[]DeltaTarget = null,
    iceberg_targets: ?[]IcebergTarget = null,
    hudi_targets: ?[]HudiTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_targets = "S3Targets",
            .jdbc_targets = "JdbcTargets",
            .mongo_db_targets = "MongoDBTargets",
            .dynamo_db_targets = "DynamoDBTargets",
            .catalog_targets = "CatalogTargets",
            .delta_targets = "DeltaTargets",
            .iceberg_targets = "IcebergTargets",
            .hudi_targets = "HudiTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const HudiTarget = struct {
    paths: ?[][]const u8 = null,
    connection_name: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    maximum_traversal_depth: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .paths = "Paths",
            .connection_name = "ConnectionName",
            .exclusions = "Exclusions",
            .maximum_traversal_depth = "MaximumTraversalDepth",
        };
        return @field(mappings, field_name);
    }
};

pub const IcebergTarget = struct {
    paths: ?[][]const u8 = null,
    connection_name: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    maximum_traversal_depth: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .paths = "Paths",
            .connection_name = "ConnectionName",
            .exclusions = "Exclusions",
            .maximum_traversal_depth = "MaximumTraversalDepth",
        };
        return @field(mappings, field_name);
    }
};

pub const DeltaTarget = struct {
    delta_tables: ?[][]const u8 = null,
    connection_name: ?[]const u8 = null,
    write_manifest: ?bool = null,
    create_native_delta_table: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delta_tables = "DeltaTables",
            .connection_name = "ConnectionName",
            .write_manifest = "WriteManifest",
            .create_native_delta_table = "CreateNativeDeltaTable",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogTarget = struct {
    database_name: []const u8,
    tables: [][]const u8,
    connection_name: ?[]const u8 = null,
    event_queue_arn: ?[]const u8 = null,
    dlq_event_queue_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .tables = "Tables",
            .connection_name = "ConnectionName",
            .event_queue_arn = "EventQueueArn",
            .dlq_event_queue_arn = "DlqEventQueueArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBTarget = struct {
    path: ?[]const u8 = null,
    scan_all: ?bool = null,
    scan_rate: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .scan_all = "scanAll",
            .scan_rate = "scanRate",
        };
        return @field(mappings, field_name);
    }
};

pub const MongoDBTarget = struct {
    connection_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    scan_all: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .path = "Path",
            .scan_all = "ScanAll",
        };
        return @field(mappings, field_name);
    }
};

pub const JdbcTarget = struct {
    connection_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    enable_additional_metadata: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .path = "Path",
            .exclusions = "Exclusions",
            .enable_additional_metadata = "EnableAdditionalMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Target = struct {
    path: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    connection_name: ?[]const u8 = null,
    sample_size: ?i64 = null,
    event_queue_arn: ?[]const u8 = null,
    dlq_event_queue_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .exclusions = "Exclusions",
            .connection_name = "ConnectionName",
            .sample_size = "SampleSize",
            .event_queue_arn = "EventQueueArn",
            .dlq_event_queue_arn = "DlqEventQueueArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    connection_type: []const u8,
    match_criteria: ?[][]const u8 = null,
    connection_properties: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    physical_connection_requirements: ?PhysicalConnectionRequirements = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .connection_type = "ConnectionType",
            .match_criteria = "MatchCriteria",
            .connection_properties = "ConnectionProperties",
            .physical_connection_requirements = "PhysicalConnectionRequirements",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "connection_properties", field_name))
            return try serializeMap(self.connection_properties, self.fieldNameFor("connection_properties"), options, out_stream);
        return false;
    }
};

pub const PhysicalConnectionRequirements = struct {
    subnet_id: ?[]const u8 = null,
    security_group_id_list: ?[][]const u8 = null,
    availability_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .security_group_id_list = "SecurityGroupIdList",
            .availability_zone = "AvailabilityZone",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatisticsError = struct {
    column_statistics: ?ColumnStatistics = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_statistics = "ColumnStatistics",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatistics = struct {
    column_name: []const u8,
    column_type: []const u8,
    analyzed_time: i64,
    statistics_data: ColumnStatisticsData,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_type = "ColumnType",
            .analyzed_time = "AnalyzedTime",
            .statistics_data = "StatisticsData",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatisticsData = struct {
    type: []const u8,
    boolean_column_statistics_data: ?BooleanColumnStatisticsData = null,
    date_column_statistics_data: ?DateColumnStatisticsData = null,
    decimal_column_statistics_data: ?DecimalColumnStatisticsData = null,
    double_column_statistics_data: ?DoubleColumnStatisticsData = null,
    long_column_statistics_data: ?LongColumnStatisticsData = null,
    string_column_statistics_data: ?StringColumnStatisticsData = null,
    binary_column_statistics_data: ?BinaryColumnStatisticsData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .boolean_column_statistics_data = "BooleanColumnStatisticsData",
            .date_column_statistics_data = "DateColumnStatisticsData",
            .decimal_column_statistics_data = "DecimalColumnStatisticsData",
            .double_column_statistics_data = "DoubleColumnStatisticsData",
            .long_column_statistics_data = "LongColumnStatisticsData",
            .string_column_statistics_data = "StringColumnStatisticsData",
            .binary_column_statistics_data = "BinaryColumnStatisticsData",
        };
        return @field(mappings, field_name);
    }
};

pub const BinaryColumnStatisticsData = struct {
    maximum_length: i64,
    average_length: f64,
    number_of_nulls: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_length = "MaximumLength",
            .average_length = "AverageLength",
            .number_of_nulls = "NumberOfNulls",
        };
        return @field(mappings, field_name);
    }
};

pub const StringColumnStatisticsData = struct {
    maximum_length: i64,
    average_length: f64,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_length = "MaximumLength",
            .average_length = "AverageLength",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const LongColumnStatisticsData = struct {
    minimum_value: ?i64 = null,
    maximum_value: ?i64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DoubleColumnStatisticsData = struct {
    minimum_value: ?f64 = null,
    maximum_value: ?f64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalColumnStatisticsData = struct {
    minimum_value: ?DecimalNumber = null,
    maximum_value: ?DecimalNumber = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalNumber = struct {
    unscaled_value: []const u8,
    scale: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unscaled_value = "UnscaledValue",
            .scale = "Scale",
        };
        return @field(mappings, field_name);
    }
};

pub const DateColumnStatisticsData = struct {
    minimum_value: ?i64 = null,
    maximum_value: ?i64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const BooleanColumnStatisticsData = struct {
    number_of_trues: i64,
    number_of_falses: i64,
    number_of_nulls: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_trues = "NumberOfTrues",
            .number_of_falses = "NumberOfFalses",
            .number_of_nulls = "NumberOfNulls",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    glue_table: GlueTable,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .glue_table = "GlueTable",
        };
        return @field(mappings, field_name);
    }
};

pub const GlueTable = struct {
    database_name: []const u8,
    table_name: []const u8,
    catalog_id: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,
    additional_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .catalog_id = "CatalogId",
            .connection_name = "ConnectionName",
            .additional_options = "AdditionalOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_options", field_name))
            return try serializeMap(self.additional_options, self.fieldNameFor("additional_options"), options, out_stream);
        return false;
    }
};

pub const DataQualityEvaluationRunAdditionalRunOptions = struct {
    cloud_watch_metrics_enabled: ?bool = null,
    results_s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .results_s3_prefix = "ResultsS3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Table = struct {
    name: []const u8,
    database_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    create_time: ?i64 = null,
    update_time: ?i64 = null,
    last_access_time: ?i64 = null,
    last_analyzed_time: ?i64 = null,
    retention: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    partition_keys: ?[]Column = null,
    view_original_text: ?[]const u8 = null,
    view_expanded_text: ?[]const u8 = null,
    table_type: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_by: ?[]const u8 = null,
    is_registered_with_lake_formation: ?bool = null,
    target_table: ?TableIdentifier = null,
    catalog_id: ?[]const u8 = null,
    version_id: ?[]const u8 = null,
    federated_table: ?FederatedTable = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database_name = "DatabaseName",
            .description = "Description",
            .owner = "Owner",
            .create_time = "CreateTime",
            .update_time = "UpdateTime",
            .last_access_time = "LastAccessTime",
            .last_analyzed_time = "LastAnalyzedTime",
            .retention = "Retention",
            .storage_descriptor = "StorageDescriptor",
            .partition_keys = "PartitionKeys",
            .view_original_text = "ViewOriginalText",
            .view_expanded_text = "ViewExpandedText",
            .table_type = "TableType",
            .parameters = "Parameters",
            .created_by = "CreatedBy",
            .is_registered_with_lake_formation = "IsRegisteredWithLakeFormation",
            .target_table = "TargetTable",
            .catalog_id = "CatalogId",
            .version_id = "VersionId",
            .federated_table = "FederatedTable",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const FederatedTable = struct {
    identifier: ?[]const u8 = null,
    database_identifier: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .database_identifier = "DatabaseIdentifier",
            .connection_name = "ConnectionName",
        };
        return @field(mappings, field_name);
    }
};

pub const JobBookmarkEntry = struct {
    job_name: ?[]const u8 = null,
    version: ?i64 = null,
    run: ?i64 = null,
    attempt: ?i64 = null,
    previous_run_id: ?[]const u8 = null,
    run_id: ?[]const u8 = null,
    job_bookmark: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .version = "Version",
            .run = "Run",
            .attempt = "Attempt",
            .previous_run_id = "PreviousRunId",
            .run_id = "RunId",
            .job_bookmark = "JobBookmark",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataKeyValuePair = struct {
    metadata_key: ?[]const u8 = null,
    metadata_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metadata_key = "MetadataKey",
            .metadata_value = "MetadataValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCatalogEncryptionSettings = struct {
    encryption_at_rest: ?EncryptionAtRest = null,
    connection_password_encryption: ?ConnectionPasswordEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_at_rest = "EncryptionAtRest",
            .connection_password_encryption = "ConnectionPasswordEncryption",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionPasswordEncryption = struct {
    return_connection_password_encrypted: bool,
    aws_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .return_connection_password_encrypted = "ReturnConnectionPasswordEncrypted",
            .aws_kms_key_id = "AwsKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRest = struct {
    catalog_encryption_mode: []const u8,
    sse_aws_kms_key_id: ?[]const u8 = null,
    catalog_encryption_service_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_encryption_mode = "CatalogEncryptionMode",
            .sse_aws_kms_key_id = "SseAwsKmsKeyId",
            .catalog_encryption_service_role = "CatalogEncryptionServiceRole",
        };
        return @field(mappings, field_name);
    }
};

pub const TableOptimizerRun = struct {
    event_type: ?[]const u8 = null,
    start_timestamp: ?i64 = null,
    end_timestamp: ?i64 = null,
    metrics: ?RunMetrics = null,
    @"error": ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_type = "eventType",
            .start_timestamp = "startTimestamp",
            .end_timestamp = "endTimestamp",
            .metrics = "metrics",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const RunMetrics = struct {
    number_of_bytes_compacted: ?[]const u8 = null,
    number_of_files_compacted: ?[]const u8 = null,
    number_of_dpus: ?[]const u8 = null,
    job_duration_in_hour: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_bytes_compacted = "NumberOfBytesCompacted",
            .number_of_files_compacted = "NumberOfFilesCompacted",
            .number_of_dpus = "NumberOfDpus",
            .job_duration_in_hour = "JobDurationInHour",
        };
        return @field(mappings, field_name);
    }
};

pub const Statement = struct {
    id: ?i64 = null,
    code: ?[]const u8 = null,
    state: ?[]const u8 = null,
    output: ?StatementOutput = null,
    progress: ?f64 = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .code = "Code",
            .state = "State",
            .output = "Output",
            .progress = "Progress",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
        };
        return @field(mappings, field_name);
    }
};

pub const StatementOutput = struct {
    data: ?StatementOutputData = null,
    execution_count: ?i64 = null,
    status: ?[]const u8 = null,
    error_name: ?[]const u8 = null,
    error_value: ?[]const u8 = null,
    traceback: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
            .execution_count = "ExecutionCount",
            .status = "Status",
            .error_name = "ErrorName",
            .error_value = "ErrorValue",
            .traceback = "Traceback",
        };
        return @field(mappings, field_name);
    }
};

pub const StatementOutputData = struct {
    text_plain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_plain = "TextPlain",
        };
        return @field(mappings, field_name);
    }
};

pub const Session = struct {
    id: ?[]const u8 = null,
    created_on: ?i64 = null,
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    description: ?[]const u8 = null,
    role: ?[]const u8 = null,
    command: ?SessionCommand = null,
    default_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    connections: ?ConnectionsList = null,
    progress: ?f64 = null,
    max_capacity: ?f64 = null,
    security_configuration: ?[]const u8 = null,
    glue_version: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    worker_type: ?[]const u8 = null,
    completed_on: ?i64 = null,
    execution_time: ?f64 = null,
    dpu_seconds: ?f64 = null,
    idle_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .created_on = "CreatedOn",
            .status = "Status",
            .error_message = "ErrorMessage",
            .description = "Description",
            .role = "Role",
            .command = "Command",
            .default_arguments = "DefaultArguments",
            .connections = "Connections",
            .progress = "Progress",
            .max_capacity = "MaxCapacity",
            .security_configuration = "SecurityConfiguration",
            .glue_version = "GlueVersion",
            .number_of_workers = "NumberOfWorkers",
            .worker_type = "WorkerType",
            .completed_on = "CompletedOn",
            .execution_time = "ExecutionTime",
            .dpu_seconds = "DPUSeconds",
            .idle_timeout = "IdleTimeout",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_arguments", field_name))
            return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
        return false;
    }
};

pub const SessionCommand = struct {
    name: ?[]const u8 = null,
    python_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .python_version = "PythonVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformSortCriteria = struct {
    column: []const u8,
    sort_direction: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .sort_direction = "SortDirection",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformFilterCriteria = struct {
    name: ?[]const u8 = null,
    transform_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    glue_version: ?[]const u8 = null,
    created_before: ?i64 = null,
    created_after: ?i64 = null,
    last_modified_before: ?i64 = null,
    last_modified_after: ?i64 = null,
    schema: ?[]SchemaColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .transform_type = "TransformType",
            .status = "Status",
            .glue_version = "GlueVersion",
            .created_before = "CreatedBefore",
            .created_after = "CreatedAfter",
            .last_modified_before = "LastModifiedBefore",
            .last_modified_after = "LastModifiedAfter",
            .schema = "Schema",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaColumn = struct {
    name: ?[]const u8 = null,
    data_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data_type = "DataType",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualityTargetTable = struct {
    table_name: []const u8,
    database_name: []const u8,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .database_name = "DatabaseName",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomEntityType = struct {
    name: []const u8,
    regex_string: []const u8,
    context_words: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .regex_string = "RegexString",
            .context_words = "ContextWords",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowRun = struct {
    name: ?[]const u8 = null,
    workflow_run_id: ?[]const u8 = null,
    previous_run_id: ?[]const u8 = null,
    workflow_run_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    statistics: ?WorkflowRunStatistics = null,
    graph: ?WorkflowGraph = null,
    starting_event_batch_condition: ?StartingEventBatchCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .workflow_run_id = "WorkflowRunId",
            .previous_run_id = "PreviousRunId",
            .workflow_run_properties = "WorkflowRunProperties",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
            .status = "Status",
            .error_message = "ErrorMessage",
            .statistics = "Statistics",
            .graph = "Graph",
            .starting_event_batch_condition = "StartingEventBatchCondition",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "workflow_run_properties", field_name))
            return try serializeMap(self.workflow_run_properties, self.fieldNameFor("workflow_run_properties"), options, out_stream);
        return false;
    }
};

pub const StartingEventBatchCondition = struct {
    batch_size: ?i64 = null,
    batch_window: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .batch_size = "BatchSize",
            .batch_window = "BatchWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowGraph = struct {
    nodes: ?[]Node = null,
    edges: ?[]Edge = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nodes = "Nodes",
            .edges = "Edges",
        };
        return @field(mappings, field_name);
    }
};

pub const Edge = struct {
    source_id: ?[]const u8 = null,
    destination_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_id = "SourceId",
            .destination_id = "DestinationId",
        };
        return @field(mappings, field_name);
    }
};

pub const Node = struct {
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    unique_id: ?[]const u8 = null,
    trigger_details: ?TriggerNodeDetails = null,
    job_details: ?JobNodeDetails = null,
    crawler_details: ?CrawlerNodeDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .name = "Name",
            .unique_id = "UniqueId",
            .trigger_details = "TriggerDetails",
            .job_details = "JobDetails",
            .crawler_details = "CrawlerDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const CrawlerNodeDetails = struct {
    crawls: ?[]Crawl = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawls = "Crawls",
        };
        return @field(mappings, field_name);
    }
};

pub const Crawl = struct {
    state: ?[]const u8 = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,
    error_message: ?[]const u8 = null,
    log_group: ?[]const u8 = null,
    log_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
            .error_message = "ErrorMessage",
            .log_group = "LogGroup",
            .log_stream = "LogStream",
        };
        return @field(mappings, field_name);
    }
};

pub const JobNodeDetails = struct {
    job_runs: ?[]JobRun = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_runs = "JobRuns",
        };
        return @field(mappings, field_name);
    }
};

pub const JobRun = struct {
    id: ?[]const u8 = null,
    attempt: ?i64 = null,
    previous_run_id: ?[]const u8 = null,
    trigger_name: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    started_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    completed_on: ?i64 = null,
    job_run_state: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    error_message: ?[]const u8 = null,
    predecessor_runs: ?[]Predecessor = null,
    allocated_capacity: ?i64 = null,
    execution_time: ?i64 = null,
    timeout: ?i64 = null,
    max_capacity: ?f64 = null,
    worker_type: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    log_group_name: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    glue_version: ?[]const u8 = null,
    dpu_seconds: ?f64 = null,
    execution_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .attempt = "Attempt",
            .previous_run_id = "PreviousRunId",
            .trigger_name = "TriggerName",
            .job_name = "JobName",
            .started_on = "StartedOn",
            .last_modified_on = "LastModifiedOn",
            .completed_on = "CompletedOn",
            .job_run_state = "JobRunState",
            .arguments = "Arguments",
            .error_message = "ErrorMessage",
            .predecessor_runs = "PredecessorRuns",
            .allocated_capacity = "AllocatedCapacity",
            .execution_time = "ExecutionTime",
            .timeout = "Timeout",
            .max_capacity = "MaxCapacity",
            .worker_type = "WorkerType",
            .number_of_workers = "NumberOfWorkers",
            .security_configuration = "SecurityConfiguration",
            .log_group_name = "LogGroupName",
            .notification_property = "NotificationProperty",
            .glue_version = "GlueVersion",
            .dpu_seconds = "DPUSeconds",
            .execution_class = "ExecutionClass",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const Predecessor = struct {
    job_name: ?[]const u8 = null,
    run_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .run_id = "RunId",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerNodeDetails = struct {
    trigger: ?Trigger = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trigger = "Trigger",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowRunStatistics = struct {
    total_actions: ?i64 = null,
    timeout_actions: ?i64 = null,
    failed_actions: ?i64 = null,
    stopped_actions: ?i64 = null,
    succeeded_actions: ?i64 = null,
    running_actions: ?i64 = null,
    errored_actions: ?i64 = null,
    waiting_actions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_actions = "TotalActions",
            .timeout_actions = "TimeoutActions",
            .failed_actions = "FailedActions",
            .stopped_actions = "StoppedActions",
            .succeeded_actions = "SucceededActions",
            .running_actions = "RunningActions",
            .errored_actions = "ErroredActions",
            .waiting_actions = "WaitingActions",
        };
        return @field(mappings, field_name);
    }
};

pub const Workflow = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_run_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    last_run: ?WorkflowRun = null,
    graph: ?WorkflowGraph = null,
    max_concurrent_runs: ?i64 = null,
    blueprint_details: ?BlueprintDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .default_run_properties = "DefaultRunProperties",
            .created_on = "CreatedOn",
            .last_modified_on = "LastModifiedOn",
            .last_run = "LastRun",
            .graph = "Graph",
            .max_concurrent_runs = "MaxConcurrentRuns",
            .blueprint_details = "BlueprintDetails",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_run_properties", field_name))
            return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
        return false;
    }
};

pub const BlueprintDetails = struct {
    blueprint_name: ?[]const u8 = null,
    run_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blueprint_name = "BlueprintName",
            .run_id = "RunId",
        };
        return @field(mappings, field_name);
    }
};

pub const UserDefinedFunction = struct {
    function_name: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    class_name: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    owner_type: ?[]const u8 = null,
    create_time: ?i64 = null,
    resource_uris: ?[]ResourceUri = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_name = "FunctionName",
            .database_name = "DatabaseName",
            .class_name = "ClassName",
            .owner_name = "OwnerName",
            .owner_type = "OwnerType",
            .create_time = "CreateTime",
            .resource_uris = "ResourceUris",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }
};

pub const QuerySessionContext = struct {
    query_id: ?[]const u8 = null,
    query_start_time: ?i64 = null,
    cluster_id: ?[]const u8 = null,
    query_authorization_id: ?[]const u8 = null,
    additional_context: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_id = "QueryId",
            .query_start_time = "QueryStartTime",
            .cluster_id = "ClusterId",
            .query_authorization_id = "QueryAuthorizationId",
            .additional_context = "AdditionalContext",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_context", field_name))
            return try serializeMap(self.additional_context, self.fieldNameFor("additional_context"), options, out_stream);
        return false;
    }
};

pub const AuditContext = struct {
    additional_audit_context: ?[]const u8 = null,
    requested_columns: ?[][]const u8 = null,
    all_columns_requested: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_audit_context = "AdditionalAuditContext",
            .requested_columns = "RequestedColumns",
            .all_columns_requested = "AllColumnsRequested",
        };
        return @field(mappings, field_name);
    }
};

pub const Partition = struct {
    values: ?[][]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_access_time: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_analyzed_time: ?i64 = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .creation_time = "CreationTime",
            .last_access_time = "LastAccessTime",
            .storage_descriptor = "StorageDescriptor",
            .parameters = "Parameters",
            .last_analyzed_time = "LastAnalyzedTime",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Segment = struct {
    segment_number: i64,
    total_segments: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .segment_number = "SegmentNumber",
            .total_segments = "TotalSegments",
        };
        return @field(mappings, field_name);
    }
};

pub const TableVersion = struct {
    table: ?Table = null,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table = "Table",
            .version_id = "VersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const TableOptimizer = struct {
    type: ?[]const u8 = null,
    configuration: ?TableOptimizerConfiguration = null,
    last_run: ?TableOptimizerRun = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .configuration = "configuration",
            .last_run = "lastRun",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityConfiguration = struct {
    name: ?[]const u8 = null,
    created_time_stamp: ?i64 = null,
    encryption_configuration: ?EncryptionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .created_time_stamp = "CreatedTimeStamp",
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    s3_encryption: ?[]S3Encryption = null,
    cloud_watch_encryption: ?CloudWatchEncryption = null,
    job_bookmarks_encryption: ?JobBookmarksEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_encryption = "S3Encryption",
            .cloud_watch_encryption = "CloudWatchEncryption",
            .job_bookmarks_encryption = "JobBookmarksEncryption",
        };
        return @field(mappings, field_name);
    }
};

pub const JobBookmarksEncryption = struct {
    job_bookmarks_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_bookmarks_encryption_mode = "JobBookmarksEncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchEncryption = struct {
    cloud_watch_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_encryption_mode = "CloudWatchEncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Encryption = struct {
    s3_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_encryption_mode = "S3EncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    jdbc: ?[]CodeGenNodeArg = null,
    s3: ?[]CodeGenNodeArg = null,
    dynamo_db: ?[]CodeGenNodeArg = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jdbc = "Jdbc",
            .s3 = "S3",
            .dynamo_db = "DynamoDB",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeGenNodeArg = struct {
    name: []const u8,
    value: []const u8,
    param: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .param = "Param",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogEntry = struct {
    database_name: []const u8,
    table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .table_name = "TableName",
        };
        return @field(mappings, field_name);
    }
};

pub const MappingEntry = struct {
    source_table: ?[]const u8 = null,
    source_path: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    target_table: ?[]const u8 = null,
    target_path: ?[]const u8 = null,
    target_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_table = "SourceTable",
            .source_path = "SourcePath",
            .source_type = "SourceType",
            .target_table = "TargetTable",
            .target_path = "TargetPath",
            .target_type = "TargetType",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionValueList = struct {
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformEncryption = struct {
    ml_user_data_encryption: ?MLUserDataEncryption = null,
    task_run_security_configuration_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ml_user_data_encryption = "MlUserDataEncryption",
            .task_run_security_configuration_name = "TaskRunSecurityConfigurationName",
        };
        return @field(mappings, field_name);
    }
};

pub const MLUserDataEncryption = struct {
    ml_user_data_encryption_mode: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ml_user_data_encryption_mode = "MlUserDataEncryptionMode",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationMetrics = struct {
    transform_type: []const u8,
    find_matches_metrics: ?FindMatchesMetrics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transform_type = "TransformType",
            .find_matches_metrics = "FindMatchesMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesMetrics = struct {
    area_under_pr_curve: ?f64 = null,
    precision: ?f64 = null,
    recall: ?f64 = null,
    f1: ?f64 = null,
    confusion_matrix: ?ConfusionMatrix = null,
    column_importances: ?[]ColumnImportance = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .area_under_pr_curve = "AreaUnderPRCurve",
            .precision = "Precision",
            .recall = "Recall",
            .f1 = "F1",
            .confusion_matrix = "ConfusionMatrix",
            .column_importances = "ColumnImportances",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnImportance = struct {
    column_name: ?[]const u8 = null,
    importance: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .importance = "Importance",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfusionMatrix = struct {
    num_true_positives: ?i64 = null,
    num_false_positives: ?i64 = null,
    num_true_negatives: ?i64 = null,
    num_false_negatives: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .num_true_positives = "NumTruePositives",
            .num_false_positives = "NumFalsePositives",
            .num_true_negatives = "NumTrueNegatives",
            .num_false_negatives = "NumFalseNegatives",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskRunProperties = struct {
    task_type: ?[]const u8 = null,
    import_labels_task_run_properties: ?ImportLabelsTaskRunProperties = null,
    export_labels_task_run_properties: ?ExportLabelsTaskRunProperties = null,
    labeling_set_generation_task_run_properties: ?LabelingSetGenerationTaskRunProperties = null,
    find_matches_task_run_properties: ?FindMatchesTaskRunProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_type = "TaskType",
            .import_labels_task_run_properties = "ImportLabelsTaskRunProperties",
            .export_labels_task_run_properties = "ExportLabelsTaskRunProperties",
            .labeling_set_generation_task_run_properties = "LabelingSetGenerationTaskRunProperties",
            .find_matches_task_run_properties = "FindMatchesTaskRunProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesTaskRunProperties = struct {
    job_id: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    job_run_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_name = "JobName",
            .job_run_id = "JobRunId",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingSetGenerationTaskRunProperties = struct {
    output_s3_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "OutputS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportLabelsTaskRunProperties = struct {
    output_s3_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "OutputS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportLabelsTaskRunProperties = struct {
    input_s3_path: ?[]const u8 = null,
    replace: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_s3_path = "InputS3Path",
            .replace = "Replace",
        };
        return @field(mappings, field_name);
    }
};

pub const Job = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    log_uri: ?[]const u8 = null,
    role: ?[]const u8 = null,
    created_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    execution_property: ?ExecutionProperty = null,
    command: ?JobCommand = null,
    default_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    non_overridable_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    connections: ?ConnectionsList = null,
    max_retries: ?i64 = null,
    allocated_capacity: ?i64 = null,
    timeout: ?i64 = null,
    max_capacity: ?f64 = null,
    worker_type: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    glue_version: ?[]const u8 = null,
    code_gen_configuration_nodes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CodeGenConfigurationNode = null,
    } = null,
    execution_class: ?[]const u8 = null,
    source_control_details: ?SourceControlDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .log_uri = "LogUri",
            .role = "Role",
            .created_on = "CreatedOn",
            .last_modified_on = "LastModifiedOn",
            .execution_property = "ExecutionProperty",
            .command = "Command",
            .default_arguments = "DefaultArguments",
            .non_overridable_arguments = "NonOverridableArguments",
            .connections = "Connections",
            .max_retries = "MaxRetries",
            .allocated_capacity = "AllocatedCapacity",
            .timeout = "Timeout",
            .max_capacity = "MaxCapacity",
            .worker_type = "WorkerType",
            .number_of_workers = "NumberOfWorkers",
            .security_configuration = "SecurityConfiguration",
            .notification_property = "NotificationProperty",
            .glue_version = "GlueVersion",
            .code_gen_configuration_nodes = "CodeGenConfigurationNodes",
            .execution_class = "ExecutionClass",
            .source_control_details = "SourceControlDetails",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_arguments", field_name))
            return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
        if (std.mem.eql(u8, "non_overridable_arguments", field_name))
            return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
        if (std.mem.eql(u8, "code_gen_configuration_nodes", field_name))
            return try serializeMap(self.code_gen_configuration_nodes, self.fieldNameFor("code_gen_configuration_nodes"), options, out_stream);
        return false;
    }
};

pub const DevEndpoint = struct {
    endpoint_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_id: ?[]const u8 = null,
    yarn_endpoint_address: ?[]const u8 = null,
    private_address: ?[]const u8 = null,
    zeppelin_remote_spark_interpreter_port: ?i64 = null,
    public_address: ?[]const u8 = null,
    status: ?[]const u8 = null,
    worker_type: ?[]const u8 = null,
    glue_version: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    number_of_nodes: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    extra_python_libs_s3_path: ?[]const u8 = null,
    extra_jars_s3_path: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    last_update_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    last_modified_timestamp: ?i64 = null,
    public_key: ?[]const u8 = null,
    public_keys: ?[][]const u8 = null,
    security_configuration: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_name = "EndpointName",
            .role_arn = "RoleArn",
            .security_group_ids = "SecurityGroupIds",
            .subnet_id = "SubnetId",
            .yarn_endpoint_address = "YarnEndpointAddress",
            .private_address = "PrivateAddress",
            .zeppelin_remote_spark_interpreter_port = "ZeppelinRemoteSparkInterpreterPort",
            .public_address = "PublicAddress",
            .status = "Status",
            .worker_type = "WorkerType",
            .glue_version = "GlueVersion",
            .number_of_workers = "NumberOfWorkers",
            .number_of_nodes = "NumberOfNodes",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
            .extra_jars_s3_path = "ExtraJarsS3Path",
            .failure_reason = "FailureReason",
            .last_update_status = "LastUpdateStatus",
            .created_timestamp = "CreatedTimestamp",
            .last_modified_timestamp = "LastModifiedTimestamp",
            .public_key = "PublicKey",
            .public_keys = "PublicKeys",
            .security_configuration = "SecurityConfiguration",
            .arguments = "Arguments",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const DataQualityObservation = struct {
    description: ?[]const u8 = null,
    metric_based_observation: ?MetricBasedObservation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .metric_based_observation = "MetricBasedObservation",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricBasedObservation = struct {
    metric_name: ?[]const u8 = null,
    metric_values: ?DataQualityMetricValues = null,
    new_rules: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .metric_values = "MetricValues",
            .new_rules = "NewRules",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualityMetricValues = struct {
    actual_value: ?f64 = null,
    expected_value: ?f64 = null,
    lower_limit: ?f64 = null,
    upper_limit: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actual_value = "ActualValue",
            .expected_value = "ExpectedValue",
            .lower_limit = "LowerLimit",
            .upper_limit = "UpperLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualityAnalyzerResult = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    evaluation_message: ?[]const u8 = null,
    evaluated_metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .evaluation_message = "EvaluationMessage",
            .evaluated_metrics = "EvaluatedMetrics",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "evaluated_metrics", field_name))
            return try serializeMap(self.evaluated_metrics, self.fieldNameFor("evaluated_metrics"), options, out_stream);
        return false;
    }
};

pub const DataQualityRuleResult = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    evaluation_message: ?[]const u8 = null,
    result: ?[]const u8 = null,
    evaluated_metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .evaluation_message = "EvaluationMessage",
            .result = "Result",
            .evaluated_metrics = "EvaluatedMetrics",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "evaluated_metrics", field_name))
            return try serializeMap(self.evaluated_metrics, self.fieldNameFor("evaluated_metrics"), options, out_stream);
        return false;
    }
};

pub const CodeGenEdge = struct {
    source: []const u8,
    target: []const u8,
    target_parameter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .target = "Target",
            .target_parameter = "TargetParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeGenNode = struct {
    id: []const u8,
    node_type: []const u8,
    args: []CodeGenNodeArg,
    line_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .node_type = "NodeType",
            .args = "Args",
            .line_number = "LineNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const Database = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    location_uri: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    create_time: ?i64 = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    target_database: ?DatabaseIdentifier = null,
    catalog_id: ?[]const u8 = null,
    federated_database: ?FederatedDatabase = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .location_uri = "LocationUri",
            .parameters = "Parameters",
            .create_time = "CreateTime",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .target_database = "TargetDatabase",
            .catalog_id = "CatalogId",
            .federated_database = "FederatedDatabase",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Crawler = struct {
    name: ?[]const u8 = null,
    role: ?[]const u8 = null,
    targets: ?CrawlerTargets = null,
    database_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    classifiers: ?[][]const u8 = null,
    recrawl_policy: ?RecrawlPolicy = null,
    schema_change_policy: ?SchemaChangePolicy = null,
    lineage_configuration: ?LineageConfiguration = null,
    state: ?[]const u8 = null,
    table_prefix: ?[]const u8 = null,
    schedule: ?Schedule = null,
    crawl_elapsed_time: ?i64 = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    last_crawl: ?LastCrawlInfo = null,
    version: ?i64 = null,
    configuration: ?[]const u8 = null,
    crawler_security_configuration: ?[]const u8 = null,
    lake_formation_configuration: ?LakeFormationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .role = "Role",
            .targets = "Targets",
            .database_name = "DatabaseName",
            .description = "Description",
            .classifiers = "Classifiers",
            .recrawl_policy = "RecrawlPolicy",
            .schema_change_policy = "SchemaChangePolicy",
            .lineage_configuration = "LineageConfiguration",
            .state = "State",
            .table_prefix = "TablePrefix",
            .schedule = "Schedule",
            .crawl_elapsed_time = "CrawlElapsedTime",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .last_crawl = "LastCrawl",
            .version = "Version",
            .configuration = "Configuration",
            .crawler_security_configuration = "CrawlerSecurityConfiguration",
            .lake_formation_configuration = "LakeFormationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LastCrawlInfo = struct {
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    log_group: ?[]const u8 = null,
    log_stream: ?[]const u8 = null,
    message_prefix: ?[]const u8 = null,
    start_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .error_message = "ErrorMessage",
            .log_group = "LogGroup",
            .log_stream = "LogStream",
            .message_prefix = "MessagePrefix",
            .start_time = "StartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    schedule_expression: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    connection_type: ?[]const u8 = null,
    match_criteria: ?[][]const u8 = null,
    connection_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    physical_connection_requirements: ?PhysicalConnectionRequirements = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    last_updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .connection_type = "ConnectionType",
            .match_criteria = "MatchCriteria",
            .connection_properties = "ConnectionProperties",
            .physical_connection_requirements = "PhysicalConnectionRequirements",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
            .last_updated_by = "LastUpdatedBy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "connection_properties", field_name))
            return try serializeMap(self.connection_properties, self.fieldNameFor("connection_properties"), options, out_stream);
        return false;
    }
};

pub const ColumnStatisticsTaskRun = struct {
    customer_id: ?[]const u8 = null,
    column_statistics_task_run_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    column_name_list: ?[][]const u8 = null,
    catalog_id: ?[]const u8 = null,
    role: ?[]const u8 = null,
    sample_size: ?f64 = null,
    security_configuration: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    worker_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    error_message: ?[]const u8 = null,
    dpu_seconds: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_id = "CustomerId",
            .column_statistics_task_run_id = "ColumnStatisticsTaskRunId",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .column_name_list = "ColumnNameList",
            .catalog_id = "CatalogID",
            .role = "Role",
            .sample_size = "SampleSize",
            .security_configuration = "SecurityConfiguration",
            .number_of_workers = "NumberOfWorkers",
            .worker_type = "WorkerType",
            .status = "Status",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .error_message = "ErrorMessage",
            .dpu_seconds = "DPUSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnError = struct {
    column_name: ?[]const u8 = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const Classifier = struct {
    grok_classifier: ?GrokClassifier = null,
    xml_classifier: ?XMLClassifier = null,
    json_classifier: ?JsonClassifier = null,
    csv_classifier: ?CsvClassifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grok_classifier = "GrokClassifier",
            .xml_classifier = "XMLClassifier",
            .json_classifier = "JsonClassifier",
            .csv_classifier = "CsvClassifier",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvClassifier = struct {
    name: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    delimiter: ?[]const u8 = null,
    quote_symbol: ?[]const u8 = null,
    contains_header: ?[]const u8 = null,
    header: ?[][]const u8 = null,
    disable_value_trimming: ?bool = null,
    allow_single_column: ?bool = null,
    custom_datatype_configured: ?bool = null,
    custom_datatypes: ?[][]const u8 = null,
    serde: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .delimiter = "Delimiter",
            .quote_symbol = "QuoteSymbol",
            .contains_header = "ContainsHeader",
            .header = "Header",
            .disable_value_trimming = "DisableValueTrimming",
            .allow_single_column = "AllowSingleColumn",
            .custom_datatype_configured = "CustomDatatypeConfigured",
            .custom_datatypes = "CustomDatatypes",
            .serde = "Serde",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonClassifier = struct {
    name: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    json_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .json_path = "JsonPath",
        };
        return @field(mappings, field_name);
    }
};

pub const XMLClassifier = struct {
    name: []const u8,
    classification: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    row_tag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .classification = "Classification",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .row_tag = "RowTag",
        };
        return @field(mappings, field_name);
    }
};

pub const GrokClassifier = struct {
    name: []const u8,
    classification: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    grok_pattern: []const u8,
    custom_patterns: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .classification = "Classification",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .grok_pattern = "GrokPattern",
            .custom_patterns = "CustomPatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const BlueprintRun = struct {
    blueprint_name: ?[]const u8 = null,
    run_id: ?[]const u8 = null,
    workflow_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,
    error_message: ?[]const u8 = null,
    rollback_error_message: ?[]const u8 = null,
    parameters: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blueprint_name = "BlueprintName",
            .run_id = "RunId",
            .workflow_name = "WorkflowName",
            .state = "State",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
            .error_message = "ErrorMessage",
            .rollback_error_message = "RollbackErrorMessage",
            .parameters = "Parameters",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Blueprint = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    parameter_spec: ?[]const u8 = null,
    blueprint_location: ?[]const u8 = null,
    blueprint_service_location: ?[]const u8 = null,
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    last_active_definition: ?LastActiveDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .created_on = "CreatedOn",
            .last_modified_on = "LastModifiedOn",
            .parameter_spec = "ParameterSpec",
            .blueprint_location = "BlueprintLocation",
            .blueprint_service_location = "BlueprintServiceLocation",
            .status = "Status",
            .error_message = "ErrorMessage",
            .last_active_definition = "LastActiveDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const LastActiveDefinition = struct {
    description: ?[]const u8 = null,
    last_modified_on: ?i64 = null,
    parameter_spec: ?[]const u8 = null,
    blueprint_location: ?[]const u8 = null,
    blueprint_service_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .last_modified_on = "LastModifiedOn",
            .parameter_spec = "ParameterSpec",
            .blueprint_location = "BlueprintLocation",
            .blueprint_service_location = "BlueprintServiceLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionIndex = struct {
    keys: [][]const u8,
    index_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keys = "Keys",
            .index_name = "IndexName",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionError = struct {
    partition_values: ?[][]const u8 = null,
    error_detail: ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partition_values = "PartitionValues",
            .error_detail = "ErrorDetail",
        };
        return @field(mappings, field_name);
    }
};
