const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-05-28";
pub const sdk_id: []const u8 = "IoT";
pub const arn_namespace: ?[]const u8 = "iot";
pub const endpoint_prefix: []const u8 = "iot";
pub const sigv4_name: []const u8 = "iot";
pub const name: []const u8 = "AWSIotService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-05-28",
    sdk_id: []const u8 = "IoT",
    arn_namespace: ?[]const u8 = "iot",
    endpoint_prefix: []const u8 = "iot",
    sigv4_name: []const u8 = "iot",
    name: []const u8 = "AWSIotService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_certificate_transfer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/accept-certificate-transfer/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptCertificateTransfer",
    Request: type = struct {
        certificate_id: []const u8,
        set_as_active: ?bool = null,

        pub const http_query = .{
            .set_as_active = "setAsActive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .set_as_active = "setAsActive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_certificate_transfer) } {
            return .{ .service_metadata = service_metadata, .action = accept_certificate_transfer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        TransferAlreadyCompleted,
        Unauthorized,
    },
} = .{};
pub const add_thing_to_billing_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/billing-groups/addThingToBillingGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "AddThingToBillingGroup",
    Request: type = struct {
        billing_group_name: ?[]const u8 = null,
        billing_group_arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_arn = "billingGroupArn",
                .thing_name = "thingName",
                .thing_arn = "thingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_thing_to_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = add_thing_to_billing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const add_thing_to_thing_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/thing-groups/addThingToThingGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "AddThingToThingGroup",
    Request: type = struct {
        thing_group_name: ?[]const u8 = null,
        thing_group_arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,
        override_dynamic_groups: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_arn = "thingGroupArn",
                .thing_name = "thingName",
                .thing_arn = "thingArn",
                .override_dynamic_groups = "overrideDynamicGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_thing_to_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = add_thing_to_thing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_targets_with_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs/{jobId}/targets",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateTargetsWithJob",
    Request: type = struct {
        targets: [][]const u8,
        job_id: []const u8,
        comment: ?[]const u8 = null,
        namespace_id: ?[]const u8 = null,

        pub const http_query = .{
            .namespace_id = "namespaceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "targets",
                .job_id = "jobId",
                .comment = "comment",
                .namespace_id = "namespaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_targets_with_job) } {
            return .{ .service_metadata = service_metadata, .action = associate_targets_with_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_id = "jobId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const attach_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/target-policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachPolicy",
    Request: type = struct {
        policy_name: []const u8,
        target: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_policy) } {
            return .{ .service_metadata = service_metadata, .action = attach_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const attach_principal_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/principal-policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachPrincipalPolicy",
    Request: type = struct {
        policy_name: []const u8,
        principal: []const u8,
        pub const http_header = .{
            .principal = "x-amzn-iot-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .principal = "principal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_principal_policy) } {
            return .{ .service_metadata = service_metadata, .action = attach_principal_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const attach_security_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/security-profiles/{securityProfileName}/targets",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        security_profile_target_arn: []const u8,

        pub const http_query = .{
            .security_profile_target_arn = "securityProfileTargetArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_target_arn = "securityProfileTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = attach_security_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const attach_thing_principal: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/things/{thingName}/principals",
        .success_code = 200,
    };

    action_name: []const u8 = "AttachThingPrincipal",
    Request: type = struct {
        thing_name: []const u8,
        principal: []const u8,
        pub const http_header = .{
            .principal = "x-amzn-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .principal = "principal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_thing_principal) } {
            return .{ .service_metadata = service_metadata, .action = attach_thing_principal };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const cancel_audit_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/audit/mitigationactions/tasks/{taskId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelAuditMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_audit_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_audit_mitigation_actions_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_audit_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/audit/tasks/{taskId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelAuditTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_audit_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_audit_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_certificate_transfer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/cancel-certificate-transfer/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelCertificateTransfer",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_certificate_transfer) } {
            return .{ .service_metadata = service_metadata, .action = cancel_certificate_transfer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        TransferAlreadyCompleted,
        Unauthorized,
    },
} = .{};
pub const cancel_detect_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/detect/mitigationactions/tasks/{taskId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelDetectMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_detect_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_detect_mitigation_actions_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/jobs/{jobId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        job_id: []const u8,
        reason_code: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        force: ?bool = null,

        pub const http_query = .{
            .force = "force",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .reason_code = "reasonCode",
                .comment = "comment",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_id = "jobId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const cancel_job_execution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/things/{thingName}/jobs/{jobId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJobExecution",
    Request: type = struct {
        job_id: []const u8,
        thing_name: []const u8,
        force: ?bool = null,
        expected_version: ?i64 = null,
        status_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub const http_query = .{
            .force = "force",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .thing_name = "thingName",
                .force = "force",
                .expected_version = "expectedVersion",
                .status_details = "statusDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status_details", field_name))
                return try serializeMap(self.status_details, self.fieldNameFor("status_details"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        InvalidStateTransition,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const clear_default_authorizer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/default-authorizer",
        .success_code = 200,
    };

    action_name: []const u8 = "ClearDefaultAuthorizer",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(clear_default_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = clear_default_authorizer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const confirm_topic_rule_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/confirmdestination/{confirmationToken+}",
        .success_code = 200,
    };

    action_name: []const u8 = "ConfirmTopicRuleDestination",
    Request: type = struct {
        confirmation_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .confirmation_token = "confirmationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_topic_rule_destination) } {
            return .{ .service_metadata = service_metadata, .action = confirm_topic_rule_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const create_audit_suppression: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/suppressions/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAuditSuppression",
    Request: type = struct {
        check_name: []const u8,
        resource_identifier: ResourceIdentifier,
        expiration_date: ?i64 = null,
        suppress_indefinitely: ?bool = null,
        description: ?[]const u8 = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
                .expiration_date = "expirationDate",
                .suppress_indefinitely = "suppressIndefinitely",
                .description = "description",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_audit_suppression) } {
            return .{ .service_metadata = service_metadata, .action = create_audit_suppression };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/authorizer/{authorizerName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,
        authorizer_function_arn: []const u8,
        token_key_name: ?[]const u8 = null,
        token_signing_public_keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        tags: ?[]Tag = null,
        signing_disabled: ?bool = null,
        enable_caching_for_http: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .authorizer_function_arn = "authorizerFunctionArn",
                .token_key_name = "tokenKeyName",
                .token_signing_public_keys = "tokenSigningPublicKeys",
                .status = "status",
                .tags = "tags",
                .signing_disabled = "signingDisabled",
                .enable_caching_for_http = "enableCachingForHttp",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "token_signing_public_keys", field_name))
                return try serializeMap(self.token_signing_public_keys, self.fieldNameFor("token_signing_public_keys"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = create_authorizer };
        }
    },
    Response: type = struct {
        authorizer_name: ?[]const u8 = null,
        authorizer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .authorizer_arn = "authorizerArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_billing_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/billing-groups/{billingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBillingGroup",
    Request: type = struct {
        billing_group_name: []const u8,
        billing_group_properties: ?BillingGroupProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_properties = "billingGroupProperties",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = create_billing_group };
        }
    },
    Response: type = struct {
        billing_group_name: ?[]const u8 = null,
        billing_group_arn: ?[]const u8 = null,
        billing_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_arn = "billingGroupArn",
                .billing_group_id = "billingGroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_certificate_from_csr: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/certificates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCertificateFromCsr",
    Request: type = struct {
        certificate_signing_request: []const u8,
        set_as_active: ?bool = null,

        pub const http_query = .{
            .set_as_active = "setAsActive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_signing_request = "certificateSigningRequest",
                .set_as_active = "setAsActive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_certificate_from_csr) } {
            return .{ .service_metadata = service_metadata, .action = create_certificate_from_csr };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate_id: ?[]const u8 = null,
        certificate_pem: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "certificateArn",
                .certificate_id = "certificateId",
                .certificate_pem = "certificatePem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_certificate_provider: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/certificate-providers/{certificateProviderName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCertificateProvider",
    Request: type = struct {
        certificate_provider_name: []const u8,
        lambda_function_arn: []const u8,
        account_default_for_operations: [][]const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
                .lambda_function_arn = "lambdaFunctionArn",
                .account_default_for_operations = "accountDefaultForOperations",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_certificate_provider) } {
            return .{ .service_metadata = service_metadata, .action = create_certificate_provider };
        }
    },
    Response: type = struct {
        certificate_provider_name: ?[]const u8 = null,
        certificate_provider_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
                .certificate_provider_arn = "certificateProviderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_custom_metric: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/custom-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCustomMetric",
    Request: type = struct {
        metric_name: []const u8,
        display_name: ?[]const u8 = null,
        metric_type: []const u8,
        tags: ?[]Tag = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .display_name = "displayName",
                .metric_type = "metricType",
                .tags = "tags",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_metric) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_metric };
        }
    },
    Response: type = struct {
        metric_name: ?[]const u8 = null,
        metric_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .metric_arn = "metricArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_dimension: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/dimensions/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDimension",
    Request: type = struct {
        name: []const u8,
        type: []const u8,
        string_values: [][]const u8,
        tags: ?[]Tag = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .type = "type",
                .string_values = "stringValues",
                .tags = "tags",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dimension) } {
            return .{ .service_metadata = service_metadata, .action = create_dimension };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_domain_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domainConfigurations/{domainConfigurationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomainConfiguration",
    Request: type = struct {
        domain_configuration_name: []const u8,
        domain_name: ?[]const u8 = null,
        server_certificate_arns: ?[][]const u8 = null,
        validation_certificate_arn: ?[]const u8 = null,
        authorizer_config: ?AuthorizerConfig = null,
        service_type: ?[]const u8 = null,
        tags: ?[]Tag = null,
        tls_config: ?TlsConfig = null,
        server_certificate_config: ?ServerCertificateConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
                .domain_name = "domainName",
                .server_certificate_arns = "serverCertificateArns",
                .validation_certificate_arn = "validationCertificateArn",
                .authorizer_config = "authorizerConfig",
                .service_type = "serviceType",
                .tags = "tags",
                .tls_config = "tlsConfig",
                .server_certificate_config = "serverCertificateConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_domain_configuration };
        }
    },
    Response: type = struct {
        domain_configuration_name: ?[]const u8 = null,
        domain_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
                .domain_configuration_arn = "domainConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_dynamic_thing_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/dynamic-thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDynamicThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        thing_group_properties: ?ThingGroupProperties = null,
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        query_version: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_properties = "thingGroupProperties",
                .index_name = "indexName",
                .query_string = "queryString",
                .query_version = "queryVersion",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dynamic_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = create_dynamic_thing_group };
        }
    },
    Response: type = struct {
        thing_group_name: ?[]const u8 = null,
        thing_group_arn: ?[]const u8 = null,
        thing_group_id: ?[]const u8 = null,
        index_name: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_arn = "thingGroupArn",
                .thing_group_id = "thingGroupId",
                .index_name = "indexName",
                .query_string = "queryString",
                .query_version = "queryVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidQuery,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_fleet_metric: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/fleet-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFleetMetric",
    Request: type = struct {
        metric_name: []const u8,
        query_string: []const u8,
        aggregation_type: AggregationType,
        period: i64,
        aggregation_field: []const u8,
        description: ?[]const u8 = null,
        query_version: ?[]const u8 = null,
        index_name: ?[]const u8 = null,
        unit: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .query_string = "queryString",
                .aggregation_type = "aggregationType",
                .period = "period",
                .aggregation_field = "aggregationField",
                .description = "description",
                .query_version = "queryVersion",
                .index_name = "indexName",
                .unit = "unit",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet_metric) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet_metric };
        }
    },
    Response: type = struct {
        metric_name: ?[]const u8 = null,
        metric_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .metric_arn = "metricArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        job_id: []const u8,
        targets: [][]const u8,
        document_source: ?[]const u8 = null,
        document: ?[]const u8 = null,
        description: ?[]const u8 = null,
        presigned_url_config: ?PresignedUrlConfig = null,
        target_selection: ?[]const u8 = null,
        job_executions_rollout_config: ?JobExecutionsRolloutConfig = null,
        abort_config: ?AbortConfig = null,
        timeout_config: ?TimeoutConfig = null,
        tags: ?[]Tag = null,
        namespace_id: ?[]const u8 = null,
        job_template_arn: ?[]const u8 = null,
        job_executions_retry_config: ?JobExecutionsRetryConfig = null,
        document_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        scheduling_config: ?SchedulingConfig = null,
        destination_package_versions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .targets = "targets",
                .document_source = "documentSource",
                .document = "document",
                .description = "description",
                .presigned_url_config = "presignedUrlConfig",
                .target_selection = "targetSelection",
                .job_executions_rollout_config = "jobExecutionsRolloutConfig",
                .abort_config = "abortConfig",
                .timeout_config = "timeoutConfig",
                .tags = "tags",
                .namespace_id = "namespaceId",
                .job_template_arn = "jobTemplateArn",
                .job_executions_retry_config = "jobExecutionsRetryConfig",
                .document_parameters = "documentParameters",
                .scheduling_config = "schedulingConfig",
                .destination_package_versions = "destinationPackageVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "document_parameters", field_name))
                return try serializeMap(self.document_parameters, self.fieldNameFor("document_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_id = "jobId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_job_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/job-templates/{jobTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJobTemplate",
    Request: type = struct {
        job_template_id: []const u8,
        job_arn: ?[]const u8 = null,
        document_source: ?[]const u8 = null,
        document: ?[]const u8 = null,
        description: []const u8,
        presigned_url_config: ?PresignedUrlConfig = null,
        job_executions_rollout_config: ?JobExecutionsRolloutConfig = null,
        abort_config: ?AbortConfig = null,
        timeout_config: ?TimeoutConfig = null,
        tags: ?[]Tag = null,
        job_executions_retry_config: ?JobExecutionsRetryConfig = null,
        maintenance_windows: ?[]MaintenanceWindow = null,
        destination_package_versions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template_id = "jobTemplateId",
                .job_arn = "jobArn",
                .document_source = "documentSource",
                .document = "document",
                .description = "description",
                .presigned_url_config = "presignedUrlConfig",
                .job_executions_rollout_config = "jobExecutionsRolloutConfig",
                .abort_config = "abortConfig",
                .timeout_config = "timeoutConfig",
                .tags = "tags",
                .job_executions_retry_config = "jobExecutionsRetryConfig",
                .maintenance_windows = "maintenanceWindows",
                .destination_package_versions = "destinationPackageVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_template) } {
            return .{ .service_metadata = service_metadata, .action = create_job_template };
        }
    },
    Response: type = struct {
        job_template_arn: ?[]const u8 = null,
        job_template_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template_arn = "jobTemplateArn",
                .job_template_id = "jobTemplateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_keys_and_certificate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/keys-and-certificate",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateKeysAndCertificate",
    Request: type = struct {
        set_as_active: ?bool = null,

        pub const http_query = .{
            .set_as_active = "setAsActive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .set_as_active = "setAsActive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_keys_and_certificate) } {
            return .{ .service_metadata = service_metadata, .action = create_keys_and_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate_id: ?[]const u8 = null,
        certificate_pem: ?[]const u8 = null,
        key_pair: ?KeyPair = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "certificateArn",
                .certificate_id = "certificateId",
                .certificate_pem = "certificatePem",
                .key_pair = "keyPair",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_mitigation_action: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/mitigationactions/actions/{actionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMitigationAction",
    Request: type = struct {
        action_name: []const u8,
        role_arn: []const u8,
        action_params: MitigationActionParams,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "actionName",
                .role_arn = "roleArn",
                .action_params = "actionParams",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_mitigation_action) } {
            return .{ .service_metadata = service_metadata, .action = create_mitigation_action };
        }
    },
    Response: type = struct {
        action_arn: ?[]const u8 = null,
        action_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_arn = "actionArn",
                .action_id = "actionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_ota_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/otaUpdates/{otaUpdateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOTAUpdate",
    Request: type = struct {
        ota_update_id: []const u8,
        description: ?[]const u8 = null,
        targets: [][]const u8,
        protocols: ?[][]const u8 = null,
        target_selection: ?[]const u8 = null,
        aws_job_executions_rollout_config: ?AwsJobExecutionsRolloutConfig = null,
        aws_job_presigned_url_config: ?AwsJobPresignedUrlConfig = null,
        aws_job_abort_config: ?struct {
            abort_criteria_list: []struct {
                failure_type: []const u8,
                action: []const u8,
                threshold_percentage: f64,
                min_number_of_executed_things: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .failure_type = "failureType",
                        .action = "action",
                        .threshold_percentage = "thresholdPercentage",
                        .min_number_of_executed_things = "minNumberOfExecutedThings",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .abort_criteria_list = "abortCriteriaList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        aws_job_timeout_config: ?struct {
            in_progress_timeout_in_minutes: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .in_progress_timeout_in_minutes = "inProgressTimeoutInMinutes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        files: []OTAUpdateFile,
        role_arn: []const u8,
        additional_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_update_id = "otaUpdateId",
                .description = "description",
                .targets = "targets",
                .protocols = "protocols",
                .target_selection = "targetSelection",
                .aws_job_executions_rollout_config = "awsJobExecutionsRolloutConfig",
                .aws_job_presigned_url_config = "awsJobPresignedUrlConfig",
                .aws_job_abort_config = "awsJobAbortConfig",
                .aws_job_timeout_config = "awsJobTimeoutConfig",
                .files = "files",
                .role_arn = "roleArn",
                .additional_parameters = "additionalParameters",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_parameters", field_name))
                return try serializeMap(self.additional_parameters, self.fieldNameFor("additional_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ota_update) } {
            return .{ .service_metadata = service_metadata, .action = create_ota_update };
        }
    },
    Response: type = struct {
        ota_update_id: ?[]const u8 = null,
        aws_iot_job_id: ?[]const u8 = null,
        ota_update_arn: ?[]const u8 = null,
        aws_iot_job_arn: ?[]const u8 = null,
        ota_update_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_update_id = "otaUpdateId",
                .aws_iot_job_id = "awsIotJobId",
                .ota_update_arn = "otaUpdateArn",
                .aws_iot_job_arn = "awsIotJobArn",
                .ota_update_status = "otaUpdateStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_package: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/packages/{packageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackage",
    Request: type = struct {
        package_name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .description = "description",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package) } {
            return .{ .service_metadata = service_metadata, .action = create_package };
        }
    },
    Response: type = struct {
        package_name: ?[]const u8 = null,
        package_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .package_arn = "packageArn",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_package_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/packages/{packageName}/versions/{versionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackageVersion",
    Request: type = struct {
        package_name: []const u8,
        version_name: []const u8,
        description: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .version_name = "versionName",
                .description = "description",
                .attributes = "attributes",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package_version) } {
            return .{ .service_metadata = service_metadata, .action = create_package_version };
        }
    },
    Response: type = struct {
        package_version_arn: ?[]const u8 = null,
        package_name: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        error_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_version_arn = "packageVersionArn",
                .package_name = "packageName",
                .version_name = "versionName",
                .description = "description",
                .attributes = "attributes",
                .status = "status",
                .error_reason = "errorReason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePolicy",
    Request: type = struct {
        policy_name: []const u8,
        policy_document: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_document = "policyDocument",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_policy };
        }
    },
    Response: type = struct {
        policy_name: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        policy_version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_arn = "policyArn",
                .policy_document = "policyDocument",
                .policy_version_id = "policyVersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MalformedPolicy,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_policy_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policies/{policyName}/version",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePolicyVersion",
    Request: type = struct {
        policy_name: []const u8,
        policy_document: []const u8,
        set_as_default: ?bool = null,

        pub const http_query = .{
            .set_as_default = "setAsDefault",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_document = "policyDocument",
                .set_as_default = "setAsDefault",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = create_policy_version };
        }
    },
    Response: type = struct {
        policy_arn: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        policy_version_id: ?[]const u8 = null,
        is_default_version: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
                .policy_document = "policyDocument",
                .policy_version_id = "policyVersionId",
                .is_default_version = "isDefaultVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        MalformedPolicy,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionsLimitExceeded,
    },
} = .{};
pub const create_provisioning_claim: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/provisioning-templates/{templateName}/provisioning-claim",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProvisioningClaim",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_provisioning_claim) } {
            return .{ .service_metadata = service_metadata, .action = create_provisioning_claim };
        }
    },
    Response: type = struct {
        certificate_id: ?[]const u8 = null,
        certificate_pem: ?[]const u8 = null,
        key_pair: ?KeyPair = null,
        expiration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .certificate_pem = "certificatePem",
                .key_pair = "keyPair",
                .expiration = "expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_provisioning_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/provisioning-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProvisioningTemplate",
    Request: type = struct {
        template_name: []const u8,
        description: ?[]const u8 = null,
        template_body: []const u8,
        enabled: ?bool = null,
        provisioning_role_arn: []const u8,
        pre_provisioning_hook: ?ProvisioningHook = null,
        tags: ?[]Tag = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .description = "description",
                .template_body = "templateBody",
                .enabled = "enabled",
                .provisioning_role_arn = "provisioningRoleArn",
                .pre_provisioning_hook = "preProvisioningHook",
                .tags = "tags",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_provisioning_template) } {
            return .{ .service_metadata = service_metadata, .action = create_provisioning_template };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        default_version_id: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "templateArn",
                .template_name = "templateName",
                .default_version_id = "defaultVersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_provisioning_template_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/provisioning-templates/{templateName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProvisioningTemplateVersion",
    Request: type = struct {
        template_name: []const u8,
        template_body: []const u8,
        set_as_default: ?bool = null,

        pub const http_query = .{
            .set_as_default = "setAsDefault",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .template_body = "templateBody",
                .set_as_default = "setAsDefault",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_provisioning_template_version) } {
            return .{ .service_metadata = service_metadata, .action = create_provisioning_template_version };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        version_id: ?i64 = null,
        is_default_version: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "templateArn",
                .template_name = "templateName",
                .version_id = "versionId",
                .is_default_version = "isDefaultVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
        VersionsLimitExceeded,
    },
} = .{};
pub const create_role_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/role-aliases/{roleAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoleAlias",
    Request: type = struct {
        role_alias: []const u8,
        role_arn: []const u8,
        credential_duration_seconds: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
                .role_arn = "roleArn",
                .credential_duration_seconds = "credentialDurationSeconds",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_role_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_role_alias };
        }
    },
    Response: type = struct {
        role_alias: ?[]const u8 = null,
        role_alias_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
                .role_alias_arn = "roleAliasArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_scheduled_audit: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/scheduledaudits/{scheduledAuditName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateScheduledAudit",
    Request: type = struct {
        frequency: []const u8,
        day_of_month: ?[]const u8 = null,
        day_of_week: ?[]const u8 = null,
        target_check_names: [][]const u8,
        scheduled_audit_name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .frequency = "frequency",
                .day_of_month = "dayOfMonth",
                .day_of_week = "dayOfWeek",
                .target_check_names = "targetCheckNames",
                .scheduled_audit_name = "scheduledAuditName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scheduled_audit) } {
            return .{ .service_metadata = service_metadata, .action = create_scheduled_audit };
        }
    },
    Response: type = struct {
        scheduled_audit_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_audit_arn = "scheduledAuditArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_security_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/security-profiles/{securityProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        security_profile_description: ?[]const u8 = null,
        behaviors: ?[]Behavior = null,
        alert_targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AlertTarget = null,
        } = null,
        additional_metrics_to_retain: ?[][]const u8 = null,
        additional_metrics_to_retain_v2: ?[]MetricToRetain = null,
        tags: ?[]Tag = null,
        metrics_export_config: ?MetricsExportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_description = "securityProfileDescription",
                .behaviors = "behaviors",
                .alert_targets = "alertTargets",
                .additional_metrics_to_retain = "additionalMetricsToRetain",
                .additional_metrics_to_retain_v2 = "additionalMetricsToRetainV2",
                .tags = "tags",
                .metrics_export_config = "metricsExportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "alert_targets", field_name))
                return try serializeMap(self.alert_targets, self.fieldNameFor("alert_targets"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_security_profile };
        }
    },
    Response: type = struct {
        security_profile_name: ?[]const u8 = null,
        security_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_arn = "securityProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/streams/{streamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStream",
    Request: type = struct {
        stream_id: []const u8,
        description: ?[]const u8 = null,
        files: []StreamFile,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
                .description = "description",
                .files = "files",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_stream };
        }
    },
    Response: type = struct {
        stream_id: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        stream_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
                .stream_arn = "streamArn",
                .description = "description",
                .stream_version = "streamVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_thing: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/things/{thingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThing",
    Request: type = struct {
        thing_name: []const u8,
        thing_type_name: ?[]const u8 = null,
        attribute_payload: ?AttributePayload = null,
        billing_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .thing_type_name = "thingTypeName",
                .attribute_payload = "attributePayload",
                .billing_group_name = "billingGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_thing) } {
            return .{ .service_metadata = service_metadata, .action = create_thing };
        }
    },
    Response: type = struct {
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,
        thing_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .thing_arn = "thingArn",
                .thing_id = "thingId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_thing_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        parent_group_name: ?[]const u8 = null,
        thing_group_properties: ?ThingGroupProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .parent_group_name = "parentGroupName",
                .thing_group_properties = "thingGroupProperties",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = create_thing_group };
        }
    },
    Response: type = struct {
        thing_group_name: ?[]const u8 = null,
        thing_group_arn: ?[]const u8 = null,
        thing_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_arn = "thingGroupArn",
                .thing_group_id = "thingGroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_thing_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/thing-types/{thingTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThingType",
    Request: type = struct {
        thing_type_name: []const u8,
        thing_type_properties: ?ThingTypeProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
                .thing_type_properties = "thingTypeProperties",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_thing_type) } {
            return .{ .service_metadata = service_metadata, .action = create_thing_type };
        }
    },
    Response: type = struct {
        thing_type_name: ?[]const u8 = null,
        thing_type_arn: ?[]const u8 = null,
        thing_type_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
                .thing_type_arn = "thingTypeArn",
                .thing_type_id = "thingTypeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const create_topic_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rules/{ruleName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTopicRule",
    Request: type = struct {
        rule_name: []const u8,
        topic_rule_payload: TopicRulePayload,
        tags: ?[]const u8 = null,
        pub const http_header = .{
            .tags = "x-amz-tagging",
        };

        pub const http_payload: []const u8 = "topic_rule_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
                .topic_rule_payload = "topicRulePayload",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_topic_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
        SqlParse,
    },
} = .{};
pub const create_topic_rule_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTopicRuleDestination",
    Request: type = struct {
        destination_configuration: struct {
            http_url_configuration: ?struct {
                confirmation_url: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .confirmation_url = "confirmationUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vpc_configuration: ?struct {
                subnet_ids: [][]const u8,
                security_groups: ?[][]const u8 = null,
                vpc_id: []const u8,
                role_arn: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .subnet_ids = "subnetIds",
                        .security_groups = "securityGroups",
                        .vpc_id = "vpcId",
                        .role_arn = "roleArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .http_url_configuration = "httpUrlConfiguration",
                    .vpc_configuration = "vpcConfiguration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_configuration = "destinationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_topic_rule_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_topic_rule_destination };
        }
    },
    Response: type = struct {
        topic_rule_destination: ?TopicRuleDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_rule_destination = "topicRuleDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
    },
} = .{};
pub const delete_account_audit_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/audit/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccountAuditConfiguration",
    Request: type = struct {
        delete_scheduled_audits: ?bool = null,

        pub const http_query = .{
            .delete_scheduled_audits = "deleteScheduledAudits",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delete_scheduled_audits = "deleteScheduledAudits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_audit_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_audit_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_audit_suppression: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/suppressions/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAuditSuppression",
    Request: type = struct {
        check_name: []const u8,
        resource_identifier: ResourceIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_audit_suppression) } {
            return .{ .service_metadata = service_metadata, .action = delete_audit_suppression };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const delete_authorizer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/authorizer/{authorizerName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = delete_authorizer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_billing_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/billing-groups/{billingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBillingGroup",
    Request: type = struct {
        billing_group_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_billing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const delete_ca_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cacertificate/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCACertificate",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ca_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_ca_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateState,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/certificates/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCertificate",
    Request: type = struct {
        certificate_id: []const u8,
        force_delete: ?bool = null,

        pub const http_query = .{
            .force_delete = "forceDelete",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .force_delete = "forceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CertificateState,
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_certificate_provider: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/certificate-providers/{certificateProviderName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCertificateProvider",
    Request: type = struct {
        certificate_provider_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate_provider) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate_provider };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_custom_metric: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/custom-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCustomMetric",
    Request: type = struct {
        metric_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_metric) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_metric };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const delete_dimension: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/dimensions/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDimension",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dimension) } {
            return .{ .service_metadata = service_metadata, .action = delete_dimension };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const delete_domain_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domainConfigurations/{domainConfigurationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomainConfiguration",
    Request: type = struct {
        domain_configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_dynamic_thing_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/dynamic-thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDynamicThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dynamic_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_dynamic_thing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const delete_fleet_metric: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/fleet-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFleetMetric",
    Request: type = struct {
        metric_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet_metric) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet_metric };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionConflict,
    },
} = .{};
pub const delete_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJob",
    Request: type = struct {
        job_id: []const u8,
        force: ?bool = null,
        namespace_id: ?[]const u8 = null,

        pub const http_query = .{
            .force = "force",
            .namespace_id = "namespaceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .force = "force",
                .namespace_id = "namespaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        InvalidStateTransition,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_job_execution: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/things/{thingName}/jobs/{jobId}/executionNumber/{executionNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobExecution",
    Request: type = struct {
        job_id: []const u8,
        thing_name: []const u8,
        execution_number: i64,
        force: ?bool = null,
        namespace_id: ?[]const u8 = null,

        pub const http_query = .{
            .force = "force",
            .namespace_id = "namespaceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .thing_name = "thingName",
                .execution_number = "executionNumber",
                .force = "force",
                .namespace_id = "namespaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        InvalidStateTransition,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_job_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/job-templates/{jobTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobTemplate",
    Request: type = struct {
        job_template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template_id = "jobTemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_mitigation_action: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/mitigationactions/actions/{actionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMitigationAction",
    Request: type = struct {
        action_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "actionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mitigation_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_mitigation_action };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const delete_ota_update: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/otaUpdates/{otaUpdateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteOTAUpdate",
    Request: type = struct {
        ota_update_id: []const u8,
        delete_stream: ?bool = null,
        force_delete_aws_job: ?bool = null,

        pub const http_query = .{
            .delete_stream = "deleteStream",
            .force_delete_aws_job = "forceDeleteAWSJob",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_update_id = "otaUpdateId",
                .delete_stream = "deleteStream",
                .force_delete_aws_job = "forceDeleteAWSJob",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ota_update) } {
            return .{ .service_metadata = service_metadata, .action = delete_ota_update };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionConflict,
    },
} = .{};
pub const delete_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packages/{packageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackage",
    Request: type = struct {
        package_name: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_package };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_package_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packages/{packageName}/versions/{versionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackageVersion",
    Request: type = struct {
        package_name: []const u8,
        version_name: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .version_name = "versionName",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_package_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePolicy",
    Request: type = struct {
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_policy_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policies/{policyName}/version/{policyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePolicyVersion",
    Request: type = struct {
        policy_name: []const u8,
        policy_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_version_id = "policyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_policy_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_provisioning_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/provisioning-templates/{templateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProvisioningTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_provisioning_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_provisioning_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_provisioning_template_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/provisioning-templates/{templateName}/versions/{versionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProvisioningTemplateVersion",
    Request: type = struct {
        template_name: []const u8,
        version_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_provisioning_template_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_provisioning_template_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_registration_code: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/registrationcode",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRegistrationCode",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registration_code) } {
            return .{ .service_metadata = service_metadata, .action = delete_registration_code };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_role_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/role-aliases/{roleAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoleAlias",
    Request: type = struct {
        role_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_role_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_role_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_scheduled_audit: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/audit/scheduledaudits/{scheduledAuditName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteScheduledAudit",
    Request: type = struct {
        scheduled_audit_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_audit_name = "scheduledAuditName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scheduled_audit) } {
            return .{ .service_metadata = service_metadata, .action = delete_scheduled_audit };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_security_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/security-profiles/{securityProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const delete_stream: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/streams/{streamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStream",
    Request: type = struct {
        stream_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeleteConflict,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_thing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/things/{thingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThing",
    Request: type = struct {
        thing_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thing) } {
            return .{ .service_metadata = service_metadata, .action = delete_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionConflict,
    },
} = .{};
pub const delete_thing_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        expected_version: ?i64 = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_thing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const delete_thing_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/thing-types/{thingTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThingType",
    Request: type = struct {
        thing_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_thing_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_thing_type };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const delete_topic_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/rules/{ruleName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTopicRule",
    Request: type = struct {
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_topic_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_topic_rule_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/destinations/{arn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTopicRuleDestination",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_topic_rule_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_topic_rule_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_v2_logging_level: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2LoggingLevel",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteV2LoggingLevel",
    Request: type = struct {
        target_type: []const u8,
        target_name: []const u8,

        pub const http_query = .{
            .target_type = "targetType",
            .target_name = "targetName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_type = "targetType",
                .target_name = "targetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_v2_logging_level) } {
            return .{ .service_metadata = service_metadata, .action = delete_v2_logging_level };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const deprecate_thing_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/thing-types/{thingTypeName}/deprecate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeprecateThingType",
    Request: type = struct {
        thing_type_name: []const u8,
        undo_deprecate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
                .undo_deprecate = "undoDeprecate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_thing_type) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_thing_type };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_account_audit_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountAuditConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_audit_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_audit_configuration };
        }
    },
    Response: type = struct {
        role_arn: ?[]const u8 = null,
        audit_notification_target_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AuditNotificationTarget = null,
        } = null,
        audit_check_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AuditCheckConfiguration = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .audit_notification_target_configurations = "auditNotificationTargetConfigurations",
                .audit_check_configurations = "auditCheckConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "audit_notification_target_configurations", field_name))
                return try serializeMap(self.audit_notification_target_configurations, self.fieldNameFor("audit_notification_target_configurations"), options, out_stream);
            if (std.mem.eql(u8, "audit_check_configurations", field_name))
                return try serializeMap(self.audit_check_configurations, self.fieldNameFor("audit_check_configurations"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        Throttling,
    },
} = .{};
pub const describe_audit_finding: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/findings/{findingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuditFinding",
    Request: type = struct {
        finding_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_id = "findingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_audit_finding) } {
            return .{ .service_metadata = service_metadata, .action = describe_audit_finding };
        }
    },
    Response: type = struct {
        finding: ?AuditFinding = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding = "finding",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_audit_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/mitigationactions/tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuditMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_audit_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_audit_mitigation_actions_task };
        }
    },
    Response: type = struct {
        task_status: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        task_statistics: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                total_findings_count: ?i64 = null,
                failed_findings_count: ?i64 = null,
                succeeded_findings_count: ?i64 = null,
                skipped_findings_count: ?i64 = null,
                canceled_findings_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_findings_count = "totalFindingsCount",
                        .failed_findings_count = "failedFindingsCount",
                        .succeeded_findings_count = "succeededFindingsCount",
                        .skipped_findings_count = "skippedFindingsCount",
                        .canceled_findings_count = "canceledFindingsCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        target: ?AuditMitigationActionsTaskTarget = null,
        audit_check_to_actions_mapping: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        actions_definition: ?[]MitigationAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_status = "taskStatus",
                .start_time = "startTime",
                .end_time = "endTime",
                .task_statistics = "taskStatistics",
                .target = "target",
                .audit_check_to_actions_mapping = "auditCheckToActionsMapping",
                .actions_definition = "actionsDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_statistics", field_name))
                return try serializeMap(self.task_statistics, self.fieldNameFor("task_statistics"), options, out_stream);
            if (std.mem.eql(u8, "audit_check_to_actions_mapping", field_name))
                return try serializeMap(self.audit_check_to_actions_mapping, self.fieldNameFor("audit_check_to_actions_mapping"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_audit_suppression: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/suppressions/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuditSuppression",
    Request: type = struct {
        check_name: []const u8,
        resource_identifier: ResourceIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_audit_suppression) } {
            return .{ .service_metadata = service_metadata, .action = describe_audit_suppression };
        }
    },
    Response: type = struct {
        check_name: ?[]const u8 = null,
        resource_identifier: ?ResourceIdentifier = null,
        expiration_date: ?i64 = null,
        suppress_indefinitely: ?bool = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
                .expiration_date = "expirationDate",
                .suppress_indefinitely = "suppressIndefinitely",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_audit_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuditTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_audit_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_audit_task };
        }
    },
    Response: type = struct {
        task_status: ?[]const u8 = null,
        task_type: ?[]const u8 = null,
        task_start_time: ?i64 = null,
        task_statistics: ?struct {
            total_checks: ?i64 = null,
            in_progress_checks: ?i64 = null,
            waiting_for_data_collection_checks: ?i64 = null,
            compliant_checks: ?i64 = null,
            non_compliant_checks: ?i64 = null,
            failed_checks: ?i64 = null,
            canceled_checks: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_checks = "totalChecks",
                    .in_progress_checks = "inProgressChecks",
                    .waiting_for_data_collection_checks = "waitingForDataCollectionChecks",
                    .compliant_checks = "compliantChecks",
                    .non_compliant_checks = "nonCompliantChecks",
                    .failed_checks = "failedChecks",
                    .canceled_checks = "canceledChecks",
                };
                return @field(mappings, field_name);
            }
        } = null,
        scheduled_audit_name: ?[]const u8 = null,
        audit_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                check_run_status: ?[]const u8 = null,
                check_compliant: ?bool = null,
                total_resources_count: ?i64 = null,
                non_compliant_resources_count: ?i64 = null,
                suppressed_non_compliant_resources_count: ?i64 = null,
                error_code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .check_run_status = "checkRunStatus",
                        .check_compliant = "checkCompliant",
                        .total_resources_count = "totalResourcesCount",
                        .non_compliant_resources_count = "nonCompliantResourcesCount",
                        .suppressed_non_compliant_resources_count = "suppressedNonCompliantResourcesCount",
                        .error_code = "errorCode",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_status = "taskStatus",
                .task_type = "taskType",
                .task_start_time = "taskStartTime",
                .task_statistics = "taskStatistics",
                .scheduled_audit_name = "scheduledAuditName",
                .audit_details = "auditDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "audit_details", field_name))
                return try serializeMap(self.audit_details, self.fieldNameFor("audit_details"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_authorizer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/authorizer/{authorizerName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = describe_authorizer };
        }
    },
    Response: type = struct {
        authorizer_description: ?AuthorizerDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_description = "authorizerDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_billing_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/billing-groups/{billingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBillingGroup",
    Request: type = struct {
        billing_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_billing_group };
        }
    },
    Response: type = struct {
        billing_group_name: ?[]const u8 = null,
        billing_group_id: ?[]const u8 = null,
        billing_group_arn: ?[]const u8 = null,
        version: ?i64 = null,
        billing_group_properties: ?BillingGroupProperties = null,
        billing_group_metadata: ?struct {
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_id = "billingGroupId",
                .billing_group_arn = "billingGroupArn",
                .version = "version",
                .billing_group_properties = "billingGroupProperties",
                .billing_group_metadata = "billingGroupMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_ca_certificate: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cacertificate/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCACertificate",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ca_certificate) } {
            return .{ .service_metadata = service_metadata, .action = describe_ca_certificate };
        }
    },
    Response: type = struct {
        certificate_description: ?struct {
            certificate_arn: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            certificate_pem: ?[]const u8 = null,
            owned_by: ?[]const u8 = null,
            creation_date: ?i64 = null,
            auto_registration_status: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            customer_version: ?i64 = null,
            generation_id: ?[]const u8 = null,
            validity: ?CertificateValidity = null,
            certificate_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "certificateArn",
                    .certificate_id = "certificateId",
                    .status = "status",
                    .certificate_pem = "certificatePem",
                    .owned_by = "ownedBy",
                    .creation_date = "creationDate",
                    .auto_registration_status = "autoRegistrationStatus",
                    .last_modified_date = "lastModifiedDate",
                    .customer_version = "customerVersion",
                    .generation_id = "generationId",
                    .validity = "validity",
                    .certificate_mode = "certificateMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        registration_config: ?RegistrationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_description = "certificateDescription",
                .registration_config = "registrationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_certificate: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificates/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCertificate",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate };
        }
    },
    Response: type = struct {
        certificate_description: ?struct {
            certificate_arn: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            ca_certificate_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            certificate_pem: ?[]const u8 = null,
            owned_by: ?[]const u8 = null,
            previous_owned_by: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,
            customer_version: ?i64 = null,
            transfer_data: ?struct {
                transfer_message: ?[]const u8 = null,
                reject_reason: ?[]const u8 = null,
                transfer_date: ?i64 = null,
                accept_date: ?i64 = null,
                reject_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transfer_message = "transferMessage",
                        .reject_reason = "rejectReason",
                        .transfer_date = "transferDate",
                        .accept_date = "acceptDate",
                        .reject_date = "rejectDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            generation_id: ?[]const u8 = null,
            validity: ?CertificateValidity = null,
            certificate_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "certificateArn",
                    .certificate_id = "certificateId",
                    .ca_certificate_id = "caCertificateId",
                    .status = "status",
                    .certificate_pem = "certificatePem",
                    .owned_by = "ownedBy",
                    .previous_owned_by = "previousOwnedBy",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                    .customer_version = "customerVersion",
                    .transfer_data = "transferData",
                    .generation_id = "generationId",
                    .validity = "validity",
                    .certificate_mode = "certificateMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_description = "certificateDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_certificate_provider: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificate-providers/{certificateProviderName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCertificateProvider",
    Request: type = struct {
        certificate_provider_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate_provider) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate_provider };
        }
    },
    Response: type = struct {
        certificate_provider_name: ?[]const u8 = null,
        certificate_provider_arn: ?[]const u8 = null,
        lambda_function_arn: ?[]const u8 = null,
        account_default_for_operations: ?[][]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
                .certificate_provider_arn = "certificateProviderArn",
                .lambda_function_arn = "lambdaFunctionArn",
                .account_default_for_operations = "accountDefaultForOperations",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_custom_metric: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/custom-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCustomMetric",
    Request: type = struct {
        metric_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_metric) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_metric };
        }
    },
    Response: type = struct {
        metric_name: ?[]const u8 = null,
        metric_arn: ?[]const u8 = null,
        metric_type: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .metric_arn = "metricArn",
                .metric_type = "metricType",
                .display_name = "displayName",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_default_authorizer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/default-authorizer",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDefaultAuthorizer",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_default_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = describe_default_authorizer };
        }
    },
    Response: type = struct {
        authorizer_description: ?AuthorizerDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_description = "authorizerDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_detect_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detect/mitigationactions/tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDetectMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_detect_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_detect_mitigation_actions_task };
        }
    },
    Response: type = struct {
        task_summary: ?DetectMitigationActionsTaskSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_summary = "taskSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_dimension: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dimensions/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDimension",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dimension) } {
            return .{ .service_metadata = service_metadata, .action = describe_dimension };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        type: ?[]const u8 = null,
        string_values: ?[][]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .arn = "arn",
                .type = "type",
                .string_values = "stringValues",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_domain_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainConfigurations/{domainConfigurationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainConfiguration",
    Request: type = struct {
        domain_configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_configuration };
        }
    },
    Response: type = struct {
        domain_configuration_name: ?[]const u8 = null,
        domain_configuration_arn: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        server_certificates: ?[]struct {
            server_certificate_arn: ?[]const u8 = null,
            server_certificate_status: ?[]const u8 = null,
            server_certificate_status_detail: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .server_certificate_arn = "serverCertificateArn",
                    .server_certificate_status = "serverCertificateStatus",
                    .server_certificate_status_detail = "serverCertificateStatusDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        authorizer_config: ?AuthorizerConfig = null,
        domain_configuration_status: ?[]const u8 = null,
        service_type: ?[]const u8 = null,
        domain_type: ?[]const u8 = null,
        last_status_change_date: ?i64 = null,
        tls_config: ?TlsConfig = null,
        server_certificate_config: ?ServerCertificateConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
                .domain_configuration_arn = "domainConfigurationArn",
                .domain_name = "domainName",
                .server_certificates = "serverCertificates",
                .authorizer_config = "authorizerConfig",
                .domain_configuration_status = "domainConfigurationStatus",
                .service_type = "serviceType",
                .domain_type = "domainType",
                .last_status_change_date = "lastStatusChangeDate",
                .tls_config = "tlsConfig",
                .server_certificate_config = "serverCertificateConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/endpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEndpoint",
    Request: type = struct {
        endpoint_type: ?[]const u8 = null,

        pub const http_query = .{
            .endpoint_type = "endpointType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_type = "endpointType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint };
        }
    },
    Response: type = struct {
        endpoint_address: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_address = "endpointAddress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_event_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/event-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEventConfigurations",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_configurations };
        }
    },
    Response: type = struct {
        event_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Configuration = null,
        } = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_configurations = "eventConfigurations",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "event_configurations", field_name))
                return try serializeMap(self.event_configurations, self.fieldNameFor("event_configurations"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        Throttling,
    },
} = .{};
pub const describe_fleet_metric: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/fleet-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFleetMetric",
    Request: type = struct {
        metric_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_metric) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_metric };
        }
    },
    Response: type = struct {
        metric_name: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        aggregation_type: ?AggregationType = null,
        period: ?i64 = null,
        aggregation_field: ?[]const u8 = null,
        description: ?[]const u8 = null,
        query_version: ?[]const u8 = null,
        index_name: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        unit: ?[]const u8 = null,
        version: ?i64 = null,
        metric_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .query_string = "queryString",
                .aggregation_type = "aggregationType",
                .period = "period",
                .aggregation_field = "aggregationField",
                .description = "description",
                .query_version = "queryVersion",
                .index_name = "indexName",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .unit = "unit",
                .version = "version",
                .metric_arn = "metricArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_index: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/indices/{indexName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIndex",
    Request: type = struct {
        index_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_index) } {
            return .{ .service_metadata = service_metadata, .action = describe_index };
        }
    },
    Response: type = struct {
        index_name: ?[]const u8 = null,
        index_status: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .index_status = "indexStatus",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        document_source: ?[]const u8 = null,
        job: ?struct {
            job_arn: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            target_selection: ?[]const u8 = null,
            status: ?[]const u8 = null,
            force_canceled: ?bool = null,
            reason_code: ?[]const u8 = null,
            comment: ?[]const u8 = null,
            targets: ?[][]const u8 = null,
            description: ?[]const u8 = null,
            presigned_url_config: ?PresignedUrlConfig = null,
            job_executions_rollout_config: ?JobExecutionsRolloutConfig = null,
            abort_config: ?AbortConfig = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            completed_at: ?i64 = null,
            job_process_details: ?struct {
                processing_targets: ?[][]const u8 = null,
                number_of_canceled_things: ?i64 = null,
                number_of_succeeded_things: ?i64 = null,
                number_of_failed_things: ?i64 = null,
                number_of_rejected_things: ?i64 = null,
                number_of_queued_things: ?i64 = null,
                number_of_in_progress_things: ?i64 = null,
                number_of_removed_things: ?i64 = null,
                number_of_timed_out_things: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .processing_targets = "processingTargets",
                        .number_of_canceled_things = "numberOfCanceledThings",
                        .number_of_succeeded_things = "numberOfSucceededThings",
                        .number_of_failed_things = "numberOfFailedThings",
                        .number_of_rejected_things = "numberOfRejectedThings",
                        .number_of_queued_things = "numberOfQueuedThings",
                        .number_of_in_progress_things = "numberOfInProgressThings",
                        .number_of_removed_things = "numberOfRemovedThings",
                        .number_of_timed_out_things = "numberOfTimedOutThings",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            timeout_config: ?TimeoutConfig = null,
            namespace_id: ?[]const u8 = null,
            job_template_arn: ?[]const u8 = null,
            job_executions_retry_config: ?JobExecutionsRetryConfig = null,
            document_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            is_concurrent: ?bool = null,
            scheduling_config: ?SchedulingConfig = null,
            scheduled_job_rollouts: ?[]struct {
                start_time: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_time = "startTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            destination_package_versions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_id = "jobId",
                    .target_selection = "targetSelection",
                    .status = "status",
                    .force_canceled = "forceCanceled",
                    .reason_code = "reasonCode",
                    .comment = "comment",
                    .targets = "targets",
                    .description = "description",
                    .presigned_url_config = "presignedUrlConfig",
                    .job_executions_rollout_config = "jobExecutionsRolloutConfig",
                    .abort_config = "abortConfig",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .completed_at = "completedAt",
                    .job_process_details = "jobProcessDetails",
                    .timeout_config = "timeoutConfig",
                    .namespace_id = "namespaceId",
                    .job_template_arn = "jobTemplateArn",
                    .job_executions_retry_config = "jobExecutionsRetryConfig",
                    .document_parameters = "documentParameters",
                    .is_concurrent = "isConcurrent",
                    .scheduling_config = "schedulingConfig",
                    .scheduled_job_rollouts = "scheduledJobRollouts",
                    .destination_package_versions = "destinationPackageVersions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "document_parameters", field_name))
                    return try serializeMap(self.document_parameters, self.fieldNameFor("document_parameters"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_source = "documentSource",
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_job_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobExecution",
    Request: type = struct {
        job_id: []const u8,
        thing_name: []const u8,
        execution_number: ?i64 = null,

        pub const http_query = .{
            .execution_number = "executionNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .thing_name = "thingName",
                .execution_number = "executionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_execution };
        }
    },
    Response: type = struct {
        execution: ?struct {
            job_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            force_canceled: ?bool = null,
            status_details: ?struct {
                details_map: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .details_map = "detailsMap",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "details_map", field_name))
                        return try serializeMap(self.details_map, self.fieldNameFor("details_map"), options, out_stream);
                    return false;
                }
            } = null,
            thing_arn: ?[]const u8 = null,
            queued_at: ?i64 = null,
            started_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            execution_number: ?i64 = null,
            version_number: ?i64 = null,
            approximate_seconds_before_timed_out: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .status = "status",
                    .force_canceled = "forceCanceled",
                    .status_details = "statusDetails",
                    .thing_arn = "thingArn",
                    .queued_at = "queuedAt",
                    .started_at = "startedAt",
                    .last_updated_at = "lastUpdatedAt",
                    .execution_number = "executionNumber",
                    .version_number = "versionNumber",
                    .approximate_seconds_before_timed_out = "approximateSecondsBeforeTimedOut",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution = "execution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_job_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/job-templates/{jobTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobTemplate",
    Request: type = struct {
        job_template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template_id = "jobTemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_template };
        }
    },
    Response: type = struct {
        job_template_arn: ?[]const u8 = null,
        job_template_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        document_source: ?[]const u8 = null,
        document: ?[]const u8 = null,
        created_at: ?i64 = null,
        presigned_url_config: ?PresignedUrlConfig = null,
        job_executions_rollout_config: ?JobExecutionsRolloutConfig = null,
        abort_config: ?AbortConfig = null,
        timeout_config: ?TimeoutConfig = null,
        job_executions_retry_config: ?JobExecutionsRetryConfig = null,
        maintenance_windows: ?[]MaintenanceWindow = null,
        destination_package_versions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template_arn = "jobTemplateArn",
                .job_template_id = "jobTemplateId",
                .description = "description",
                .document_source = "documentSource",
                .document = "document",
                .created_at = "createdAt",
                .presigned_url_config = "presignedUrlConfig",
                .job_executions_rollout_config = "jobExecutionsRolloutConfig",
                .abort_config = "abortConfig",
                .timeout_config = "timeoutConfig",
                .job_executions_retry_config = "jobExecutionsRetryConfig",
                .maintenance_windows = "maintenanceWindows",
                .destination_package_versions = "destinationPackageVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_managed_job_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/managed-job-templates/{templateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeManagedJobTemplate",
    Request: type = struct {
        template_name: []const u8,
        template_version: ?[]const u8 = null,

        pub const http_query = .{
            .template_version = "templateVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .template_version = "templateVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_job_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_job_template };
        }
    },
    Response: type = struct {
        template_name: ?[]const u8 = null,
        template_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        template_version: ?[]const u8 = null,
        environments: ?[][]const u8 = null,
        document_parameters: ?[]struct {
            key: ?[]const u8 = null,
            description: ?[]const u8 = null,
            regex: ?[]const u8 = null,
            example: ?[]const u8 = null,
            optional: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .description = "description",
                    .regex = "regex",
                    .example = "example",
                    .optional = "optional",
                };
                return @field(mappings, field_name);
            }
        } = null,
        document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .template_arn = "templateArn",
                .description = "description",
                .template_version = "templateVersion",
                .environments = "environments",
                .document_parameters = "documentParameters",
                .document = "document",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_mitigation_action: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/mitigationactions/actions/{actionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMitigationAction",
    Request: type = struct {
        action_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "actionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_mitigation_action) } {
            return .{ .service_metadata = service_metadata, .action = describe_mitigation_action };
        }
    },
    Response: type = struct {
        action_name: ?[]const u8 = null,
        action_type: ?[]const u8 = null,
        action_arn: ?[]const u8 = null,
        action_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        action_params: ?MitigationActionParams = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "actionName",
                .action_type = "actionType",
                .action_arn = "actionArn",
                .action_id = "actionId",
                .role_arn = "roleArn",
                .action_params = "actionParams",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_provisioning_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/provisioning-templates/{templateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProvisioningTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioning_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioning_template };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        default_version_id: ?i64 = null,
        template_body: ?[]const u8 = null,
        enabled: ?bool = null,
        provisioning_role_arn: ?[]const u8 = null,
        pre_provisioning_hook: ?ProvisioningHook = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "templateArn",
                .template_name = "templateName",
                .description = "description",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .default_version_id = "defaultVersionId",
                .template_body = "templateBody",
                .enabled = "enabled",
                .provisioning_role_arn = "provisioningRoleArn",
                .pre_provisioning_hook = "preProvisioningHook",
                .type = "type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_provisioning_template_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/provisioning-templates/{templateName}/versions/{versionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProvisioningTemplateVersion",
    Request: type = struct {
        template_name: []const u8,
        version_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioning_template_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioning_template_version };
        }
    },
    Response: type = struct {
        version_id: ?i64 = null,
        creation_date: ?i64 = null,
        template_body: ?[]const u8 = null,
        is_default_version: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_id = "versionId",
                .creation_date = "creationDate",
                .template_body = "templateBody",
                .is_default_version = "isDefaultVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_role_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/role-aliases/{roleAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRoleAlias",
    Request: type = struct {
        role_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_role_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_role_alias };
        }
    },
    Response: type = struct {
        role_alias_description: ?struct {
            role_alias: ?[]const u8 = null,
            role_alias_arn: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            credential_duration_seconds: ?i64 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_alias = "roleAlias",
                    .role_alias_arn = "roleAliasArn",
                    .role_arn = "roleArn",
                    .owner = "owner",
                    .credential_duration_seconds = "credentialDurationSeconds",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias_description = "roleAliasDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_scheduled_audit: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/scheduledaudits/{scheduledAuditName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeScheduledAudit",
    Request: type = struct {
        scheduled_audit_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_audit_name = "scheduledAuditName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_audit) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_audit };
        }
    },
    Response: type = struct {
        frequency: ?[]const u8 = null,
        day_of_month: ?[]const u8 = null,
        day_of_week: ?[]const u8 = null,
        target_check_names: ?[][]const u8 = null,
        scheduled_audit_name: ?[]const u8 = null,
        scheduled_audit_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .frequency = "frequency",
                .day_of_month = "dayOfMonth",
                .day_of_week = "dayOfWeek",
                .target_check_names = "targetCheckNames",
                .scheduled_audit_name = "scheduledAuditName",
                .scheduled_audit_arn = "scheduledAuditArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_security_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles/{securityProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_profile };
        }
    },
    Response: type = struct {
        security_profile_name: ?[]const u8 = null,
        security_profile_arn: ?[]const u8 = null,
        security_profile_description: ?[]const u8 = null,
        behaviors: ?[]Behavior = null,
        alert_targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AlertTarget = null,
        } = null,
        additional_metrics_to_retain: ?[][]const u8 = null,
        additional_metrics_to_retain_v2: ?[]MetricToRetain = null,
        version: ?i64 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        metrics_export_config: ?MetricsExportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_arn = "securityProfileArn",
                .security_profile_description = "securityProfileDescription",
                .behaviors = "behaviors",
                .alert_targets = "alertTargets",
                .additional_metrics_to_retain = "additionalMetricsToRetain",
                .additional_metrics_to_retain_v2 = "additionalMetricsToRetainV2",
                .version = "version",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .metrics_export_config = "metricsExportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "alert_targets", field_name))
                return try serializeMap(self.alert_targets, self.fieldNameFor("alert_targets"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/streams/{streamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStream",
    Request: type = struct {
        stream_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream };
        }
    },
    Response: type = struct {
        stream_info: ?struct {
            stream_id: ?[]const u8 = null,
            stream_arn: ?[]const u8 = null,
            stream_version: ?i64 = null,
            description: ?[]const u8 = null,
            files: ?[]StreamFile = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_id = "streamId",
                    .stream_arn = "streamArn",
                    .stream_version = "streamVersion",
                    .description = "description",
                    .files = "files",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .role_arn = "roleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_info = "streamInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_thing: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThing",
    Request: type = struct {
        thing_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thing) } {
            return .{ .service_metadata = service_metadata, .action = describe_thing };
        }
    },
    Response: type = struct {
        default_client_id: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_id: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,
        thing_type_name: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?i64 = null,
        billing_group_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_client_id = "defaultClientId",
                .thing_name = "thingName",
                .thing_id = "thingId",
                .thing_arn = "thingArn",
                .thing_type_name = "thingTypeName",
                .attributes = "attributes",
                .version = "version",
                .billing_group_name = "billingGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_thing_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_thing_group };
        }
    },
    Response: type = struct {
        thing_group_name: ?[]const u8 = null,
        thing_group_id: ?[]const u8 = null,
        thing_group_arn: ?[]const u8 = null,
        version: ?i64 = null,
        thing_group_properties: ?ThingGroupProperties = null,
        thing_group_metadata: ?struct {
            parent_group_name: ?[]const u8 = null,
            root_to_parent_thing_groups: ?[]GroupNameAndArn = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parent_group_name = "parentGroupName",
                    .root_to_parent_thing_groups = "rootToParentThingGroups",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        index_name: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_version: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_id = "thingGroupId",
                .thing_group_arn = "thingGroupArn",
                .version = "version",
                .thing_group_properties = "thingGroupProperties",
                .thing_group_metadata = "thingGroupMetadata",
                .index_name = "indexName",
                .query_string = "queryString",
                .query_version = "queryVersion",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_thing_registration_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-registration-tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThingRegistrationTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thing_registration_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_thing_registration_task };
        }
    },
    Response: type = struct {
        task_id: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        template_body: ?[]const u8 = null,
        input_file_bucket: ?[]const u8 = null,
        input_file_key: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        success_count: ?i64 = null,
        failure_count: ?i64 = null,
        percentage_progress: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .template_body = "templateBody",
                .input_file_bucket = "inputFileBucket",
                .input_file_key = "inputFileKey",
                .role_arn = "roleArn",
                .status = "status",
                .message = "message",
                .success_count = "successCount",
                .failure_count = "failureCount",
                .percentage_progress = "percentageProgress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const describe_thing_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-types/{thingTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThingType",
    Request: type = struct {
        thing_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thing_type) } {
            return .{ .service_metadata = service_metadata, .action = describe_thing_type };
        }
    },
    Response: type = struct {
        thing_type_name: ?[]const u8 = null,
        thing_type_id: ?[]const u8 = null,
        thing_type_arn: ?[]const u8 = null,
        thing_type_properties: ?ThingTypeProperties = null,
        thing_type_metadata: ?ThingTypeMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_type_name = "thingTypeName",
                .thing_type_id = "thingTypeId",
                .thing_type_arn = "thingTypeArn",
                .thing_type_properties = "thingTypeProperties",
                .thing_type_metadata = "thingTypeMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const detach_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/target-policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachPolicy",
    Request: type = struct {
        policy_name: []const u8,
        target: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_policy) } {
            return .{ .service_metadata = service_metadata, .action = detach_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const detach_principal_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/principal-policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachPrincipalPolicy",
    Request: type = struct {
        policy_name: []const u8,
        principal: []const u8,
        pub const http_header = .{
            .principal = "x-amzn-iot-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .principal = "principal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_principal_policy) } {
            return .{ .service_metadata = service_metadata, .action = detach_principal_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const detach_security_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/security-profiles/{securityProfileName}/targets",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        security_profile_target_arn: []const u8,

        pub const http_query = .{
            .security_profile_target_arn = "securityProfileTargetArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_target_arn = "securityProfileTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = detach_security_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const detach_thing_principal: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/things/{thingName}/principals",
        .success_code = 200,
    };

    action_name: []const u8 = "DetachThingPrincipal",
    Request: type = struct {
        thing_name: []const u8,
        principal: []const u8,
        pub const http_header = .{
            .principal = "x-amzn-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .principal = "principal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_thing_principal) } {
            return .{ .service_metadata = service_metadata, .action = detach_thing_principal };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const disable_topic_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rules/{ruleName}/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableTopicRule",
    Request: type = struct {
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = disable_topic_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const enable_topic_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rules/{ruleName}/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableTopicRule",
    Request: type = struct {
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = enable_topic_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const get_behavior_model_training_summaries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/behavior-model-training/summaries",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBehaviorModelTrainingSummaries",
    Request: type = struct {
        security_profile_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .security_profile_name = "securityProfileName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_behavior_model_training_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_behavior_model_training_summaries };
        }
    },
    Response: type = struct {
        summaries: ?[]struct {
            security_profile_name: ?[]const u8 = null,
            behavior_name: ?[]const u8 = null,
            training_data_collection_start_date: ?i64 = null,
            model_status: ?[]const u8 = null,
            datapoints_collection_percentage: ?f64 = null,
            last_model_refresh_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_profile_name = "securityProfileName",
                    .behavior_name = "behaviorName",
                    .training_data_collection_start_date = "trainingDataCollectionStartDate",
                    .model_status = "modelStatus",
                    .datapoints_collection_percentage = "datapointsCollectionPercentage",
                    .last_model_refresh_date = "lastModelRefreshDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_buckets_aggregation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indices/buckets",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketsAggregation",
    Request: type = struct {
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        aggregation_field: []const u8,
        query_version: ?[]const u8 = null,
        buckets_aggregation_type: struct {
            terms_aggregation: ?struct {
                max_buckets: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_buckets = "maxBuckets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .terms_aggregation = "termsAggregation",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .query_string = "queryString",
                .aggregation_field = "aggregationField",
                .query_version = "queryVersion",
                .buckets_aggregation_type = "bucketsAggregationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_buckets_aggregation) } {
            return .{ .service_metadata = service_metadata, .action = get_buckets_aggregation };
        }
    },
    Response: type = struct {
        total_count: ?i64 = null,
        buckets: ?[]struct {
            key_value: ?[]const u8 = null,
            count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_value = "keyValue",
                    .count = "count",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total_count = "totalCount",
                .buckets = "buckets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_cardinality: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indices/cardinality",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCardinality",
    Request: type = struct {
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        aggregation_field: ?[]const u8 = null,
        query_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .query_string = "queryString",
                .aggregation_field = "aggregationField",
                .query_version = "queryVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cardinality) } {
            return .{ .service_metadata = service_metadata, .action = get_cardinality };
        }
    },
    Response: type = struct {
        cardinality: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cardinality = "cardinality",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_effective_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/effective-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEffectivePolicies",
    Request: type = struct {
        principal: ?[]const u8 = null,
        cognito_identity_pool_id: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,

        pub const http_query = .{
            .thing_name = "thingName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "principal",
                .cognito_identity_pool_id = "cognitoIdentityPoolId",
                .thing_name = "thingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_effective_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_effective_policies };
        }
    },
    Response: type = struct {
        effective_policies: ?[]struct {
            policy_name: ?[]const u8 = null,
            policy_arn: ?[]const u8 = null,
            policy_document: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_name = "policyName",
                    .policy_arn = "policyArn",
                    .policy_document = "policyDocument",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_policies = "effectivePolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_indexing_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/indexing/config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIndexingConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_indexing_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_indexing_configuration };
        }
    },
    Response: type = struct {
        thing_indexing_configuration: ?ThingIndexingConfiguration = null,
        thing_group_indexing_configuration: ?ThingGroupIndexingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_indexing_configuration = "thingIndexingConfiguration",
                .thing_group_indexing_configuration = "thingGroupIndexingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_job_document: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{jobId}/job-document",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJobDocument",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_document) } {
            return .{ .service_metadata = service_metadata, .action = get_job_document };
        }
    },
    Response: type = struct {
        document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "document",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/loggingOptions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_options };
        }
    },
    Response: type = struct {
        role_arn: ?[]const u8 = null,
        log_level: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .log_level = "logLevel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const get_ota_update: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/otaUpdates/{otaUpdateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOTAUpdate",
    Request: type = struct {
        ota_update_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_update_id = "otaUpdateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ota_update) } {
            return .{ .service_metadata = service_metadata, .action = get_ota_update };
        }
    },
    Response: type = struct {
        ota_update_info: ?struct {
            ota_update_id: ?[]const u8 = null,
            ota_update_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,
            description: ?[]const u8 = null,
            targets: ?[][]const u8 = null,
            protocols: ?[][]const u8 = null,
            aws_job_executions_rollout_config: ?AwsJobExecutionsRolloutConfig = null,
            aws_job_presigned_url_config: ?AwsJobPresignedUrlConfig = null,
            target_selection: ?[]const u8 = null,
            ota_update_files: ?[]OTAUpdateFile = null,
            ota_update_status: ?[]const u8 = null,
            aws_iot_job_id: ?[]const u8 = null,
            aws_iot_job_arn: ?[]const u8 = null,
            error_info: ?struct {
                code: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .message = "message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            additional_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ota_update_id = "otaUpdateId",
                    .ota_update_arn = "otaUpdateArn",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                    .description = "description",
                    .targets = "targets",
                    .protocols = "protocols",
                    .aws_job_executions_rollout_config = "awsJobExecutionsRolloutConfig",
                    .aws_job_presigned_url_config = "awsJobPresignedUrlConfig",
                    .target_selection = "targetSelection",
                    .ota_update_files = "otaUpdateFiles",
                    .ota_update_status = "otaUpdateStatus",
                    .aws_iot_job_id = "awsIotJobId",
                    .aws_iot_job_arn = "awsIotJobArn",
                    .error_info = "errorInfo",
                    .additional_parameters = "additionalParameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "additional_parameters", field_name))
                    return try serializeMap(self.additional_parameters, self.fieldNameFor("additional_parameters"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_update_info = "otaUpdateInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/{packageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackage",
    Request: type = struct {
        package_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package) } {
            return .{ .service_metadata = service_metadata, .action = get_package };
        }
    },
    Response: type = struct {
        package_name: ?[]const u8 = null,
        package_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        default_version_name: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .package_arn = "packageArn",
                .description = "description",
                .default_version_name = "defaultVersionName",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_package_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/package-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_package_configuration };
        }
    },
    Response: type = struct {
        version_update_by_jobs_config: ?VersionUpdateByJobsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_update_by_jobs_config = "versionUpdateByJobsConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
    },
} = .{};
pub const get_package_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/{packageName}/versions/{versionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageVersion",
    Request: type = struct {
        package_name: []const u8,
        version_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .version_name = "versionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_version) } {
            return .{ .service_metadata = service_metadata, .action = get_package_version };
        }
    },
    Response: type = struct {
        package_version_arn: ?[]const u8 = null,
        package_name: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        error_reason: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_version_arn = "packageVersionArn",
                .package_name = "packageName",
                .version_name = "versionName",
                .description = "description",
                .attributes = "attributes",
                .status = "status",
                .error_reason = "errorReason",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_percentiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indices/percentiles",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPercentiles",
    Request: type = struct {
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        aggregation_field: ?[]const u8 = null,
        query_version: ?[]const u8 = null,
        percents: ?[]f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .query_string = "queryString",
                .aggregation_field = "aggregationField",
                .query_version = "queryVersion",
                .percents = "percents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_percentiles) } {
            return .{ .service_metadata = service_metadata, .action = get_percentiles };
        }
    },
    Response: type = struct {
        percentiles: ?[]struct {
            percent: ?f64 = null,
            value: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .percent = "percent",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .percentiles = "percentiles",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPolicy",
    Request: type = struct {
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_policy };
        }
    },
    Response: type = struct {
        policy_name: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        default_version_id: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        generation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_arn = "policyArn",
                .policy_document = "policyDocument",
                .default_version_id = "defaultVersionId",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .generation_id = "generationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_policy_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies/{policyName}/version/{policyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPolicyVersion",
    Request: type = struct {
        policy_name: []const u8,
        policy_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_version_id = "policyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = get_policy_version };
        }
    },
    Response: type = struct {
        policy_arn: ?[]const u8 = null,
        policy_name: ?[]const u8 = null,
        policy_document: ?[]const u8 = null,
        policy_version_id: ?[]const u8 = null,
        is_default_version: ?bool = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        generation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
                .policy_name = "policyName",
                .policy_document = "policyDocument",
                .policy_version_id = "policyVersionId",
                .is_default_version = "isDefaultVersion",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .generation_id = "generationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_registration_code: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/registrationcode",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRegistrationCode",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_registration_code) } {
            return .{ .service_metadata = service_metadata, .action = get_registration_code };
        }
    },
    Response: type = struct {
        registration_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_code = "registrationCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indices/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStatistics",
    Request: type = struct {
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        aggregation_field: ?[]const u8 = null,
        query_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .query_string = "queryString",
                .aggregation_field = "aggregationField",
                .query_version = "queryVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_statistics };
        }
    },
    Response: type = struct {
        statistics: ?struct {
            count: ?i64 = null,
            average: ?f64 = null,
            sum: ?f64 = null,
            minimum: ?f64 = null,
            maximum: ?f64 = null,
            sum_of_squares: ?f64 = null,
            variance: ?f64 = null,
            std_deviation: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count = "count",
                    .average = "average",
                    .sum = "sum",
                    .minimum = "minimum",
                    .maximum = "maximum",
                    .sum_of_squares = "sumOfSquares",
                    .variance = "variance",
                    .std_deviation = "stdDeviation",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statistics = "statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const get_topic_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules/{ruleName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTopicRule",
    Request: type = struct {
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_topic_rule };
        }
    },
    Response: type = struct {
        rule_arn: ?[]const u8 = null,
        rule: ?struct {
            rule_name: ?[]const u8 = null,
            sql: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,
            actions: ?[]Action = null,
            rule_disabled: ?bool = null,
            aws_iot_sql_version: ?[]const u8 = null,
            error_action: ?Action = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "ruleName",
                    .sql = "sql",
                    .description = "description",
                    .created_at = "createdAt",
                    .actions = "actions",
                    .rule_disabled = "ruleDisabled",
                    .aws_iot_sql_version = "awsIotSqlVersion",
                    .error_action = "errorAction",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "ruleArn",
                .rule = "rule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const get_topic_rule_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations/{arn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTopicRuleDestination",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_topic_rule_destination) } {
            return .{ .service_metadata = service_metadata, .action = get_topic_rule_destination };
        }
    },
    Response: type = struct {
        topic_rule_destination: ?TopicRuleDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_rule_destination = "topicRuleDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const get_v2_logging_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2LoggingOptions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetV2LoggingOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_v2_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = get_v2_logging_options };
        }
    },
    Response: type = struct {
        role_arn: ?[]const u8 = null,
        default_log_level: ?[]const u8 = null,
        disable_all_logs: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .default_log_level = "defaultLogLevel",
                .disable_all_logs = "disableAllLogs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        NotConfigured,
        ServiceUnavailable,
    },
} = .{};
pub const list_active_violations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/active-violations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListActiveViolations",
    Request: type = struct {
        thing_name: ?[]const u8 = null,
        security_profile_name: ?[]const u8 = null,
        behavior_criteria_type: ?[]const u8 = null,
        list_suppressed_alerts: ?bool = null,
        verification_state: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .thing_name = "thingName",
            .security_profile_name = "securityProfileName",
            .behavior_criteria_type = "behaviorCriteriaType",
            .list_suppressed_alerts = "listSuppressedAlerts",
            .verification_state = "verificationState",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .security_profile_name = "securityProfileName",
                .behavior_criteria_type = "behaviorCriteriaType",
                .list_suppressed_alerts = "listSuppressedAlerts",
                .verification_state = "verificationState",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_active_violations) } {
            return .{ .service_metadata = service_metadata, .action = list_active_violations };
        }
    },
    Response: type = struct {
        active_violations: ?[]struct {
            violation_id: ?[]const u8 = null,
            thing_name: ?[]const u8 = null,
            security_profile_name: ?[]const u8 = null,
            behavior: ?Behavior = null,
            last_violation_value: ?MetricValue = null,
            violation_event_additional_info: ?ViolationEventAdditionalInfo = null,
            verification_state: ?[]const u8 = null,
            verification_state_description: ?[]const u8 = null,
            last_violation_time: ?i64 = null,
            violation_start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .violation_id = "violationId",
                    .thing_name = "thingName",
                    .security_profile_name = "securityProfileName",
                    .behavior = "behavior",
                    .last_violation_value = "lastViolationValue",
                    .violation_event_additional_info = "violationEventAdditionalInfo",
                    .verification_state = "verificationState",
                    .verification_state_description = "verificationStateDescription",
                    .last_violation_time = "lastViolationTime",
                    .violation_start_time = "violationStartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_violations = "activeViolations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_attached_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/attached-policies/{target}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttachedPolicies",
    Request: type = struct {
        target: []const u8,
        recursive: ?bool = null,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .recursive = "recursive",
            .marker = "marker",
            .page_size = "pageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "target",
                .recursive = "recursive",
                .marker = "marker",
                .page_size = "pageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attached_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_attached_policies };
        }
    },
    Response: type = struct {
        policies: ?[]Policy = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "policies",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_audit_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuditFindings",
    Request: type = struct {
        task_id: ?[]const u8 = null,
        check_name: ?[]const u8 = null,
        resource_identifier: ?ResourceIdentifier = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        list_suppressed_findings: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .start_time = "startTime",
                .end_time = "endTime",
                .list_suppressed_findings = "listSuppressedFindings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_audit_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_audit_findings };
        }
    },
    Response: type = struct {
        findings: ?[]AuditFinding = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_audit_mitigation_actions_executions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/mitigationactions/executions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuditMitigationActionsExecutions",
    Request: type = struct {
        task_id: []const u8,
        action_status: ?[]const u8 = null,
        finding_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .task_id = "taskId",
            .action_status = "actionStatus",
            .finding_id = "findingId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .action_status = "actionStatus",
                .finding_id = "findingId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_audit_mitigation_actions_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_audit_mitigation_actions_executions };
        }
    },
    Response: type = struct {
        actions_executions: ?[]struct {
            task_id: ?[]const u8 = null,
            finding_id: ?[]const u8 = null,
            action_name: ?[]const u8 = null,
            action_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            error_code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "taskId",
                    .finding_id = "findingId",
                    .action_name = "actionName",
                    .action_id = "actionId",
                    .status = "status",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .error_code = "errorCode",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions_executions = "actionsExecutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_audit_mitigation_actions_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/mitigationactions/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuditMitigationActionsTasks",
    Request: type = struct {
        audit_task_id: ?[]const u8 = null,
        finding_id: ?[]const u8 = null,
        task_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        start_time: i64,
        end_time: i64,

        pub const http_query = .{
            .audit_task_id = "auditTaskId",
            .finding_id = "findingId",
            .task_status = "taskStatus",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .start_time = "startTime",
            .end_time = "endTime",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audit_task_id = "auditTaskId",
                .finding_id = "findingId",
                .task_status = "taskStatus",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_audit_mitigation_actions_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_audit_mitigation_actions_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]struct {
            task_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            task_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "taskId",
                    .start_time = "startTime",
                    .task_status = "taskStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_audit_suppressions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/suppressions/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuditSuppressions",
    Request: type = struct {
        check_name: ?[]const u8 = null,
        resource_identifier: ?ResourceIdentifier = null,
        ascending_order: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
                .ascending_order = "ascendingOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_audit_suppressions) } {
            return .{ .service_metadata = service_metadata, .action = list_audit_suppressions };
        }
    },
    Response: type = struct {
        suppressions: ?[]struct {
            check_name: []const u8,
            resource_identifier: ResourceIdentifier,
            expiration_date: ?i64 = null,
            suppress_indefinitely: ?bool = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .check_name = "checkName",
                    .resource_identifier = "resourceIdentifier",
                    .expiration_date = "expirationDate",
                    .suppress_indefinitely = "suppressIndefinitely",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suppressions = "suppressions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_audit_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuditTasks",
    Request: type = struct {
        start_time: i64,
        end_time: i64,
        task_type: ?[]const u8 = null,
        task_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .start_time = "startTime",
            .end_time = "endTime",
            .task_type = "taskType",
            .task_status = "taskStatus",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "startTime",
                .end_time = "endTime",
                .task_type = "taskType",
                .task_status = "taskStatus",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_audit_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_audit_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]struct {
            task_id: ?[]const u8 = null,
            task_status: ?[]const u8 = null,
            task_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "taskId",
                    .task_status = "taskStatus",
                    .task_type = "taskType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_authorizers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/authorizers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAuthorizers",
    Request: type = struct {
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
            .status = "status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_authorizers) } {
            return .{ .service_metadata = service_metadata, .action = list_authorizers };
        }
    },
    Response: type = struct {
        authorizers: ?[]struct {
            authorizer_name: ?[]const u8 = null,
            authorizer_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authorizer_name = "authorizerName",
                    .authorizer_arn = "authorizerArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizers = "authorizers",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_billing_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/billing-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBillingGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_prefix_filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_prefix_filter = "namePrefixFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_prefix_filter = "namePrefixFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_billing_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_billing_groups };
        }
    },
    Response: type = struct {
        billing_groups: ?[]GroupNameAndArn = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_groups = "billingGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_ca_certificates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cacertificates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCACertificates",
    Request: type = struct {
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,
        template_name: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
            .template_name = "templateName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
                .template_name = "templateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ca_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_ca_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]struct {
            certificate_arn: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "certificateArn",
                    .certificate_id = "certificateId",
                    .status = "status",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "certificates",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_certificate_providers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificate-providers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCertificateProviders",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificate_providers) } {
            return .{ .service_metadata = service_metadata, .action = list_certificate_providers };
        }
    },
    Response: type = struct {
        certificate_providers: ?[]struct {
            certificate_provider_name: ?[]const u8 = null,
            certificate_provider_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_provider_name = "certificateProviderName",
                    .certificate_provider_arn = "certificateProviderArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_providers = "certificateProviders",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_certificates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCertificates",
    Request: type = struct {
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_certificates };
        }
    },
    Response: type = struct {
        certificates: ?[]Certificate = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "certificates",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_certificates_by_ca: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificates-by-ca/{caCertificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCertificatesByCA",
    Request: type = struct {
        ca_certificate_id: []const u8,
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ca_certificate_id = "caCertificateId",
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificates_by_ca) } {
            return .{ .service_metadata = service_metadata, .action = list_certificates_by_ca };
        }
    },
    Response: type = struct {
        certificates: ?[]Certificate = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificates = "certificates",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_custom_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/custom-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCustomMetrics",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_metrics };
        }
    },
    Response: type = struct {
        metric_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_names = "metricNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_detect_mitigation_actions_executions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detect/mitigationactions/executions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectMitigationActionsExecutions",
    Request: type = struct {
        task_id: ?[]const u8 = null,
        violation_id: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .task_id = "taskId",
            .violation_id = "violationId",
            .thing_name = "thingName",
            .start_time = "startTime",
            .end_time = "endTime",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .violation_id = "violationId",
                .thing_name = "thingName",
                .start_time = "startTime",
                .end_time = "endTime",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detect_mitigation_actions_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_detect_mitigation_actions_executions };
        }
    },
    Response: type = struct {
        actions_executions: ?[]struct {
            task_id: ?[]const u8 = null,
            violation_id: ?[]const u8 = null,
            action_name: ?[]const u8 = null,
            thing_name: ?[]const u8 = null,
            execution_start_date: ?i64 = null,
            execution_end_date: ?i64 = null,
            status: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "taskId",
                    .violation_id = "violationId",
                    .action_name = "actionName",
                    .thing_name = "thingName",
                    .execution_start_date = "executionStartDate",
                    .execution_end_date = "executionEndDate",
                    .status = "status",
                    .error_code = "errorCode",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions_executions = "actionsExecutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_detect_mitigation_actions_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detect/mitigationactions/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectMitigationActionsTasks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        start_time: i64,
        end_time: i64,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .start_time = "startTime",
            .end_time = "endTime",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detect_mitigation_actions_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_detect_mitigation_actions_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]DetectMitigationActionsTaskSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "tasks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_dimensions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/dimensions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDimensions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dimensions) } {
            return .{ .service_metadata = service_metadata, .action = list_dimensions };
        }
    },
    Response: type = struct {
        dimension_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dimension_names = "dimensionNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_domain_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainConfigurations",
    Request: type = struct {
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,
        service_type: ?[]const u8 = null,

        pub const http_query = .{
            .marker = "marker",
            .page_size = "pageSize",
            .service_type = "serviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "marker",
                .page_size = "pageSize",
                .service_type = "serviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_configurations };
        }
    },
    Response: type = struct {
        domain_configurations: ?[]struct {
            domain_configuration_name: ?[]const u8 = null,
            domain_configuration_arn: ?[]const u8 = null,
            service_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_configuration_name = "domainConfigurationName",
                    .domain_configuration_arn = "domainConfigurationArn",
                    .service_type = "serviceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configurations = "domainConfigurations",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_fleet_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/fleet-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFleetMetrics",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fleet_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_fleet_metrics };
        }
    },
    Response: type = struct {
        fleet_metrics: ?[]struct {
            metric_name: ?[]const u8 = null,
            metric_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric_name = "metricName",
                    .metric_arn = "metricArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_metrics = "fleetMetrics",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_indices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/indices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIndices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_indices) } {
            return .{ .service_metadata = service_metadata, .action = list_indices };
        }
    },
    Response: type = struct {
        index_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_names = "indexNames",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_job_executions_for_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{jobId}/things",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobExecutionsForJob",
    Request: type = struct {
        job_id: []const u8,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .status = "status",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_executions_for_job) } {
            return .{ .service_metadata = service_metadata, .action = list_job_executions_for_job };
        }
    },
    Response: type = struct {
        execution_summaries: ?[]struct {
            thing_arn: ?[]const u8 = null,
            job_execution_summary: ?JobExecutionSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_arn = "thingArn",
                    .job_execution_summary = "jobExecutionSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_summaries = "executionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_job_executions_for_thing: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobExecutionsForThing",
    Request: type = struct {
        thing_name: []const u8,
        status: ?[]const u8 = null,
        namespace_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        job_id: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .namespace_id = "namespaceId",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .job_id = "jobId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .status = "status",
                .namespace_id = "namespaceId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_executions_for_thing) } {
            return .{ .service_metadata = service_metadata, .action = list_job_executions_for_thing };
        }
    },
    Response: type = struct {
        execution_summaries: ?[]struct {
            job_id: ?[]const u8 = null,
            job_execution_summary: ?JobExecutionSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .job_execution_summary = "jobExecutionSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_summaries = "executionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        target_selection: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        thing_group_name: ?[]const u8 = null,
        thing_group_id: ?[]const u8 = null,
        namespace_id: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .target_selection = "targetSelection",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .thing_group_name = "thingGroupName",
            .thing_group_id = "thingGroupId",
            .namespace_id = "namespaceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .target_selection = "targetSelection",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .thing_group_name = "thingGroupName",
                .thing_group_id = "thingGroupId",
                .namespace_id = "namespaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_arn: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            thing_group_id: ?[]const u8 = null,
            target_selection: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            completed_at: ?i64 = null,
            is_concurrent: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_id = "jobId",
                    .thing_group_id = "thingGroupId",
                    .target_selection = "targetSelection",
                    .status = "status",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .completed_at = "completedAt",
                    .is_concurrent = "isConcurrent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_job_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/job-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobTemplates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_job_templates };
        }
    },
    Response: type = struct {
        job_templates: ?[]struct {
            job_template_arn: ?[]const u8 = null,
            job_template_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_template_arn = "jobTemplateArn",
                    .job_template_id = "jobTemplateId",
                    .description = "description",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_templates = "jobTemplates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_managed_job_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/managed-job-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListManagedJobTemplates",
    Request: type = struct {
        template_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .template_name = "templateName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_job_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_job_templates };
        }
    },
    Response: type = struct {
        managed_job_templates: ?[]struct {
            template_arn: ?[]const u8 = null,
            template_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            environments: ?[][]const u8 = null,
            template_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_arn = "templateArn",
                    .template_name = "templateName",
                    .description = "description",
                    .environments = "environments",
                    .template_version = "templateVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_job_templates = "managedJobTemplates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_metric_values: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/metric-values",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMetricValues",
    Request: type = struct {
        thing_name: []const u8,
        metric_name: []const u8,
        dimension_name: ?[]const u8 = null,
        dimension_value_operator: ?[]const u8 = null,
        start_time: i64,
        end_time: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .thing_name = "thingName",
            .metric_name = "metricName",
            .dimension_name = "dimensionName",
            .dimension_value_operator = "dimensionValueOperator",
            .start_time = "startTime",
            .end_time = "endTime",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .metric_name = "metricName",
                .dimension_name = "dimensionName",
                .dimension_value_operator = "dimensionValueOperator",
                .start_time = "startTime",
                .end_time = "endTime",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_metric_values) } {
            return .{ .service_metadata = service_metadata, .action = list_metric_values };
        }
    },
    Response: type = struct {
        metric_datum_list: ?[]struct {
            timestamp: ?i64 = null,
            value: ?MetricValue = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "timestamp",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_datum_list = "metricDatumList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_mitigation_actions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/mitigationactions/actions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMitigationActions",
    Request: type = struct {
        action_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .action_type = "actionType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "actionType",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mitigation_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_mitigation_actions };
        }
    },
    Response: type = struct {
        action_identifiers: ?[]struct {
            action_name: ?[]const u8 = null,
            action_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_name = "actionName",
                    .action_arn = "actionArn",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_identifiers = "actionIdentifiers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_ota_updates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/otaUpdates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOTAUpdates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ota_update_status: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .ota_update_status = "otaUpdateStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .ota_update_status = "otaUpdateStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ota_updates) } {
            return .{ .service_metadata = service_metadata, .action = list_ota_updates };
        }
    },
    Response: type = struct {
        ota_updates: ?[]struct {
            ota_update_id: ?[]const u8 = null,
            ota_update_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ota_update_id = "otaUpdateId",
                    .ota_update_arn = "otaUpdateArn",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ota_updates = "otaUpdates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_outgoing_certificates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/certificates-out-going",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOutgoingCertificates",
    Request: type = struct {
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_outgoing_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_outgoing_certificates };
        }
    },
    Response: type = struct {
        outgoing_certificates: ?[]struct {
            certificate_arn: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            transferred_to: ?[]const u8 = null,
            transfer_date: ?i64 = null,
            transfer_message: ?[]const u8 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .certificate_arn = "certificateArn",
                    .certificate_id = "certificateId",
                    .transferred_to = "transferredTo",
                    .transfer_date = "transferDate",
                    .transfer_message = "transferMessage",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outgoing_certificates = "outgoingCertificates",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_packages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackages",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_packages };
        }
    },
    Response: type = struct {
        package_summaries: ?[]struct {
            package_name: ?[]const u8 = null,
            default_version_name: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_name = "packageName",
                    .default_version_name = "defaultVersionName",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_summaries = "packageSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_package_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/{packageName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackageVersions",
    Request: type = struct {
        package_name: []const u8,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .status = "status",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_package_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_package_versions };
        }
    },
    Response: type = struct {
        package_version_summaries: ?[]struct {
            package_name: ?[]const u8 = null,
            version_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_name = "packageName",
                    .version_name = "versionName",
                    .status = "status",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_version_summaries = "packageVersionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPolicies",
    Request: type = struct {
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .marker = "marker",
            .page_size = "pageSize",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "marker",
                .page_size = "pageSize",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_policies };
        }
    },
    Response: type = struct {
        policies: ?[]Policy = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "policies",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_policy_principals: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policy-principals",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPolicyPrincipals",
    Request: type = struct {
        policy_name: []const u8,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .marker = "marker",
            .page_size = "pageSize",
            .ascending_order = "isAscendingOrder",
        };

        pub const http_header = .{
            .policy_name = "x-amzn-iot-policy",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .marker = "marker",
                .page_size = "pageSize",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policy_principals) } {
            return .{ .service_metadata = service_metadata, .action = list_policy_principals };
        }
    },
    Response: type = struct {
        principals: ?[][]const u8 = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "principals",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_policy_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policies/{policyName}/version",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPolicyVersions",
    Request: type = struct {
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policy_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_policy_versions };
        }
    },
    Response: type = struct {
        policy_versions: ?[]struct {
            version_id: ?[]const u8 = null,
            is_default_version: ?bool = null,
            create_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_id = "versionId",
                    .is_default_version = "isDefaultVersion",
                    .create_date = "createDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_versions = "policyVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_principal_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/principal-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPrincipalPolicies",
    Request: type = struct {
        principal: []const u8,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .marker = "marker",
            .page_size = "pageSize",
            .ascending_order = "isAscendingOrder",
        };

        pub const http_header = .{
            .principal = "x-amzn-iot-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "principal",
                .marker = "marker",
                .page_size = "pageSize",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_principal_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_principal_policies };
        }
    },
    Response: type = struct {
        policies: ?[]Policy = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "policies",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_principal_things: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/principals/things",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPrincipalThings",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        principal: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .principal = "x-amzn-principal",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .principal = "principal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_principal_things) } {
            return .{ .service_metadata = service_metadata, .action = list_principal_things };
        }
    },
    Response: type = struct {
        things: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .things = "things",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_provisioning_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/provisioning-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProvisioningTemplates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioning_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioning_templates };
        }
    },
    Response: type = struct {
        templates: ?[]struct {
            template_arn: ?[]const u8 = null,
            template_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            creation_date: ?i64 = null,
            last_modified_date: ?i64 = null,
            enabled: ?bool = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_arn = "templateArn",
                    .template_name = "templateName",
                    .description = "description",
                    .creation_date = "creationDate",
                    .last_modified_date = "lastModifiedDate",
                    .enabled = "enabled",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .templates = "templates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_provisioning_template_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/provisioning-templates/{templateName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProvisioningTemplateVersions",
    Request: type = struct {
        template_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioning_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioning_template_versions };
        }
    },
    Response: type = struct {
        versions: ?[]struct {
            version_id: ?i64 = null,
            creation_date: ?i64 = null,
            is_default_version: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_id = "versionId",
                    .creation_date = "creationDate",
                    .is_default_version = "isDefaultVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .versions = "versions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_related_resources_for_audit_finding: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/relatedResources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRelatedResourcesForAuditFinding",
    Request: type = struct {
        finding_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .finding_id = "findingId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_id = "findingId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_related_resources_for_audit_finding) } {
            return .{ .service_metadata = service_metadata, .action = list_related_resources_for_audit_finding };
        }
    },
    Response: type = struct {
        related_resources: ?[]RelatedResource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .related_resources = "relatedResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_role_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/role-aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoleAliases",
    Request: type = struct {
        page_size: ?i64 = null,
        marker: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .page_size = "pageSize",
            .marker = "marker",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "pageSize",
                .marker = "marker",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_role_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_role_aliases };
        }
    },
    Response: type = struct {
        role_aliases: ?[][]const u8 = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_aliases = "roleAliases",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_scheduled_audits: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/scheduledaudits",
        .success_code = 200,
    };

    action_name: []const u8 = "ListScheduledAudits",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scheduled_audits) } {
            return .{ .service_metadata = service_metadata, .action = list_scheduled_audits };
        }
    },
    Response: type = struct {
        scheduled_audits: ?[]struct {
            scheduled_audit_name: ?[]const u8 = null,
            scheduled_audit_arn: ?[]const u8 = null,
            frequency: ?[]const u8 = null,
            day_of_month: ?[]const u8 = null,
            day_of_week: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .scheduled_audit_name = "scheduledAuditName",
                    .scheduled_audit_arn = "scheduledAuditArn",
                    .frequency = "frequency",
                    .day_of_month = "dayOfMonth",
                    .day_of_week = "dayOfWeek",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_audits = "scheduledAudits",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_security_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dimension_name: ?[]const u8 = null,
        metric_name: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .dimension_name = "dimensionName",
            .metric_name = "metricName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .dimension_name = "dimensionName",
                .metric_name = "metricName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profiles };
        }
    },
    Response: type = struct {
        security_profile_identifiers: ?[]SecurityProfileIdentifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_identifiers = "securityProfileIdentifiers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_profiles_for_target: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles-for-target",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfilesForTarget",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        recursive: ?bool = null,
        security_profile_target_arn: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .recursive = "recursive",
            .security_profile_target_arn = "securityProfileTargetArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .recursive = "recursive",
                .security_profile_target_arn = "securityProfileTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profiles_for_target) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profiles_for_target };
        }
    },
    Response: type = struct {
        security_profile_target_mappings: ?[]struct {
            security_profile_identifier: ?SecurityProfileIdentifier = null,
            target: ?SecurityProfileTarget = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_profile_identifier = "securityProfileIdentifier",
                    .target = "target",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_target_mappings = "securityProfileTargetMappings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_streams: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/streams",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreams",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        ascending_order: ?bool = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .ascending_order = "isAscendingOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .ascending_order = "ascendingOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_streams };
        }
    },
    Response: type = struct {
        streams: ?[]struct {
            stream_id: ?[]const u8 = null,
            stream_arn: ?[]const u8 = null,
            stream_version: ?i64 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stream_id = "streamId",
                    .stream_arn = "streamArn",
                    .stream_version = "streamVersion",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streams = "streams",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_targets_for_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy-targets/{policyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTargetsForPolicy",
    Request: type = struct {
        policy_name: []const u8,
        marker: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .page_size = "pageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .marker = "marker",
                .page_size = "pageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_targets_for_policy) } {
            return .{ .service_metadata = service_metadata, .action = list_targets_for_policy };
        }
    },
    Response: type = struct {
        targets: ?[][]const u8 = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "targets",
                .next_marker = "nextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_targets_for_security_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles/{securityProfileName}/targets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTargetsForSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_targets_for_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = list_targets_for_security_profile };
        }
    },
    Response: type = struct {
        security_profile_targets: ?[]SecurityProfileTarget = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_targets = "securityProfileTargets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_thing_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        parent_group: ?[]const u8 = null,
        name_prefix_filter: ?[]const u8 = null,
        recursive: ?bool = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .parent_group = "parentGroup",
            .name_prefix_filter = "namePrefixFilter",
            .recursive = "recursive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .parent_group = "parentGroup",
                .name_prefix_filter = "namePrefixFilter",
                .recursive = "recursive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_groups };
        }
    },
    Response: type = struct {
        thing_groups: ?[]GroupNameAndArn = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_groups = "thingGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_thing_groups_for_thing: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/thing-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingGroupsForThing",
    Request: type = struct {
        thing_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_groups_for_thing) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_groups_for_thing };
        }
    },
    Response: type = struct {
        thing_groups: ?[]GroupNameAndArn = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_groups = "thingGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_thing_principals: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things/{thingName}/principals",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingPrincipals",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        thing_name: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .thing_name = "thingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_principals) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_principals };
        }
    },
    Response: type = struct {
        principals: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "principals",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_thing_registration_task_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-registration-tasks/{taskId}/reports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingRegistrationTaskReports",
    Request: type = struct {
        task_id: []const u8,
        report_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .report_type = "reportType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .report_type = "reportType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_registration_task_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_registration_task_reports };
        }
    },
    Response: type = struct {
        resource_links: ?[][]const u8 = null,
        report_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_links = "resourceLinks",
                .report_type = "reportType",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_thing_registration_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-registration-tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingRegistrationTasks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .status = "status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_registration_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_registration_tasks };
        }
    },
    Response: type = struct {
        task_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_ids = "taskIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_things: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/things",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThings",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        attribute_name: ?[]const u8 = null,
        attribute_value: ?[]const u8 = null,
        thing_type_name: ?[]const u8 = null,
        use_prefix_attribute_value: ?bool = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .attribute_name = "attributeName",
            .attribute_value = "attributeValue",
            .thing_type_name = "thingTypeName",
            .use_prefix_attribute_value = "usePrefixAttributeValue",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .attribute_name = "attributeName",
                .attribute_value = "attributeValue",
                .thing_type_name = "thingTypeName",
                .use_prefix_attribute_value = "usePrefixAttributeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_things) } {
            return .{ .service_metadata = service_metadata, .action = list_things };
        }
    },
    Response: type = struct {
        things: ?[]struct {
            thing_name: ?[]const u8 = null,
            thing_type_name: ?[]const u8 = null,
            thing_arn: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_name = "thingName",
                    .thing_type_name = "thingTypeName",
                    .thing_arn = "thingArn",
                    .attributes = "attributes",
                    .version = "version",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .things = "things",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_things_in_billing_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/billing-groups/{billingGroupName}/things",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingsInBillingGroup",
    Request: type = struct {
        billing_group_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_things_in_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = list_things_in_billing_group };
        }
    },
    Response: type = struct {
        things: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .things = "things",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_things_in_thing_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-groups/{thingGroupName}/things",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingsInThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        recursive: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .recursive = "recursive",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .recursive = "recursive",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_things_in_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = list_things_in_thing_group };
        }
    },
    Response: type = struct {
        things: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .things = "things",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_thing_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/thing-types",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThingTypes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        thing_type_name: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .thing_type_name = "thingTypeName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .thing_type_name = "thingTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_thing_types) } {
            return .{ .service_metadata = service_metadata, .action = list_thing_types };
        }
    },
    Response: type = struct {
        thing_types: ?[]struct {
            thing_type_name: ?[]const u8 = null,
            thing_type_arn: ?[]const u8 = null,
            thing_type_properties: ?ThingTypeProperties = null,
            thing_type_metadata: ?ThingTypeMetadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_type_name = "thingTypeName",
                    .thing_type_arn = "thingTypeArn",
                    .thing_type_properties = "thingTypeProperties",
                    .thing_type_metadata = "thingTypeMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_types = "thingTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const list_topic_rule_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTopicRuleDestinations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_topic_rule_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_topic_rule_destinations };
        }
    },
    Response: type = struct {
        destination_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            status_reason: ?[]const u8 = null,
            http_url_summary: ?struct {
                confirmation_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .confirmation_url = "confirmationUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vpc_destination_summary: ?struct {
                subnet_ids: ?[][]const u8 = null,
                security_groups: ?[][]const u8 = null,
                vpc_id: ?[]const u8 = null,
                role_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .subnet_ids = "subnetIds",
                        .security_groups = "securityGroups",
                        .vpc_id = "vpcId",
                        .role_arn = "roleArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .status = "status",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .status_reason = "statusReason",
                    .http_url_summary = "httpUrlSummary",
                    .vpc_destination_summary = "vpcDestinationSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_summaries = "destinationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_topic_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTopicRules",
    Request: type = struct {
        topic: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        rule_disabled: ?bool = null,

        pub const http_query = .{
            .topic = "topic",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .rule_disabled = "ruleDisabled",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic = "topic",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .rule_disabled = "ruleDisabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_topic_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_topic_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            rule_arn: ?[]const u8 = null,
            rule_name: ?[]const u8 = null,
            topic_pattern: ?[]const u8 = null,
            created_at: ?i64 = null,
            rule_disabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_arn = "ruleArn",
                    .rule_name = "ruleName",
                    .topic_pattern = "topicPattern",
                    .created_at = "createdAt",
                    .rule_disabled = "ruleDisabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "rules",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_v2_logging_levels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2LoggingLevel",
        .success_code = 200,
    };

    action_name: []const u8 = "ListV2LoggingLevels",
    Request: type = struct {
        target_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .target_type = "targetType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_type = "targetType",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_v2_logging_levels) } {
            return .{ .service_metadata = service_metadata, .action = list_v2_logging_levels };
        }
    },
    Response: type = struct {
        log_target_configurations: ?[]struct {
            log_target: ?LogTarget = null,
            log_level: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .log_target = "logTarget",
                    .log_level = "logLevel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_target_configurations = "logTargetConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        NotConfigured,
        ServiceUnavailable,
    },
} = .{};
pub const list_violation_events: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/violation-events",
        .success_code = 200,
    };

    action_name: []const u8 = "ListViolationEvents",
    Request: type = struct {
        start_time: i64,
        end_time: i64,
        thing_name: ?[]const u8 = null,
        security_profile_name: ?[]const u8 = null,
        behavior_criteria_type: ?[]const u8 = null,
        list_suppressed_alerts: ?bool = null,
        verification_state: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .start_time = "startTime",
            .end_time = "endTime",
            .thing_name = "thingName",
            .security_profile_name = "securityProfileName",
            .behavior_criteria_type = "behaviorCriteriaType",
            .list_suppressed_alerts = "listSuppressedAlerts",
            .verification_state = "verificationState",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "startTime",
                .end_time = "endTime",
                .thing_name = "thingName",
                .security_profile_name = "securityProfileName",
                .behavior_criteria_type = "behaviorCriteriaType",
                .list_suppressed_alerts = "listSuppressedAlerts",
                .verification_state = "verificationState",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_violation_events) } {
            return .{ .service_metadata = service_metadata, .action = list_violation_events };
        }
    },
    Response: type = struct {
        violation_events: ?[]struct {
            violation_id: ?[]const u8 = null,
            thing_name: ?[]const u8 = null,
            security_profile_name: ?[]const u8 = null,
            behavior: ?Behavior = null,
            metric_value: ?MetricValue = null,
            violation_event_additional_info: ?ViolationEventAdditionalInfo = null,
            violation_event_type: ?[]const u8 = null,
            verification_state: ?[]const u8 = null,
            verification_state_description: ?[]const u8 = null,
            violation_event_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .violation_id = "violationId",
                    .thing_name = "thingName",
                    .security_profile_name = "securityProfileName",
                    .behavior = "behavior",
                    .metric_value = "metricValue",
                    .violation_event_additional_info = "violationEventAdditionalInfo",
                    .violation_event_type = "violationEventType",
                    .verification_state = "verificationState",
                    .verification_state_description = "verificationStateDescription",
                    .violation_event_time = "violationEventTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .violation_events = "violationEvents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const put_verification_state_on_violation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/violations/verification-state/{violationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVerificationStateOnViolation",
    Request: type = struct {
        violation_id: []const u8,
        verification_state: []const u8,
        verification_state_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .violation_id = "violationId",
                .verification_state = "verificationState",
                .verification_state_description = "verificationStateDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_verification_state_on_violation) } {
            return .{ .service_metadata = service_metadata, .action = put_verification_state_on_violation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const register_ca_certificate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cacertificate",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterCACertificate",
    Request: type = struct {
        ca_certificate: []const u8,
        verification_certificate: ?[]const u8 = null,
        set_as_active: ?bool = null,
        allow_auto_registration: ?bool = null,
        registration_config: ?RegistrationConfig = null,
        tags: ?[]Tag = null,
        certificate_mode: ?[]const u8 = null,

        pub const http_query = .{
            .set_as_active = "setAsActive",
            .allow_auto_registration = "allowAutoRegistration",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ca_certificate = "caCertificate",
                .verification_certificate = "verificationCertificate",
                .set_as_active = "setAsActive",
                .allow_auto_registration = "allowAutoRegistration",
                .registration_config = "registrationConfig",
                .tags = "tags",
                .certificate_mode = "certificateMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_ca_certificate) } {
            return .{ .service_metadata = service_metadata, .action = register_ca_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "certificateArn",
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        RegistrationCodeValidation,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const register_certificate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/certificate/register",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterCertificate",
    Request: type = struct {
        certificate_pem: []const u8,
        ca_certificate_pem: ?[]const u8 = null,
        set_as_active: ?bool = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .set_as_active = "setAsActive",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_pem = "certificatePem",
                .ca_certificate_pem = "caCertificatePem",
                .set_as_active = "setAsActive",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_certificate) } {
            return .{ .service_metadata = service_metadata, .action = register_certificate };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "certificateArn",
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateConflict,
        CertificateState,
        CertificateValidation,
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const register_certificate_without_ca: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/certificate/register-no-ca",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterCertificateWithoutCA",
    Request: type = struct {
        certificate_pem: []const u8,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_pem = "certificatePem",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_certificate_without_ca) } {
            return .{ .service_metadata = service_metadata, .action = register_certificate_without_ca };
        }
    },
    Response: type = struct {
        certificate_arn: ?[]const u8 = null,
        certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "certificateArn",
                .certificate_id = "certificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateState,
        CertificateValidation,
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const register_thing: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/things",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterThing",
    Request: type = struct {
        template_body: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_body = "templateBody",
                .parameters = "parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_thing) } {
            return .{ .service_metadata = service_metadata, .action = register_thing };
        }
    },
    Response: type = struct {
        certificate_pem: ?[]const u8 = null,
        resource_arns: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_pem = "certificatePem",
                .resource_arns = "resourceArns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_arns", field_name))
                return try serializeMap(self.resource_arns, self.fieldNameFor("resource_arns"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        InternalFailure,
        InvalidRequest,
        ResourceRegistrationFailure,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const reject_certificate_transfer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/reject-certificate-transfer/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectCertificateTransfer",
    Request: type = struct {
        certificate_id: []const u8,
        reject_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .reject_reason = "rejectReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_certificate_transfer) } {
            return .{ .service_metadata = service_metadata, .action = reject_certificate_transfer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        TransferAlreadyCompleted,
        Unauthorized,
    },
} = .{};
pub const remove_thing_from_billing_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/billing-groups/removeThingFromBillingGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveThingFromBillingGroup",
    Request: type = struct {
        billing_group_name: ?[]const u8 = null,
        billing_group_arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_arn = "billingGroupArn",
                .thing_name = "thingName",
                .thing_arn = "thingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_thing_from_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = remove_thing_from_billing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const remove_thing_from_thing_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/thing-groups/removeThingFromThingGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveThingFromThingGroup",
    Request: type = struct {
        thing_group_name: ?[]const u8 = null,
        thing_group_arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_arn = "thingGroupArn",
                .thing_name = "thingName",
                .thing_arn = "thingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_thing_from_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = remove_thing_from_thing_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const replace_topic_rule: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/rules/{ruleName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ReplaceTopicRule",
    Request: type = struct {
        rule_name: []const u8,
        topic_rule_payload: TopicRulePayload,

        pub const http_payload: []const u8 = "topic_rule_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "ruleName",
                .topic_rule_payload = "topicRulePayload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_topic_rule) } {
            return .{ .service_metadata = service_metadata, .action = replace_topic_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        SqlParse,
        Unauthorized,
    },
} = .{};
pub const search_index: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indices/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchIndex",
    Request: type = struct {
        index_name: ?[]const u8 = null,
        query_string: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        query_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .index_name = "indexName",
                .query_string = "queryString",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .query_version = "queryVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_index) } {
            return .{ .service_metadata = service_metadata, .action = search_index };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        things: ?[]struct {
            thing_name: ?[]const u8 = null,
            thing_id: ?[]const u8 = null,
            thing_type_name: ?[]const u8 = null,
            thing_group_names: ?[][]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            shadow: ?[]const u8 = null,
            device_defender: ?[]const u8 = null,
            connectivity: ?struct {
                connected: ?bool = null,
                timestamp: ?i64 = null,
                disconnect_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .connected = "connected",
                        .timestamp = "timestamp",
                        .disconnect_reason = "disconnectReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_name = "thingName",
                    .thing_id = "thingId",
                    .thing_type_name = "thingTypeName",
                    .thing_group_names = "thingGroupNames",
                    .attributes = "attributes",
                    .shadow = "shadow",
                    .device_defender = "deviceDefender",
                    .connectivity = "connectivity",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        thing_groups: ?[]struct {
            thing_group_name: ?[]const u8 = null,
            thing_group_id: ?[]const u8 = null,
            thing_group_description: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            parent_group_names: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .thing_group_name = "thingGroupName",
                    .thing_group_id = "thingGroupId",
                    .thing_group_description = "thingGroupDescription",
                    .attributes = "attributes",
                    .parent_group_names = "parentGroupNames",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .things = "things",
                .thing_groups = "thingGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const set_default_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/default-authorizer",
        .success_code = 200,
    };

    action_name: []const u8 = "SetDefaultAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_default_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = set_default_authorizer };
        }
    },
    Response: type = struct {
        authorizer_name: ?[]const u8 = null,
        authorizer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .authorizer_arn = "authorizerArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const set_default_policy_version: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/policies/{policyName}/version/{policyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "SetDefaultPolicyVersion",
    Request: type = struct {
        policy_name: []const u8,
        policy_version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_version_id = "policyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_default_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = set_default_policy_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const set_logging_options: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/loggingOptions",
        .success_code = 200,
    };

    action_name: []const u8 = "SetLoggingOptions",
    Request: type = struct {
        logging_options_payload: struct {
            role_arn: []const u8,
            log_level: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_arn = "roleArn",
                    .log_level = "logLevel",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "logging_options_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_options_payload = "loggingOptionsPayload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = set_logging_options };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const set_v2_logging_level: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2LoggingLevel",
        .success_code = 200,
    };

    action_name: []const u8 = "SetV2LoggingLevel",
    Request: type = struct {
        log_target: LogTarget,
        log_level: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_target = "logTarget",
                .log_level = "logLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_v2_logging_level) } {
            return .{ .service_metadata = service_metadata, .action = set_v2_logging_level };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        LimitExceeded,
        NotConfigured,
        ServiceUnavailable,
    },
} = .{};
pub const set_v2_logging_options: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2LoggingOptions",
        .success_code = 200,
    };

    action_name: []const u8 = "SetV2LoggingOptions",
    Request: type = struct {
        role_arn: ?[]const u8 = null,
        default_log_level: ?[]const u8 = null,
        disable_all_logs: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .default_log_level = "defaultLogLevel",
                .disable_all_logs = "disableAllLogs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_v2_logging_options) } {
            return .{ .service_metadata = service_metadata, .action = set_v2_logging_options };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const start_audit_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/mitigationactions/tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAuditMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,
        target: AuditMitigationActionsTaskTarget,
        audit_check_to_actions_mapping: []struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        },
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .target = "target",
                .audit_check_to_actions_mapping = "auditCheckToActionsMapping",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "audit_check_to_actions_mapping", field_name))
                return try serializeMap(self.audit_check_to_actions_mapping, self.fieldNameFor("audit_check_to_actions_mapping"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_audit_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = start_audit_mitigation_actions_task };
        }
    },
    Response: type = struct {
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        TaskAlreadyExists,
        Throttling,
    },
} = .{};
pub const start_detect_mitigation_actions_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/detect/mitigationactions/tasks/{taskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDetectMitigationActionsTask",
    Request: type = struct {
        task_id: []const u8,
        target: DetectMitigationActionsTaskTarget,
        actions: [][]const u8,
        violation_event_occurrence_range: ?ViolationEventOccurrenceRange = null,
        include_only_active_violations: ?bool = null,
        include_suppressed_alerts: ?bool = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
                .target = "target",
                .actions = "actions",
                .violation_event_occurrence_range = "violationEventOccurrenceRange",
                .include_only_active_violations = "includeOnlyActiveViolations",
                .include_suppressed_alerts = "includeSuppressedAlerts",
                .client_request_token = "clientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_detect_mitigation_actions_task) } {
            return .{ .service_metadata = service_metadata, .action = start_detect_mitigation_actions_task };
        }
    },
    Response: type = struct {
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        TaskAlreadyExists,
        Throttling,
    },
} = .{};
pub const start_on_demand_audit_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "StartOnDemandAuditTask",
    Request: type = struct {
        target_check_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_check_names = "targetCheckNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_on_demand_audit_task) } {
            return .{ .service_metadata = service_metadata, .action = start_on_demand_audit_task };
        }
    },
    Response: type = struct {
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const start_thing_registration_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/thing-registration-tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "StartThingRegistrationTask",
    Request: type = struct {
        template_body: []const u8,
        input_file_bucket: []const u8,
        input_file_key: []const u8,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_body = "templateBody",
                .input_file_bucket = "inputFileBucket",
                .input_file_key = "inputFileKey",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_thing_registration_task) } {
            return .{ .service_metadata = service_metadata, .action = start_thing_registration_task };
        }
    },
    Response: type = struct {
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const stop_thing_registration_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/thing-registration-tasks/{taskId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "StopThingRegistrationTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "taskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_thing_registration_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_thing_registration_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const test_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/test-authorization",
        .success_code = 200,
    };

    action_name: []const u8 = "TestAuthorization",
    Request: type = struct {
        principal: ?[]const u8 = null,
        cognito_identity_pool_id: ?[]const u8 = null,
        auth_infos: []AuthInfo,
        client_id: ?[]const u8 = null,
        policy_names_to_add: ?[][]const u8 = null,
        policy_names_to_skip: ?[][]const u8 = null,

        pub const http_query = .{
            .client_id = "clientId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "principal",
                .cognito_identity_pool_id = "cognitoIdentityPoolId",
                .auth_infos = "authInfos",
                .client_id = "clientId",
                .policy_names_to_add = "policyNamesToAdd",
                .policy_names_to_skip = "policyNamesToSkip",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_authorization) } {
            return .{ .service_metadata = service_metadata, .action = test_authorization };
        }
    },
    Response: type = struct {
        auth_results: ?[]struct {
            auth_info: ?AuthInfo = null,
            allowed: ?struct {
                policies: ?[]Policy = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policies = "policies",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            denied: ?struct {
                implicit_deny: ?struct {
                    policies: ?[]Policy = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .policies = "policies",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                explicit_deny: ?struct {
                    policies: ?[]Policy = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .policies = "policies",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .implicit_deny = "implicitDeny",
                        .explicit_deny = "explicitDeny",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            auth_decision: ?[]const u8 = null,
            missing_context_values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auth_info = "authInfo",
                    .allowed = "allowed",
                    .denied = "denied",
                    .auth_decision = "authDecision",
                    .missing_context_values = "missingContextValues",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auth_results = "authResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const test_invoke_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/authorizer/{authorizerName}/test",
        .success_code = 200,
    };

    action_name: []const u8 = "TestInvokeAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,
        token: ?[]const u8 = null,
        token_signature: ?[]const u8 = null,
        http_context: ?struct {
            headers: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            query_string: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .headers = "headers",
                    .query_string = "queryString",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "headers", field_name))
                    return try serializeMap(self.headers, self.fieldNameFor("headers"), options, out_stream);
                return false;
            }
        } = null,
        mqtt_context: ?struct {
            username: ?[]const u8 = null,
            password: ?[]const u8 = null,
            client_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .username = "username",
                    .password = "password",
                    .client_id = "clientId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tls_context: ?struct {
            server_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .server_name = "serverName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .token = "token",
                .token_signature = "tokenSignature",
                .http_context = "httpContext",
                .mqtt_context = "mqttContext",
                .tls_context = "tlsContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_invoke_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = test_invoke_authorizer };
        }
    },
    Response: type = struct {
        is_authenticated: ?bool = null,
        principal_id: ?[]const u8 = null,
        policy_documents: ?[][]const u8 = null,
        refresh_after_in_seconds: ?i64 = null,
        disconnect_after_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_authenticated = "isAuthenticated",
                .principal_id = "principalId",
                .policy_documents = "policyDocuments",
                .refresh_after_in_seconds = "refreshAfterInSeconds",
                .disconnect_after_in_seconds = "disconnectAfterInSeconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        InvalidResponse,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const transfer_certificate: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/transfer-certificate/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "TransferCertificate",
    Request: type = struct {
        certificate_id: []const u8,
        target_aws_account: []const u8,
        transfer_message: ?[]const u8 = null,

        pub const http_query = .{
            .target_aws_account = "targetAwsAccount",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .target_aws_account = "targetAwsAccount",
                .transfer_message = "transferMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(transfer_certificate) } {
            return .{ .service_metadata = service_metadata, .action = transfer_certificate };
        }
    },
    Response: type = struct {
        transferred_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transferred_certificate_arn = "transferredCertificateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateState,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        TransferConflict,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untag",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_account_audit_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/audit/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountAuditConfiguration",
    Request: type = struct {
        role_arn: ?[]const u8 = null,
        audit_notification_target_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AuditNotificationTarget = null,
        } = null,
        audit_check_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AuditCheckConfiguration = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "roleArn",
                .audit_notification_target_configurations = "auditNotificationTargetConfigurations",
                .audit_check_configurations = "auditCheckConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "audit_notification_target_configurations", field_name))
                return try serializeMap(self.audit_notification_target_configurations, self.fieldNameFor("audit_notification_target_configurations"), options, out_stream);
            if (std.mem.eql(u8, "audit_check_configurations", field_name))
                return try serializeMap(self.audit_check_configurations, self.fieldNameFor("audit_check_configurations"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_audit_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_account_audit_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const update_audit_suppression: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/audit/suppressions/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAuditSuppression",
    Request: type = struct {
        check_name: []const u8,
        resource_identifier: ResourceIdentifier,
        expiration_date: ?i64 = null,
        suppress_indefinitely: ?bool = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_name = "checkName",
                .resource_identifier = "resourceIdentifier",
                .expiration_date = "expirationDate",
                .suppress_indefinitely = "suppressIndefinitely",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_audit_suppression) } {
            return .{ .service_metadata = service_metadata, .action = update_audit_suppression };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_authorizer: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/authorizer/{authorizerName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAuthorizer",
    Request: type = struct {
        authorizer_name: []const u8,
        authorizer_function_arn: ?[]const u8 = null,
        token_key_name: ?[]const u8 = null,
        token_signing_public_keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        enable_caching_for_http: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .authorizer_function_arn = "authorizerFunctionArn",
                .token_key_name = "tokenKeyName",
                .token_signing_public_keys = "tokenSigningPublicKeys",
                .status = "status",
                .enable_caching_for_http = "enableCachingForHttp",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "token_signing_public_keys", field_name))
                return try serializeMap(self.token_signing_public_keys, self.fieldNameFor("token_signing_public_keys"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = update_authorizer };
        }
    },
    Response: type = struct {
        authorizer_name: ?[]const u8 = null,
        authorizer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorizer_name = "authorizerName",
                .authorizer_arn = "authorizerArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_billing_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/billing-groups/{billingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBillingGroup",
    Request: type = struct {
        billing_group_name: []const u8,
        billing_group_properties: BillingGroupProperties,
        expected_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .billing_group_name = "billingGroupName",
                .billing_group_properties = "billingGroupProperties",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_billing_group) } {
            return .{ .service_metadata = service_metadata, .action = update_billing_group };
        }
    },
    Response: type = struct {
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const update_ca_certificate: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cacertificate/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCACertificate",
    Request: type = struct {
        certificate_id: []const u8,
        new_status: ?[]const u8 = null,
        new_auto_registration_status: ?[]const u8 = null,
        registration_config: ?RegistrationConfig = null,
        remove_auto_registration: ?bool = null,

        pub const http_query = .{
            .new_status = "newStatus",
            .new_auto_registration_status = "newAutoRegistrationStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .new_status = "newStatus",
                .new_auto_registration_status = "newAutoRegistrationStatus",
                .registration_config = "registrationConfig",
                .remove_auto_registration = "removeAutoRegistration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ca_certificate) } {
            return .{ .service_metadata = service_metadata, .action = update_ca_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_certificate: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/certificates/{certificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCertificate",
    Request: type = struct {
        certificate_id: []const u8,
        new_status: []const u8,

        pub const http_query = .{
            .new_status = "newStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "certificateId",
                .new_status = "newStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_certificate) } {
            return .{ .service_metadata = service_metadata, .action = update_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CertificateState,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_certificate_provider: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/certificate-providers/{certificateProviderName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCertificateProvider",
    Request: type = struct {
        certificate_provider_name: []const u8,
        lambda_function_arn: ?[]const u8 = null,
        account_default_for_operations: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
                .lambda_function_arn = "lambdaFunctionArn",
                .account_default_for_operations = "accountDefaultForOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_certificate_provider) } {
            return .{ .service_metadata = service_metadata, .action = update_certificate_provider };
        }
    },
    Response: type = struct {
        certificate_provider_name: ?[]const u8 = null,
        certificate_provider_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_provider_name = "certificateProviderName",
                .certificate_provider_arn = "certificateProviderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_custom_metric: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/custom-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCustomMetric",
    Request: type = struct {
        metric_name: []const u8,
        display_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .display_name = "displayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_metric) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_metric };
        }
    },
    Response: type = struct {
        metric_name: ?[]const u8 = null,
        metric_arn: ?[]const u8 = null,
        metric_type: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .metric_arn = "metricArn",
                .metric_type = "metricType",
                .display_name = "displayName",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_dimension: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/dimensions/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDimension",
    Request: type = struct {
        name: []const u8,
        string_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .string_values = "stringValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dimension) } {
            return .{ .service_metadata = service_metadata, .action = update_dimension };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        type: ?[]const u8 = null,
        string_values: ?[][]const u8 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .arn = "arn",
                .type = "type",
                .string_values = "stringValues",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_domain_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domainConfigurations/{domainConfigurationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainConfiguration",
    Request: type = struct {
        domain_configuration_name: []const u8,
        authorizer_config: ?AuthorizerConfig = null,
        domain_configuration_status: ?[]const u8 = null,
        remove_authorizer_config: ?bool = null,
        tls_config: ?TlsConfig = null,
        server_certificate_config: ?ServerCertificateConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
                .authorizer_config = "authorizerConfig",
                .domain_configuration_status = "domainConfigurationStatus",
                .remove_authorizer_config = "removeAuthorizerConfig",
                .tls_config = "tlsConfig",
                .server_certificate_config = "serverCertificateConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_configuration };
        }
    },
    Response: type = struct {
        domain_configuration_name: ?[]const u8 = null,
        domain_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_configuration_name = "domainConfigurationName",
                .domain_configuration_arn = "domainConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CertificateValidation,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_dynamic_thing_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/dynamic-thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDynamicThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        thing_group_properties: ThingGroupProperties,
        expected_version: ?i64 = null,
        index_name: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_properties = "thingGroupProperties",
                .expected_version = "expectedVersion",
                .index_name = "indexName",
                .query_string = "queryString",
                .query_version = "queryVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dynamic_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = update_dynamic_thing_group };
        }
    },
    Response: type = struct {
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const update_event_configurations: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/event-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEventConfigurations",
    Request: type = struct {
        event_configurations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Configuration = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_configurations = "eventConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "event_configurations", field_name))
                return try serializeMap(self.event_configurations, self.fieldNameFor("event_configurations"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_configurations) } {
            return .{ .service_metadata = service_metadata, .action = update_event_configurations };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const update_fleet_metric: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/fleet-metric/{metricName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFleetMetric",
    Request: type = struct {
        metric_name: []const u8,
        query_string: ?[]const u8 = null,
        aggregation_type: ?AggregationType = null,
        period: ?i64 = null,
        aggregation_field: ?[]const u8 = null,
        description: ?[]const u8 = null,
        query_version: ?[]const u8 = null,
        index_name: []const u8,
        unit: ?[]const u8 = null,
        expected_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_name = "metricName",
                .query_string = "queryString",
                .aggregation_type = "aggregationType",
                .period = "period",
                .aggregation_field = "aggregationField",
                .description = "description",
                .query_version = "queryVersion",
                .index_name = "indexName",
                .unit = "unit",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet_metric) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet_metric };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        IndexNotReady,
        InternalFailure,
        InvalidAggregation,
        InvalidQuery,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionConflict,
    },
} = .{};
pub const update_indexing_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/indexing/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIndexingConfiguration",
    Request: type = struct {
        thing_indexing_configuration: ?ThingIndexingConfiguration = null,
        thing_group_indexing_configuration: ?ThingGroupIndexingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_indexing_configuration = "thingIndexingConfiguration",
                .thing_group_indexing_configuration = "thingGroupIndexingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_indexing_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_indexing_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_job: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJob",
    Request: type = struct {
        job_id: []const u8,
        description: ?[]const u8 = null,
        presigned_url_config: ?PresignedUrlConfig = null,
        job_executions_rollout_config: ?JobExecutionsRolloutConfig = null,
        abort_config: ?AbortConfig = null,
        timeout_config: ?TimeoutConfig = null,
        namespace_id: ?[]const u8 = null,
        job_executions_retry_config: ?JobExecutionsRetryConfig = null,

        pub const http_query = .{
            .namespace_id = "namespaceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .description = "description",
                .presigned_url_config = "presignedUrlConfig",
                .job_executions_rollout_config = "jobExecutionsRolloutConfig",
                .abort_config = "abortConfig",
                .timeout_config = "timeoutConfig",
                .namespace_id = "namespaceId",
                .job_executions_retry_config = "jobExecutionsRetryConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job) } {
            return .{ .service_metadata = service_metadata, .action = update_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_mitigation_action: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/mitigationactions/actions/{actionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMitigationAction",
    Request: type = struct {
        action_name: []const u8,
        role_arn: ?[]const u8 = null,
        action_params: ?MitigationActionParams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "actionName",
                .role_arn = "roleArn",
                .action_params = "actionParams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_mitigation_action) } {
            return .{ .service_metadata = service_metadata, .action = update_mitigation_action };
        }
    },
    Response: type = struct {
        action_arn: ?[]const u8 = null,
        action_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_arn = "actionArn",
                .action_id = "actionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_package: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/packages/{packageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackage",
    Request: type = struct {
        package_name: []const u8,
        description: ?[]const u8 = null,
        default_version_name: ?[]const u8 = null,
        unset_default_version: ?bool = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .description = "description",
                .default_version_name = "defaultVersionName",
                .unset_default_version = "unsetDefaultVersion",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package) } {
            return .{ .service_metadata = service_metadata, .action = update_package };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_package_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/package-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackageConfiguration",
    Request: type = struct {
        version_update_by_jobs_config: ?VersionUpdateByJobsConfig = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_update_by_jobs_config = "versionUpdateByJobsConfig",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_package_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_package_version: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/packages/{packageName}/versions/{versionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackageVersion",
    Request: type = struct {
        package_name: []const u8,
        version_name: []const u8,
        description: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        action: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "packageName",
                .version_name = "versionName",
                .description = "description",
                .attributes = "attributes",
                .action = "action",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package_version) } {
            return .{ .service_metadata = service_metadata, .action = update_package_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_provisioning_template: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/provisioning-templates/{templateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProvisioningTemplate",
    Request: type = struct {
        template_name: []const u8,
        description: ?[]const u8 = null,
        enabled: ?bool = null,
        default_version_id: ?i64 = null,
        provisioning_role_arn: ?[]const u8 = null,
        pre_provisioning_hook: ?ProvisioningHook = null,
        remove_pre_provisioning_hook: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .description = "description",
                .enabled = "enabled",
                .default_version_id = "defaultVersionId",
                .provisioning_role_arn = "provisioningRoleArn",
                .pre_provisioning_hook = "preProvisioningHook",
                .remove_pre_provisioning_hook = "removePreProvisioningHook",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_provisioning_template) } {
            return .{ .service_metadata = service_metadata, .action = update_provisioning_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Unauthorized,
    },
} = .{};
pub const update_role_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/role-aliases/{roleAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoleAlias",
    Request: type = struct {
        role_alias: []const u8,
        role_arn: ?[]const u8 = null,
        credential_duration_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
                .role_arn = "roleArn",
                .credential_duration_seconds = "credentialDurationSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_role_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_role_alias };
        }
    },
    Response: type = struct {
        role_alias: ?[]const u8 = null,
        role_alias_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_alias = "roleAlias",
                .role_alias_arn = "roleAliasArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_scheduled_audit: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/audit/scheduledaudits/{scheduledAuditName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateScheduledAudit",
    Request: type = struct {
        frequency: ?[]const u8 = null,
        day_of_month: ?[]const u8 = null,
        day_of_week: ?[]const u8 = null,
        target_check_names: ?[][]const u8 = null,
        scheduled_audit_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .frequency = "frequency",
                .day_of_month = "dayOfMonth",
                .day_of_week = "dayOfWeek",
                .target_check_names = "targetCheckNames",
                .scheduled_audit_name = "scheduledAuditName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scheduled_audit) } {
            return .{ .service_metadata = service_metadata, .action = update_scheduled_audit };
        }
    },
    Response: type = struct {
        scheduled_audit_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_audit_arn = "scheduledAuditArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_security_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/security-profiles/{securityProfileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        security_profile_description: ?[]const u8 = null,
        behaviors: ?[]Behavior = null,
        alert_targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AlertTarget = null,
        } = null,
        additional_metrics_to_retain: ?[][]const u8 = null,
        additional_metrics_to_retain_v2: ?[]MetricToRetain = null,
        delete_behaviors: ?bool = null,
        delete_alert_targets: ?bool = null,
        delete_additional_metrics_to_retain: ?bool = null,
        expected_version: ?i64 = null,
        metrics_export_config: ?MetricsExportConfig = null,
        delete_metrics_export_config: ?bool = null,

        pub const http_query = .{
            .expected_version = "expectedVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_description = "securityProfileDescription",
                .behaviors = "behaviors",
                .alert_targets = "alertTargets",
                .additional_metrics_to_retain = "additionalMetricsToRetain",
                .additional_metrics_to_retain_v2 = "additionalMetricsToRetainV2",
                .delete_behaviors = "deleteBehaviors",
                .delete_alert_targets = "deleteAlertTargets",
                .delete_additional_metrics_to_retain = "deleteAdditionalMetricsToRetain",
                .expected_version = "expectedVersion",
                .metrics_export_config = "metricsExportConfig",
                .delete_metrics_export_config = "deleteMetricsExportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "alert_targets", field_name))
                return try serializeMap(self.alert_targets, self.fieldNameFor("alert_targets"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_security_profile };
        }
    },
    Response: type = struct {
        security_profile_name: ?[]const u8 = null,
        security_profile_arn: ?[]const u8 = null,
        security_profile_description: ?[]const u8 = null,
        behaviors: ?[]Behavior = null,
        alert_targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?AlertTarget = null,
        } = null,
        additional_metrics_to_retain: ?[][]const u8 = null,
        additional_metrics_to_retain_v2: ?[]MetricToRetain = null,
        version: ?i64 = null,
        creation_date: ?i64 = null,
        last_modified_date: ?i64 = null,
        metrics_export_config: ?MetricsExportConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "securityProfileName",
                .security_profile_arn = "securityProfileArn",
                .security_profile_description = "securityProfileDescription",
                .behaviors = "behaviors",
                .alert_targets = "alertTargets",
                .additional_metrics_to_retain = "additionalMetricsToRetain",
                .additional_metrics_to_retain_v2 = "additionalMetricsToRetainV2",
                .version = "version",
                .creation_date = "creationDate",
                .last_modified_date = "lastModifiedDate",
                .metrics_export_config = "metricsExportConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "alert_targets", field_name))
                return try serializeMap(self.alert_targets, self.fieldNameFor("alert_targets"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const update_stream: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/streams/{streamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStream",
    Request: type = struct {
        stream_id: []const u8,
        description: ?[]const u8 = null,
        files: ?[]StreamFile = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
                .description = "description",
                .files = "files",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stream) } {
            return .{ .service_metadata = service_metadata, .action = update_stream };
        }
    },
    Response: type = struct {
        stream_id: ?[]const u8 = null,
        stream_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        stream_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "streamId",
                .stream_arn = "streamArn",
                .description = "description",
                .stream_version = "streamVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
    },
} = .{};
pub const update_thing: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/things/{thingName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThing",
    Request: type = struct {
        thing_name: []const u8,
        thing_type_name: ?[]const u8 = null,
        attribute_payload: ?AttributePayload = null,
        expected_version: ?i64 = null,
        remove_thing_type: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .thing_type_name = "thingTypeName",
                .attribute_payload = "attributePayload",
                .expected_version = "expectedVersion",
                .remove_thing_type = "removeThingType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thing) } {
            return .{ .service_metadata = service_metadata, .action = update_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Unauthorized,
        VersionConflict,
    },
} = .{};
pub const update_thing_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/thing-groups/{thingGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThingGroup",
    Request: type = struct {
        thing_group_name: []const u8,
        thing_group_properties: ThingGroupProperties,
        expected_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_group_name = "thingGroupName",
                .thing_group_properties = "thingGroupProperties",
                .expected_version = "expectedVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thing_group) } {
            return .{ .service_metadata = service_metadata, .action = update_thing_group };
        }
    },
    Response: type = struct {
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        VersionConflict,
    },
} = .{};
pub const update_thing_groups_for_thing: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/thing-groups/updateThingGroupsForThing",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThingGroupsForThing",
    Request: type = struct {
        thing_name: ?[]const u8 = null,
        thing_groups_to_add: ?[][]const u8 = null,
        thing_groups_to_remove: ?[][]const u8 = null,
        override_dynamic_groups: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thing_name = "thingName",
                .thing_groups_to_add = "thingGroupsToAdd",
                .thing_groups_to_remove = "thingGroupsToRemove",
                .override_dynamic_groups = "overrideDynamicGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_thing_groups_for_thing) } {
            return .{ .service_metadata = service_metadata, .action = update_thing_groups_for_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_topic_rule_destination: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTopicRuleDestination",
    Request: type = struct {
        arn: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_topic_rule_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_topic_rule_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingResourceUpdate,
        Internal,
        InvalidRequest,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const validate_security_profile_behaviors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/security-profile-behaviors/validate",
        .success_code = 200,
    };

    action_name: []const u8 = "ValidateSecurityProfileBehaviors",
    Request: type = struct {
        behaviors: []Behavior,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .behaviors = "behaviors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_security_profile_behaviors) } {
            return .{ .service_metadata = service_metadata, .action = validate_security_profile_behaviors };
        }
    },
    Response: type = struct {
        valid: ?bool = null,
        validation_errors: ?[]struct {
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .valid = "valid",
                .validation_errors = "validationErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        Throttling,
    },
} = .{};

pub const Behavior = struct {
    name: []const u8,
    metric: ?[]const u8 = null,
    metric_dimension: ?MetricDimension = null,
    criteria: ?BehaviorCriteria = null,
    suppress_alerts: ?bool = null,
    export_metric: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .metric = "metric",
            .metric_dimension = "metricDimension",
            .criteria = "criteria",
            .suppress_alerts = "suppressAlerts",
            .export_metric = "exportMetric",
        };
        return @field(mappings, field_name);
    }
};

pub const BehaviorCriteria = struct {
    comparison_operator: ?[]const u8 = null,
    value: ?MetricValue = null,
    duration_seconds: ?i64 = null,
    consecutive_datapoints_to_alarm: ?i64 = null,
    consecutive_datapoints_to_clear: ?i64 = null,
    statistical_threshold: ?StatisticalThreshold = null,
    ml_detection_config: ?MachineLearningDetectionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison_operator = "comparisonOperator",
            .value = "value",
            .duration_seconds = "durationSeconds",
            .consecutive_datapoints_to_alarm = "consecutiveDatapointsToAlarm",
            .consecutive_datapoints_to_clear = "consecutiveDatapointsToClear",
            .statistical_threshold = "statisticalThreshold",
            .ml_detection_config = "mlDetectionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const MachineLearningDetectionConfig = struct {
    confidence_level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence_level = "confidenceLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const StatisticalThreshold = struct {
    statistic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistic = "statistic",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricValue = struct {
    count: ?i64 = null,
    cidrs: ?[][]const u8 = null,
    ports: ?[]i64 = null,
    number: ?f64 = null,
    numbers: ?[]f64 = null,
    strings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "count",
            .cidrs = "cidrs",
            .ports = "ports",
            .number = "number",
            .numbers = "numbers",
            .strings = "strings",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDimension = struct {
    dimension_name: []const u8,
    operator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "dimensionName",
            .operator = "operator",
        };
        return @field(mappings, field_name);
    }
};

pub const ThingGroupProperties = struct {
    thing_group_description: ?[]const u8 = null,
    attribute_payload: ?AttributePayload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_group_description = "thingGroupDescription",
            .attribute_payload = "attributePayload",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributePayload = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    merge: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .merge = "merge",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const StreamFile = struct {
    file_id: ?i64 = null,
    s3_location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_id = "fileId",
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsExportConfig = struct {
    mqtt_topic: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mqtt_topic = "mqttTopic",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricToRetain = struct {
    metric: []const u8,
    metric_dimension: ?MetricDimension = null,
    export_metric: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric = "metric",
            .metric_dimension = "metricDimension",
            .export_metric = "exportMetric",
        };
        return @field(mappings, field_name);
    }
};

pub const AlertTarget = struct {
    alert_target_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alert_target_arn = "alertTargetArn",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningHook = struct {
    payload_version: ?[]const u8 = null,
    target_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_version = "payloadVersion",
            .target_arn = "targetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VersionUpdateByJobsConfig = struct {
    enabled: ?bool = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MitigationActionParams = struct {
    update_device_certificate_params: ?UpdateDeviceCertificateParams = null,
    update_ca_certificate_params: ?UpdateCACertificateParams = null,
    add_things_to_thing_group_params: ?AddThingsToThingGroupParams = null,
    replace_default_policy_version_params: ?ReplaceDefaultPolicyVersionParams = null,
    enable_io_t_logging_params: ?EnableIoTLoggingParams = null,
    publish_finding_to_sns_params: ?PublishFindingToSnsParams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_device_certificate_params = "updateDeviceCertificateParams",
            .update_ca_certificate_params = "updateCACertificateParams",
            .add_things_to_thing_group_params = "addThingsToThingGroupParams",
            .replace_default_policy_version_params = "replaceDefaultPolicyVersionParams",
            .enable_io_t_logging_params = "enableIoTLoggingParams",
            .publish_finding_to_sns_params = "publishFindingToSnsParams",
        };
        return @field(mappings, field_name);
    }
};

pub const PublishFindingToSnsParams = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "topicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EnableIoTLoggingParams = struct {
    role_arn_for_logging: []const u8,
    log_level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn_for_logging = "roleArnForLogging",
            .log_level = "logLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplaceDefaultPolicyVersionParams = struct {
    template_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_name = "templateName",
        };
        return @field(mappings, field_name);
    }
};

pub const AddThingsToThingGroupParams = struct {
    thing_group_names: [][]const u8,
    override_dynamic_groups: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_group_names = "thingGroupNames",
            .override_dynamic_groups = "overrideDynamicGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateCACertificateParams = struct {
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateDeviceCertificateParams = struct {
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const JobExecutionsRetryConfig = struct {
    criteria_list: []RetryCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criteria_list = "criteriaList",
        };
        return @field(mappings, field_name);
    }
};

pub const RetryCriteria = struct {
    failure_type: []const u8,
    number_of_retries: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_type = "failureType",
            .number_of_retries = "numberOfRetries",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeoutConfig = struct {
    in_progress_timeout_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .in_progress_timeout_in_minutes = "inProgressTimeoutInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const AbortConfig = struct {
    criteria_list: []AbortCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criteria_list = "criteriaList",
        };
        return @field(mappings, field_name);
    }
};

pub const AbortCriteria = struct {
    failure_type: []const u8,
    action: []const u8,
    threshold_percentage: f64,
    min_number_of_executed_things: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_type = "failureType",
            .action = "action",
            .threshold_percentage = "thresholdPercentage",
            .min_number_of_executed_things = "minNumberOfExecutedThings",
        };
        return @field(mappings, field_name);
    }
};

pub const JobExecutionsRolloutConfig = struct {
    maximum_per_minute: ?i64 = null,
    exponential_rate: ?ExponentialRolloutRate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_per_minute = "maximumPerMinute",
            .exponential_rate = "exponentialRate",
        };
        return @field(mappings, field_name);
    }
};

pub const ExponentialRolloutRate = struct {
    base_rate_per_minute: i64,
    increment_factor: f64,
    rate_increase_criteria: RateIncreaseCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_rate_per_minute = "baseRatePerMinute",
            .increment_factor = "incrementFactor",
            .rate_increase_criteria = "rateIncreaseCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const RateIncreaseCriteria = struct {
    number_of_notified_things: ?i64 = null,
    number_of_succeeded_things: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_notified_things = "numberOfNotifiedThings",
            .number_of_succeeded_things = "numberOfSucceededThings",
        };
        return @field(mappings, field_name);
    }
};

pub const PresignedUrlConfig = struct {
    role_arn: ?[]const u8 = null,
    expires_in_sec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .expires_in_sec = "expiresInSec",
        };
        return @field(mappings, field_name);
    }
};

pub const ThingGroupIndexingConfiguration = struct {
    thing_group_indexing_mode: []const u8,
    managed_fields: ?[]Field = null,
    custom_fields: ?[]Field = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_group_indexing_mode = "thingGroupIndexingMode",
            .managed_fields = "managedFields",
            .custom_fields = "customFields",
        };
        return @field(mappings, field_name);
    }
};

pub const Field = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ThingIndexingConfiguration = struct {
    thing_indexing_mode: []const u8,
    thing_connectivity_indexing_mode: ?[]const u8 = null,
    device_defender_indexing_mode: ?[]const u8 = null,
    named_shadow_indexing_mode: ?[]const u8 = null,
    managed_fields: ?[]Field = null,
    custom_fields: ?[]Field = null,
    filter: ?IndexingFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_indexing_mode = "thingIndexingMode",
            .thing_connectivity_indexing_mode = "thingConnectivityIndexingMode",
            .device_defender_indexing_mode = "deviceDefenderIndexingMode",
            .named_shadow_indexing_mode = "namedShadowIndexingMode",
            .managed_fields = "managedFields",
            .custom_fields = "customFields",
            .filter = "filter",
        };
        return @field(mappings, field_name);
    }
};

pub const IndexingFilter = struct {
    named_shadow_names: ?[][]const u8 = null,
    geo_locations: ?[]GeoLocationTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .named_shadow_names = "namedShadowNames",
            .geo_locations = "geoLocations",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocationTarget = struct {
    name: ?[]const u8 = null,
    order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .order = "order",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregationType = struct {
    name: []const u8,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const Configuration = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerCertificateConfig = struct {
    enable_ocsp_check: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_ocsp_check = "enableOCSPCheck",
        };
        return @field(mappings, field_name);
    }
};

pub const TlsConfig = struct {
    security_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_policy = "securityPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizerConfig = struct {
    default_authorizer_name: ?[]const u8 = null,
    allow_authorizer_override: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_authorizer_name = "defaultAuthorizerName",
            .allow_authorizer_override = "allowAuthorizerOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistrationConfig = struct {
    template_body: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    template_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_body = "templateBody",
            .role_arn = "roleArn",
            .template_name = "templateName",
        };
        return @field(mappings, field_name);
    }
};

pub const BillingGroupProperties = struct {
    billing_group_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .billing_group_description = "billingGroupDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceIdentifier = struct {
    device_certificate_id: ?[]const u8 = null,
    ca_certificate_id: ?[]const u8 = null,
    cognito_identity_pool_id: ?[]const u8 = null,
    client_id: ?[]const u8 = null,
    policy_version_identifier: ?PolicyVersionIdentifier = null,
    account: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,
    role_alias_arn: ?[]const u8 = null,
    issuer_certificate_identifier: ?IssuerCertificateIdentifier = null,
    device_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_certificate_id = "deviceCertificateId",
            .ca_certificate_id = "caCertificateId",
            .cognito_identity_pool_id = "cognitoIdentityPoolId",
            .client_id = "clientId",
            .policy_version_identifier = "policyVersionIdentifier",
            .account = "account",
            .iam_role_arn = "iamRoleArn",
            .role_alias_arn = "roleAliasArn",
            .issuer_certificate_identifier = "issuerCertificateIdentifier",
            .device_certificate_arn = "deviceCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IssuerCertificateIdentifier = struct {
    issuer_certificate_subject: ?[]const u8 = null,
    issuer_id: ?[]const u8 = null,
    issuer_certificate_serial_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer_certificate_subject = "issuerCertificateSubject",
            .issuer_id = "issuerId",
            .issuer_certificate_serial_number = "issuerCertificateSerialNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyVersionIdentifier = struct {
    policy_name: ?[]const u8 = null,
    policy_version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "policyName",
            .policy_version_id = "policyVersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditCheckConfiguration = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditNotificationTarget = struct {
    target_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "targetArn",
            .role_arn = "roleArn",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Policy = struct {
    policy_name: ?[]const u8 = null,
    policy_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "policyName",
            .policy_arn = "policyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthInfo = struct {
    action_type: ?[]const u8 = null,
    resources: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type = "actionType",
            .resources = "resources",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ViolationEventOccurrenceRange = struct {
    start_time: i64,
    end_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .end_time = "endTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectMitigationActionsTaskTarget = struct {
    violation_ids: ?[][]const u8 = null,
    security_profile_name: ?[]const u8 = null,
    behavior_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .violation_ids = "violationIds",
            .security_profile_name = "securityProfileName",
            .behavior_name = "behaviorName",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditMitigationActionsTaskTarget = struct {
    audit_task_id: ?[]const u8 = null,
    finding_ids: ?[][]const u8 = null,
    audit_check_to_reason_code_filter: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_task_id = "auditTaskId",
            .finding_ids = "findingIds",
            .audit_check_to_reason_code_filter = "auditCheckToReasonCodeFilter",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "audit_check_to_reason_code_filter", field_name))
            return try serializeMap(self.audit_check_to_reason_code_filter, self.fieldNameFor("audit_check_to_reason_code_filter"), options, out_stream);
        return false;
    }
};

pub const LogTarget = struct {
    target_type: []const u8,
    target_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_type = "targetType",
            .target_name = "targetName",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicRulePayload = struct {
    sql: []const u8,
    description: ?[]const u8 = null,
    actions: []Action,
    rule_disabled: ?bool = null,
    aws_iot_sql_version: ?[]const u8 = null,
    error_action: ?Action = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sql = "sql",
            .description = "description",
            .actions = "actions",
            .rule_disabled = "ruleDisabled",
            .aws_iot_sql_version = "awsIotSqlVersion",
            .error_action = "errorAction",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    dynamo_db: ?DynamoDBAction = null,
    dynamo_d_bv2: ?DynamoDBv2Action = null,
    lambda: ?LambdaAction = null,
    sns: ?SnsAction = null,
    sqs: ?SqsAction = null,
    kinesis: ?KinesisAction = null,
    republish: ?RepublishAction = null,
    s3: ?S3Action = null,
    firehose: ?FirehoseAction = null,
    cloudwatch_metric: ?CloudwatchMetricAction = null,
    cloudwatch_alarm: ?CloudwatchAlarmAction = null,
    cloudwatch_logs: ?CloudwatchLogsAction = null,
    elasticsearch: ?ElasticsearchAction = null,
    salesforce: ?SalesforceAction = null,
    iot_analytics: ?IotAnalyticsAction = null,
    iot_events: ?IotEventsAction = null,
    iot_site_wise: ?IotSiteWiseAction = null,
    step_functions: ?StepFunctionsAction = null,
    timestream: ?TimestreamAction = null,
    http: ?HttpAction = null,
    kafka: ?KafkaAction = null,
    open_search: ?OpenSearchAction = null,
    location: ?LocationAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamo_db = "dynamoDB",
            .dynamo_d_bv2 = "dynamoDBv2",
            .lambda = "lambda",
            .sns = "sns",
            .sqs = "sqs",
            .kinesis = "kinesis",
            .republish = "republish",
            .s3 = "s3",
            .firehose = "firehose",
            .cloudwatch_metric = "cloudwatchMetric",
            .cloudwatch_alarm = "cloudwatchAlarm",
            .cloudwatch_logs = "cloudwatchLogs",
            .elasticsearch = "elasticsearch",
            .salesforce = "salesforce",
            .iot_analytics = "iotAnalytics",
            .iot_events = "iotEvents",
            .iot_site_wise = "iotSiteWise",
            .step_functions = "stepFunctions",
            .timestream = "timestream",
            .http = "http",
            .kafka = "kafka",
            .open_search = "openSearch",
            .location = "location",
        };
        return @field(mappings, field_name);
    }
};

pub const LocationAction = struct {
    role_arn: []const u8,
    tracker_name: []const u8,
    device_id: []const u8,
    timestamp: ?LocationTimestamp = null,
    latitude: []const u8,
    longitude: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .tracker_name = "trackerName",
            .device_id = "deviceId",
            .timestamp = "timestamp",
            .latitude = "latitude",
            .longitude = "longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const LocationTimestamp = struct {
    value: []const u8,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenSearchAction = struct {
    role_arn: []const u8,
    endpoint: []const u8,
    index: []const u8,
    type: []const u8,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .endpoint = "endpoint",
            .index = "index",
            .type = "type",
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaAction = struct {
    destination_arn: []const u8,
    topic: []const u8,
    key: ?[]const u8 = null,
    partition: ?[]const u8 = null,
    client_properties: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    headers: ?[]KafkaActionHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_arn = "destinationArn",
            .topic = "topic",
            .key = "key",
            .partition = "partition",
            .client_properties = "clientProperties",
            .headers = "headers",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "client_properties", field_name))
            return try serializeMap(self.client_properties, self.fieldNameFor("client_properties"), options, out_stream);
        return false;
    }
};

pub const KafkaActionHeader = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpAction = struct {
    url: []const u8,
    confirmation_url: ?[]const u8 = null,
    headers: ?[]HttpActionHeader = null,
    auth: ?HttpAuthorization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url = "url",
            .confirmation_url = "confirmationUrl",
            .headers = "headers",
            .auth = "auth",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpAuthorization = struct {
    sigv4: ?SigV4Authorization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sigv4 = "sigv4",
        };
        return @field(mappings, field_name);
    }
};

pub const SigV4Authorization = struct {
    signing_region: []const u8,
    service_name: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_region = "signingRegion",
            .service_name = "serviceName",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpActionHeader = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamAction = struct {
    role_arn: []const u8,
    database_name: []const u8,
    table_name: []const u8,
    dimensions: []TimestreamDimension,
    timestamp: ?TimestreamTimestamp = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .database_name = "databaseName",
            .table_name = "tableName",
            .dimensions = "dimensions",
            .timestamp = "timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamTimestamp = struct {
    value: []const u8,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .unit = "unit",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamDimension = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const StepFunctionsAction = struct {
    execution_name_prefix: ?[]const u8 = null,
    state_machine_name: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_name_prefix = "executionNamePrefix",
            .state_machine_name = "stateMachineName",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IotSiteWiseAction = struct {
    put_asset_property_value_entries: []PutAssetPropertyValueEntry,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .put_asset_property_value_entries = "putAssetPropertyValueEntries",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PutAssetPropertyValueEntry = struct {
    entry_id: ?[]const u8 = null,
    asset_id: ?[]const u8 = null,
    property_id: ?[]const u8 = null,
    property_alias: ?[]const u8 = null,
    property_values: []AssetPropertyValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_id = "entryId",
            .asset_id = "assetId",
            .property_id = "propertyId",
            .property_alias = "propertyAlias",
            .property_values = "propertyValues",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyValue = struct {
    value: AssetPropertyVariant,
    timestamp: AssetPropertyTimestamp,
    quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .timestamp = "timestamp",
            .quality = "quality",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyTimestamp = struct {
    time_in_seconds: []const u8,
    offset_in_nanos: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_in_seconds = "timeInSeconds",
            .offset_in_nanos = "offsetInNanos",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetPropertyVariant = union {
    string_value: ?[]const u8,
    integer_value: ?[]const u8,
    double_value: ?[]const u8,
    boolean_value: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "stringValue",
            .integer_value = "integerValue",
            .double_value = "doubleValue",
            .boolean_value = "booleanValue",
        };
        return @field(mappings, field_name);
    }
};

pub const IotEventsAction = struct {
    input_name: []const u8,
    message_id: ?[]const u8 = null,
    batch_mode: ?bool = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_name = "inputName",
            .message_id = "messageId",
            .batch_mode = "batchMode",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const IotAnalyticsAction = struct {
    channel_arn: ?[]const u8 = null,
    channel_name: ?[]const u8 = null,
    batch_mode: ?bool = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_arn = "channelArn",
            .channel_name = "channelName",
            .batch_mode = "batchMode",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SalesforceAction = struct {
    token: []const u8,
    url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .token = "token",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchAction = struct {
    role_arn: []const u8,
    endpoint: []const u8,
    index: []const u8,
    type: []const u8,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .endpoint = "endpoint",
            .index = "index",
            .type = "type",
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudwatchLogsAction = struct {
    role_arn: []const u8,
    log_group_name: []const u8,
    batch_mode: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .log_group_name = "logGroupName",
            .batch_mode = "batchMode",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudwatchAlarmAction = struct {
    role_arn: []const u8,
    alarm_name: []const u8,
    state_reason: []const u8,
    state_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .alarm_name = "alarmName",
            .state_reason = "stateReason",
            .state_value = "stateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudwatchMetricAction = struct {
    role_arn: []const u8,
    metric_namespace: []const u8,
    metric_name: []const u8,
    metric_value: []const u8,
    metric_unit: []const u8,
    metric_timestamp: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .metric_namespace = "metricNamespace",
            .metric_name = "metricName",
            .metric_value = "metricValue",
            .metric_unit = "metricUnit",
            .metric_timestamp = "metricTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const FirehoseAction = struct {
    role_arn: []const u8,
    delivery_stream_name: []const u8,
    separator: ?[]const u8 = null,
    batch_mode: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .delivery_stream_name = "deliveryStreamName",
            .separator = "separator",
            .batch_mode = "batchMode",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Action = struct {
    role_arn: []const u8,
    bucket_name: []const u8,
    key: []const u8,
    canned_acl: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .bucket_name = "bucketName",
            .key = "key",
            .canned_acl = "cannedAcl",
        };
        return @field(mappings, field_name);
    }
};

pub const RepublishAction = struct {
    role_arn: []const u8,
    topic: []const u8,
    qos: ?i64 = null,
    headers: ?MqttHeaders = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .topic = "topic",
            .qos = "qos",
            .headers = "headers",
        };
        return @field(mappings, field_name);
    }
};

pub const MqttHeaders = struct {
    payload_format_indicator: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    response_topic: ?[]const u8 = null,
    correlation_data: ?[]const u8 = null,
    message_expiry: ?[]const u8 = null,
    user_properties: ?[]UserProperty = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_format_indicator = "payloadFormatIndicator",
            .content_type = "contentType",
            .response_topic = "responseTopic",
            .correlation_data = "correlationData",
            .message_expiry = "messageExpiry",
            .user_properties = "userProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const UserProperty = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisAction = struct {
    role_arn: []const u8,
    stream_name: []const u8,
    partition_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .stream_name = "streamName",
            .partition_key = "partitionKey",
        };
        return @field(mappings, field_name);
    }
};

pub const SqsAction = struct {
    role_arn: []const u8,
    queue_url: []const u8,
    use_base64: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .queue_url = "queueUrl",
            .use_base64 = "useBase64",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsAction = struct {
    target_arn: []const u8,
    role_arn: []const u8,
    message_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "targetArn",
            .role_arn = "roleArn",
            .message_format = "messageFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaAction = struct {
    function_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "functionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBv2Action = struct {
    role_arn: []const u8,
    put_item: PutItemInput,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .put_item = "putItem",
        };
        return @field(mappings, field_name);
    }
};

pub const PutItemInput = struct {
    table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "tableName",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBAction = struct {
    table_name: []const u8,
    role_arn: []const u8,
    operation: ?[]const u8 = null,
    hash_key_field: []const u8,
    hash_key_value: []const u8,
    hash_key_type: ?[]const u8 = null,
    range_key_field: ?[]const u8 = null,
    range_key_value: ?[]const u8 = null,
    range_key_type: ?[]const u8 = null,
    payload_field: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "tableName",
            .role_arn = "roleArn",
            .operation = "operation",
            .hash_key_field = "hashKeyField",
            .hash_key_value = "hashKeyValue",
            .hash_key_type = "hashKeyType",
            .range_key_field = "rangeKeyField",
            .range_key_value = "rangeKeyValue",
            .range_key_type = "rangeKeyType",
            .payload_field = "payloadField",
        };
        return @field(mappings, field_name);
    }
};

pub const ViolationEventAdditionalInfo = struct {
    confidence_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence_level = "confidenceLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const ThingTypeMetadata = struct {
    deprecated: ?bool = null,
    deprecation_date: ?i64 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deprecated = "deprecated",
            .deprecation_date = "deprecationDate",
            .creation_date = "creationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ThingTypeProperties = struct {
    thing_type_description: ?[]const u8 = null,
    searchable_attributes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .thing_type_description = "thingTypeDescription",
            .searchable_attributes = "searchableAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupNameAndArn = struct {
    group_name: ?[]const u8 = null,
    group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "groupName",
            .group_arn = "groupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityProfileTarget = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityProfileIdentifier = struct {
    name: []const u8,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedResource = struct {
    resource_type: ?[]const u8 = null,
    resource_identifier: ?ResourceIdentifier = null,
    additional_info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_identifier = "resourceIdentifier",
            .additional_info = "additionalInfo",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_info", field_name))
            return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
        return false;
    }
};

pub const JobExecutionSummary = struct {
    status: ?[]const u8 = null,
    queued_at: ?i64 = null,
    started_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    execution_number: ?i64 = null,
    retry_attempt: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .queued_at = "queuedAt",
            .started_at = "startedAt",
            .last_updated_at = "lastUpdatedAt",
            .execution_number = "executionNumber",
            .retry_attempt = "retryAttempt",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectMitigationActionsTaskSummary = struct {
    task_id: ?[]const u8 = null,
    task_status: ?[]const u8 = null,
    task_start_time: ?i64 = null,
    task_end_time: ?i64 = null,
    target: ?DetectMitigationActionsTaskTarget = null,
    violation_event_occurrence_range: ?ViolationEventOccurrenceRange = null,
    only_active_violations_included: ?bool = null,
    suppressed_alerts_included: ?bool = null,
    actions_definition: ?[]MitigationAction = null,
    task_statistics: ?DetectMitigationActionsTaskStatistics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_id = "taskId",
            .task_status = "taskStatus",
            .task_start_time = "taskStartTime",
            .task_end_time = "taskEndTime",
            .target = "target",
            .violation_event_occurrence_range = "violationEventOccurrenceRange",
            .only_active_violations_included = "onlyActiveViolationsIncluded",
            .suppressed_alerts_included = "suppressedAlertsIncluded",
            .actions_definition = "actionsDefinition",
            .task_statistics = "taskStatistics",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectMitigationActionsTaskStatistics = struct {
    actions_executed: ?i64 = null,
    actions_skipped: ?i64 = null,
    actions_failed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions_executed = "actionsExecuted",
            .actions_skipped = "actionsSkipped",
            .actions_failed = "actionsFailed",
        };
        return @field(mappings, field_name);
    }
};

pub const MitigationAction = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    action_params: ?MitigationActionParams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .id = "id",
            .role_arn = "roleArn",
            .action_params = "actionParams",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    certificate_arn: ?[]const u8 = null,
    certificate_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    certificate_mode: ?[]const u8 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .certificate_id = "certificateId",
            .status = "status",
            .certificate_mode = "certificateMode",
            .creation_date = "creationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditFinding = struct {
    finding_id: ?[]const u8 = null,
    task_id: ?[]const u8 = null,
    check_name: ?[]const u8 = null,
    task_start_time: ?i64 = null,
    finding_time: ?i64 = null,
    severity: ?[]const u8 = null,
    non_compliant_resource: ?NonCompliantResource = null,
    related_resources: ?[]RelatedResource = null,
    reason_for_non_compliance: ?[]const u8 = null,
    reason_for_non_compliance_code: ?[]const u8 = null,
    is_suppressed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .finding_id = "findingId",
            .task_id = "taskId",
            .check_name = "checkName",
            .task_start_time = "taskStartTime",
            .finding_time = "findingTime",
            .severity = "severity",
            .non_compliant_resource = "nonCompliantResource",
            .related_resources = "relatedResources",
            .reason_for_non_compliance = "reasonForNonCompliance",
            .reason_for_non_compliance_code = "reasonForNonComplianceCode",
            .is_suppressed = "isSuppressed",
        };
        return @field(mappings, field_name);
    }
};

pub const NonCompliantResource = struct {
    resource_type: ?[]const u8 = null,
    resource_identifier: ?ResourceIdentifier = null,
    additional_info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_identifier = "resourceIdentifier",
            .additional_info = "additionalInfo",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_info", field_name))
            return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
        return false;
    }
};

pub const TopicRuleDestination = struct {
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    status_reason: ?[]const u8 = null,
    http_url_properties: ?HttpUrlDestinationProperties = null,
    vpc_properties: ?VpcDestinationProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .status = "status",
            .created_at = "createdAt",
            .last_updated_at = "lastUpdatedAt",
            .status_reason = "statusReason",
            .http_url_properties = "httpUrlProperties",
            .vpc_properties = "vpcProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcDestinationProperties = struct {
    subnet_ids: ?[][]const u8 = null,
    security_groups: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "subnetIds",
            .security_groups = "securityGroups",
            .vpc_id = "vpcId",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpUrlDestinationProperties = struct {
    confirmation_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confirmation_url = "confirmationUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const OTAUpdateFile = struct {
    file_name: ?[]const u8 = null,
    file_type: ?i64 = null,
    file_version: ?[]const u8 = null,
    file_location: ?FileLocation = null,
    code_signing: ?CodeSigning = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_name = "fileName",
            .file_type = "fileType",
            .file_version = "fileVersion",
            .file_location = "fileLocation",
            .code_signing = "codeSigning",
            .attributes = "attributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const CodeSigning = struct {
    aws_signer_job_id: ?[]const u8 = null,
    start_signing_job_parameter: ?StartSigningJobParameter = null,
    custom_code_signing: ?CustomCodeSigning = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_signer_job_id = "awsSignerJobId",
            .start_signing_job_parameter = "startSigningJobParameter",
            .custom_code_signing = "customCodeSigning",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomCodeSigning = struct {
    signature: ?CodeSigningSignature = null,
    certificate_chain: ?CodeSigningCertificateChain = null,
    hash_algorithm: ?[]const u8 = null,
    signature_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signature = "signature",
            .certificate_chain = "certificateChain",
            .hash_algorithm = "hashAlgorithm",
            .signature_algorithm = "signatureAlgorithm",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeSigningCertificateChain = struct {
    certificate_name: ?[]const u8 = null,
    inline_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_name = "certificateName",
            .inline_document = "inlineDocument",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeSigningSignature = struct {
    inline_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inline_document = "inlineDocument",
        };
        return @field(mappings, field_name);
    }
};

pub const StartSigningJobParameter = struct {
    signing_profile_parameter: ?SigningProfileParameter = null,
    signing_profile_name: ?[]const u8 = null,
    destination: ?Destination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_profile_parameter = "signingProfileParameter",
            .signing_profile_name = "signingProfileName",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    s3_destination: ?S3Destination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_destination = "s3Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket: ?[]const u8 = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningProfileParameter = struct {
    certificate_arn: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    certificate_path_on_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .platform = "platform",
            .certificate_path_on_device = "certificatePathOnDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const FileLocation = struct {
    stream: ?Stream = null,
    s3_location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream = "stream",
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const Stream = struct {
    stream_id: ?[]const u8 = null,
    file_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_id = "streamId",
            .file_id = "fileId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsJobPresignedUrlConfig = struct {
    expires_in_sec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expires_in_sec = "expiresInSec",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsJobExecutionsRolloutConfig = struct {
    maximum_per_minute: ?i64 = null,
    exponential_rate: ?AwsJobExponentialRolloutRate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_per_minute = "maximumPerMinute",
            .exponential_rate = "exponentialRate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsJobExponentialRolloutRate = struct {
    base_rate_per_minute: i64,
    increment_factor: f64,
    rate_increase_criteria: AwsJobRateIncreaseCriteria,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_rate_per_minute = "baseRatePerMinute",
            .increment_factor = "incrementFactor",
            .rate_increase_criteria = "rateIncreaseCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsJobRateIncreaseCriteria = struct {
    number_of_notified_things: ?i64 = null,
    number_of_succeeded_things: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_notified_things = "numberOfNotifiedThings",
            .number_of_succeeded_things = "numberOfSucceededThings",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindow = struct {
    start_time: []const u8,
    duration_in_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .duration_in_minutes = "durationInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const SchedulingConfig = struct {
    start_time: ?[]const u8 = null,
    end_time: ?[]const u8 = null,
    end_behavior: ?[]const u8 = null,
    maintenance_windows: ?[]MaintenanceWindow = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .end_time = "endTime",
            .end_behavior = "endBehavior",
            .maintenance_windows = "maintenanceWindows",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizerDescription = struct {
    authorizer_name: ?[]const u8 = null,
    authorizer_arn: ?[]const u8 = null,
    authorizer_function_arn: ?[]const u8 = null,
    token_key_name: ?[]const u8 = null,
    token_signing_public_keys: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    status: ?[]const u8 = null,
    creation_date: ?i64 = null,
    last_modified_date: ?i64 = null,
    signing_disabled: ?bool = null,
    enable_caching_for_http: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorizer_name = "authorizerName",
            .authorizer_arn = "authorizerArn",
            .authorizer_function_arn = "authorizerFunctionArn",
            .token_key_name = "tokenKeyName",
            .token_signing_public_keys = "tokenSigningPublicKeys",
            .status = "status",
            .creation_date = "creationDate",
            .last_modified_date = "lastModifiedDate",
            .signing_disabled = "signingDisabled",
            .enable_caching_for_http = "enableCachingForHttp",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "token_signing_public_keys", field_name))
            return try serializeMap(self.token_signing_public_keys, self.fieldNameFor("token_signing_public_keys"), options, out_stream);
        return false;
    }
};

pub const CertificateValidity = struct {
    not_before: ?i64 = null,
    not_after: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .not_before = "notBefore",
            .not_after = "notAfter",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyPair = struct {
    public_key: ?[]const u8 = null,
    private_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .public_key = "PublicKey",
            .private_key = "PrivateKey",
        };
        return @field(mappings, field_name);
    }
};
