const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-22";
pub const sdk_id: []const u8 = "IoT Wireless";
pub const arn_namespace: ?[]const u8 = "iotwireless";
pub const endpoint_prefix: []const u8 = "api.iotwireless";
pub const sigv4_name: []const u8 = "iotwireless";
pub const name: []const u8 = "iotwireless";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-22",
    sdk_id: []const u8 = "IoT Wireless",
    arn_namespace: ?[]const u8 = "iotwireless",
    endpoint_prefix: []const u8 = "api.iotwireless",
    sigv4_name: []const u8 = "iotwireless",
    name: []const u8 = "iotwireless",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_aws_account_with_partner_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/partner-accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAwsAccountWithPartnerAccount",
    Request: type = struct {
        sidewalk: SidewalkAccountInfo,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_aws_account_with_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = associate_aws_account_with_partner_account };
        }
    },
    Response: type = struct {
        sidewalk: ?SidewalkAccountInfo = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_multicast_group_with_fuota_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/fuota-tasks/{Id}/multicast-group",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateMulticastGroupWithFuotaTask",
    Request: type = struct {
        id: []const u8,
        multicast_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .multicast_group_id = "MulticastGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_multicast_group_with_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = associate_multicast_group_with_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_device_with_fuota_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/fuota-tasks/{Id}/wireless-device",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessDeviceWithFuotaTask",
    Request: type = struct {
        id: []const u8,
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_device_with_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_device_with_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_device_with_multicast_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/multicast-groups/{Id}/wireless-device",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessDeviceWithMulticastGroup",
    Request: type = struct {
        id: []const u8,
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_device_with_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_device_with_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_device_with_thing: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-devices/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessDeviceWithThing",
    Request: type = struct {
        id: []const u8,
        thing_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_device_with_thing) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_device_with_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_gateway_with_certificate: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateWirelessGatewayWithCertificate",
    Request: type = struct {
        id: []const u8,
        iot_certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .iot_certificate_id = "IotCertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_gateway_with_certificate) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_gateway_with_certificate };
        }
    },
    Response: type = struct {
        iot_certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iot_certificate_id = "IotCertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_gateway_with_thing: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-gateways/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessGatewayWithThing",
    Request: type = struct {
        id: []const u8,
        thing_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_gateway_with_thing) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_gateway_with_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_multicast_group_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/multicast-groups/{Id}/session",
        .success_code = 204,
    };

    action_name: []const u8 = "CancelMulticastGroupSession",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_multicast_group_session) } {
            return .{ .service_metadata = service_metadata, .action = cancel_multicast_group_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/destinations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDestination",
    Request: type = struct {
        name: []const u8,
        expression_type: []const u8,
        expression: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .expression_type = "ExpressionType",
                .expression = "Expression",
                .description = "Description",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_destination };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_device_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/device-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeviceProfile",
    Request: type = struct {
        name: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDeviceProfile = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,
        sidewalk: ?struct {

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{};
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_device_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_fuota_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/fuota-tasks",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFuotaTask",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANFuotaTask = null,
        firmware_update_image: []const u8,
        firmware_update_role: []const u8,
        tags: ?[]Tag = null,
        redundancy_percent: ?i64 = null,
        fragment_size_bytes: ?i64 = null,
        fragment_interval_ms: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .client_request_token = "ClientRequestToken",
                .lo_ra_wan = "LoRaWAN",
                .firmware_update_image = "FirmwareUpdateImage",
                .firmware_update_role = "FirmwareUpdateRole",
                .tags = "Tags",
                .redundancy_percent = "RedundancyPercent",
                .fragment_size_bytes = "FragmentSizeBytes",
                .fragment_interval_ms = "FragmentIntervalMS",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = create_fuota_task };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_multicast_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/multicast-groups",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMulticastGroup",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        lo_ra_wan: LoRaWANMulticast,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .client_request_token = "ClientRequestToken",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = create_multicast_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_network_analyzer_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/network-analyzer-configurations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateNetworkAnalyzerConfiguration",
    Request: type = struct {
        name: []const u8,
        trace_content: ?TraceContent = null,
        wireless_devices: ?[][]const u8 = null,
        wireless_gateways: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,
        multicast_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .trace_content = "TraceContent",
                .wireless_devices = "WirelessDevices",
                .wireless_gateways = "WirelessGateways",
                .description = "Description",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
                .multicast_groups = "MulticastGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_analyzer_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_network_analyzer_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_service_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/service-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateServiceProfile",
    Request: type = struct {
        name: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            add_gw_metadata: ?bool = null,
            dr_min: ?i64 = null,
            dr_max: ?i64 = null,
            pr_allowed: ?bool = null,
            ra_allowed: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_gw_metadata = "AddGwMetadata",
                    .dr_min = "DrMin",
                    .dr_max = "DrMax",
                    .pr_allowed = "PrAllowed",
                    .ra_allowed = "RaAllowed",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_service_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessDevice",
    Request: type = struct {
        type: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        destination_name: []const u8,
        client_request_token: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDevice = null,
        tags: ?[]Tag = null,
        positioning: ?[]const u8 = null,
        sidewalk: ?struct {
            device_profile_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_profile_id = "DeviceProfileId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .name = "Name",
                .description = "Description",
                .destination_name = "DestinationName",
                .client_request_token = "ClientRequestToken",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .positioning = "Positioning",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_device };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateways",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGateway",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: LoRaWANGateway,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,
        wireless_gateway_task_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway_task };
        }
    },
    Response: type = struct {
        wireless_gateway_task_definition_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateway-task-definitions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGatewayTaskDefinition",
    Request: type = struct {
        auto_create_tasks: bool,
        name: ?[]const u8 = null,
        update: ?UpdateWirelessGatewayTaskCreate = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_create_tasks = "AutoCreateTasks",
                .name = "Name",
                .update = "Update",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/destinations/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_device_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/device-profiles/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDeviceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_device_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_fuota_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/fuota-tasks/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFuotaTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_multicast_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/multicast-groups/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMulticastGroup",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_network_analyzer_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/network-analyzer-configurations/{ConfigurationName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteNetworkAnalyzerConfiguration",
    Request: type = struct {
        configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_name = "ConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_analyzer_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_analyzer_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_queued_messages: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-devices/{Id}/data",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteQueuedMessages",
    Request: type = struct {
        id: []const u8,
        message_id: []const u8,
        wireless_device_type: ?[]const u8 = null,

        pub const http_query = .{
            .message_id = "messageId",
            .wireless_device_type = "WirelessDeviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .message_id = "MessageId",
                .wireless_device_type = "WirelessDeviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queued_messages) } {
            return .{ .service_metadata = service_metadata, .action = delete_queued_messages };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_service_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/service-profiles/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteServiceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_service_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-devices/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessDevice",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless_device_import_task/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessDeviceImportTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_device_import_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGateway",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateway-task-definitions/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGatewayTaskDefinition",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_wireless_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless-devices/{Identifier}/deregister",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterWirelessDevice",
    Request: type = struct {
        identifier: []const u8,
        wireless_device_type: ?[]const u8 = null,

        pub const http_query = .{
            .wireless_device_type = "WirelessDeviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .wireless_device_type = "WirelessDeviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = deregister_wireless_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_aws_account_from_partner_account: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateAwsAccountFromPartnerAccount",
    Request: type = struct {
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_aws_account_from_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_aws_account_from_partner_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_multicast_group_from_fuota_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/fuota-tasks/{Id}/multicast-groups/{MulticastGroupId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateMulticastGroupFromFuotaTask",
    Request: type = struct {
        id: []const u8,
        multicast_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .multicast_group_id = "MulticastGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_multicast_group_from_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_multicast_group_from_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disassociate_wireless_device_from_fuota_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/fuota-tasks/{Id}/wireless-devices/{WirelessDeviceId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessDeviceFromFuotaTask",
    Request: type = struct {
        id: []const u8,
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_device_from_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_device_from_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_device_from_multicast_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/multicast-groups/{Id}/wireless-devices/{WirelessDeviceId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessDeviceFromMulticastGroup",
    Request: type = struct {
        id: []const u8,
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_device_from_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_device_from_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_device_from_thing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-devices/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessDeviceFromThing",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_device_from_thing) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_device_from_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_gateway_from_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessGatewayFromCertificate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_gateway_from_certificate) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_gateway_from_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_gateway_from_thing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessGatewayFromThing",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_gateway_from_thing) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_gateway_from_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_destination) } {
            return .{ .service_metadata = service_metadata, .action = get_destination };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        expression: ?[]const u8 = null,
        expression_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .expression = "Expression",
                .expression_type = "ExpressionType",
                .description = "Description",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_device_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/device-profiles/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_device_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDeviceProfile = null,
        sidewalk: ?struct {
            application_server_public_key: ?[]const u8 = null,
            qualification_status: ?bool = null,
            dak_certificate_metadata: ?[]struct {
                certificate_id: []const u8,
                max_allowed_signature: ?i64 = null,
                factory_support: ?bool = null,
                ap_id: ?[]const u8 = null,
                device_type_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .certificate_id = "CertificateId",
                        .max_allowed_signature = "MaxAllowedSignature",
                        .factory_support = "FactorySupport",
                        .ap_id = "ApId",
                        .device_type_id = "DeviceTypeId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_server_public_key = "ApplicationServerPublicKey",
                    .qualification_status = "QualificationStatus",
                    .dak_certificate_metadata = "DakCertificateMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_event_configuration_by_resource_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/event-configurations-resource-types",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventConfigurationByResourceTypes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_configuration_by_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = get_event_configuration_by_resource_types };
        }
    },
    Response: type = struct {
        device_registration_state: ?DeviceRegistrationStateResourceTypeEventConfiguration = null,
        proximity: ?ProximityResourceTypeEventConfiguration = null,
        join: ?JoinResourceTypeEventConfiguration = null,
        connection_status: ?ConnectionStatusResourceTypeEventConfiguration = null,
        message_delivery_status: ?MessageDeliveryStatusResourceTypeEventConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_registration_state = "DeviceRegistrationState",
                .proximity = "Proximity",
                .join = "Join",
                .connection_status = "ConnectionStatus",
                .message_delivery_status = "MessageDeliveryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
    },
} = .{};
pub const get_fuota_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/fuota-tasks/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFuotaTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = get_fuota_task };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            rf_region: ?[]const u8 = null,
            start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rf_region = "RfRegion",
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        firmware_update_image: ?[]const u8 = null,
        firmware_update_role: ?[]const u8 = null,
        created_at: ?i64 = null,
        redundancy_percent: ?i64 = null,
        fragment_size_bytes: ?i64 = null,
        fragment_interval_ms: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .status = "Status",
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .firmware_update_image = "FirmwareUpdateImage",
                .firmware_update_role = "FirmwareUpdateRole",
                .created_at = "CreatedAt",
                .redundancy_percent = "RedundancyPercent",
                .fragment_size_bytes = "FragmentSizeBytes",
                .fragment_interval_ms = "FragmentIntervalMS",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_log_levels_by_resource_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/log-levels",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLogLevelsByResourceTypes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_log_levels_by_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = get_log_levels_by_resource_types };
        }
    },
    Response: type = struct {
        default_log_level: ?[]const u8 = null,
        wireless_gateway_log_options: ?[]WirelessGatewayLogOption = null,
        wireless_device_log_options: ?[]WirelessDeviceLogOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_log_level = "DefaultLogLevel",
                .wireless_gateway_log_options = "WirelessGatewayLogOptions",
                .wireless_device_log_options = "WirelessDeviceLogOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_multicast_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/multicast-groups/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMulticastGroup",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = get_multicast_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            rf_region: ?[]const u8 = null,
            dl_class: ?[]const u8 = null,
            number_of_devices_requested: ?i64 = null,
            number_of_devices_in_group: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rf_region = "RfRegion",
                    .dl_class = "DlClass",
                    .number_of_devices_requested = "NumberOfDevicesRequested",
                    .number_of_devices_in_group = "NumberOfDevicesInGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .lo_ra_wan = "LoRaWAN",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_multicast_group_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/multicast-groups/{Id}/session",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMulticastGroupSession",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multicast_group_session) } {
            return .{ .service_metadata = service_metadata, .action = get_multicast_group_session };
        }
    },
    Response: type = struct {
        lo_ra_wan: ?LoRaWANMulticastSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_analyzer_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/network-analyzer-configurations/{ConfigurationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkAnalyzerConfiguration",
    Request: type = struct {
        configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_name = "ConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_analyzer_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_network_analyzer_configuration };
        }
    },
    Response: type = struct {
        trace_content: ?TraceContent = null,
        wireless_devices: ?[][]const u8 = null,
        wireless_gateways: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        multicast_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trace_content = "TraceContent",
                .wireless_devices = "WirelessDevices",
                .wireless_gateways = "WirelessGateways",
                .description = "Description",
                .arn = "Arn",
                .name = "Name",
                .multicast_groups = "MulticastGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_partner_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPartnerAccount",
    Request: type = struct {
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = get_partner_account };
        }
    },
    Response: type = struct {
        sidewalk: ?SidewalkAccountInfoWithFingerprint = null,
        account_linked: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .account_linked = "AccountLinked",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_position: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/positions/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPosition",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_position) } {
            return .{ .service_metadata = service_metadata, .action = get_position };
        }
    },
    Response: type = struct {
        position: ?[]f32 = null,
        accuracy: ?struct {
            horizontal_accuracy: ?f32 = null,
            vertical_accuracy: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .horizontal_accuracy = "HorizontalAccuracy",
                    .vertical_accuracy = "VerticalAccuracy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        solver_type: ?[]const u8 = null,
        solver_provider: ?[]const u8 = null,
        solver_version: ?[]const u8 = null,
        timestamp: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "Position",
                .accuracy = "Accuracy",
                .solver_type = "SolverType",
                .solver_provider = "SolverProvider",
                .solver_version = "SolverVersion",
                .timestamp = "Timestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_position_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/position-configurations/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPositionConfiguration",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_position_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_position_configuration };
        }
    },
    Response: type = struct {
        solvers: ?PositionSolverDetails = null,
        destination: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solvers = "Solvers",
                .destination = "Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_position_estimate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/position-estimate",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPositionEstimate",
    Request: type = struct {
        wi_fi_access_points: ?[]struct {
            mac_address: []const u8,
            rss: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mac_address = "MacAddress",
                    .rss = "Rss",
                };
                return @field(mappings, field_name);
            }
        } = null,
        cell_towers: ?struct {
            gsm: ?[]struct {
                mcc: i64,
                mnc: i64,
                lac: i64,
                geran_cid: i64,
                gsm_local_id: ?struct {
                    bsic: i64,
                    bcch: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bsic = "Bsic",
                            .bcch = "Bcch",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                gsm_timing_advance: ?i64 = null,
                rx_level: ?i64 = null,
                gsm_nmr: ?[]struct {
                    bsic: i64,
                    bcch: i64,
                    rx_level: ?i64 = null,
                    global_identity: ?struct {
                        lac: i64,
                        geran_cid: i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .lac = "Lac",
                                .geran_cid = "GeranCid",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bsic = "Bsic",
                            .bcch = "Bcch",
                            .rx_level = "RxLevel",
                            .global_identity = "GlobalIdentity",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcc = "Mcc",
                        .mnc = "Mnc",
                        .lac = "Lac",
                        .geran_cid = "GeranCid",
                        .gsm_local_id = "GsmLocalId",
                        .gsm_timing_advance = "GsmTimingAdvance",
                        .rx_level = "RxLevel",
                        .gsm_nmr = "GsmNmr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            wcdma: ?[]struct {
                mcc: i64,
                mnc: i64,
                lac: ?i64 = null,
                utran_cid: i64,
                wcdma_local_id: ?struct {
                    uarfcndl: i64,
                    psc: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .uarfcndl = "Uarfcndl",
                            .psc = "Psc",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                rscp: ?i64 = null,
                path_loss: ?i64 = null,
                wcdma_nmr: ?[]struct {
                    uarfcndl: i64,
                    psc: i64,
                    utran_cid: i64,
                    rscp: ?i64 = null,
                    path_loss: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .uarfcndl = "Uarfcndl",
                            .psc = "Psc",
                            .utran_cid = "UtranCid",
                            .rscp = "Rscp",
                            .path_loss = "PathLoss",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcc = "Mcc",
                        .mnc = "Mnc",
                        .lac = "Lac",
                        .utran_cid = "UtranCid",
                        .wcdma_local_id = "WcdmaLocalId",
                        .rscp = "Rscp",
                        .path_loss = "PathLoss",
                        .wcdma_nmr = "WcdmaNmr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tdscdma: ?[]struct {
                mcc: i64,
                mnc: i64,
                lac: ?i64 = null,
                utran_cid: i64,
                tdscdma_local_id: ?struct {
                    uarfcn: i64,
                    cell_params: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .uarfcn = "Uarfcn",
                            .cell_params = "CellParams",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                tdscdma_timing_advance: ?i64 = null,
                rscp: ?i64 = null,
                path_loss: ?i64 = null,
                tdscdma_nmr: ?[]struct {
                    uarfcn: i64,
                    cell_params: i64,
                    utran_cid: ?i64 = null,
                    rscp: ?i64 = null,
                    path_loss: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .uarfcn = "Uarfcn",
                            .cell_params = "CellParams",
                            .utran_cid = "UtranCid",
                            .rscp = "Rscp",
                            .path_loss = "PathLoss",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcc = "Mcc",
                        .mnc = "Mnc",
                        .lac = "Lac",
                        .utran_cid = "UtranCid",
                        .tdscdma_local_id = "TdscdmaLocalId",
                        .tdscdma_timing_advance = "TdscdmaTimingAdvance",
                        .rscp = "Rscp",
                        .path_loss = "PathLoss",
                        .tdscdma_nmr = "TdscdmaNmr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lte: ?[]struct {
                mcc: i64,
                mnc: i64,
                eutran_cid: i64,
                tac: ?i64 = null,
                lte_local_id: ?struct {
                    pci: i64,
                    earfcn: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pci = "Pci",
                            .earfcn = "Earfcn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                lte_timing_advance: ?i64 = null,
                rsrp: ?i64 = null,
                rsrq: ?f32 = null,
                nr_capable: ?bool = null,
                lte_nmr: ?[]struct {
                    pci: i64,
                    earfcn: i64,
                    eutran_cid: i64,
                    rsrp: ?i64 = null,
                    rsrq: ?f32 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pci = "Pci",
                            .earfcn = "Earfcn",
                            .eutran_cid = "EutranCid",
                            .rsrp = "Rsrp",
                            .rsrq = "Rsrq",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mcc = "Mcc",
                        .mnc = "Mnc",
                        .eutran_cid = "EutranCid",
                        .tac = "Tac",
                        .lte_local_id = "LteLocalId",
                        .lte_timing_advance = "LteTimingAdvance",
                        .rsrp = "Rsrp",
                        .rsrq = "Rsrq",
                        .nr_capable = "NrCapable",
                        .lte_nmr = "LteNmr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cdma: ?[]struct {
                system_id: i64,
                network_id: i64,
                base_station_id: i64,
                registration_zone: ?i64 = null,
                cdma_local_id: ?struct {
                    pn_offset: i64,
                    cdma_channel: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pn_offset = "PnOffset",
                            .cdma_channel = "CdmaChannel",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                pilot_power: ?i64 = null,
                base_lat: ?f32 = null,
                base_lng: ?f32 = null,
                cdma_nmr: ?[]struct {
                    pn_offset: i64,
                    cdma_channel: i64,
                    pilot_power: ?i64 = null,
                    base_station_id: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pn_offset = "PnOffset",
                            .cdma_channel = "CdmaChannel",
                            .pilot_power = "PilotPower",
                            .base_station_id = "BaseStationId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .system_id = "SystemId",
                        .network_id = "NetworkId",
                        .base_station_id = "BaseStationId",
                        .registration_zone = "RegistrationZone",
                        .cdma_local_id = "CdmaLocalId",
                        .pilot_power = "PilotPower",
                        .base_lat = "BaseLat",
                        .base_lng = "BaseLng",
                        .cdma_nmr = "CdmaNmr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gsm = "Gsm",
                    .wcdma = "Wcdma",
                    .tdscdma = "Tdscdma",
                    .lte = "Lte",
                    .cdma = "Cdma",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ip: ?struct {
            ip_address: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ip_address = "IpAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,
        gnss: ?struct {
            payload: []const u8,
            capture_time: ?f32 = null,
            capture_time_accuracy: ?f32 = null,
            assist_position: ?[]f32 = null,
            assist_altitude: ?f32 = null,
            use2d_solver: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .payload = "Payload",
                    .capture_time = "CaptureTime",
                    .capture_time_accuracy = "CaptureTimeAccuracy",
                    .assist_position = "AssistPosition",
                    .assist_altitude = "AssistAltitude",
                    .use2d_solver = "Use2DSolver",
                };
                return @field(mappings, field_name);
            }
        } = null,
        timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wi_fi_access_points = "WiFiAccessPoints",
                .cell_towers = "CellTowers",
                .ip = "Ip",
                .gnss = "Gnss",
                .timestamp = "Timestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_position_estimate) } {
            return .{ .service_metadata = service_metadata, .action = get_position_estimate };
        }
    },
    Response: type = struct {
        geo_json_payload: ?[]const u8 = null,

        pub const http_payload: []const u8 = "geo_json_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_json_payload = "GeoJsonPayload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_event_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/event-configurations/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceEventConfiguration",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,
        partner_type: ?[]const u8 = null,

        pub const http_query = .{
            .identifier_type = "identifierType",
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_event_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_event_configuration };
        }
    },
    Response: type = struct {
        device_registration_state: ?DeviceRegistrationStateEventConfiguration = null,
        proximity: ?ProximityEventConfiguration = null,
        join: ?JoinEventConfiguration = null,
        connection_status: ?ConnectionStatusEventConfiguration = null,
        message_delivery_status: ?MessageDeliveryStatusEventConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_registration_state = "DeviceRegistrationState",
                .proximity = "Proximity",
                .join = "Join",
                .connection_status = "ConnectionStatus",
                .message_delivery_status = "MessageDeliveryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_log_level: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/log-levels/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceLogLevel",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_log_level) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_log_level };
        }
    },
    Response: type = struct {
        log_level: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .log_level = "LogLevel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_position: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-positions/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePosition",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_position) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_position };
        }
    },
    Response: type = struct {
        geo_json_payload: ?[]const u8 = null,

        pub const http_payload: []const u8 = "geo_json_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_json_payload = "GeoJsonPayload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-endpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceEndpoint",
    Request: type = struct {
        service_type: ?[]const u8 = null,

        pub const http_query = .{
            .service_type = "serviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_service_endpoint };
        }
    },
    Response: type = struct {
        service_type: ?[]const u8 = null,
        service_endpoint: ?[]const u8 = null,
        server_trust: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .service_endpoint = "ServiceEndpoint",
                .server_trust = "ServerTrust",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-profiles/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_service_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            ul_rate: ?i64 = null,
            ul_bucket_size: ?i64 = null,
            ul_rate_policy: ?[]const u8 = null,
            dl_rate: ?i64 = null,
            dl_bucket_size: ?i64 = null,
            dl_rate_policy: ?[]const u8 = null,
            add_gw_metadata: ?bool = null,
            dev_status_req_freq: ?i64 = null,
            report_dev_status_battery: ?bool = null,
            report_dev_status_margin: ?bool = null,
            dr_min: ?i64 = null,
            dr_max: ?i64 = null,
            channel_mask: ?[]const u8 = null,
            pr_allowed: ?bool = null,
            hr_allowed: ?bool = null,
            ra_allowed: ?bool = null,
            nwk_geo_loc: ?bool = null,
            target_per: ?i64 = null,
            min_gw_diversity: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ul_rate = "UlRate",
                    .ul_bucket_size = "UlBucketSize",
                    .ul_rate_policy = "UlRatePolicy",
                    .dl_rate = "DlRate",
                    .dl_bucket_size = "DlBucketSize",
                    .dl_rate_policy = "DlRatePolicy",
                    .add_gw_metadata = "AddGwMetadata",
                    .dev_status_req_freq = "DevStatusReqFreq",
                    .report_dev_status_battery = "ReportDevStatusBattery",
                    .report_dev_status_margin = "ReportDevStatusMargin",
                    .dr_min = "DrMin",
                    .dr_max = "DrMax",
                    .channel_mask = "ChannelMask",
                    .pr_allowed = "PrAllowed",
                    .hr_allowed = "HrAllowed",
                    .ra_allowed = "RaAllowed",
                    .nwk_geo_loc = "NwkGeoLoc",
                    .target_per = "TargetPer",
                    .min_gw_diversity = "MinGwDiversity",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessDevice",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,

        pub const http_query = .{
            .identifier_type = "identifierType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_device };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDevice = null,
        sidewalk: ?struct {
            amazon_id: ?[]const u8 = null,
            sidewalk_id: ?[]const u8 = null,
            sidewalk_manufacturing_sn: ?[]const u8 = null,
            device_certificates: ?[]CertificateList = null,
            private_keys: ?[]CertificateList = null,
            device_profile_id: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amazon_id = "AmazonId",
                    .sidewalk_id = "SidewalkId",
                    .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                    .device_certificates = "DeviceCertificates",
                    .private_keys = "PrivateKeys",
                    .device_profile_id = "DeviceProfileId",
                    .certificate_id = "CertificateId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        positioning: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .name = "Name",
                .description = "Description",
                .destination_name = "DestinationName",
                .id = "Id",
                .arn = "Arn",
                .thing_name = "ThingName",
                .thing_arn = "ThingArn",
                .lo_ra_wan = "LoRaWAN",
                .sidewalk = "Sidewalk",
                .positioning = "Positioning",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless_device_import_task/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessDeviceImportTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_device_import_task };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        sidewalk: ?SidewalkGetStartImportInfo = null,
        creation_time: ?i64 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        initialized_imported_device_count: ?i64 = null,
        pending_imported_device_count: ?i64 = null,
        onboarded_imported_device_count: ?i64 = null,
        failed_imported_device_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
                .destination_name = "DestinationName",
                .sidewalk = "Sidewalk",
                .creation_time = "CreationTime",
                .status = "Status",
                .status_reason = "StatusReason",
                .initialized_imported_device_count = "InitializedImportedDeviceCount",
                .pending_imported_device_count = "PendingImportedDeviceCount",
                .onboarded_imported_device_count = "OnboardedImportedDeviceCount",
                .failed_imported_device_count = "FailedImportedDeviceCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_device_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices/{WirelessDeviceId}/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessDeviceStatistics",
    Request: type = struct {
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_device_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_device_statistics };
        }
    },
    Response: type = struct {
        wireless_device_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            dev_eui: ?[]const u8 = null,
            f_port: ?i64 = null,
            data_rate: ?i64 = null,
            frequency: ?i64 = null,
            timestamp: ?[]const u8 = null,
            gateways: ?[]struct {
                gateway_eui: ?[]const u8 = null,
                snr: ?f64 = null,
                rssi: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .gateway_eui = "GatewayEui",
                        .snr = "Snr",
                        .rssi = "Rssi",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dev_eui = "DevEui",
                    .f_port = "FPort",
                    .data_rate = "DataRate",
                    .frequency = "Frequency",
                    .timestamp = "Timestamp",
                    .gateways = "Gateways",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sidewalk: ?struct {
            rssi: ?i64 = null,
            battery_level: ?[]const u8 = null,
            event: ?[]const u8 = null,
            device_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rssi = "Rssi",
                    .battery_level = "BatteryLevel",
                    .event = "Event",
                    .device_state = "DeviceState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_device_id = "WirelessDeviceId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .lo_ra_wan = "LoRaWAN",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGateway",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,

        pub const http_query = .{
            .identifier_type = "identifierType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANGateway = null,
        arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .id = "Id",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .arn = "Arn",
                .thing_name = "ThingName",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_certificate: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayCertificate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_certificate };
        }
    },
    Response: type = struct {
        iot_certificate_id: ?[]const u8 = null,
        lo_ra_wan_network_server_certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iot_certificate_id = "IotCertificateId",
                .lo_ra_wan_network_server_certificate_id = "LoRaWANNetworkServerCertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_firmware_information: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/firmware-information",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayFirmwareInformation",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_firmware_information) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_firmware_information };
        }
    },
    Response: type = struct {
        lo_ra_wan: ?struct {
            current_version: ?LoRaWANGatewayVersion = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_version = "CurrentVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{WirelessGatewayId}/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayStatistics",
    Request: type = struct {
        wireless_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_statistics };
        }
    },
    Response: type = struct {
        wireless_gateway_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        connection_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .connection_status = "ConnectionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_task };
        }
    },
    Response: type = struct {
        wireless_gateway_id: ?[]const u8 = null,
        wireless_gateway_task_definition_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        task_created_at: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .task_created_at = "TaskCreatedAt",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateway-task-definitions/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayTaskDefinition",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {
        auto_create_tasks: ?bool = null,
        name: ?[]const u8 = null,
        update: ?UpdateWirelessGatewayTaskCreate = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_create_tasks = "AutoCreateTasks",
                .name = "Name",
                .update = "Update",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDestinations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_destinations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        destination_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            expression_type: ?[]const u8 = null,
            expression: ?[]const u8 = null,
            description: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .expression_type = "ExpressionType",
                    .expression = "Expression",
                    .description = "Description",
                    .role_arn = "RoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .destination_list = "DestinationList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_device_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/device-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        device_profile_type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .device_profile_type = "deviceProfileType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .device_profile_type = "DeviceProfileType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_device_profiles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        device_profile_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .device_profile_list = "DeviceProfileList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_devices_for_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless_device_import_task",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevicesForWirelessDeviceImportTask",
    Request: type = struct {
        id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .status = "status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices_for_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = list_devices_for_wireless_device_import_task };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        imported_wireless_device_list: ?[]struct {
            sidewalk: ?struct {
                sidewalk_manufacturing_sn: ?[]const u8 = null,
                onboarding_status: ?[]const u8 = null,
                onboarding_status_reason: ?[]const u8 = null,
                last_update_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                        .onboarding_status = "OnboardingStatus",
                        .onboarding_status_reason = "OnboardingStatusReason",
                        .last_update_time = "LastUpdateTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sidewalk = "Sidewalk",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .destination_name = "DestinationName",
                .imported_wireless_device_list = "ImportedWirelessDeviceList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_event_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/event-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventConfigurations",
    Request: type = struct {
        resource_type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_event_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        event_configurations_list: ?[]struct {
            identifier: ?[]const u8 = null,
            identifier_type: ?[]const u8 = null,
            partner_type: ?[]const u8 = null,
            events: ?struct {
                device_registration_state: ?DeviceRegistrationStateEventConfiguration = null,
                proximity: ?ProximityEventConfiguration = null,
                join: ?JoinEventConfiguration = null,
                connection_status: ?ConnectionStatusEventConfiguration = null,
                message_delivery_status: ?MessageDeliveryStatusEventConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .device_registration_state = "DeviceRegistrationState",
                        .proximity = "Proximity",
                        .join = "Join",
                        .connection_status = "ConnectionStatus",
                        .message_delivery_status = "MessageDeliveryStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "Identifier",
                    .identifier_type = "IdentifierType",
                    .partner_type = "PartnerType",
                    .events = "Events",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .event_configurations_list = "EventConfigurationsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fuota_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/fuota-tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFuotaTasks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fuota_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_fuota_tasks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        fuota_task_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .fuota_task_list = "FuotaTaskList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_multicast_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/multicast-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMulticastGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multicast_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_multicast_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        multicast_group_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .multicast_group_list = "MulticastGroupList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_multicast_groups_by_fuota_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/fuota-tasks/{Id}/multicast-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMulticastGroupsByFuotaTask",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multicast_groups_by_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = list_multicast_groups_by_fuota_task };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        multicast_group_list: ?[]struct {
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .multicast_group_list = "MulticastGroupList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_network_analyzer_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/network-analyzer-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNetworkAnalyzerConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_network_analyzer_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_network_analyzer_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        network_analyzer_configuration_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .network_analyzer_configuration_list = "NetworkAnalyzerConfigurationList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_partner_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/partner-accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPartnerAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_partner_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_partner_accounts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sidewalk: ?[]SidewalkAccountInfoWithFingerprint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_position_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/position-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPositionConfigurations",
    Request: type = struct {
        resource_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_position_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_position_configurations };
        }
    },
    Response: type = struct {
        position_configuration_list: ?[]struct {
            resource_identifier: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            solvers: ?PositionSolverDetails = null,
            destination: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_identifier = "ResourceIdentifier",
                    .resource_type = "ResourceType",
                    .solvers = "Solvers",
                    .destination = "Destination",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position_configuration_list = "PositionConfigurationList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_queued_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices/{Id}/data",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueuedMessages",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        wireless_device_type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .wireless_device_type = "WirelessDeviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .wireless_device_type = "WirelessDeviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queued_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_queued_messages };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        downlink_queue_messages_list: ?[]struct {
            message_id: ?[]const u8 = null,
            transmit_mode: ?i64 = null,
            received_at: ?[]const u8 = null,
            lo_ra_wan: ?LoRaWANSendDataToDevice = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "MessageId",
                    .transmit_mode = "TransmitMode",
                    .received_at = "ReceivedAt",
                    .lo_ra_wan = "LoRaWAN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .downlink_queue_messages_list = "DownlinkQueueMessagesList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_service_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListServiceProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_service_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_service_profiles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        service_profile_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .service_profile_list = "ServiceProfileList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_device_import_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless_device_import_tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessDeviceImportTasks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_device_import_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_device_import_tasks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        wireless_device_import_task_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            destination_name: ?[]const u8 = null,
            sidewalk: ?SidewalkGetStartImportInfo = null,
            creation_time: ?i64 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            initialized_imported_device_count: ?i64 = null,
            pending_imported_device_count: ?i64 = null,
            onboarded_imported_device_count: ?i64 = null,
            failed_imported_device_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .destination_name = "DestinationName",
                    .sidewalk = "Sidewalk",
                    .creation_time = "CreationTime",
                    .status = "Status",
                    .status_reason = "StatusReason",
                    .initialized_imported_device_count = "InitializedImportedDeviceCount",
                    .pending_imported_device_count = "PendingImportedDeviceCount",
                    .onboarded_imported_device_count = "OnboardedImportedDeviceCount",
                    .failed_imported_device_count = "FailedImportedDeviceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .wireless_device_import_task_list = "WirelessDeviceImportTaskList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessDevices",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        device_profile_id: ?[]const u8 = null,
        service_profile_id: ?[]const u8 = null,
        wireless_device_type: ?[]const u8 = null,
        fuota_task_id: ?[]const u8 = null,
        multicast_group_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .destination_name = "destinationName",
            .device_profile_id = "deviceProfileId",
            .service_profile_id = "serviceProfileId",
            .wireless_device_type = "wirelessDeviceType",
            .fuota_task_id = "fuotaTaskId",
            .multicast_group_id = "multicastGroupId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .destination_name = "DestinationName",
                .device_profile_id = "DeviceProfileId",
                .service_profile_id = "ServiceProfileId",
                .wireless_device_type = "WirelessDeviceType",
                .fuota_task_id = "FuotaTaskId",
                .multicast_group_id = "MulticastGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_devices };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        wireless_device_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            destination_name: ?[]const u8 = null,
            last_uplink_received_at: ?[]const u8 = null,
            lo_ra_wan: ?struct {
                dev_eui: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dev_eui = "DevEui",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sidewalk: ?struct {
                amazon_id: ?[]const u8 = null,
                sidewalk_id: ?[]const u8 = null,
                sidewalk_manufacturing_sn: ?[]const u8 = null,
                device_certificates: ?[]CertificateList = null,
                device_profile_id: ?[]const u8 = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .amazon_id = "AmazonId",
                        .sidewalk_id = "SidewalkId",
                        .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                        .device_certificates = "DeviceCertificates",
                        .device_profile_id = "DeviceProfileId",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fuota_device_status: ?[]const u8 = null,
            multicast_device_status: ?[]const u8 = null,
            mc_group_id: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .type = "Type",
                    .name = "Name",
                    .destination_name = "DestinationName",
                    .last_uplink_received_at = "LastUplinkReceivedAt",
                    .lo_ra_wan = "LoRaWAN",
                    .sidewalk = "Sidewalk",
                    .fuota_device_status = "FuotaDeviceStatus",
                    .multicast_device_status = "MulticastDeviceStatus",
                    .mc_group_id = "McGroupId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .wireless_device_list = "WirelessDeviceList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_gateways: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessGateways",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_gateways) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_gateways };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        wireless_gateway_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            lo_ra_wan: ?LoRaWANGateway = null,
            last_uplink_received_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .lo_ra_wan = "LoRaWAN",
                    .last_uplink_received_at = "LastUplinkReceivedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .wireless_gateway_list = "WirelessGatewayList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_gateway_task_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateway-task-definitions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessGatewayTaskDefinitions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        task_definition_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .task_definition_type = "taskDefinitionType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .task_definition_type = "TaskDefinitionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_gateway_task_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_gateway_task_definitions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        task_definitions: ?[]struct {
            id: ?[]const u8 = null,
            lo_ra_wan: ?struct {
                current_version: ?LoRaWANGatewayVersion = null,
                update_version: ?LoRaWANGatewayVersion = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .current_version = "CurrentVersion",
                        .update_version = "UpdateVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .lo_ra_wan = "LoRaWAN",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .task_definitions = "TaskDefinitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const put_position_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/position-configurations/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPositionConfiguration",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,
        solvers: ?struct {
            semtech_gnss: ?struct {
                status: []const u8,
                fec: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .fec = "Fec",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .semtech_gnss = "SemtechGnss",
                };
                return @field(mappings, field_name);
            }
        } = null,
        destination: ?[]const u8 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
                .solvers = "Solvers",
                .destination = "Destination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_position_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_position_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_log_level: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/log-levels/{ResourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourceLogLevel",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,
        log_level: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
                .log_level = "LogLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_log_level) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_log_level };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const reset_all_resource_log_levels: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/log-levels",
        .success_code = 204,
    };

    action_name: []const u8 = "ResetAllResourceLogLevels",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_all_resource_log_levels) } {
            return .{ .service_metadata = service_metadata, .action = reset_all_resource_log_levels };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const reset_resource_log_level: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/log-levels/{ResourceIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "ResetResourceLogLevel",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_resource_log_level) } {
            return .{ .service_metadata = service_metadata, .action = reset_resource_log_level };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_data_to_multicast_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/multicast-groups/{Id}/data",
        .success_code = 201,
    };

    action_name: []const u8 = "SendDataToMulticastGroup",
    Request: type = struct {
        id: []const u8,
        payload_data: []const u8,
        wireless_metadata: struct {
            lo_ra_wan: ?struct {
                f_port: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f_port = "FPort",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lo_ra_wan = "LoRaWAN",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .payload_data = "PayloadData",
                .wireless_metadata = "WirelessMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_data_to_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = send_data_to_multicast_group };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_data_to_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices/{Id}/data",
        .success_code = 202,
    };

    action_name: []const u8 = "SendDataToWirelessDevice",
    Request: type = struct {
        id: []const u8,
        transmit_mode: i64,
        payload_data: []const u8,
        wireless_metadata: ?struct {
            lo_ra_wan: ?LoRaWANSendDataToDevice = null,
            sidewalk: ?struct {
                seq: ?i64 = null,
                message_type: ?[]const u8 = null,
                ack_mode_retry_duration_secs: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .seq = "Seq",
                        .message_type = "MessageType",
                        .ack_mode_retry_duration_secs = "AckModeRetryDurationSecs",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lo_ra_wan = "LoRaWAN",
                    .sidewalk = "Sidewalk",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .transmit_mode = "TransmitMode",
                .payload_data = "PayloadData",
                .wireless_metadata = "WirelessMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_data_to_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = send_data_to_wireless_device };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_bulk_associate_wireless_device_with_multicast_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/multicast-groups/{Id}/bulk",
        .success_code = 204,
    };

    action_name: []const u8 = "StartBulkAssociateWirelessDeviceWithMulticastGroup",
    Request: type = struct {
        id: []const u8,
        query_string: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .query_string = "QueryString",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bulk_associate_wireless_device_with_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = start_bulk_associate_wireless_device_with_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_bulk_disassociate_wireless_device_from_multicast_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/multicast-groups/{Id}/bulk",
        .success_code = 204,
    };

    action_name: []const u8 = "StartBulkDisassociateWirelessDeviceFromMulticastGroup",
    Request: type = struct {
        id: []const u8,
        query_string: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .query_string = "QueryString",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bulk_disassociate_wireless_device_from_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = start_bulk_disassociate_wireless_device_from_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_fuota_task: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/fuota-tasks/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "StartFuotaTask",
    Request: type = struct {
        id: []const u8,
        lo_ra_wan: ?struct {
            start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = start_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_multicast_group_session: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/multicast-groups/{Id}/session",
        .success_code = 204,
    };

    action_name: []const u8 = "StartMulticastGroupSession",
    Request: type = struct {
        id: []const u8,
        lo_ra_wan: LoRaWANMulticastSession,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_multicast_group_session) } {
            return .{ .service_metadata = service_metadata, .action = start_multicast_group_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_single_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless_single_device_import_task",
        .success_code = 201,
    };

    action_name: []const u8 = "StartSingleWirelessDeviceImportTask",
    Request: type = struct {
        destination_name: []const u8,
        client_request_token: ?[]const u8 = null,
        device_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        sidewalk: struct {
            sidewalk_manufacturing_sn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_name = "DestinationName",
                .client_request_token = "ClientRequestToken",
                .device_name = "DeviceName",
                .tags = "Tags",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_single_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = start_single_wireless_device_import_task };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless_device_import_task",
        .success_code = 201,
    };

    action_name: []const u8 = "StartWirelessDeviceImportTask",
    Request: type = struct {
        destination_name: []const u8,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,
        sidewalk: struct {
            device_creation_file: ?[]const u8 = null,
            role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_creation_file = "DeviceCreationFile",
                    .role = "Role",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_name = "DestinationName",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = start_wireless_device_import_task };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        TooManyTags,
        Validation,
    },
} = .{};
pub const test_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices/{Id}/test",
        .success_code = 200,
    };

    action_name: []const u8 = "TestWirelessDevice",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = test_wireless_device };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_destination: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/destinations/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateDestination",
    Request: type = struct {
        name: []const u8,
        expression_type: ?[]const u8 = null,
        expression: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .expression_type = "ExpressionType",
                .expression = "Expression",
                .description = "Description",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_event_configuration_by_resource_types: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/event-configurations-resource-types",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateEventConfigurationByResourceTypes",
    Request: type = struct {
        device_registration_state: ?DeviceRegistrationStateResourceTypeEventConfiguration = null,
        proximity: ?ProximityResourceTypeEventConfiguration = null,
        join: ?JoinResourceTypeEventConfiguration = null,
        connection_status: ?ConnectionStatusResourceTypeEventConfiguration = null,
        message_delivery_status: ?MessageDeliveryStatusResourceTypeEventConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_registration_state = "DeviceRegistrationState",
                .proximity = "Proximity",
                .join = "Join",
                .connection_status = "ConnectionStatus",
                .message_delivery_status = "MessageDeliveryStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_configuration_by_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = update_event_configuration_by_resource_types };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_fuota_task: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/fuota-tasks/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateFuotaTask",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANFuotaTask = null,
        firmware_update_image: ?[]const u8 = null,
        firmware_update_role: ?[]const u8 = null,
        redundancy_percent: ?i64 = null,
        fragment_size_bytes: ?i64 = null,
        fragment_interval_ms: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .firmware_update_image = "FirmwareUpdateImage",
                .firmware_update_role = "FirmwareUpdateRole",
                .redundancy_percent = "RedundancyPercent",
                .fragment_size_bytes = "FragmentSizeBytes",
                .fragment_interval_ms = "FragmentIntervalMS",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fuota_task) } {
            return .{ .service_metadata = service_metadata, .action = update_fuota_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_log_levels_by_resource_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/log-levels",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLogLevelsByResourceTypes",
    Request: type = struct {
        default_log_level: ?[]const u8 = null,
        wireless_device_log_options: ?[]WirelessDeviceLogOption = null,
        wireless_gateway_log_options: ?[]WirelessGatewayLogOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_log_level = "DefaultLogLevel",
                .wireless_device_log_options = "WirelessDeviceLogOptions",
                .wireless_gateway_log_options = "WirelessGatewayLogOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_log_levels_by_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = update_log_levels_by_resource_types };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_multicast_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/multicast-groups/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateMulticastGroup",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANMulticast = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_multicast_group) } {
            return .{ .service_metadata = service_metadata, .action = update_multicast_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_network_analyzer_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/network-analyzer-configurations/{ConfigurationName}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateNetworkAnalyzerConfiguration",
    Request: type = struct {
        configuration_name: []const u8,
        trace_content: ?TraceContent = null,
        wireless_devices_to_add: ?[][]const u8 = null,
        wireless_devices_to_remove: ?[][]const u8 = null,
        wireless_gateways_to_add: ?[][]const u8 = null,
        wireless_gateways_to_remove: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        multicast_groups_to_add: ?[][]const u8 = null,
        multicast_groups_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_name = "ConfigurationName",
                .trace_content = "TraceContent",
                .wireless_devices_to_add = "WirelessDevicesToAdd",
                .wireless_devices_to_remove = "WirelessDevicesToRemove",
                .wireless_gateways_to_add = "WirelessGatewaysToAdd",
                .wireless_gateways_to_remove = "WirelessGatewaysToRemove",
                .description = "Description",
                .multicast_groups_to_add = "MulticastGroupsToAdd",
                .multicast_groups_to_remove = "MulticastGroupsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_network_analyzer_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_network_analyzer_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_partner_account: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdatePartnerAccount",
    Request: type = struct {
        sidewalk: struct {
            app_server_private_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_server_private_key = "AppServerPrivateKey",
                };
                return @field(mappings, field_name);
            }
        },
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = update_partner_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_position: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/positions/{ResourceIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdatePosition",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,
        position: []f32,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
                .position = "Position",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_position) } {
            return .{ .service_metadata = service_metadata, .action = update_position };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_event_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/event-configurations/{Identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateResourceEventConfiguration",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,
        partner_type: ?[]const u8 = null,
        device_registration_state: ?DeviceRegistrationStateEventConfiguration = null,
        proximity: ?ProximityEventConfiguration = null,
        join: ?JoinEventConfiguration = null,
        connection_status: ?ConnectionStatusEventConfiguration = null,
        message_delivery_status: ?MessageDeliveryStatusEventConfiguration = null,

        pub const http_query = .{
            .identifier_type = "identifierType",
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
                .partner_type = "PartnerType",
                .device_registration_state = "DeviceRegistrationState",
                .proximity = "Proximity",
                .join = "Join",
                .connection_status = "ConnectionStatus",
                .message_delivery_status = "MessageDeliveryStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_event_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_event_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_position: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/resource-positions/{ResourceIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateResourcePosition",
    Request: type = struct {
        resource_identifier: []const u8,
        resource_type: []const u8,
        geo_json_payload: ?[]const u8 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub const http_payload: []const u8 = "geo_json_payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "ResourceIdentifier",
                .resource_type = "ResourceType",
                .geo_json_payload = "GeoJsonPayload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_position) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_position };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_wireless_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless-devices/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateWirelessDevice",
    Request: type = struct {
        id: []const u8,
        destination_name: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            device_profile_id: ?[]const u8 = null,
            service_profile_id: ?[]const u8 = null,
            abp_v1_1: ?struct {
                f_cnt_start: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f_cnt_start = "FCntStart",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            abp_v1_0_x: ?struct {
                f_cnt_start: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f_cnt_start = "FCntStart",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            f_ports: ?struct {
                positioning: ?Positioning = null,
                applications: ?[]ApplicationConfig = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .positioning = "Positioning",
                        .applications = "Applications",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_profile_id = "DeviceProfileId",
                    .service_profile_id = "ServiceProfileId",
                    .abp_v1_1 = "AbpV1_1",
                    .abp_v1_0_x = "AbpV1_0_x",
                    .f_ports = "FPorts",
                };
                return @field(mappings, field_name);
            }
        } = null,
        positioning: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .destination_name = "DestinationName",
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .positioning = "Positioning",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = update_wireless_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_wireless_device_import_task: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless_device_import_task/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateWirelessDeviceImportTask",
    Request: type = struct {
        id: []const u8,
        sidewalk: struct {
            device_creation_file: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_creation_file = "DeviceCreationFile",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_wireless_device_import_task) } {
            return .{ .service_metadata = service_metadata, .action = update_wireless_device_import_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_wireless_gateway: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless-gateways/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateWirelessGateway",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        join_eui_filters: ?[][][]const u8 = null,
        net_id_filters: ?[][]const u8 = null,
        max_eirp: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .join_eui_filters = "JoinEuiFilters",
                .net_id_filters = "NetIdFilters",
                .max_eirp = "MaxEirp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = update_wireless_gateway };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const ApplicationConfig = struct {
    f_port: ?i64 = null,
    type: ?[]const u8 = null,
    destination_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f_port = "FPort",
            .type = "Type",
            .destination_name = "DestinationName",
        };
        return @field(mappings, field_name);
    }
};

pub const Positioning = struct {
    clock_sync: ?i64 = null,
    stream: ?i64 = null,
    gnss: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .clock_sync = "ClockSync",
            .stream = "Stream",
            .gnss = "Gnss",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageDeliveryStatusEventConfiguration = struct {
    sidewalk: ?SidewalkEventNotificationConfigurations = null,
    wireless_device_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
            .wireless_device_id_event_topic = "WirelessDeviceIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkEventNotificationConfigurations = struct {
    amazon_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_id_event_topic = "AmazonIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionStatusEventConfiguration = struct {
    lo_ra_wan: ?LoRaWANConnectionStatusEventNotificationConfigurations = null,
    wireless_gateway_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lo_ra_wan = "LoRaWAN",
            .wireless_gateway_id_event_topic = "WirelessGatewayIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANConnectionStatusEventNotificationConfigurations = struct {
    gateway_eui_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_eui_event_topic = "GatewayEuiEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinEventConfiguration = struct {
    lo_ra_wan: ?LoRaWANJoinEventNotificationConfigurations = null,
    wireless_device_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lo_ra_wan = "LoRaWAN",
            .wireless_device_id_event_topic = "WirelessDeviceIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANJoinEventNotificationConfigurations = struct {
    dev_eui_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_eui_event_topic = "DevEuiEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const ProximityEventConfiguration = struct {
    sidewalk: ?SidewalkEventNotificationConfigurations = null,
    wireless_device_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
            .wireless_device_id_event_topic = "WirelessDeviceIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceRegistrationStateEventConfiguration = struct {
    sidewalk: ?SidewalkEventNotificationConfigurations = null,
    wireless_device_id_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
            .wireless_device_id_event_topic = "WirelessDeviceIdEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const TraceContent = struct {
    wireless_device_frame_info: ?[]const u8 = null,
    log_level: ?[]const u8 = null,
    multicast_frame_info: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wireless_device_frame_info = "WirelessDeviceFrameInfo",
            .log_level = "LogLevel",
            .multicast_frame_info = "MulticastFrameInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANMulticast = struct {
    rf_region: ?[]const u8 = null,
    dl_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rf_region = "RfRegion",
            .dl_class = "DlClass",
        };
        return @field(mappings, field_name);
    }
};

pub const WirelessGatewayLogOption = struct {
    type: []const u8,
    log_level: []const u8,
    events: ?[]WirelessGatewayEventLogOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .log_level = "LogLevel",
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const WirelessGatewayEventLogOption = struct {
    event: []const u8,
    log_level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event = "Event",
            .log_level = "LogLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const WirelessDeviceLogOption = struct {
    type: []const u8,
    log_level: []const u8,
    events: ?[]WirelessDeviceEventLogOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .log_level = "LogLevel",
            .events = "Events",
        };
        return @field(mappings, field_name);
    }
};

pub const WirelessDeviceEventLogOption = struct {
    event: []const u8,
    log_level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event = "Event",
            .log_level = "LogLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANFuotaTask = struct {
    rf_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rf_region = "RfRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageDeliveryStatusResourceTypeEventConfiguration = struct {
    sidewalk: ?SidewalkResourceTypeEventConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkResourceTypeEventConfiguration = struct {
    wireless_device_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wireless_device_event_topic = "WirelessDeviceEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionStatusResourceTypeEventConfiguration = struct {
    lo_ra_wan: ?LoRaWANConnectionStatusResourceTypeEventConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lo_ra_wan = "LoRaWAN",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANConnectionStatusResourceTypeEventConfiguration = struct {
    wireless_gateway_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wireless_gateway_event_topic = "WirelessGatewayEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinResourceTypeEventConfiguration = struct {
    lo_ra_wan: ?LoRaWANJoinResourceTypeEventConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lo_ra_wan = "LoRaWAN",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANJoinResourceTypeEventConfiguration = struct {
    wireless_device_event_topic: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wireless_device_event_topic = "WirelessDeviceEventTopic",
        };
        return @field(mappings, field_name);
    }
};

pub const ProximityResourceTypeEventConfiguration = struct {
    sidewalk: ?SidewalkResourceTypeEventConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceRegistrationStateResourceTypeEventConfiguration = struct {
    sidewalk: ?SidewalkResourceTypeEventConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sidewalk = "Sidewalk",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANMulticastSession = struct {
    dl_dr: ?i64 = null,
    dl_freq: ?i64 = null,
    session_start_time: ?i64 = null,
    session_timeout: ?i64 = null,
    ping_slot_period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dl_dr = "DlDr",
            .dl_freq = "DlFreq",
            .session_start_time = "SessionStartTime",
            .session_timeout = "SessionTimeout",
            .ping_slot_period = "PingSlotPeriod",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANSendDataToDevice = struct {
    f_port: ?i64 = null,
    participating_gateways: ?ParticipatingGateways = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f_port = "FPort",
            .participating_gateways = "ParticipatingGateways",
        };
        return @field(mappings, field_name);
    }
};

pub const ParticipatingGateways = struct {
    downlink_mode: []const u8,
    gateway_list: []GatewayListItem,
    transmission_interval: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .downlink_mode = "DownlinkMode",
            .gateway_list = "GatewayList",
            .transmission_interval = "TransmissionInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayListItem = struct {
    gateway_id: []const u8,
    downlink_frequency: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_id = "GatewayId",
            .downlink_frequency = "DownlinkFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANGatewayVersion = struct {
    package_version: ?[]const u8 = null,
    model: ?[]const u8 = null,
    station: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_version = "PackageVersion",
            .model = "Model",
            .station = "Station",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANGateway = struct {
    gateway_eui: ?[]const u8 = null,
    rf_region: ?[]const u8 = null,
    join_eui_filters: ?[][][]const u8 = null,
    net_id_filters: ?[][]const u8 = null,
    sub_bands: ?[]i64 = null,
    beaconing: ?Beaconing = null,
    max_eirp: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_eui = "GatewayEui",
            .rf_region = "RfRegion",
            .join_eui_filters = "JoinEuiFilters",
            .net_id_filters = "NetIdFilters",
            .sub_bands = "SubBands",
            .beaconing = "Beaconing",
            .max_eirp = "MaxEirp",
        };
        return @field(mappings, field_name);
    }
};

pub const Beaconing = struct {
    data_rate: ?i64 = null,
    frequencies: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_rate = "DataRate",
            .frequencies = "Frequencies",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateList = struct {
    signing_alg: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_alg = "SigningAlg",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkGetStartImportInfo = struct {
    device_creation_file_list: ?[][]const u8 = null,
    role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_creation_file_list = "DeviceCreationFileList",
            .role = "Role",
        };
        return @field(mappings, field_name);
    }
};

pub const PositionSolverDetails = struct {
    semtech_gnss: ?SemtechGnssDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .semtech_gnss = "SemtechGnss",
        };
        return @field(mappings, field_name);
    }
};

pub const SemtechGnssDetail = struct {
    provider: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    fec: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider = "Provider",
            .type = "Type",
            .status = "Status",
            .fec = "Fec",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkAccountInfoWithFingerprint = struct {
    amazon_id: ?[]const u8 = null,
    fingerprint: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_id = "AmazonId",
            .fingerprint = "Fingerprint",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateWirelessGatewayTaskCreate = struct {
    update_data_source: ?[]const u8 = null,
    update_data_role: ?[]const u8 = null,
    lo_ra_wan: ?LoRaWANUpdateGatewayTaskCreate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_data_source = "UpdateDataSource",
            .update_data_role = "UpdateDataRole",
            .lo_ra_wan = "LoRaWAN",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANUpdateGatewayTaskCreate = struct {
    update_signature: ?[]const u8 = null,
    sig_key_crc: ?i64 = null,
    current_version: ?LoRaWANGatewayVersion = null,
    update_version: ?LoRaWANGatewayVersion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_signature = "UpdateSignature",
            .sig_key_crc = "SigKeyCrc",
            .current_version = "CurrentVersion",
            .update_version = "UpdateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANDevice = struct {
    dev_eui: ?[]const u8 = null,
    device_profile_id: ?[]const u8 = null,
    service_profile_id: ?[]const u8 = null,
    otaa_v1_1: ?OtaaV1_1 = null,
    otaa_v1_0_x: ?OtaaV1_0_x = null,
    abp_v1_1: ?AbpV1_1 = null,
    abp_v1_0_x: ?AbpV1_0_x = null,
    f_ports: ?FPorts = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_eui = "DevEui",
            .device_profile_id = "DeviceProfileId",
            .service_profile_id = "ServiceProfileId",
            .otaa_v1_1 = "OtaaV1_1",
            .otaa_v1_0_x = "OtaaV1_0_x",
            .abp_v1_1 = "AbpV1_1",
            .abp_v1_0_x = "AbpV1_0_x",
            .f_ports = "FPorts",
        };
        return @field(mappings, field_name);
    }
};

pub const FPorts = struct {
    fuota: ?i64 = null,
    multicast: ?i64 = null,
    clock_sync: ?i64 = null,
    positioning: ?Positioning = null,
    applications: ?[]ApplicationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fuota = "Fuota",
            .multicast = "Multicast",
            .clock_sync = "ClockSync",
            .positioning = "Positioning",
            .applications = "Applications",
        };
        return @field(mappings, field_name);
    }
};

pub const AbpV1_0_x = struct {
    dev_addr: ?[]const u8 = null,
    session_keys: ?SessionKeysAbpV1_0_x = null,
    f_cnt_start: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_addr = "DevAddr",
            .session_keys = "SessionKeys",
            .f_cnt_start = "FCntStart",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionKeysAbpV1_0_x = struct {
    nwk_s_key: ?[]const u8 = null,
    app_s_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nwk_s_key = "NwkSKey",
            .app_s_key = "AppSKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AbpV1_1 = struct {
    dev_addr: ?[]const u8 = null,
    session_keys: ?SessionKeysAbpV1_1 = null,
    f_cnt_start: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_addr = "DevAddr",
            .session_keys = "SessionKeys",
            .f_cnt_start = "FCntStart",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionKeysAbpV1_1 = struct {
    f_nwk_s_int_key: ?[]const u8 = null,
    s_nwk_s_int_key: ?[]const u8 = null,
    nwk_s_enc_key: ?[]const u8 = null,
    app_s_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f_nwk_s_int_key = "FNwkSIntKey",
            .s_nwk_s_int_key = "SNwkSIntKey",
            .nwk_s_enc_key = "NwkSEncKey",
            .app_s_key = "AppSKey",
        };
        return @field(mappings, field_name);
    }
};

pub const OtaaV1_0_x = struct {
    app_key: ?[]const u8 = null,
    app_eui: ?[]const u8 = null,
    join_eui: ?[]const u8 = null,
    gen_app_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_key = "AppKey",
            .app_eui = "AppEui",
            .join_eui = "JoinEui",
            .gen_app_key = "GenAppKey",
        };
        return @field(mappings, field_name);
    }
};

pub const OtaaV1_1 = struct {
    app_key: ?[]const u8 = null,
    nwk_key: ?[]const u8 = null,
    join_eui: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_key = "AppKey",
            .nwk_key = "NwkKey",
            .join_eui = "JoinEui",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANDeviceProfile = struct {
    supports_classb: ?bool = null,
    class_b_timeout: ?i64 = null,
    ping_slot_period: ?i64 = null,
    ping_slot_dr: ?i64 = null,
    ping_slot_freq: ?i64 = null,
    supports_classc: ?bool = null,
    class_c_timeout: ?i64 = null,
    mac_version: ?[]const u8 = null,
    reg_params_revision: ?[]const u8 = null,
    rx_delay1: ?i64 = null,
    rx_dr_offset1: ?i64 = null,
    rx_data_rate2: ?i64 = null,
    rx_freq2: ?i64 = null,
    factory_preset_freqs_list: ?[]i64 = null,
    max_eirp: ?i64 = null,
    max_duty_cycle: ?i64 = null,
    rf_region: ?[]const u8 = null,
    supports_join: ?bool = null,
    supports32_bit_f_cnt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supports_classb = "SupportsClassB",
            .class_b_timeout = "ClassBTimeout",
            .ping_slot_period = "PingSlotPeriod",
            .ping_slot_dr = "PingSlotDr",
            .ping_slot_freq = "PingSlotFreq",
            .supports_classc = "SupportsClassC",
            .class_c_timeout = "ClassCTimeout",
            .mac_version = "MacVersion",
            .reg_params_revision = "RegParamsRevision",
            .rx_delay1 = "RxDelay1",
            .rx_dr_offset1 = "RxDrOffset1",
            .rx_data_rate2 = "RxDataRate2",
            .rx_freq2 = "RxFreq2",
            .factory_preset_freqs_list = "FactoryPresetFreqsList",
            .max_eirp = "MaxEirp",
            .max_duty_cycle = "MaxDutyCycle",
            .rf_region = "RfRegion",
            .supports_join = "SupportsJoin",
            .supports32_bit_f_cnt = "Supports32BitFCnt",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkAccountInfo = struct {
    amazon_id: ?[]const u8 = null,
    app_server_private_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_id = "AmazonId",
            .app_server_private_key = "AppServerPrivateKey",
        };
        return @field(mappings, field_name);
    }
};
