const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-07";
pub const sdk_id: []const u8 = "Lex Models V2";
pub const arn_namespace: ?[]const u8 = "lex";
pub const endpoint_prefix: []const u8 = "models-v2-lex";
pub const sigv4_name: []const u8 = "lex";
pub const name: []const u8 = "LexModelBuildingServiceV2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-07",
    sdk_id: []const u8 = "Lex Models V2",
    arn_namespace: ?[]const u8 = "lex",
    endpoint_prefix: []const u8 = "models-v2-lex",
    sigv4_name: []const u8 = "lex",
    name: []const u8 = "LexModelBuildingServiceV2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_create_custom_vocabulary_item: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary/DEFAULT/batchcreate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateCustomVocabularyItem",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        custom_vocabulary_item_list: []struct {
            phrase: []const u8,
            weight: ?i64 = null,
            display_as: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phrase = "phrase",
                    .weight = "weight",
                    .display_as = "displayAs",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_item_list = "customVocabularyItemList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_custom_vocabulary_item) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_custom_vocabulary_item };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        errors: ?[]FailedCustomVocabularyItem = null,
        resources: ?[]CustomVocabularyItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .errors = "errors",
                .resources = "resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_delete_custom_vocabulary_item: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary/DEFAULT/batchdelete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteCustomVocabularyItem",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        custom_vocabulary_item_list: []struct {
            item_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item_id = "itemId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_item_list = "customVocabularyItemList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_custom_vocabulary_item) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_custom_vocabulary_item };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        errors: ?[]FailedCustomVocabularyItem = null,
        resources: ?[]CustomVocabularyItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .errors = "errors",
                .resources = "resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_update_custom_vocabulary_item: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary/DEFAULT/batchupdate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateCustomVocabularyItem",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        custom_vocabulary_item_list: []CustomVocabularyItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_item_list = "customVocabularyItemList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_custom_vocabulary_item) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_custom_vocabulary_item };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        errors: ?[]FailedCustomVocabularyItem = null,
        resources: ?[]CustomVocabularyItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .errors = "errors",
                .resources = "resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const build_bot_locale: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "BuildBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(build_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = build_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_locale_status: ?[]const u8 = null,
        last_build_submitted_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_locale_status = "botLocaleStatus",
                .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBot",
    Request: type = struct {
        bot_name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        data_privacy: DataPrivacy,
        idle_session_ttl_in_seconds: i64,
        bot_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        test_bot_alias_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_tags = "botTags",
                .test_bot_alias_tags = "testBotAliasTags",
                .bot_type = "botType",
                .bot_members = "botMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_tags", field_name))
                return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
            if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
                return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot) } {
            return .{ .service_metadata = service_metadata, .action = create_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        bot_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        test_bot_alias_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .bot_tags = "botTags",
                .test_bot_alias_tags = "testBotAliasTags",
                .bot_type = "botType",
                .bot_members = "botMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_tags", field_name))
                return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
            if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
                return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botaliases",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotAlias",
    Request: type = struct {
        bot_alias_name: []const u8,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_id = "botId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_locale: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: f64,
        voice_settings: ?VoiceSettings = null,
        generative_ai_settings: ?GenerativeAISettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .generative_ai_settings = "generativeAISettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        bot_locale_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        generative_ai_settings: ?GenerativeAISettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_name = "localeName",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .bot_locale_status = "botLocaleStatus",
                .creation_date_time = "creationDateTime",
                .generative_ai_settings = "generativeAISettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_replica: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/replicas",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotReplica",
    Request: type = struct {
        bot_id: []const u8,
        replica_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_replica) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_replica };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        replica_region: ?[]const u8 = null,
        source_region: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        bot_replica_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
                .source_region = "sourceRegion",
                .creation_date_time = "creationDateTime",
                .bot_replica_status = "botReplicaStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        description: ?[]const u8 = null,
        bot_version_locale_specification: []struct {
            key: ?[]const u8 = null,
            value: ?BotVersionLocaleDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .description = "description",
                .bot_version_locale_specification = "botVersionLocaleSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_version_locale_specification", field_name))
                return try serializeMap(self.bot_version_locale_specification, self.fieldNameFor("bot_version_locale_specification"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_version_locale_specification: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotVersionLocaleDetails = null,
        } = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .description = "description",
                .bot_version = "botVersion",
                .bot_version_locale_specification = "botVersionLocaleSpecification",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_version_locale_specification", field_name))
                return try serializeMap(self.bot_version_locale_specification, self.fieldNameFor("bot_version_locale_specification"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_export: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/exports",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateExport",
    Request: type = struct {
        resource_specification: ExportResourceSpecification,
        file_format: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_export) } {
            return .{ .service_metadata = service_metadata, .action = create_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_intent: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIntent",
    Request: type = struct {
        intent_name: []const u8,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        initial_response_setting: ?InitialResponseSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .initial_response_setting = "initialResponseSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_intent) } {
            return .{ .service_metadata = service_metadata, .action = create_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        initial_response_setting: ?InitialResponseSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .initial_response_setting = "initialResponseSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resource_policy_statement: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/{resourceArn}/statements",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourcePolicyStatement",
    Request: type = struct {
        resource_arn: []const u8,
        statement_id: []const u8,
        effect: []const u8,
        principal: []struct {
            service: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "service",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },
        action: [][]const u8,
        condition: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .statement_id = "statementId",
                .effect = "effect",
                .principal = "principal",
                .action = "action",
                .condition = "condition",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "condition", field_name))
                return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_policy_statement) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_policy_statement };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_slot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSlot",
    Request: type = struct {
        slot_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: SlotValueElicitationSetting,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,
        multiple_values_setting: ?MultipleValuesSetting = null,
        sub_slot_setting: ?SubSlotSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .multiple_values_setting = "multipleValuesSetting",
                .sub_slot_setting = "subSlotSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_slot) } {
            return .{ .service_metadata = service_metadata, .action = create_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        multiple_values_setting: ?MultipleValuesSetting = null,
        sub_slot_setting: ?SubSlotSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
                .multiple_values_setting = "multipleValuesSetting",
                .sub_slot_setting = "subSlotSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_slot_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSlotType",
    Request: type = struct {
        slot_type_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        external_source_setting: ?ExternalSourceSetting = null,
        composite_slot_type_setting: ?CompositeSlotTypeSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .external_source_setting = "externalSourceSetting",
                .composite_slot_type_setting = "compositeSlotTypeSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = create_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        external_source_setting: ?ExternalSourceSetting = null,
        composite_slot_type_setting: ?CompositeSlotTypeSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .external_source_setting = "externalSourceSetting",
                .composite_slot_type_setting = "compositeSlotTypeSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_test_set_discrepancy_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testsets/{testSetId}/testsetdiscrepancy",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateTestSetDiscrepancyReport",
    Request: type = struct {
        test_set_id: []const u8,
        target: TestSetDiscrepancyReportResourceTarget,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .target = "target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_test_set_discrepancy_report) } {
            return .{ .service_metadata = service_metadata, .action = create_test_set_discrepancy_report };
        }
    },
    Response: type = struct {
        test_set_discrepancy_report_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        test_set_id: ?[]const u8 = null,
        target: ?TestSetDiscrepancyReportResourceTarget = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_discrepancy_report_id = "testSetDiscrepancyReportId",
                .creation_date_time = "creationDateTime",
                .test_set_id = "testSetId",
                .target = "target",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_upload_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createuploadurl",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUploadUrl",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_upload_url) } {
            return .{ .service_metadata = service_metadata, .action = create_upload_url };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        upload_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .upload_url = "uploadUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBot",
    Request: type = struct {
        bot_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_status = "botStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_alias_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
                .bot_alias_status = "botAliasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_locale: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_locale_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_locale_status = "botLocaleStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_replica: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/replicas/{replicaRegion}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotReplica",
    Request: type = struct {
        bot_id: []const u8,
        replica_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_replica) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_replica };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        replica_region: ?[]const u8 = null,
        bot_replica_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
                .bot_replica_status = "botReplicaStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .bot_status = "botStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_custom_vocabulary: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteCustomVocabulary",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_vocabulary };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        custom_vocabulary_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_status = "customVocabularyStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_export: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/exports/{exportId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteExport",
    Request: type = struct {
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_export) } {
            return .{ .service_metadata = service_metadata, .action = delete_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        export_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .export_status = "exportStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_import: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/imports/{importId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_import) } {
            return .{ .service_metadata = service_metadata, .action = delete_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        import_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .import_status = "importStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_intent: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntent",
    Request: type = struct {
        intent_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_intent) } {
            return .{ .service_metadata = service_metadata, .action = delete_intent };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policy/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_resource_policy_statement: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policy/{resourceArn}/statements/{statementId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicyStatement",
    Request: type = struct {
        resource_arn: []const u8,
        statement_id: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .statement_id = "statementId",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy_statement) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy_statement };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_slot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlot",
    Request: type = struct {
        slot_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_slot_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_test_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/testsets/{testSetId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTestSet",
    Request: type = struct {
        test_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_test_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_test_set };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_utterances: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/utterances",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteUtterances",
    Request: type = struct {
        bot_id: []const u8,
        locale_id: ?[]const u8 = null,
        session_id: ?[]const u8 = null,

        pub const http_query = .{
            .locale_id = "localeId",
            .session_id = "sessionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .locale_id = "localeId",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_utterances) } {
            return .{ .service_metadata = service_metadata, .action = delete_utterances };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBot",
    Request: type = struct {
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,
        failure_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .bot_type = "botType",
                .bot_members = "botMembers",
                .failure_reasons = "failureReasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_history_events: ?[]struct {
            bot_version: ?[]const u8 = null,
            start_date: ?i64 = null,
            end_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_version = "botVersion",
                    .start_date = "startDate",
                    .end_date = "endDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        parent_bot_networks: ?[]ParentBotNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_history_events = "botAliasHistoryEvents",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .parent_bot_networks = "parentBotNetworks",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_locale: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        intents_count: ?i64 = null,
        slot_types_count: ?i64 = null,
        bot_locale_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        last_build_submitted_date_time: ?i64 = null,
        bot_locale_history_events: ?[]struct {
            event: []const u8,
            event_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event = "event",
                    .event_date = "eventDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        recommended_actions: ?[][]const u8 = null,
        generative_ai_settings: ?GenerativeAISettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .locale_name = "localeName",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .intents_count = "intentsCount",
                .slot_types_count = "slotTypesCount",
                .bot_locale_status = "botLocaleStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
                .bot_locale_history_events = "botLocaleHistoryEvents",
                .recommended_actions = "recommendedActions",
                .generative_ai_settings = "generativeAISettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_recommendation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations/{botRecommendationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotRecommendation",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        bot_recommendation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_recommendation };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_status: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        transcript_source_setting: ?TranscriptSourceSetting = null,
        encryption_setting: ?EncryptionSetting = null,
        bot_recommendation_results: ?struct {
            bot_locale_export_url: ?[]const u8 = null,
            associated_transcripts_url: ?[]const u8 = null,
            statistics: ?struct {
                intents: ?struct {
                    discovered_intent_count: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .discovered_intent_count = "discoveredIntentCount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                slot_types: ?struct {
                    discovered_slot_type_count: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .discovered_slot_type_count = "discoveredSlotTypeCount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .intents = "intents",
                        .slot_types = "slotTypes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_locale_export_url = "botLocaleExportUrl",
                    .associated_transcripts_url = "associatedTranscriptsUrl",
                    .statistics = "statistics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_status = "botRecommendationStatus",
                .bot_recommendation_id = "botRecommendationId",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .transcript_source_setting = "transcriptSourceSetting",
                .encryption_setting = "encryptionSetting",
                .bot_recommendation_results = "botRecommendationResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_replica: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/replicas/{replicaRegion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotReplica",
    Request: type = struct {
        bot_id: []const u8,
        replica_region: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_replica) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_replica };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        replica_region: ?[]const u8 = null,
        source_region: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        bot_replica_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
                .source_region = "sourceRegion",
                .creation_date_time = "creationDateTime",
                .bot_replica_status = "botReplicaStatus",
                .failure_reasons = "failureReasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_resource_generation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/generations/{generationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotResourceGeneration",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        generation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .generation_id = "generationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_resource_generation) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_resource_generation };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        generation_id: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        generation_status: ?[]const u8 = null,
        generation_input_prompt: ?[]const u8 = null,
        generated_bot_locale_url: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        model_arn: ?[]const u8 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .generation_id = "generationId",
                .failure_reasons = "failureReasons",
                .generation_status = "generationStatus",
                .generation_input_prompt = "generationInputPrompt",
                .generated_bot_locale_url = "generatedBotLocaleUrl",
                .creation_date_time = "creationDateTime",
                .model_arn = "modelArn",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        parent_bot_networks: ?[]ParentBotNetwork = null,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .bot_version = "botVersion",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .parent_bot_networks = "parentBotNetworks",
                .bot_type = "botType",
                .bot_members = "botMembers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_custom_vocabulary_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary/DEFAULT/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCustomVocabularyMetadata",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_vocabulary_metadata) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_vocabulary_metadata };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        custom_vocabulary_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_status = "customVocabularyStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_export: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/exports/{exportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeExport",
    Request: type = struct {
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export) } {
            return .{ .service_metadata = service_metadata, .action = describe_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        download_url: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .failure_reasons = "failureReasons",
                .download_url = "downloadUrl",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_import: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/imports/{importId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_import) } {
            return .{ .service_metadata = service_metadata, .action = describe_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        resource_specification: ?ImportResourceSpecification = null,
        imported_resource_id: ?[]const u8 = null,
        imported_resource_name: ?[]const u8 = null,
        merge_strategy: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .imported_resource_id = "importedResourceId",
                .imported_resource_name = "importedResourceName",
                .merge_strategy = "mergeStrategy",
                .import_status = "importStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_intent: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIntent",
    Request: type = struct {
        intent_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_intent) } {
            return .{ .service_metadata = service_metadata, .action = describe_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        initial_response_setting: ?InitialResponseSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .initial_response_setting = "initialResponseSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_slot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSlot",
    Request: type = struct {
        slot_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_slot) } {
            return .{ .service_metadata = service_metadata, .action = describe_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        multiple_values_setting: ?MultipleValuesSetting = null,
        sub_slot_setting: ?SubSlotSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .multiple_values_setting = "multipleValuesSetting",
                .sub_slot_setting = "subSlotSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_slot_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = describe_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        external_source_setting: ?ExternalSourceSetting = null,
        composite_slot_type_setting: ?CompositeSlotTypeSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .external_source_setting = "externalSourceSetting",
                .composite_slot_type_setting = "compositeSlotTypeSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_test_execution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/testexecutions/{testExecutionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTestExecution",
    Request: type = struct {
        test_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_test_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_test_execution };
        }
    },
    Response: type = struct {
        test_execution_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        test_execution_status: ?[]const u8 = null,
        test_set_id: ?[]const u8 = null,
        test_set_name: ?[]const u8 = null,
        target: ?TestExecutionTarget = null,
        api_mode: ?[]const u8 = null,
        test_execution_modality: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .test_execution_status = "testExecutionStatus",
                .test_set_id = "testSetId",
                .test_set_name = "testSetName",
                .target = "target",
                .api_mode = "apiMode",
                .test_execution_modality = "testExecutionModality",
                .failure_reasons = "failureReasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_test_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/testsets/{testSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTestSet",
    Request: type = struct {
        test_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_test_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_test_set };
        }
    },
    Response: type = struct {
        test_set_id: ?[]const u8 = null,
        test_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        modality: ?[]const u8 = null,
        status: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        num_turns: ?i64 = null,
        storage_location: ?TestSetStorageLocation = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .test_set_name = "testSetName",
                .description = "description",
                .modality = "modality",
                .status = "status",
                .role_arn = "roleArn",
                .num_turns = "numTurns",
                .storage_location = "storageLocation",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_test_set_discrepancy_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/testsetdiscrepancy/{testSetDiscrepancyReportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTestSetDiscrepancyReport",
    Request: type = struct {
        test_set_discrepancy_report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_discrepancy_report_id = "testSetDiscrepancyReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_test_set_discrepancy_report) } {
            return .{ .service_metadata = service_metadata, .action = describe_test_set_discrepancy_report };
        }
    },
    Response: type = struct {
        test_set_discrepancy_report_id: ?[]const u8 = null,
        test_set_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        target: ?TestSetDiscrepancyReportResourceTarget = null,
        test_set_discrepancy_report_status: ?[]const u8 = null,
        last_updated_data_time: ?i64 = null,
        test_set_discrepancy_top_errors: ?struct {
            intent_discrepancies: []struct {
                intent_name: []const u8,
                error_message: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .intent_name = "intentName",
                        .error_message = "errorMessage",
                    };
                    return @field(mappings, field_name);
                }
            },
            slot_discrepancies: []struct {
                intent_name: []const u8,
                slot_name: []const u8,
                error_message: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .intent_name = "intentName",
                        .slot_name = "slotName",
                        .error_message = "errorMessage",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_discrepancies = "intentDiscrepancies",
                    .slot_discrepancies = "slotDiscrepancies",
                };
                return @field(mappings, field_name);
            }
        } = null,
        test_set_discrepancy_raw_output_url: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_discrepancy_report_id = "testSetDiscrepancyReportId",
                .test_set_id = "testSetId",
                .creation_date_time = "creationDateTime",
                .target = "target",
                .test_set_discrepancy_report_status = "testSetDiscrepancyReportStatus",
                .last_updated_data_time = "lastUpdatedDataTime",
                .test_set_discrepancy_top_errors = "testSetDiscrepancyTopErrors",
                .test_set_discrepancy_raw_output_url = "testSetDiscrepancyRawOutputUrl",
                .failure_reasons = "failureReasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_test_set_generation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/testsetgenerations/{testSetGenerationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTestSetGeneration",
    Request: type = struct {
        test_set_generation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_generation_id = "testSetGenerationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_test_set_generation) } {
            return .{ .service_metadata = service_metadata, .action = describe_test_set_generation };
        }
    },
    Response: type = struct {
        test_set_generation_id: ?[]const u8 = null,
        test_set_generation_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        test_set_id: ?[]const u8 = null,
        test_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        storage_location: ?TestSetStorageLocation = null,
        generation_data_source: ?TestSetGenerationDataSource = null,
        role_arn: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_generation_id = "testSetGenerationId",
                .test_set_generation_status = "testSetGenerationStatus",
                .failure_reasons = "failureReasons",
                .test_set_id = "testSetId",
                .test_set_name = "testSetName",
                .description = "description",
                .storage_location = "storageLocation",
                .generation_data_source = "generationDataSource",
                .role_arn = "roleArn",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const generate_bot_element: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/generate",
        .success_code = 202,
    };

    action_name: []const u8 = "GenerateBotElement",
    Request: type = struct {
        intent_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_bot_element) } {
            return .{ .service_metadata = service_metadata, .action = generate_bot_element };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .sample_utterances = "sampleUtterances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_test_execution_artifacts_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/testexecutions/{testExecutionId}/artifacturl",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTestExecutionArtifactsUrl",
    Request: type = struct {
        test_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_test_execution_artifacts_url) } {
            return .{ .service_metadata = service_metadata, .action = get_test_execution_artifacts_url };
        }
    },
    Response: type = struct {
        test_execution_id: ?[]const u8 = null,
        download_artifacts_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
                .download_artifacts_url = "downloadArtifactsUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_aggregated_utterances: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/aggregatedutterances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAggregatedUtterances",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: []const u8,
        aggregation_duration: UtteranceAggregationDuration,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .aggregation_duration = "aggregationDuration",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aggregated_utterances) } {
            return .{ .service_metadata = service_metadata, .action = list_aggregated_utterances };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_alias_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        aggregation_duration: ?UtteranceAggregationDuration = null,
        aggregation_window_start_time: ?i64 = null,
        aggregation_window_end_time: ?i64 = null,
        aggregation_last_refreshed_date_time: ?i64 = null,
        aggregated_utterances_summaries: ?[]struct {
            utterance: ?[]const u8 = null,
            hit_count: ?i64 = null,
            missed_count: ?i64 = null,
            utterance_first_recorded_in_aggregation_duration: ?i64 = null,
            utterance_last_recorded_in_aggregation_duration: ?i64 = null,
            contains_data_from_deleted_resources: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .utterance = "utterance",
                    .hit_count = "hitCount",
                    .missed_count = "missedCount",
                    .utterance_first_recorded_in_aggregation_duration = "utteranceFirstRecordedInAggregationDuration",
                    .utterance_last_recorded_in_aggregation_duration = "utteranceLastRecordedInAggregationDuration",
                    .contains_data_from_deleted_resources = "containsDataFromDeletedResources",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .aggregation_duration = "aggregationDuration",
                .aggregation_window_start_time = "aggregationWindowStartTime",
                .aggregation_window_end_time = "aggregationWindowEndTime",
                .aggregation_last_refreshed_date_time = "aggregationLastRefreshedDateTime",
                .aggregated_utterances_summaries = "aggregatedUtterancesSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_aliases: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botaliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotAliases",
    Request: type = struct {
        bot_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_aliases };
        }
    },
    Response: type = struct {
        bot_alias_summaries: ?[]struct {
            bot_alias_id: ?[]const u8 = null,
            bot_alias_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            bot_alias_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_alias_id = "botAliasId",
                    .bot_alias_name = "botAliasName",
                    .description = "description",
                    .bot_version = "botVersion",
                    .bot_alias_status = "botAliasStatus",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_summaries = "botAliasSummaries",
                .next_token = "nextToken",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_alias_replicas: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/replicas/{replicaRegion}/botaliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotAliasReplicas",
    Request: type = struct {
        bot_id: []const u8,
        replica_region: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_alias_replicas) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_alias_replicas };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        source_region: ?[]const u8 = null,
        replica_region: ?[]const u8 = null,
        bot_alias_replica_summaries: ?[]struct {
            bot_alias_id: ?[]const u8 = null,
            bot_alias_replication_status: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_alias_id = "botAliasId",
                    .bot_alias_replication_status = "botAliasReplicationStatus",
                    .bot_version = "botVersion",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reasons = "failureReasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .source_region = "sourceRegion",
                .replica_region = "replicaRegion",
                .bot_alias_replica_summaries = "botAliasReplicaSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_locales: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotLocales",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_locales) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_locales };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        bot_locale_summaries: ?[]struct {
            locale_id: ?[]const u8 = null,
            locale_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_locale_status: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,
            last_build_submitted_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .locale_id = "localeId",
                    .locale_name = "localeName",
                    .description = "description",
                    .bot_locale_status = "botLocaleStatus",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .next_token = "nextToken",
                .bot_locale_summaries = "botLocaleSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotRecommendations",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_recommendations };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_summaries: ?[]struct {
            bot_recommendation_status: []const u8,
            bot_recommendation_id: []const u8,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_recommendation_status = "botRecommendationStatus",
                    .bot_recommendation_id = "botRecommendationId",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_summaries = "botRecommendationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_replicas: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/replicas",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotReplicas",
    Request: type = struct {
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_replicas) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_replicas };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        source_region: ?[]const u8 = null,
        bot_replica_summaries: ?[]struct {
            replica_region: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            bot_replica_status: ?[]const u8 = null,
            failure_reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replica_region = "replicaRegion",
                    .creation_date_time = "creationDateTime",
                    .bot_replica_status = "botReplicaStatus",
                    .failure_reasons = "failureReasons",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .source_region = "sourceRegion",
                .bot_replica_summaries = "botReplicaSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_resource_generations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/generations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotResourceGenerations",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_resource_generations) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_resource_generations };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        generation_summaries: ?[]struct {
            generation_id: ?[]const u8 = null,
            generation_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .generation_id = "generationId",
                    .generation_status = "generationStatus",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .generation_summaries = "generationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bots: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBots",
    Request: type = struct {
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_bots };
        }
    },
    Response: type = struct {
        bot_summaries: ?[]struct {
            bot_id: ?[]const u8 = null,
            bot_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_status: ?[]const u8 = null,
            latest_bot_version: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,
            bot_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_id = "botId",
                    .bot_name = "botName",
                    .description = "description",
                    .bot_status = "botStatus",
                    .latest_bot_version = "latestBotVersion",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .bot_type = "botType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_summaries = "botSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_version_replicas: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/replicas/{replicaRegion}/botversions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotVersionReplicas",
    Request: type = struct {
        bot_id: []const u8,
        replica_region: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .replica_region = "replicaRegion",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_by = "sortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_version_replicas) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_version_replicas };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        source_region: ?[]const u8 = null,
        replica_region: ?[]const u8 = null,
        bot_version_replica_summaries: ?[]struct {
            bot_version: ?[]const u8 = null,
            bot_version_replication_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            failure_reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_version = "botVersion",
                    .bot_version_replication_status = "botVersionReplicationStatus",
                    .creation_date_time = "creationDateTime",
                    .failure_reasons = "failureReasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .source_region = "sourceRegion",
                .replica_region = "replicaRegion",
                .bot_version_replica_summaries = "botVersionReplicaSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotVersions",
    Request: type = struct {
        bot_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_versions };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version_summaries: ?[]struct {
            bot_name: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_name = "botName",
                    .bot_version = "botVersion",
                    .description = "description",
                    .bot_status = "botStatus",
                    .creation_date_time = "creationDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version_summaries = "botVersionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_built_in_intents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/builtins/locales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBuiltInIntents",
    Request: type = struct {
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_built_in_intents) } {
            return .{ .service_metadata = service_metadata, .action = list_built_in_intents };
        }
    },
    Response: type = struct {
        built_in_intent_summaries: ?[]struct {
            intent_signature: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_signature = "intentSignature",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .built_in_intent_summaries = "builtInIntentSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_built_in_slot_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/builtins/locales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBuiltInSlotTypes",
    Request: type = struct {
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_built_in_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = list_built_in_slot_types };
        }
    },
    Response: type = struct {
        built_in_slot_type_summaries: ?[]struct {
            slot_type_signature: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_type_signature = "slotTypeSignature",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .built_in_slot_type_summaries = "builtInSlotTypeSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_custom_vocabulary_items: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/customvocabulary/DEFAULT/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCustomVocabularyItems",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_vocabulary_items) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_vocabulary_items };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        custom_vocabulary_items: ?[]CustomVocabularyItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .custom_vocabulary_items = "customVocabularyItems",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_exports: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/exports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExports",
    Request: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_exports) } {
            return .{ .service_metadata = service_metadata, .action = list_exports };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        export_summaries: ?[]struct {
            export_id: ?[]const u8 = null,
            resource_specification: ?ExportResourceSpecification = null,
            file_format: ?[]const u8 = null,
            export_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_id = "exportId",
                    .resource_specification = "resourceSpecification",
                    .file_format = "fileFormat",
                    .export_status = "exportStatus",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .export_summaries = "exportSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_imports: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/imports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImports",
    Request: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_imports) } {
            return .{ .service_metadata = service_metadata, .action = list_imports };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        import_summaries: ?[]struct {
            import_id: ?[]const u8 = null,
            imported_resource_id: ?[]const u8 = null,
            imported_resource_name: ?[]const u8 = null,
            import_status: ?[]const u8 = null,
            merge_strategy: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            imported_resource_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_id = "importId",
                    .imported_resource_id = "importedResourceId",
                    .imported_resource_name = "importedResourceName",
                    .import_status = "importStatus",
                    .merge_strategy = "mergeStrategy",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .imported_resource_type = "importedResourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .import_summaries = "importSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_intent_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/intentmetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntentMetrics",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        metrics: []struct {
            name: []const u8,
            statistic: []const u8,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .statistic = "statistic",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        },
        bin_by: ?[]AnalyticsBinBySpecification = null,
        group_by: ?[]struct {
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            operator: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .operator = "operator",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .metrics = "metrics",
                .bin_by = "binBy",
                .group_by = "groupBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_intent_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_intent_metrics };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        results: ?[]struct {
            bin_keys: ?[]AnalyticsBinKey = null,
            group_by_keys: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            metrics_results: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bin_keys = "binKeys",
                    .group_by_keys = "groupByKeys",
                    .metrics_results = "metricsResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .results = "results",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_intent_paths: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/intentpaths",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntentPaths",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        intent_path: []const u8,
        filters: ?[]struct {
            name: []const u8,
            operator: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .operator = "operator",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .intent_path = "intentPath",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_intent_paths) } {
            return .{ .service_metadata = service_metadata, .action = list_intent_paths };
        }
    },
    Response: type = struct {
        node_summaries: ?[]struct {
            intent_name: ?[]const u8 = null,
            intent_path: ?[]const u8 = null,
            intent_count: ?i64 = null,
            intent_level: ?i64 = null,
            node_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_name = "intentName",
                    .intent_path = "intentPath",
                    .intent_count = "intentCount",
                    .intent_level = "intentLevel",
                    .node_type = "nodeType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_summaries = "nodeSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_intents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntents",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_intents) } {
            return .{ .service_metadata = service_metadata, .action = list_intents };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_summaries: ?[]struct {
            intent_id: ?[]const u8 = null,
            intent_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            parent_intent_signature: ?[]const u8 = null,
            input_contexts: ?[]InputContext = null,
            output_contexts: ?[]OutputContext = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_id = "intentId",
                    .intent_name = "intentName",
                    .description = "description",
                    .parent_intent_signature = "parentIntentSignature",
                    .input_contexts = "inputContexts",
                    .output_contexts = "outputContexts",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_summaries = "intentSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_intent_stage_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/intentstagemetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntentStageMetrics",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        metrics: []struct {
            name: []const u8,
            statistic: []const u8,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .statistic = "statistic",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        },
        bin_by: ?[]AnalyticsBinBySpecification = null,
        group_by: ?[]struct {
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            operator: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .operator = "operator",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .metrics = "metrics",
                .bin_by = "binBy",
                .group_by = "groupBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_intent_stage_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_intent_stage_metrics };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        results: ?[]struct {
            bin_keys: ?[]AnalyticsBinKey = null,
            group_by_keys: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            metrics_results: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bin_keys = "binKeys",
                    .group_by_keys = "groupByKeys",
                    .metrics_results = "metricsResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .results = "results",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommended_intents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations/{botRecommendationId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendedIntents",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        bot_recommendation_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommended_intents) } {
            return .{ .service_metadata = service_metadata, .action = list_recommended_intents };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,
        summary_list: ?[]struct {
            intent_id: ?[]const u8 = null,
            intent_name: ?[]const u8 = null,
            sample_utterances_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_id = "intentId",
                    .intent_name = "intentName",
                    .sample_utterances_count = "sampleUtterancesCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
                .summary_list = "summaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_session_analytics_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/sessions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSessionAnalyticsData",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        sort_by: ?struct {
            name: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]AnalyticsSessionFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_session_analytics_data) } {
            return .{ .service_metadata = service_metadata, .action = list_session_analytics_data };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sessions: ?[]struct {
            bot_alias_id: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            locale_id: ?[]const u8 = null,
            channel: ?[]const u8 = null,
            session_id: ?[]const u8 = null,
            conversation_start_time: ?i64 = null,
            conversation_end_time: ?i64 = null,
            conversation_duration_seconds: ?i64 = null,
            conversation_end_state: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            number_of_turns: ?i64 = null,
            invoked_intent_samples: ?[]struct {
                intent_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .intent_name = "intentName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            originating_request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_alias_id = "botAliasId",
                    .bot_version = "botVersion",
                    .locale_id = "localeId",
                    .channel = "channel",
                    .session_id = "sessionId",
                    .conversation_start_time = "conversationStartTime",
                    .conversation_end_time = "conversationEndTime",
                    .conversation_duration_seconds = "conversationDurationSeconds",
                    .conversation_end_state = "conversationEndState",
                    .mode = "mode",
                    .number_of_turns = "numberOfTurns",
                    .invoked_intent_samples = "invokedIntentSamples",
                    .originating_request_id = "originatingRequestId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .next_token = "nextToken",
                .sessions = "sessions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_session_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/sessionmetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSessionMetrics",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        metrics: []struct {
            name: []const u8,
            statistic: []const u8,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .statistic = "statistic",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        },
        bin_by: ?[]AnalyticsBinBySpecification = null,
        group_by: ?[]struct {
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]AnalyticsSessionFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .metrics = "metrics",
                .bin_by = "binBy",
                .group_by = "groupBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_session_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_session_metrics };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        results: ?[]struct {
            bin_keys: ?[]AnalyticsBinKey = null,
            group_by_keys: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            metrics_results: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bin_keys = "binKeys",
                    .group_by_keys = "groupByKeys",
                    .metrics_results = "metricsResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .results = "results",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_slots: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSlots",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_slots) } {
            return .{ .service_metadata = service_metadata, .action = list_slots };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        slot_summaries: ?[]struct {
            slot_id: ?[]const u8 = null,
            slot_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            slot_constraint: ?[]const u8 = null,
            slot_type_id: ?[]const u8 = null,
            value_elicitation_prompt_specification: ?PromptSpecification = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_id = "slotId",
                    .slot_name = "slotName",
                    .description = "description",
                    .slot_constraint = "slotConstraint",
                    .slot_type_id = "slotTypeId",
                    .value_elicitation_prompt_specification = "valueElicitationPromptSpecification",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .slot_summaries = "slotSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_slot_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSlotTypes",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = list_slot_types };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        slot_type_summaries: ?[]struct {
            slot_type_id: ?[]const u8 = null,
            slot_type_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            parent_slot_type_signature: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,
            slot_type_category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_type_id = "slotTypeId",
                    .slot_type_name = "slotTypeName",
                    .description = "description",
                    .parent_slot_type_signature = "parentSlotTypeSignature",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .slot_type_category = "slotTypeCategory",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .slot_type_summaries = "slotTypeSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_test_execution_result_items: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testexecutions/{testExecutionId}/results",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTestExecutionResultItems",
    Request: type = struct {
        test_execution_id: []const u8,
        result_filter_by: struct {
            result_type_filter: []const u8,
            conversation_level_test_results_filter_by: ?struct {
                end_to_end_result: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .end_to_end_result = "endToEndResult",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_type_filter = "resultTypeFilter",
                    .conversation_level_test_results_filter_by = "conversationLevelTestResultsFilterBy",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
                .result_filter_by = "resultFilterBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_execution_result_items) } {
            return .{ .service_metadata = service_metadata, .action = list_test_execution_result_items };
        }
    },
    Response: type = struct {
        test_execution_results: ?struct {
            overall_test_results: ?struct {
                items: []struct {
                    multi_turn_conversation: bool,
                    total_result_count: i64,
                    speech_transcription_result_counts: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?i64 = null,
                    } = null,
                    end_to_end_result_counts: []struct {
                        key: ?[]const u8 = null,
                        value: ?i64 = null,
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .multi_turn_conversation = "multiTurnConversation",
                            .total_result_count = "totalResultCount",
                            .speech_transcription_result_counts = "speechTranscriptionResultCounts",
                            .end_to_end_result_counts = "endToEndResultCounts",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "speech_transcription_result_counts", field_name))
                            return try serializeMap(self.speech_transcription_result_counts, self.fieldNameFor("speech_transcription_result_counts"), options, out_stream);
                        if (std.mem.eql(u8, "end_to_end_result_counts", field_name))
                            return try serializeMap(self.end_to_end_result_counts, self.fieldNameFor("end_to_end_result_counts"), options, out_stream);
                        return false;
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .items = "items",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            conversation_level_test_results: ?struct {
                items: []struct {
                    conversation_id: []const u8,
                    end_to_end_result: []const u8,
                    speech_transcription_result: ?[]const u8 = null,
                    intent_classification_results: []struct {
                        intent_name: []const u8,
                        match_result: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .intent_name = "intentName",
                                .match_result = "matchResult",
                            };
                            return @field(mappings, field_name);
                        }
                    },
                    slot_resolution_results: []struct {
                        intent_name: []const u8,
                        slot_name: []const u8,
                        match_result: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .intent_name = "intentName",
                                .slot_name = "slotName",
                                .match_result = "matchResult",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .conversation_id = "conversationId",
                            .end_to_end_result = "endToEndResult",
                            .speech_transcription_result = "speechTranscriptionResult",
                            .intent_classification_results = "intentClassificationResults",
                            .slot_resolution_results = "slotResolutionResults",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .items = "items",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            intent_classification_test_results: ?struct {
                items: []struct {
                    intent_name: []const u8,
                    multi_turn_conversation: bool,
                    result_counts: struct {
                        total_result_count: i64,
                        speech_transcription_result_counts: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?i64 = null,
                        } = null,
                        intent_match_result_counts: []struct {
                            key: ?[]const u8 = null,
                            value: ?i64 = null,
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .total_result_count = "totalResultCount",
                                .speech_transcription_result_counts = "speechTranscriptionResultCounts",
                                .intent_match_result_counts = "intentMatchResultCounts",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "speech_transcription_result_counts", field_name))
                                return try serializeMap(self.speech_transcription_result_counts, self.fieldNameFor("speech_transcription_result_counts"), options, out_stream);
                            if (std.mem.eql(u8, "intent_match_result_counts", field_name))
                                return try serializeMap(self.intent_match_result_counts, self.fieldNameFor("intent_match_result_counts"), options, out_stream);
                            return false;
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .intent_name = "intentName",
                            .multi_turn_conversation = "multiTurnConversation",
                            .result_counts = "resultCounts",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .items = "items",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            intent_level_slot_resolution_test_results: ?struct {
                items: []struct {
                    intent_name: []const u8,
                    multi_turn_conversation: bool,
                    slot_resolution_results: []struct {
                        slot_name: []const u8,
                        result_counts: struct {
                            total_result_count: i64,
                            speech_transcription_result_counts: ?[]struct {
                                key: ?[]const u8 = null,
                                value: ?i64 = null,
                            } = null,
                            slot_match_result_counts: []struct {
                                key: ?[]const u8 = null,
                                value: ?i64 = null,
                            },

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .total_result_count = "totalResultCount",
                                    .speech_transcription_result_counts = "speechTranscriptionResultCounts",
                                    .slot_match_result_counts = "slotMatchResultCounts",
                                };
                                return @field(mappings, field_name);
                            }

                            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                                if (std.mem.eql(u8, "speech_transcription_result_counts", field_name))
                                    return try serializeMap(self.speech_transcription_result_counts, self.fieldNameFor("speech_transcription_result_counts"), options, out_stream);
                                if (std.mem.eql(u8, "slot_match_result_counts", field_name))
                                    return try serializeMap(self.slot_match_result_counts, self.fieldNameFor("slot_match_result_counts"), options, out_stream);
                                return false;
                            }
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .slot_name = "slotName",
                                .result_counts = "resultCounts",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .intent_name = "intentName",
                            .multi_turn_conversation = "multiTurnConversation",
                            .slot_resolution_results = "slotResolutionResults",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .items = "items",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            utterance_level_test_results: ?struct {
                items: []struct {
                    record_number: i64,
                    conversation_id: ?[]const u8 = null,
                    turn_result: struct {
                        agent: ?struct {
                            expected_agent_prompt: []const u8,
                            actual_agent_prompt: ?[]const u8 = null,
                            error_details: ?ExecutionErrorDetails = null,
                            actual_elicited_slot: ?[]const u8 = null,
                            actual_intent: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .expected_agent_prompt = "expectedAgentPrompt",
                                    .actual_agent_prompt = "actualAgentPrompt",
                                    .error_details = "errorDetails",
                                    .actual_elicited_slot = "actualElicitedSlot",
                                    .actual_intent = "actualIntent",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        user: ?struct {
                            input: UserTurnInputSpecification,
                            expected_output: UserTurnOutputSpecification,
                            actual_output: ?UserTurnOutputSpecification = null,
                            error_details: ?ExecutionErrorDetails = null,
                            end_to_end_result: ?[]const u8 = null,
                            intent_match_result: ?[]const u8 = null,
                            slot_match_result: ?[]const u8 = null,
                            speech_transcription_result: ?[]const u8 = null,
                            conversation_level_result: ?struct {
                                end_to_end_result: []const u8,
                                speech_transcription_result: ?[]const u8 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .end_to_end_result = "endToEndResult",
                                        .speech_transcription_result = "speechTranscriptionResult",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .input = "input",
                                    .expected_output = "expectedOutput",
                                    .actual_output = "actualOutput",
                                    .error_details = "errorDetails",
                                    .end_to_end_result = "endToEndResult",
                                    .intent_match_result = "intentMatchResult",
                                    .slot_match_result = "slotMatchResult",
                                    .speech_transcription_result = "speechTranscriptionResult",
                                    .conversation_level_result = "conversationLevelResult",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .agent = "agent",
                                .user = "user",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .record_number = "recordNumber",
                            .conversation_id = "conversationId",
                            .turn_result = "turnResult",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .items = "items",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .overall_test_results = "overallTestResults",
                    .conversation_level_test_results = "conversationLevelTestResults",
                    .intent_classification_test_results = "intentClassificationTestResults",
                    .intent_level_slot_resolution_test_results = "intentLevelSlotResolutionTestResults",
                    .utterance_level_test_results = "utteranceLevelTestResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_results = "testExecutionResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_test_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testexecutions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTestExecutions",
    Request: type = struct {
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_test_executions };
        }
    },
    Response: type = struct {
        test_executions: ?[]struct {
            test_execution_id: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            test_execution_status: ?[]const u8 = null,
            test_set_id: ?[]const u8 = null,
            test_set_name: ?[]const u8 = null,
            target: ?TestExecutionTarget = null,
            api_mode: ?[]const u8 = null,
            test_execution_modality: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .test_execution_id = "testExecutionId",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .test_execution_status = "testExecutionStatus",
                    .test_set_id = "testSetId",
                    .test_set_name = "testSetName",
                    .target = "target",
                    .api_mode = "apiMode",
                    .test_execution_modality = "testExecutionModality",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_executions = "testExecutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_test_set_records: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testsets/{testSetId}/records",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTestSetRecords",
    Request: type = struct {
        test_set_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_set_records) } {
            return .{ .service_metadata = service_metadata, .action = list_test_set_records };
        }
    },
    Response: type = struct {
        test_set_records: ?[]struct {
            record_number: i64,
            conversation_id: ?[]const u8 = null,
            turn_number: ?i64 = null,
            turn_specification: struct {
                agent_turn: ?struct {
                    agent_prompt: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .agent_prompt = "agentPrompt",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                user_turn: ?struct {
                    input: UserTurnInputSpecification,
                    expected: UserTurnOutputSpecification,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .input = "input",
                            .expected = "expected",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .agent_turn = "agentTurn",
                        .user_turn = "userTurn",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .record_number = "recordNumber",
                    .conversation_id = "conversationId",
                    .turn_number = "turnNumber",
                    .turn_specification = "turnSpecification",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_records = "testSetRecords",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_test_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testsets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTestSets",
    Request: type = struct {
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_test_sets };
        }
    },
    Response: type = struct {
        test_sets: ?[]struct {
            test_set_id: ?[]const u8 = null,
            test_set_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            modality: ?[]const u8 = null,
            status: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            num_turns: ?i64 = null,
            storage_location: ?TestSetStorageLocation = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .test_set_id = "testSetId",
                    .test_set_name = "testSetName",
                    .description = "description",
                    .modality = "modality",
                    .status = "status",
                    .role_arn = "roleArn",
                    .num_turns = "numTurns",
                    .storage_location = "storageLocation",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_sets = "testSets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_utterance_analytics_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/utterances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUtteranceAnalyticsData",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        sort_by: ?struct {
            name: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]AnalyticsUtteranceFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_utterance_analytics_data) } {
            return .{ .service_metadata = service_metadata, .action = list_utterance_analytics_data };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        utterances: ?[]struct {
            bot_alias_id: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            locale_id: ?[]const u8 = null,
            session_id: ?[]const u8 = null,
            channel: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            conversation_start_time: ?i64 = null,
            conversation_end_time: ?i64 = null,
            utterance: ?[]const u8 = null,
            utterance_timestamp: ?i64 = null,
            audio_voice_duration_millis: ?i64 = null,
            utterance_understood: ?bool = null,
            input_type: ?[]const u8 = null,
            output_type: ?[]const u8 = null,
            associated_intent_name: ?[]const u8 = null,
            associated_slot_name: ?[]const u8 = null,
            intent_state: ?[]const u8 = null,
            dialog_action_type: ?[]const u8 = null,
            bot_response_audio_voice_id: ?[]const u8 = null,
            slots_filled_in_session: ?[]const u8 = null,
            utterance_request_id: ?[]const u8 = null,
            bot_responses: ?[]struct {
                content: ?[]const u8 = null,
                content_type: ?[]const u8 = null,
                image_response_card: ?ImageResponseCard = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content = "content",
                        .content_type = "contentType",
                        .image_response_card = "imageResponseCard",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_alias_id = "botAliasId",
                    .bot_version = "botVersion",
                    .locale_id = "localeId",
                    .session_id = "sessionId",
                    .channel = "channel",
                    .mode = "mode",
                    .conversation_start_time = "conversationStartTime",
                    .conversation_end_time = "conversationEndTime",
                    .utterance = "utterance",
                    .utterance_timestamp = "utteranceTimestamp",
                    .audio_voice_duration_millis = "audioVoiceDurationMillis",
                    .utterance_understood = "utteranceUnderstood",
                    .input_type = "inputType",
                    .output_type = "outputType",
                    .associated_intent_name = "associatedIntentName",
                    .associated_slot_name = "associatedSlotName",
                    .intent_state = "intentState",
                    .dialog_action_type = "dialogActionType",
                    .bot_response_audio_voice_id = "botResponseAudioVoiceId",
                    .slots_filled_in_session = "slotsFilledInSession",
                    .utterance_request_id = "utteranceRequestId",
                    .bot_responses = "botResponses",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .next_token = "nextToken",
                .utterances = "utterances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_utterance_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/analytics/utterancemetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUtteranceMetrics",
    Request: type = struct {
        bot_id: []const u8,
        start_date_time: i64,
        end_date_time: i64,
        metrics: []struct {
            name: []const u8,
            statistic: []const u8,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .statistic = "statistic",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        },
        bin_by: ?[]AnalyticsBinBySpecification = null,
        group_by: ?[]struct {
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        attributes: ?[]struct {
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]AnalyticsUtteranceFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .start_date_time = "startDateTime",
                .end_date_time = "endDateTime",
                .metrics = "metrics",
                .bin_by = "binBy",
                .group_by = "groupBy",
                .attributes = "attributes",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_utterance_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_utterance_metrics };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        results: ?[]struct {
            bin_keys: ?[]AnalyticsBinKey = null,
            group_by_keys: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            metrics_results: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            attribute_results: ?[]struct {
                last_used_intent: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .last_used_intent = "lastUsedIntent",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bin_keys = "binKeys",
                    .group_by_keys = "groupByKeys",
                    .metrics_results = "metricsResults",
                    .attribute_results = "attributeResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .results = "results",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const search_associated_transcripts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations/{botRecommendationId}/associatedtranscripts",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAssociatedTranscripts",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        bot_recommendation_id: []const u8,
        search_order: ?[]const u8 = null,
        filters: []struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_index: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
                .search_order = "searchOrder",
                .filters = "filters",
                .max_results = "maxResults",
                .next_index = "nextIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_associated_transcripts) } {
            return .{ .service_metadata = service_metadata, .action = search_associated_transcripts };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,
        next_index: ?i64 = null,
        associated_transcripts: ?[]struct {
            transcript: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcript = "transcript",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
                .next_index = "nextIndex",
                .associated_transcripts = "associatedTranscripts",
                .total_results = "totalResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_bot_recommendation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations",
        .success_code = 202,
    };

    action_name: []const u8 = "StartBotRecommendation",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        transcript_source_setting: TranscriptSourceSetting,
        encryption_setting: ?EncryptionSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .transcript_source_setting = "transcriptSourceSetting",
                .encryption_setting = "encryptionSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bot_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = start_bot_recommendation };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_status: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        transcript_source_setting: ?TranscriptSourceSetting = null,
        encryption_setting: ?EncryptionSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_status = "botRecommendationStatus",
                .bot_recommendation_id = "botRecommendationId",
                .creation_date_time = "creationDateTime",
                .transcript_source_setting = "transcriptSourceSetting",
                .encryption_setting = "encryptionSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_bot_resource_generation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/startgeneration",
        .success_code = 202,
    };

    action_name: []const u8 = "StartBotResourceGeneration",
    Request: type = struct {
        generation_input_prompt: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_input_prompt = "generationInputPrompt",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_bot_resource_generation) } {
            return .{ .service_metadata = service_metadata, .action = start_bot_resource_generation };
        }
    },
    Response: type = struct {
        generation_input_prompt: ?[]const u8 = null,
        generation_id: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        generation_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_input_prompt = "generationInputPrompt",
                .generation_id = "generationId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .generation_status = "generationStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_import: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/imports",
        .success_code = 202,
    };

    action_name: []const u8 = "StartImport",
    Request: type = struct {
        import_id: []const u8,
        resource_specification: ImportResourceSpecification,
        merge_strategy: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .merge_strategy = "mergeStrategy",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import) } {
            return .{ .service_metadata = service_metadata, .action = start_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        resource_specification: ?ImportResourceSpecification = null,
        merge_strategy: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .merge_strategy = "mergeStrategy",
                .import_status = "importStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_test_execution: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/testsets/{testSetId}/testexecutions",
        .success_code = 202,
    };

    action_name: []const u8 = "StartTestExecution",
    Request: type = struct {
        test_set_id: []const u8,
        target: TestExecutionTarget,
        api_mode: []const u8,
        test_execution_modality: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .target = "target",
                .api_mode = "apiMode",
                .test_execution_modality = "testExecutionModality",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_test_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_test_execution };
        }
    },
    Response: type = struct {
        test_execution_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        test_set_id: ?[]const u8 = null,
        target: ?TestExecutionTarget = null,
        api_mode: ?[]const u8 = null,
        test_execution_modality: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_execution_id = "testExecutionId",
                .creation_date_time = "creationDateTime",
                .test_set_id = "testSetId",
                .target = "target",
                .api_mode = "apiMode",
                .test_execution_modality = "testExecutionModality",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_test_set_generation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/testsetgenerations",
        .success_code = 202,
    };

    action_name: []const u8 = "StartTestSetGeneration",
    Request: type = struct {
        test_set_name: []const u8,
        description: ?[]const u8 = null,
        storage_location: TestSetStorageLocation,
        generation_data_source: TestSetGenerationDataSource,
        role_arn: []const u8,
        test_set_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_name = "testSetName",
                .description = "description",
                .storage_location = "storageLocation",
                .generation_data_source = "generationDataSource",
                .role_arn = "roleArn",
                .test_set_tags = "testSetTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "test_set_tags", field_name))
                return try serializeMap(self.test_set_tags, self.fieldNameFor("test_set_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_test_set_generation) } {
            return .{ .service_metadata = service_metadata, .action = start_test_set_generation };
        }
    },
    Response: type = struct {
        test_set_generation_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        test_set_generation_status: ?[]const u8 = null,
        test_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        storage_location: ?TestSetStorageLocation = null,
        generation_data_source: ?TestSetGenerationDataSource = null,
        role_arn: ?[]const u8 = null,
        test_set_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_generation_id = "testSetGenerationId",
                .creation_date_time = "creationDateTime",
                .test_set_generation_status = "testSetGenerationStatus",
                .test_set_name = "testSetName",
                .description = "description",
                .storage_location = "storageLocation",
                .generation_data_source = "generationDataSource",
                .role_arn = "roleArn",
                .test_set_tags = "testSetTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "test_set_tags", field_name))
                return try serializeMap(self.test_set_tags, self.fieldNameFor("test_set_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_bot_recommendation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations/{botRecommendationId}/stopbotrecommendation",
        .success_code = 202,
    };

    action_name: []const u8 = "StopBotRecommendation",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        bot_recommendation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_bot_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = stop_bot_recommendation };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_status: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_status = "botRecommendationStatus",
                .bot_recommendation_id = "botRecommendationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBot",
    Request: type = struct {
        bot_id: []const u8,
        bot_name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        data_privacy: DataPrivacy,
        idle_session_ttl_in_seconds: i64,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_type = "botType",
                .bot_members = "botMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot) } {
            return .{ .service_metadata = service_metadata, .action = update_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        bot_type: ?[]const u8 = null,
        bot_members: ?[]BotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .bot_type = "botType",
                .bot_members = "botMembers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_alias_name: []const u8,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot_locale: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: f64,
        voice_settings: ?VoiceSettings = null,
        generative_ai_settings: ?GenerativeAISettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .generative_ai_settings = "generativeAISettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = update_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        bot_locale_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        recommended_actions: ?[][]const u8 = null,
        generative_ai_settings: ?GenerativeAISettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .locale_name = "localeName",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .bot_locale_status = "botLocaleStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .recommended_actions = "recommendedActions",
                .generative_ai_settings = "generativeAISettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot_recommendation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/botrecommendations/{botRecommendationId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBotRecommendation",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        bot_recommendation_id: []const u8,
        encryption_setting: EncryptionSetting,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_id = "botRecommendationId",
                .encryption_setting = "encryptionSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = update_bot_recommendation };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_recommendation_status: ?[]const u8 = null,
        bot_recommendation_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        transcript_source_setting: ?TranscriptSourceSetting = null,
        encryption_setting: ?EncryptionSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_recommendation_status = "botRecommendationStatus",
                .bot_recommendation_id = "botRecommendationId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .transcript_source_setting = "transcriptSourceSetting",
                .encryption_setting = "encryptionSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_export: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/exports/{exportId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateExport",
    Request: type = struct {
        export_id: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_export) } {
            return .{ .service_metadata = service_metadata, .action = update_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_intent: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntent",
    Request: type = struct {
        intent_id: []const u8,
        intent_name: []const u8,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        initial_response_setting: ?InitialResponseSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .initial_response_setting = "initialResponseSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_intent) } {
            return .{ .service_metadata = service_metadata, .action = update_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        initial_response_setting: ?InitialResponseSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .initial_response_setting = "initialResponseSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_slot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSlot",
    Request: type = struct {
        slot_id: []const u8,
        slot_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: SlotValueElicitationSetting,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,
        multiple_values_setting: ?MultipleValuesSetting = null,
        sub_slot_setting: ?SubSlotSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .multiple_values_setting = "multipleValuesSetting",
                .sub_slot_setting = "subSlotSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_slot) } {
            return .{ .service_metadata = service_metadata, .action = update_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        multiple_values_setting: ?MultipleValuesSetting = null,
        sub_slot_setting: ?SubSlotSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .multiple_values_setting = "multipleValuesSetting",
                .sub_slot_setting = "subSlotSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_slot_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        slot_type_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        external_source_setting: ?ExternalSourceSetting = null,
        composite_slot_type_setting: ?CompositeSlotTypeSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .external_source_setting = "externalSourceSetting",
                .composite_slot_type_setting = "compositeSlotTypeSetting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = update_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        external_source_setting: ?ExternalSourceSetting = null,
        composite_slot_type_setting: ?CompositeSlotTypeSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .external_source_setting = "externalSourceSetting",
                .composite_slot_type_setting = "compositeSlotTypeSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_test_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/testsets/{testSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTestSet",
    Request: type = struct {
        test_set_id: []const u8,
        test_set_name: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .test_set_name = "testSetName",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_test_set) } {
            return .{ .service_metadata = service_metadata, .action = update_test_set };
        }
    },
    Response: type = struct {
        test_set_id: ?[]const u8 = null,
        test_set_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        modality: ?[]const u8 = null,
        status: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        num_turns: ?i64 = null,
        storage_location: ?TestSetStorageLocation = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_set_id = "testSetId",
                .test_set_name = "testSetName",
                .description = "description",
                .modality = "modality",
                .status = "status",
                .role_arn = "roleArn",
                .num_turns = "numTurns",
                .storage_location = "storageLocation",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const TestSetStorageLocation = struct {
    s3_bucket_name: []const u8,
    s3_path: []const u8,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .s3_path = "s3Path",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CompositeSlotTypeSetting = struct {
    sub_slots: ?[]SubSlotTypeComposition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sub_slots = "subSlots",
        };
        return @field(mappings, field_name);
    }
};

pub const SubSlotTypeComposition = struct {
    name: []const u8,
    slot_type_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .slot_type_id = "slotTypeId",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalSourceSetting = struct {
    grammar_slot_type_setting: ?GrammarSlotTypeSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grammar_slot_type_setting = "grammarSlotTypeSetting",
        };
        return @field(mappings, field_name);
    }
};

pub const GrammarSlotTypeSetting = struct {
    source: ?GrammarSlotTypeSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
        };
        return @field(mappings, field_name);
    }
};

pub const GrammarSlotTypeSource = struct {
    s3_bucket_name: []const u8,
    s3_object_key: []const u8,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .s3_object_key = "s3ObjectKey",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValueSelectionSetting = struct {
    resolution_strategy: []const u8,
    regex_filter: ?SlotValueRegexFilter = null,
    advanced_recognition_setting: ?AdvancedRecognitionSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolution_strategy = "resolutionStrategy",
            .regex_filter = "regexFilter",
            .advanced_recognition_setting = "advancedRecognitionSetting",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedRecognitionSetting = struct {
    audio_recognition_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_recognition_strategy = "audioRecognitionStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValueRegexFilter = struct {
    pattern: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern = "pattern",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotTypeValue = struct {
    sample_value: ?SampleValue = null,
    synonyms: ?[]SampleValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sample_value = "sampleValue",
            .synonyms = "synonyms",
        };
        return @field(mappings, field_name);
    }
};

pub const SampleValue = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SubSlotSetting = struct {
    expression: ?[]const u8 = null,
    slot_specifications: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Specifications = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "expression",
            .slot_specifications = "slotSpecifications",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slot_specifications", field_name))
            return try serializeMap(self.slot_specifications, self.fieldNameFor("slot_specifications"), options, out_stream);
        return false;
    }
};

pub const Specifications = struct {
    slot_type_id: []const u8,
    value_elicitation_setting: SubSlotValueElicitationSetting,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_type_id = "slotTypeId",
            .value_elicitation_setting = "valueElicitationSetting",
        };
        return @field(mappings, field_name);
    }
};

pub const SubSlotValueElicitationSetting = struct {
    default_value_specification: ?SlotDefaultValueSpecification = null,
    prompt_specification: PromptSpecification,
    sample_utterances: ?[]SampleUtterance = null,
    wait_and_continue_specification: ?WaitAndContinueSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_specification = "defaultValueSpecification",
            .prompt_specification = "promptSpecification",
            .sample_utterances = "sampleUtterances",
            .wait_and_continue_specification = "waitAndContinueSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const WaitAndContinueSpecification = struct {
    waiting_response: ResponseSpecification,
    continue_response: ResponseSpecification,
    still_waiting_response: ?StillWaitingResponseSpecification = null,
    active: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waiting_response = "waitingResponse",
            .continue_response = "continueResponse",
            .still_waiting_response = "stillWaitingResponse",
            .active = "active",
        };
        return @field(mappings, field_name);
    }
};

pub const StillWaitingResponseSpecification = struct {
    message_groups: []MessageGroup,
    frequency_in_seconds: i64,
    timeout_in_seconds: i64,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .frequency_in_seconds = "frequencyInSeconds",
            .timeout_in_seconds = "timeoutInSeconds",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageGroup = struct {
    message: Message,
    variations: ?[]Message = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
            .variations = "variations",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    plain_text_message: ?PlainTextMessage = null,
    custom_payload: ?CustomPayload = null,
    ssml_message: ?SSMLMessage = null,
    image_response_card: ?ImageResponseCard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plain_text_message = "plainTextMessage",
            .custom_payload = "customPayload",
            .ssml_message = "ssmlMessage",
            .image_response_card = "imageResponseCard",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageResponseCard = struct {
    title: []const u8,
    subtitle: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    buttons: ?[]Button = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "title",
            .subtitle = "subtitle",
            .image_url = "imageUrl",
            .buttons = "buttons",
        };
        return @field(mappings, field_name);
    }
};

pub const Button = struct {
    text: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "text",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SSMLMessage = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPayload = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const PlainTextMessage = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseSpecification = struct {
    message_groups: []MessageGroup,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const SampleUtterance = struct {
    utterance: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .utterance = "utterance",
        };
        return @field(mappings, field_name);
    }
};

pub const PromptSpecification = struct {
    message_groups: []MessageGroup,
    max_retries: i64,
    allow_interrupt: ?bool = null,
    message_selection_strategy: ?[]const u8 = null,
    prompt_attempts_specification: ?[]struct {
        key: ?[]const u8 = null,
        value: ?PromptAttemptSpecification = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .max_retries = "maxRetries",
            .allow_interrupt = "allowInterrupt",
            .message_selection_strategy = "messageSelectionStrategy",
            .prompt_attempts_specification = "promptAttemptsSpecification",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "prompt_attempts_specification", field_name))
            return try serializeMap(self.prompt_attempts_specification, self.fieldNameFor("prompt_attempts_specification"), options, out_stream);
        return false;
    }
};

pub const PromptAttemptSpecification = struct {
    allow_interrupt: ?bool = null,
    allowed_input_types: AllowedInputTypes,
    audio_and_dtmf_input_specification: ?AudioAndDTMFInputSpecification = null,
    text_input_specification: ?TextInputSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_interrupt = "allowInterrupt",
            .allowed_input_types = "allowedInputTypes",
            .audio_and_dtmf_input_specification = "audioAndDTMFInputSpecification",
            .text_input_specification = "textInputSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const TextInputSpecification = struct {
    start_timeout_ms: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_timeout_ms = "startTimeoutMs",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioAndDTMFInputSpecification = struct {
    start_timeout_ms: i64,
    audio_specification: ?AudioSpecification = null,
    dtmf_specification: ?DTMFSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_timeout_ms = "startTimeoutMs",
            .audio_specification = "audioSpecification",
            .dtmf_specification = "dtmfSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const DTMFSpecification = struct {
    max_length: i64,
    end_timeout_ms: i64,
    deletion_character: []const u8,
    end_character: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_length = "maxLength",
            .end_timeout_ms = "endTimeoutMs",
            .deletion_character = "deletionCharacter",
            .end_character = "endCharacter",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSpecification = struct {
    max_length_ms: i64,
    end_timeout_ms: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_length_ms = "maxLengthMs",
            .end_timeout_ms = "endTimeoutMs",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowedInputTypes = struct {
    allow_audio_input: bool,
    allow_dtmf_input: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_audio_input = "allowAudioInput",
            .allow_dtmf_input = "allowDTMFInput",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValueSpecification = struct {
    default_value_list: []SlotDefaultValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_list = "defaultValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValue = struct {
    default_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const MultipleValuesSetting = struct {
    allow_multiple_values: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_multiple_values = "allowMultipleValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ObfuscationSetting = struct {
    obfuscation_setting_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .obfuscation_setting_type = "obfuscationSettingType",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValueElicitationSetting = struct {
    default_value_specification: ?SlotDefaultValueSpecification = null,
    slot_constraint: []const u8,
    prompt_specification: ?PromptSpecification = null,
    sample_utterances: ?[]SampleUtterance = null,
    wait_and_continue_specification: ?WaitAndContinueSpecification = null,
    slot_capture_setting: ?SlotCaptureSetting = null,
    slot_resolution_setting: ?SlotResolutionSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_specification = "defaultValueSpecification",
            .slot_constraint = "slotConstraint",
            .prompt_specification = "promptSpecification",
            .sample_utterances = "sampleUtterances",
            .wait_and_continue_specification = "waitAndContinueSpecification",
            .slot_capture_setting = "slotCaptureSetting",
            .slot_resolution_setting = "slotResolutionSetting",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotResolutionSetting = struct {
    slot_resolution_strategy: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_resolution_strategy = "slotResolutionStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotCaptureSetting = struct {
    capture_response: ?ResponseSpecification = null,
    capture_next_step: ?DialogState = null,
    capture_conditional: ?ConditionalSpecification = null,
    failure_response: ?ResponseSpecification = null,
    failure_next_step: ?DialogState = null,
    failure_conditional: ?ConditionalSpecification = null,
    code_hook: ?DialogCodeHookInvocationSetting = null,
    elicitation_code_hook: ?ElicitationCodeHookInvocationSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capture_response = "captureResponse",
            .capture_next_step = "captureNextStep",
            .capture_conditional = "captureConditional",
            .failure_response = "failureResponse",
            .failure_next_step = "failureNextStep",
            .failure_conditional = "failureConditional",
            .code_hook = "codeHook",
            .elicitation_code_hook = "elicitationCodeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const ElicitationCodeHookInvocationSetting = struct {
    enable_code_hook_invocation: bool,
    invocation_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_code_hook_invocation = "enableCodeHookInvocation",
            .invocation_label = "invocationLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogCodeHookInvocationSetting = struct {
    enable_code_hook_invocation: bool,
    active: bool,
    invocation_label: ?[]const u8 = null,
    post_code_hook_specification: PostDialogCodeHookInvocationSpecification,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_code_hook_invocation = "enableCodeHookInvocation",
            .active = "active",
            .invocation_label = "invocationLabel",
            .post_code_hook_specification = "postCodeHookSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const PostDialogCodeHookInvocationSpecification = struct {
    success_response: ?ResponseSpecification = null,
    success_next_step: ?DialogState = null,
    success_conditional: ?ConditionalSpecification = null,
    failure_response: ?ResponseSpecification = null,
    failure_next_step: ?DialogState = null,
    failure_conditional: ?ConditionalSpecification = null,
    timeout_response: ?ResponseSpecification = null,
    timeout_next_step: ?DialogState = null,
    timeout_conditional: ?ConditionalSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .success_response = "successResponse",
            .success_next_step = "successNextStep",
            .success_conditional = "successConditional",
            .failure_response = "failureResponse",
            .failure_next_step = "failureNextStep",
            .failure_conditional = "failureConditional",
            .timeout_response = "timeoutResponse",
            .timeout_next_step = "timeoutNextStep",
            .timeout_conditional = "timeoutConditional",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalSpecification = struct {
    active: bool,
    conditional_branches: []ConditionalBranch,
    default_branch: DefaultConditionalBranch,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active = "active",
            .conditional_branches = "conditionalBranches",
            .default_branch = "defaultBranch",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultConditionalBranch = struct {
    next_step: ?DialogState = null,
    response: ?ResponseSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .next_step = "nextStep",
            .response = "response",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogState = struct {
    dialog_action: ?DialogAction = null,
    intent: ?IntentOverride = null,
    session_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dialog_action = "dialogAction",
            .intent = "intent",
            .session_attributes = "sessionAttributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "session_attributes", field_name))
            return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
        return false;
    }
};

pub const IntentOverride = struct {
    name: ?[]const u8 = null,
    slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?SlotValueOverride = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .slots = "slots",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slots", field_name))
            return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
        return false;
    }
};

pub const SlotValueOverride = struct {
    shape: ?[]const u8 = null,
    value: ?SlotValue = null,
    values: ?[]SlotValueOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shape = "shape",
            .value = "value",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValue = struct {
    interpreted_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interpreted_value = "interpretedValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogAction = struct {
    type: []const u8,
    slot_to_elicit: ?[]const u8 = null,
    suppress_next_message: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .slot_to_elicit = "slotToElicit",
            .suppress_next_message = "suppressNextMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalBranch = struct {
    name: []const u8,
    condition: Condition,
    next_step: DialogState,
    response: ?ResponseSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .condition = "condition",
            .next_step = "nextStep",
            .response = "response",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    expression_string: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression_string = "expressionString",
        };
        return @field(mappings, field_name);
    }
};

pub const InitialResponseSetting = struct {
    initial_response: ?ResponseSpecification = null,
    next_step: ?DialogState = null,
    conditional: ?ConditionalSpecification = null,
    code_hook: ?DialogCodeHookInvocationSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .initial_response = "initialResponse",
            .next_step = "nextStep",
            .conditional = "conditional",
            .code_hook = "codeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const KendraConfiguration = struct {
    kendra_index: []const u8,
    query_filter_string_enabled: ?bool = null,
    query_filter_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kendra_index = "kendraIndex",
            .query_filter_string_enabled = "queryFilterStringEnabled",
            .query_filter_string = "queryFilterString",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputContext = struct {
    name: []const u8,
    time_to_live_in_seconds: i64,
    turns_to_live: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .time_to_live_in_seconds = "timeToLiveInSeconds",
            .turns_to_live = "turnsToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const InputContext = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentClosingSetting = struct {
    closing_response: ?ResponseSpecification = null,
    active: ?bool = null,
    next_step: ?DialogState = null,
    conditional: ?ConditionalSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .closing_response = "closingResponse",
            .active = "active",
            .next_step = "nextStep",
            .conditional = "conditional",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentConfirmationSetting = struct {
    prompt_specification: PromptSpecification,
    declination_response: ?ResponseSpecification = null,
    active: ?bool = null,
    confirmation_response: ?ResponseSpecification = null,
    confirmation_next_step: ?DialogState = null,
    confirmation_conditional: ?ConditionalSpecification = null,
    declination_next_step: ?DialogState = null,
    declination_conditional: ?ConditionalSpecification = null,
    failure_response: ?ResponseSpecification = null,
    failure_next_step: ?DialogState = null,
    failure_conditional: ?ConditionalSpecification = null,
    code_hook: ?DialogCodeHookInvocationSetting = null,
    elicitation_code_hook: ?ElicitationCodeHookInvocationSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prompt_specification = "promptSpecification",
            .declination_response = "declinationResponse",
            .active = "active",
            .confirmation_response = "confirmationResponse",
            .confirmation_next_step = "confirmationNextStep",
            .confirmation_conditional = "confirmationConditional",
            .declination_next_step = "declinationNextStep",
            .declination_conditional = "declinationConditional",
            .failure_response = "failureResponse",
            .failure_next_step = "failureNextStep",
            .failure_conditional = "failureConditional",
            .code_hook = "codeHook",
            .elicitation_code_hook = "elicitationCodeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotPriority = struct {
    priority: i64,
    slot_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "priority",
            .slot_id = "slotId",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentCodeHookSettings = struct {
    enabled: bool,
    post_fulfillment_status_specification: ?PostFulfillmentStatusSpecification = null,
    fulfillment_updates_specification: ?FulfillmentUpdatesSpecification = null,
    active: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .post_fulfillment_status_specification = "postFulfillmentStatusSpecification",
            .fulfillment_updates_specification = "fulfillmentUpdatesSpecification",
            .active = "active",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentUpdatesSpecification = struct {
    active: bool,
    start_response: ?FulfillmentStartResponseSpecification = null,
    update_response: ?FulfillmentUpdateResponseSpecification = null,
    timeout_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active = "active",
            .start_response = "startResponse",
            .update_response = "updateResponse",
            .timeout_in_seconds = "timeoutInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentUpdateResponseSpecification = struct {
    frequency_in_seconds: i64,
    message_groups: []MessageGroup,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frequency_in_seconds = "frequencyInSeconds",
            .message_groups = "messageGroups",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentStartResponseSpecification = struct {
    delay_in_seconds: i64,
    message_groups: []MessageGroup,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delay_in_seconds = "delayInSeconds",
            .message_groups = "messageGroups",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const PostFulfillmentStatusSpecification = struct {
    success_response: ?ResponseSpecification = null,
    failure_response: ?ResponseSpecification = null,
    timeout_response: ?ResponseSpecification = null,
    success_next_step: ?DialogState = null,
    success_conditional: ?ConditionalSpecification = null,
    failure_next_step: ?DialogState = null,
    failure_conditional: ?ConditionalSpecification = null,
    timeout_next_step: ?DialogState = null,
    timeout_conditional: ?ConditionalSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .success_response = "successResponse",
            .failure_response = "failureResponse",
            .timeout_response = "timeoutResponse",
            .success_next_step = "successNextStep",
            .success_conditional = "successConditional",
            .failure_next_step = "failureNextStep",
            .failure_conditional = "failureConditional",
            .timeout_next_step = "timeoutNextStep",
            .timeout_conditional = "timeoutConditional",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogCodeHookSettings = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportResourceSpecification = struct {
    bot_export_specification: ?BotExportSpecification = null,
    bot_locale_export_specification: ?BotLocaleExportSpecification = null,
    custom_vocabulary_export_specification: ?CustomVocabularyExportSpecification = null,
    test_set_export_specification: ?TestSetExportSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_export_specification = "botExportSpecification",
            .bot_locale_export_specification = "botLocaleExportSpecification",
            .custom_vocabulary_export_specification = "customVocabularyExportSpecification",
            .test_set_export_specification = "testSetExportSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const TestSetExportSpecification = struct {
    test_set_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .test_set_id = "testSetId",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomVocabularyExportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const BotLocaleExportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const BotExportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionSetting = struct {
    kms_key_arn: ?[]const u8 = null,
    bot_locale_export_password: ?[]const u8 = null,
    associated_transcripts_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "kmsKeyArn",
            .bot_locale_export_password = "botLocaleExportPassword",
            .associated_transcripts_password = "associatedTranscriptsPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const TranscriptSourceSetting = struct {
    s3_bucket_transcript_source: ?S3BucketTranscriptSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_transcript_source = "s3BucketTranscriptSource",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketTranscriptSource = struct {
    s3_bucket_name: []const u8,
    path_format: ?PathFormat = null,
    transcript_format: []const u8,
    transcript_filter: ?TranscriptFilter = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .path_format = "pathFormat",
            .transcript_format = "transcriptFormat",
            .transcript_filter = "transcriptFilter",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TranscriptFilter = struct {
    lex_transcript_filter: ?LexTranscriptFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lex_transcript_filter = "lexTranscriptFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const LexTranscriptFilter = struct {
    date_range_filter: ?DateRangeFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date_range_filter = "dateRangeFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const DateRangeFilter = struct {
    start_date_time: i64,
    end_date_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_date_time = "startDateTime",
            .end_date_time = "endDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const PathFormat = struct {
    object_prefixes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_prefixes = "objectPrefixes",
        };
        return @field(mappings, field_name);
    }
};

pub const GenerativeAISettings = struct {
    runtime_settings: ?RuntimeSettings = null,
    buildtime_settings: ?BuildtimeSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_settings = "runtimeSettings",
            .buildtime_settings = "buildtimeSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const BuildtimeSettings = struct {
    descriptive_bot_builder: ?DescriptiveBotBuilderSpecification = null,
    sample_utterance_generation: ?SampleUtteranceGenerationSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .descriptive_bot_builder = "descriptiveBotBuilder",
            .sample_utterance_generation = "sampleUtteranceGeneration",
        };
        return @field(mappings, field_name);
    }
};

pub const SampleUtteranceGenerationSpecification = struct {
    enabled: bool,
    bedrock_model_specification: ?BedrockModelSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .bedrock_model_specification = "bedrockModelSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const BedrockModelSpecification = struct {
    model_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .model_arn = "modelArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DescriptiveBotBuilderSpecification = struct {
    enabled: bool,
    bedrock_model_specification: ?BedrockModelSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .bedrock_model_specification = "bedrockModelSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimeSettings = struct {
    slot_resolution_improvement: ?SlotResolutionImprovementSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_resolution_improvement = "slotResolutionImprovement",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotResolutionImprovementSpecification = struct {
    enabled: bool,
    bedrock_model_specification: ?BedrockModelSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .bedrock_model_specification = "bedrockModelSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceSettings = struct {
    voice_id: []const u8,
    engine: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_id = "voiceId",
            .engine = "engine",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentAnalysisSettings = struct {
    detect_sentiment: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detect_sentiment = "detectSentiment",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationLogSettings = struct {
    text_log_settings: ?[]TextLogSetting = null,
    audio_log_settings: ?[]AudioLogSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_log_settings = "textLogSettings",
            .audio_log_settings = "audioLogSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioLogSetting = struct {
    enabled: bool,
    destination: AudioLogDestination,
    selective_logging_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .destination = "destination",
            .selective_logging_enabled = "selectiveLoggingEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioLogDestination = struct {
    s3_bucket: S3BucketLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketLogDestination = struct {
    kms_key_arn: ?[]const u8 = null,
    s3_bucket_arn: []const u8,
    log_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "kmsKeyArn",
            .s3_bucket_arn = "s3BucketArn",
            .log_prefix = "logPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const TextLogSetting = struct {
    enabled: bool,
    destination: TextLogDestination,
    selective_logging_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .destination = "destination",
            .selective_logging_enabled = "selectiveLoggingEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TextLogDestination = struct {
    cloud_watch: CloudWatchLogGroupLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch = "cloudWatch",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogGroupLogDestination = struct {
    cloud_watch_log_group_arn: []const u8,
    log_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_group_arn = "cloudWatchLogGroupArn",
            .log_prefix = "logPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const BotAliasLocaleSettings = struct {
    enabled: bool,
    code_hook_specification: ?CodeHookSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .code_hook_specification = "codeHookSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeHookSpecification = struct {
    lambda_code_hook: LambdaCodeHook,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_code_hook = "lambdaCodeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaCodeHook = struct {
    lambda_arn: []const u8,
    code_hook_interface_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "lambdaARN",
            .code_hook_interface_version = "codeHookInterfaceVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const BotMember = struct {
    bot_member_id: []const u8,
    bot_member_name: []const u8,
    bot_member_alias_id: []const u8,
    bot_member_alias_name: []const u8,
    bot_member_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_member_id = "botMemberId",
            .bot_member_name = "botMemberName",
            .bot_member_alias_id = "botMemberAliasId",
            .bot_member_alias_name = "botMemberAliasName",
            .bot_member_version = "botMemberVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPrivacy = struct {
    child_directed: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .child_directed = "childDirected",
        };
        return @field(mappings, field_name);
    }
};

pub const TestSetGenerationDataSource = struct {
    conversation_logs_data_source: ?ConversationLogsDataSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conversation_logs_data_source = "conversationLogsDataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationLogsDataSource = struct {
    bot_id: []const u8,
    bot_alias_id: []const u8,
    locale_id: []const u8,
    filter: ConversationLogsDataSourceFilterBy,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_alias_id = "botAliasId",
            .locale_id = "localeId",
            .filter = "filter",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationLogsDataSourceFilterBy = struct {
    start_time: i64,
    end_time: i64,
    input_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "startTime",
            .end_time = "endTime",
            .input_mode = "inputMode",
        };
        return @field(mappings, field_name);
    }
};

pub const TestExecutionTarget = struct {
    bot_alias_target: ?BotAliasTestExecutionTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_alias_target = "botAliasTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const BotAliasTestExecutionTarget = struct {
    bot_id: []const u8,
    bot_alias_id: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_alias_id = "botAliasId",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportResourceSpecification = struct {
    bot_import_specification: ?BotImportSpecification = null,
    bot_locale_import_specification: ?BotLocaleImportSpecification = null,
    custom_vocabulary_import_specification: ?CustomVocabularyImportSpecification = null,
    test_set_import_resource_specification: ?TestSetImportResourceSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_import_specification = "botImportSpecification",
            .bot_locale_import_specification = "botLocaleImportSpecification",
            .custom_vocabulary_import_specification = "customVocabularyImportSpecification",
            .test_set_import_resource_specification = "testSetImportResourceSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const TestSetImportResourceSpecification = struct {
    test_set_name: []const u8,
    description: ?[]const u8 = null,
    role_arn: []const u8,
    storage_location: TestSetStorageLocation,
    import_input_location: TestSetImportInputLocation,
    modality: []const u8,
    test_set_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .test_set_name = "testSetName",
            .description = "description",
            .role_arn = "roleArn",
            .storage_location = "storageLocation",
            .import_input_location = "importInputLocation",
            .modality = "modality",
            .test_set_tags = "testSetTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "test_set_tags", field_name))
            return try serializeMap(self.test_set_tags, self.fieldNameFor("test_set_tags"), options, out_stream);
        return false;
    }
};

pub const TestSetImportInputLocation = struct {
    s3_bucket_name: []const u8,
    s3_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .s3_path = "s3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomVocabularyImportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const BotLocaleImportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,
    nlu_intent_confidence_threshold: ?f64 = null,
    voice_settings: ?VoiceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
            .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
            .voice_settings = "voiceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const BotImportSpecification = struct {
    bot_name: []const u8,
    role_arn: []const u8,
    data_privacy: DataPrivacy,
    idle_session_ttl_in_seconds: ?i64 = null,
    bot_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    test_bot_alias_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_name = "botName",
            .role_arn = "roleArn",
            .data_privacy = "dataPrivacy",
            .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
            .bot_tags = "botTags",
            .test_bot_alias_tags = "testBotAliasTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "bot_tags", field_name))
            return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
        if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
            return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
        return false;
    }
};

pub const AnalyticsBinKey = struct {
    name: ?[]const u8 = null,
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsUtteranceFilter = struct {
    name: []const u8,
    operator: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .operator = "operator",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsBinBySpecification = struct {
    name: []const u8,
    interval: []const u8,
    order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .interval = "interval",
            .order = "order",
        };
        return @field(mappings, field_name);
    }
};

pub const UserTurnOutputSpecification = struct {
    intent: UserTurnIntentOutput,
    active_contexts: ?[]ActiveContext = null,
    transcript: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .intent = "intent",
            .active_contexts = "activeContexts",
            .transcript = "transcript",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveContext = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const UserTurnIntentOutput = struct {
    name: []const u8,
    slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?UserTurnSlotOutput = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .slots = "slots",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slots", field_name))
            return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
        return false;
    }
};

pub const UserTurnSlotOutput = struct {
    value: ?[]const u8 = null,
    values: ?[]UserTurnSlotOutput = null,
    sub_slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?UserTurnSlotOutput = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .values = "values",
            .sub_slots = "subSlots",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sub_slots", field_name))
            return try serializeMap(self.sub_slots, self.fieldNameFor("sub_slots"), options, out_stream);
        return false;
    }
};

pub const UserTurnInputSpecification = struct {
    utterance_input: UtteranceInputSpecification,
    request_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    session_state: ?InputSessionStateSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .utterance_input = "utteranceInput",
            .request_attributes = "requestAttributes",
            .session_state = "sessionState",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "request_attributes", field_name))
            return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
        return false;
    }
};

pub const InputSessionStateSpecification = struct {
    session_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    active_contexts: ?[]ActiveContext = null,
    runtime_hints: ?RuntimeHints = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .session_attributes = "sessionAttributes",
            .active_contexts = "activeContexts",
            .runtime_hints = "runtimeHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "session_attributes", field_name))
            return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
        return false;
    }
};

pub const RuntimeHints = struct {
    slot_hints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RuntimeHintDetails = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_hints = "slotHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slot_hints", field_name))
            return try serializeMap(self.slot_hints, self.fieldNameFor("slot_hints"), options, out_stream);
        return false;
    }
};

pub const RuntimeHintDetails = struct {
    runtime_hint_values: ?[]RuntimeHintValue = null,
    sub_slot_hints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RuntimeHintDetails = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_hint_values = "runtimeHintValues",
            .sub_slot_hints = "subSlotHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sub_slot_hints", field_name))
            return try serializeMap(self.sub_slot_hints, self.fieldNameFor("sub_slot_hints"), options, out_stream);
        return false;
    }
};

pub const RuntimeHintValue = struct {
    phrase: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phrase = "phrase",
        };
        return @field(mappings, field_name);
    }
};

pub const UtteranceInputSpecification = struct {
    text_input: ?[]const u8 = null,
    audio_input: ?UtteranceAudioInputSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_input = "textInput",
            .audio_input = "audioInput",
        };
        return @field(mappings, field_name);
    }
};

pub const UtteranceAudioInputSpecification = struct {
    audio_file_s3_location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_file_s3_location = "audioFileS3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionErrorDetails = struct {
    error_code: []const u8,
    error_message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsSessionFilter = struct {
    name: []const u8,
    operator: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .operator = "operator",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomVocabularyItem = struct {
    item_id: []const u8,
    phrase: []const u8,
    weight: ?i64 = null,
    display_as: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_id = "itemId",
            .phrase = "phrase",
            .weight = "weight",
            .display_as = "displayAs",
        };
        return @field(mappings, field_name);
    }
};

pub const UtteranceAggregationDuration = struct {
    relative_aggregation_duration: RelativeAggregationDuration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relative_aggregation_duration = "relativeAggregationDuration",
        };
        return @field(mappings, field_name);
    }
};

pub const RelativeAggregationDuration = struct {
    time_dimension: []const u8,
    time_value: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_dimension = "timeDimension",
            .time_value = "timeValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TestSetDiscrepancyReportResourceTarget = struct {
    bot_alias_target: ?TestSetDiscrepancyReportBotAliasTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_alias_target = "botAliasTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const TestSetDiscrepancyReportBotAliasTarget = struct {
    bot_id: []const u8,
    bot_alias_id: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_alias_id = "botAliasId",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const ParentBotNetwork = struct {
    bot_id: []const u8,
    bot_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const BotVersionLocaleDetails = struct {
    source_bot_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_bot_version = "sourceBotVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedCustomVocabularyItem = struct {
    item_id: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_id = "itemId",
            .error_message = "errorMessage",
            .error_code = "errorCode",
        };
        return @field(mappings, field_name);
    }
};
