const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-14";
pub const sdk_id: []const u8 = "MediaLive";
pub const arn_namespace: ?[]const u8 = "medialive";
pub const endpoint_prefix: []const u8 = "medialive";
pub const sigv4_name: []const u8 = "medialive";
pub const name: []const u8 = "MediaLive";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-14",
    sdk_id: []const u8 = "MediaLive",
    arn_namespace: ?[]const u8 = "medialive",
    endpoint_prefix: []const u8 = "medialive",
    sigv4_name: []const u8 = "medialive",
    name: []const u8 = "MediaLive",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_input_device_transfer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInputDeviceTransfer",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_input_device_transfer) } {
            return .{ .service_metadata = service_metadata, .action = accept_input_device_transfer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const batch_delete: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/batch/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDelete",
    Request: type = struct {
        channel_ids: ?[][]const u8 = null,
        input_ids: ?[][]const u8 = null,
        input_security_group_ids: ?[][]const u8 = null,
        multiplex_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_ids = "channelIds",
                .input_ids = "inputIds",
                .input_security_group_ids = "inputSecurityGroupIds",
                .multiplex_ids = "multiplexIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete };
        }
    },
    Response: type = struct {
        failed: ?[]BatchFailedResultModel = null,
        successful: ?[]BatchSuccessfulResultModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed = "failed",
                .successful = "successful",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const batch_start: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/batch/start",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchStart",
    Request: type = struct {
        channel_ids: ?[][]const u8 = null,
        multiplex_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_ids = "channelIds",
                .multiplex_ids = "multiplexIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_start) } {
            return .{ .service_metadata = service_metadata, .action = batch_start };
        }
    },
    Response: type = struct {
        failed: ?[]BatchFailedResultModel = null,
        successful: ?[]BatchSuccessfulResultModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed = "failed",
                .successful = "successful",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const batch_stop: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/batch/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchStop",
    Request: type = struct {
        channel_ids: ?[][]const u8 = null,
        multiplex_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_ids = "channelIds",
                .multiplex_ids = "multiplexIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_stop) } {
            return .{ .service_metadata = service_metadata, .action = batch_stop };
        }
    },
    Response: type = struct {
        failed: ?[]BatchFailedResultModel = null,
        successful: ?[]BatchSuccessfulResultModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed = "failed",
                .successful = "successful",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const batch_update_schedule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/channels/{ChannelId}/schedule",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateSchedule",
    Request: type = struct {
        channel_id: []const u8,
        creates: ?struct {
            schedule_actions: []ScheduleAction,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schedule_actions = "scheduleActions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        deletes: ?struct {
            action_names: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_names = "actionNames",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
                .creates = "creates",
                .deletes = "deletes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_schedule) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_schedule };
        }
    },
    Response: type = struct {
        creates: ?struct {
            schedule_actions: []ScheduleAction,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schedule_actions = "scheduleActions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        deletes: ?struct {
            schedule_actions: []ScheduleAction,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schedule_actions = "scheduleActions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creates = "creates",
                .deletes = "deletes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const cancel_input_device_transfer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelInputDeviceTransfer",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_input_device_transfer) } {
            return .{ .service_metadata = service_metadata, .action = cancel_input_device_transfer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const claim_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/claimDevice",
        .success_code = 200,
    };

    action_name: []const u8 = "ClaimDevice",
    Request: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(claim_device) } {
            return .{ .service_metadata = service_metadata, .action = claim_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/channels",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        encoder_settings: ?EncoderSettings = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?struct {
            maintenance_day: ?[]const u8 = null,
            maintenance_start_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_day = "maintenanceDay",
                    .maintenance_start_time = "maintenanceStartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        reserved: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?struct {
            public_address_allocation_ids: ?[][]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            subnet_ids: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .public_address_allocation_ids = "publicAddressAllocationIds",
                    .security_group_ids = "securityGroupIds",
                    .subnet_ids = "subnetIds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .encoder_settings = "encoderSettings",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .request_id = "requestId",
                .reserved = "reserved",
                .role_arn = "roleArn",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_input: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateInput",
    Request: type = struct {
        destinations: ?[]InputDestinationRequest = null,
        input_devices: ?[]InputDeviceSettings = null,
        input_security_groups: ?[][]const u8 = null,
        media_connect_flows: ?[]MediaConnectFlowRequest = null,
        name: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        sources: ?[]InputSourceRequest = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,
        vpc: ?struct {
            security_group_ids: ?[][]const u8 = null,
            subnet_ids: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_group_ids = "securityGroupIds",
                    .subnet_ids = "subnetIds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destinations = "destinations",
                .input_devices = "inputDevices",
                .input_security_groups = "inputSecurityGroups",
                .media_connect_flows = "mediaConnectFlows",
                .name = "name",
                .request_id = "requestId",
                .role_arn = "roleArn",
                .sources = "sources",
                .tags = "tags",
                .type = "type",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_input) } {
            return .{ .service_metadata = service_metadata, .action = create_input };
        }
    },
    Response: type = struct {
        input: ?Input = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_input_security_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputSecurityGroups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInputSecurityGroup",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        whitelist_rules: ?[]InputWhitelistRuleCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .whitelist_rules = "whitelistRules",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_input_security_group) } {
            return .{ .service_metadata = service_metadata, .action = create_input_security_group };
        }
    },
    Response: type = struct {
        security_group: ?InputSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group = "securityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_multiplex: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/multiplexes",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMultiplex",
    Request: type = struct {
        availability_zones: [][]const u8,
        multiplex_settings: MultiplexSettings,
        name: []const u8,
        request_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zones = "availabilityZones",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
                .request_id = "requestId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = create_multiplex };
        }
    },
    Response: type = struct {
        multiplex: ?Multiplex = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex = "multiplex",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_multiplex_program: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/multiplexes/{MultiplexId}/programs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMultiplexProgram",
    Request: type = struct {
        multiplex_id: []const u8,
        multiplex_program_settings: MultiplexProgramSettings,
        program_name: []const u8,
        request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
                .multiplex_program_settings = "multiplexProgramSettings",
                .program_name = "programName",
                .request_id = "requestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_multiplex_program) } {
            return .{ .service_metadata = service_metadata, .action = create_multiplex_program };
        }
    },
    Response: type = struct {
        multiplex_program: ?MultiplexProgram = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_program = "multiplexProgram",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_partner_input: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputs/{InputId}/partners",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePartnerInput",
    Request: type = struct {
        input_id: []const u8,
        request_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_id = "InputId",
                .request_id = "requestId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partner_input) } {
            return .{ .service_metadata = service_metadata, .action = create_partner_input };
        }
    },
    Response: type = struct {
        input: ?Input = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/channels/{ChannelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        egress_endpoints: ?[]ChannelEgressEndpoint = null,
        encoder_settings: ?EncoderSettings = null,
        id: ?[]const u8 = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?MaintenanceStatus = null,
        name: ?[]const u8 = null,
        pipeline_details: ?[]PipelineDetail = null,
        pipelines_running_count: ?i64 = null,
        role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?VpcOutputSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .egress_endpoints = "egressEndpoints",
                .encoder_settings = "encoderSettings",
                .id = "id",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .pipeline_details = "pipelineDetails",
                .pipelines_running_count = "pipelinesRunningCount",
                .role_arn = "roleArn",
                .state = "state",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_input: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/inputs/{InputId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInput",
    Request: type = struct {
        input_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_id = "InputId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_input) } {
            return .{ .service_metadata = service_metadata, .action = delete_input };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_input_security_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/inputSecurityGroups/{InputSecurityGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInputSecurityGroup",
    Request: type = struct {
        input_security_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_security_group_id = "InputSecurityGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_input_security_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_input_security_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_multiplex: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/multiplexes/{MultiplexId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteMultiplex",
    Request: type = struct {
        multiplex_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = delete_multiplex };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        availability_zones: ?[][]const u8 = null,
        destinations: ?[]MultiplexOutputDestination = null,
        id: ?[]const u8 = null,
        multiplex_settings: ?MultiplexSettings = null,
        name: ?[]const u8 = null,
        pipelines_running_count: ?i64 = null,
        program_count: ?i64 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .availability_zones = "availabilityZones",
                .destinations = "destinations",
                .id = "id",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
                .pipelines_running_count = "pipelinesRunningCount",
                .program_count = "programCount",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_multiplex_program: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/multiplexes/{MultiplexId}/programs/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMultiplexProgram",
    Request: type = struct {
        multiplex_id: []const u8,
        program_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
                .program_name = "ProgramName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_multiplex_program) } {
            return .{ .service_metadata = service_metadata, .action = delete_multiplex_program };
        }
    },
    Response: type = struct {
        channel_id: ?[]const u8 = null,
        multiplex_program_settings: ?MultiplexProgramSettings = null,
        packet_identifiers_map: ?MultiplexProgramPacketIdentifiersMap = null,
        pipeline_details: ?[]MultiplexProgramPipelineDetail = null,
        program_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "channelId",
                .multiplex_program_settings = "multiplexProgramSettings",
                .packet_identifiers_map = "packetIdentifiersMap",
                .pipeline_details = "pipelineDetails",
                .program_name = "programName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_reservation: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/reservations/{ReservationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteReservation",
    Request: type = struct {
        reservation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation_id = "ReservationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_reservation) } {
            return .{ .service_metadata = service_metadata, .action = delete_reservation };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        count: ?i64 = null,
        currency_code: ?[]const u8 = null,
        duration: ?i64 = null,
        duration_units: ?[]const u8 = null,
        end: ?[]const u8 = null,
        fixed_price: ?f64 = null,
        name: ?[]const u8 = null,
        offering_description: ?[]const u8 = null,
        offering_id: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        region: ?[]const u8 = null,
        renewal_settings: ?RenewalSettings = null,
        reservation_id: ?[]const u8 = null,
        resource_specification: ?ReservationResourceSpecification = null,
        start: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        usage_price: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .count = "count",
                .currency_code = "currencyCode",
                .duration = "duration",
                .duration_units = "durationUnits",
                .end = "end",
                .fixed_price = "fixedPrice",
                .name = "name",
                .offering_description = "offeringDescription",
                .offering_id = "offeringId",
                .offering_type = "offeringType",
                .region = "region",
                .renewal_settings = "renewalSettings",
                .reservation_id = "reservationId",
                .resource_specification = "resourceSpecification",
                .start = "start",
                .state = "state",
                .tags = "tags",
                .usage_price = "usagePrice",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_schedule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/channels/{ChannelId}/schedule",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSchedule",
    Request: type = struct {
        channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_tags: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prod/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_account_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/accountConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_configuration };
        }
    },
    Response: type = struct {
        account_configuration: ?AccountConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_configuration = "accountConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/channels/{ChannelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        egress_endpoints: ?[]ChannelEgressEndpoint = null,
        encoder_settings: ?EncoderSettings = null,
        id: ?[]const u8 = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?MaintenanceStatus = null,
        name: ?[]const u8 = null,
        pipeline_details: ?[]PipelineDetail = null,
        pipelines_running_count: ?i64 = null,
        role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?VpcOutputSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .egress_endpoints = "egressEndpoints",
                .encoder_settings = "encoderSettings",
                .id = "id",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .pipeline_details = "pipelineDetails",
                .pipelines_running_count = "pipelinesRunningCount",
                .role_arn = "roleArn",
                .state = "state",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_input: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputs/{InputId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInput",
    Request: type = struct {
        input_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_id = "InputId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_input) } {
            return .{ .service_metadata = service_metadata, .action = describe_input };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        attached_channels: ?[][]const u8 = null,
        destinations: ?[]InputDestination = null,
        id: ?[]const u8 = null,
        input_class: ?[]const u8 = null,
        input_devices: ?[]InputDeviceSettings = null,
        input_partner_ids: ?[][]const u8 = null,
        input_source_type: ?[]const u8 = null,
        media_connect_flows: ?[]MediaConnectFlow = null,
        name: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        security_groups: ?[][]const u8 = null,
        sources: ?[]InputSource = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .attached_channels = "attachedChannels",
                .destinations = "destinations",
                .id = "id",
                .input_class = "inputClass",
                .input_devices = "inputDevices",
                .input_partner_ids = "inputPartnerIds",
                .input_source_type = "inputSourceType",
                .media_connect_flows = "mediaConnectFlows",
                .name = "name",
                .role_arn = "roleArn",
                .security_groups = "securityGroups",
                .sources = "sources",
                .state = "state",
                .tags = "tags",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_input_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputDevices/{InputDeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInputDevice",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_input_device) } {
            return .{ .service_metadata = service_metadata, .action = describe_input_device };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        device_settings_sync_state: ?[]const u8 = null,
        device_update_status: ?[]const u8 = null,
        hd_device_settings: ?InputDeviceHdSettings = null,
        id: ?[]const u8 = null,
        mac_address: ?[]const u8 = null,
        name: ?[]const u8 = null,
        network_settings: ?InputDeviceNetworkSettings = null,
        serial_number: ?[]const u8 = null,
        type: ?[]const u8 = null,
        uhd_device_settings: ?InputDeviceUhdSettings = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        availability_zone: ?[]const u8 = null,
        medialive_input_arns: ?[][]const u8 = null,
        output_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .connection_state = "connectionState",
                .device_settings_sync_state = "deviceSettingsSyncState",
                .device_update_status = "deviceUpdateStatus",
                .hd_device_settings = "hdDeviceSettings",
                .id = "id",
                .mac_address = "macAddress",
                .name = "name",
                .network_settings = "networkSettings",
                .serial_number = "serialNumber",
                .type = "type",
                .uhd_device_settings = "uhdDeviceSettings",
                .tags = "tags",
                .availability_zone = "availabilityZone",
                .medialive_input_arns = "medialiveInputArns",
                .output_type = "outputType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_input_device_thumbnail: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputDevices/{InputDeviceId}/thumbnailData",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInputDeviceThumbnail",
    Request: type = struct {
        input_device_id: []const u8,
        accept: []const u8,
        pub const http_header = .{
            .accept = "accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
                .accept = "Accept",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_input_device_thumbnail) } {
            return .{ .service_metadata = service_metadata, .action = describe_input_device_thumbnail };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        content_length: ?i64 = null,
        e_tag: ?[]const u8 = null,
        last_modified: ?i64 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .content_length = "Content-Length",
            .e_tag = "ETag",
            .last_modified = "Last-Modified",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "body",
                .content_type = "ContentType",
                .content_length = "ContentLength",
                .e_tag = "ETag",
                .last_modified = "LastModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_input_security_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputSecurityGroups/{InputSecurityGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInputSecurityGroup",
    Request: type = struct {
        input_security_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_security_group_id = "InputSecurityGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_input_security_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_input_security_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        inputs: ?[][]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        whitelist_rules: ?[]InputWhitelistRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
                .inputs = "inputs",
                .state = "state",
                .tags = "tags",
                .whitelist_rules = "whitelistRules",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_multiplex: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/multiplexes/{MultiplexId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMultiplex",
    Request: type = struct {
        multiplex_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = describe_multiplex };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        availability_zones: ?[][]const u8 = null,
        destinations: ?[]MultiplexOutputDestination = null,
        id: ?[]const u8 = null,
        multiplex_settings: ?MultiplexSettings = null,
        name: ?[]const u8 = null,
        pipelines_running_count: ?i64 = null,
        program_count: ?i64 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .availability_zones = "availabilityZones",
                .destinations = "destinations",
                .id = "id",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
                .pipelines_running_count = "pipelinesRunningCount",
                .program_count = "programCount",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_multiplex_program: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/multiplexes/{MultiplexId}/programs/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMultiplexProgram",
    Request: type = struct {
        multiplex_id: []const u8,
        program_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
                .program_name = "ProgramName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_multiplex_program) } {
            return .{ .service_metadata = service_metadata, .action = describe_multiplex_program };
        }
    },
    Response: type = struct {
        channel_id: ?[]const u8 = null,
        multiplex_program_settings: ?MultiplexProgramSettings = null,
        packet_identifiers_map: ?MultiplexProgramPacketIdentifiersMap = null,
        pipeline_details: ?[]MultiplexProgramPipelineDetail = null,
        program_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "channelId",
                .multiplex_program_settings = "multiplexProgramSettings",
                .packet_identifiers_map = "packetIdentifiersMap",
                .pipeline_details = "pipelineDetails",
                .program_name = "programName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_offering: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/offerings/{OfferingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOffering",
    Request: type = struct {
        offering_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_id = "OfferingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_offering) } {
            return .{ .service_metadata = service_metadata, .action = describe_offering };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        currency_code: ?[]const u8 = null,
        duration: ?i64 = null,
        duration_units: ?[]const u8 = null,
        fixed_price: ?f64 = null,
        offering_description: ?[]const u8 = null,
        offering_id: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        region: ?[]const u8 = null,
        resource_specification: ?ReservationResourceSpecification = null,
        usage_price: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .currency_code = "currencyCode",
                .duration = "duration",
                .duration_units = "durationUnits",
                .fixed_price = "fixedPrice",
                .offering_description = "offeringDescription",
                .offering_id = "offeringId",
                .offering_type = "offeringType",
                .region = "region",
                .resource_specification = "resourceSpecification",
                .usage_price = "usagePrice",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_reservation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/reservations/{ReservationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservation",
    Request: type = struct {
        reservation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation_id = "ReservationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reservation) } {
            return .{ .service_metadata = service_metadata, .action = describe_reservation };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        count: ?i64 = null,
        currency_code: ?[]const u8 = null,
        duration: ?i64 = null,
        duration_units: ?[]const u8 = null,
        end: ?[]const u8 = null,
        fixed_price: ?f64 = null,
        name: ?[]const u8 = null,
        offering_description: ?[]const u8 = null,
        offering_id: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        region: ?[]const u8 = null,
        renewal_settings: ?RenewalSettings = null,
        reservation_id: ?[]const u8 = null,
        resource_specification: ?ReservationResourceSpecification = null,
        start: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        usage_price: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .count = "count",
                .currency_code = "currencyCode",
                .duration = "duration",
                .duration_units = "durationUnits",
                .end = "end",
                .fixed_price = "fixedPrice",
                .name = "name",
                .offering_description = "offeringDescription",
                .offering_id = "offeringId",
                .offering_type = "offeringType",
                .region = "region",
                .renewal_settings = "renewalSettings",
                .reservation_id = "reservationId",
                .resource_specification = "resourceSpecification",
                .start = "start",
                .state = "state",
                .tags = "tags",
                .usage_price = "usagePrice",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_schedule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/channels/{ChannelId}/schedule",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSchedule",
    Request: type = struct {
        channel_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_schedule };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        schedule_actions: ?[]ScheduleAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .schedule_actions = "scheduleActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_thumbnails: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/channels/{ChannelId}/thumbnails",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThumbnails",
    Request: type = struct {
        channel_id: []const u8,
        pipeline_id: []const u8,
        thumbnail_type: []const u8,

        pub const http_query = .{
            .pipeline_id = "pipelineId",
            .thumbnail_type = "thumbnailType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
                .pipeline_id = "PipelineId",
                .thumbnail_type = "ThumbnailType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_thumbnails) } {
            return .{ .service_metadata = service_metadata, .action = describe_thumbnails };
        }
    },
    Response: type = struct {
        thumbnail_details: ?[]struct {
            pipeline_id: ?[]const u8 = null,
            thumbnails: ?[]struct {
                body: ?[]const u8 = null,
                content_type: ?[]const u8 = null,
                thumbnail_type: ?[]const u8 = null,
                time_stamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .body = "body",
                        .content_type = "contentType",
                        .thumbnail_type = "thumbnailType",
                        .time_stamp = "timeStamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_id = "pipelineId",
                    .thumbnails = "thumbnails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .thumbnail_details = "thumbnailDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            arn: ?[]const u8 = null,
            cdi_input_specification: ?CdiInputSpecification = null,
            channel_class: ?[]const u8 = null,
            destinations: ?[]OutputDestination = null,
            egress_endpoints: ?[]ChannelEgressEndpoint = null,
            id: ?[]const u8 = null,
            input_attachments: ?[]InputAttachment = null,
            input_specification: ?InputSpecification = null,
            log_level: ?[]const u8 = null,
            maintenance: ?MaintenanceStatus = null,
            name: ?[]const u8 = null,
            pipelines_running_count: ?i64 = null,
            role_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            vpc: ?VpcOutputSettingsDescription = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .cdi_input_specification = "cdiInputSpecification",
                    .channel_class = "channelClass",
                    .destinations = "destinations",
                    .egress_endpoints = "egressEndpoints",
                    .id = "id",
                    .input_attachments = "inputAttachments",
                    .input_specification = "inputSpecification",
                    .log_level = "logLevel",
                    .maintenance = "maintenance",
                    .name = "name",
                    .pipelines_running_count = "pipelinesRunningCount",
                    .role_arn = "roleArn",
                    .state = "state",
                    .tags = "tags",
                    .vpc = "vpc",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "channels",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_input_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputDevices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputDevices",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_input_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_input_devices };
        }
    },
    Response: type = struct {
        input_devices: ?[]struct {
            arn: ?[]const u8 = null,
            connection_state: ?[]const u8 = null,
            device_settings_sync_state: ?[]const u8 = null,
            device_update_status: ?[]const u8 = null,
            hd_device_settings: ?InputDeviceHdSettings = null,
            id: ?[]const u8 = null,
            mac_address: ?[]const u8 = null,
            name: ?[]const u8 = null,
            network_settings: ?InputDeviceNetworkSettings = null,
            serial_number: ?[]const u8 = null,
            type: ?[]const u8 = null,
            uhd_device_settings: ?InputDeviceUhdSettings = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            availability_zone: ?[]const u8 = null,
            medialive_input_arns: ?[][]const u8 = null,
            output_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .connection_state = "connectionState",
                    .device_settings_sync_state = "deviceSettingsSyncState",
                    .device_update_status = "deviceUpdateStatus",
                    .hd_device_settings = "hdDeviceSettings",
                    .id = "id",
                    .mac_address = "macAddress",
                    .name = "name",
                    .network_settings = "networkSettings",
                    .serial_number = "serialNumber",
                    .type = "type",
                    .uhd_device_settings = "uhdDeviceSettings",
                    .tags = "tags",
                    .availability_zone = "availabilityZone",
                    .medialive_input_arns = "medialiveInputArns",
                    .output_type = "outputType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_devices = "inputDevices",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_input_device_transfers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputDeviceTransfers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputDeviceTransfers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        transfer_type: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .transfer_type = "transferType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .transfer_type = "TransferType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_input_device_transfers) } {
            return .{ .service_metadata = service_metadata, .action = list_input_device_transfers };
        }
    },
    Response: type = struct {
        input_device_transfers: ?[]struct {
            id: ?[]const u8 = null,
            message: ?[]const u8 = null,
            target_customer_id: ?[]const u8 = null,
            transfer_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .message = "message",
                    .target_customer_id = "targetCustomerId",
                    .transfer_type = "transferType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_transfers = "inputDeviceTransfers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_inputs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputs",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inputs) } {
            return .{ .service_metadata = service_metadata, .action = list_inputs };
        }
    },
    Response: type = struct {
        inputs: ?[]Input = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inputs = "inputs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_input_security_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/inputSecurityGroups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInputSecurityGroups",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_input_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_input_security_groups };
        }
    },
    Response: type = struct {
        input_security_groups: ?[]InputSecurityGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_security_groups = "inputSecurityGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_multiplexes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/multiplexes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMultiplexes",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multiplexes) } {
            return .{ .service_metadata = service_metadata, .action = list_multiplexes };
        }
    },
    Response: type = struct {
        multiplexes: ?[]struct {
            arn: ?[]const u8 = null,
            availability_zones: ?[][]const u8 = null,
            id: ?[]const u8 = null,
            multiplex_settings: ?struct {
                transport_stream_bitrate: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transport_stream_bitrate = "transportStreamBitrate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            name: ?[]const u8 = null,
            pipelines_running_count: ?i64 = null,
            program_count: ?i64 = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .availability_zones = "availabilityZones",
                    .id = "id",
                    .multiplex_settings = "multiplexSettings",
                    .name = "name",
                    .pipelines_running_count = "pipelinesRunningCount",
                    .program_count = "programCount",
                    .state = "state",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplexes = "multiplexes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_multiplex_programs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/multiplexes/{MultiplexId}/programs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMultiplexPrograms",
    Request: type = struct {
        max_results: ?i64 = null,
        multiplex_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .multiplex_id = "MultiplexId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multiplex_programs) } {
            return .{ .service_metadata = service_metadata, .action = list_multiplex_programs };
        }
    },
    Response: type = struct {
        multiplex_programs: ?[]struct {
            channel_id: ?[]const u8 = null,
            program_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_id = "channelId",
                    .program_name = "programName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_programs = "multiplexPrograms",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_offerings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/offerings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOfferings",
    Request: type = struct {
        channel_class: ?[]const u8 = null,
        channel_configuration: ?[]const u8 = null,
        codec: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        max_results: ?i64 = null,
        maximum_bitrate: ?[]const u8 = null,
        maximum_framerate: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        resolution: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        special_feature: ?[]const u8 = null,
        video_quality: ?[]const u8 = null,

        pub const http_query = .{
            .channel_class = "channelClass",
            .channel_configuration = "channelConfiguration",
            .codec = "codec",
            .duration = "duration",
            .max_results = "maxResults",
            .maximum_bitrate = "maximumBitrate",
            .maximum_framerate = "maximumFramerate",
            .next_token = "nextToken",
            .resolution = "resolution",
            .resource_type = "resourceType",
            .special_feature = "specialFeature",
            .video_quality = "videoQuality",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_class = "ChannelClass",
                .channel_configuration = "ChannelConfiguration",
                .codec = "Codec",
                .duration = "Duration",
                .max_results = "MaxResults",
                .maximum_bitrate = "MaximumBitrate",
                .maximum_framerate = "MaximumFramerate",
                .next_token = "NextToken",
                .resolution = "Resolution",
                .resource_type = "ResourceType",
                .special_feature = "SpecialFeature",
                .video_quality = "VideoQuality",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_offerings) } {
            return .{ .service_metadata = service_metadata, .action = list_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        offerings: ?[]struct {
            arn: ?[]const u8 = null,
            currency_code: ?[]const u8 = null,
            duration: ?i64 = null,
            duration_units: ?[]const u8 = null,
            fixed_price: ?f64 = null,
            offering_description: ?[]const u8 = null,
            offering_id: ?[]const u8 = null,
            offering_type: ?[]const u8 = null,
            region: ?[]const u8 = null,
            resource_specification: ?ReservationResourceSpecification = null,
            usage_price: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .currency_code = "currencyCode",
                    .duration = "duration",
                    .duration_units = "durationUnits",
                    .fixed_price = "fixedPrice",
                    .offering_description = "offeringDescription",
                    .offering_id = "offeringId",
                    .offering_type = "offeringType",
                    .region = "region",
                    .resource_specification = "resourceSpecification",
                    .usage_price = "usagePrice",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .offerings = "offerings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_reservations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/reservations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReservations",
    Request: type = struct {
        channel_class: ?[]const u8 = null,
        codec: ?[]const u8 = null,
        max_results: ?i64 = null,
        maximum_bitrate: ?[]const u8 = null,
        maximum_framerate: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        resolution: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        special_feature: ?[]const u8 = null,
        video_quality: ?[]const u8 = null,

        pub const http_query = .{
            .channel_class = "channelClass",
            .codec = "codec",
            .max_results = "maxResults",
            .maximum_bitrate = "maximumBitrate",
            .maximum_framerate = "maximumFramerate",
            .next_token = "nextToken",
            .resolution = "resolution",
            .resource_type = "resourceType",
            .special_feature = "specialFeature",
            .video_quality = "videoQuality",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_class = "ChannelClass",
                .codec = "Codec",
                .max_results = "MaxResults",
                .maximum_bitrate = "MaximumBitrate",
                .maximum_framerate = "MaximumFramerate",
                .next_token = "NextToken",
                .resolution = "Resolution",
                .resource_type = "ResourceType",
                .special_feature = "SpecialFeature",
                .video_quality = "VideoQuality",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_reservations) } {
            return .{ .service_metadata = service_metadata, .action = list_reservations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reservations: ?[]Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .reservations = "reservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prod/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const purchase_offering: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/offerings/{OfferingId}/purchase",
        .success_code = 201,
    };

    action_name: []const u8 = "PurchaseOffering",
    Request: type = struct {
        count: i64,
        name: ?[]const u8 = null,
        offering_id: []const u8,
        renewal_settings: ?RenewalSettings = null,
        request_id: ?[]const u8 = null,
        start: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .count = "count",
                .name = "name",
                .offering_id = "OfferingId",
                .renewal_settings = "renewalSettings",
                .request_id = "requestId",
                .start = "start",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_offering };
        }
    },
    Response: type = struct {
        reservation: ?Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation = "reservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const reboot_input_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/reboot",
        .success_code = 200,
    };

    action_name: []const u8 = "RebootInputDevice",
    Request: type = struct {
        force: ?[]const u8 = null,
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .force = "force",
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_input_device) } {
            return .{ .service_metadata = service_metadata, .action = reboot_input_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const reject_input_device_transfer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/reject",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectInputDeviceTransfer",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_input_device_transfer) } {
            return .{ .service_metadata = service_metadata, .action = reject_input_device_transfer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const restart_channel_pipelines: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/channels/{ChannelId}/restartChannelPipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "RestartChannelPipelines",
    Request: type = struct {
        channel_id: []const u8,
        pipeline_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
                .pipeline_ids = "pipelineIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restart_channel_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = restart_channel_pipelines };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        egress_endpoints: ?[]ChannelEgressEndpoint = null,
        encoder_settings: ?EncoderSettings = null,
        id: ?[]const u8 = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?MaintenanceStatus = null,
        maintenance_status: ?[]const u8 = null,
        name: ?[]const u8 = null,
        pipeline_details: ?[]PipelineDetail = null,
        pipelines_running_count: ?i64 = null,
        role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?VpcOutputSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .egress_endpoints = "egressEndpoints",
                .encoder_settings = "encoderSettings",
                .id = "id",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .maintenance_status = "maintenanceStatus",
                .name = "name",
                .pipeline_details = "pipelineDetails",
                .pipelines_running_count = "pipelinesRunningCount",
                .role_arn = "roleArn",
                .state = "state",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const start_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/channels/{ChannelId}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChannel",
    Request: type = struct {
        channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_channel) } {
            return .{ .service_metadata = service_metadata, .action = start_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        egress_endpoints: ?[]ChannelEgressEndpoint = null,
        encoder_settings: ?EncoderSettings = null,
        id: ?[]const u8 = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?MaintenanceStatus = null,
        name: ?[]const u8 = null,
        pipeline_details: ?[]PipelineDetail = null,
        pipelines_running_count: ?i64 = null,
        role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?VpcOutputSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .egress_endpoints = "egressEndpoints",
                .encoder_settings = "encoderSettings",
                .id = "id",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .pipeline_details = "pipelineDetails",
                .pipelines_running_count = "pipelinesRunningCount",
                .role_arn = "roleArn",
                .state = "state",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const start_input_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartInputDevice",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_input_device) } {
            return .{ .service_metadata = service_metadata, .action = start_input_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const start_input_device_maintenance_window: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/startInputDeviceMaintenanceWindow",
        .success_code = 200,
    };

    action_name: []const u8 = "StartInputDeviceMaintenanceWindow",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_input_device_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = start_input_device_maintenance_window };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const start_multiplex: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/multiplexes/{MultiplexId}/start",
        .success_code = 202,
    };

    action_name: []const u8 = "StartMultiplex",
    Request: type = struct {
        multiplex_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = start_multiplex };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        availability_zones: ?[][]const u8 = null,
        destinations: ?[]MultiplexOutputDestination = null,
        id: ?[]const u8 = null,
        multiplex_settings: ?MultiplexSettings = null,
        name: ?[]const u8 = null,
        pipelines_running_count: ?i64 = null,
        program_count: ?i64 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .availability_zones = "availabilityZones",
                .destinations = "destinations",
                .id = "id",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
                .pipelines_running_count = "pipelinesRunningCount",
                .program_count = "programCount",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const stop_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/channels/{ChannelId}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopChannel",
    Request: type = struct {
        channel_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_channel) } {
            return .{ .service_metadata = service_metadata, .action = stop_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_class: ?[]const u8 = null,
        destinations: ?[]OutputDestination = null,
        egress_endpoints: ?[]ChannelEgressEndpoint = null,
        encoder_settings: ?EncoderSettings = null,
        id: ?[]const u8 = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?MaintenanceStatus = null,
        name: ?[]const u8 = null,
        pipeline_details: ?[]PipelineDetail = null,
        pipelines_running_count: ?i64 = null,
        role_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc: ?VpcOutputSettingsDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cdi_input_specification = "cdiInputSpecification",
                .channel_class = "channelClass",
                .destinations = "destinations",
                .egress_endpoints = "egressEndpoints",
                .encoder_settings = "encoderSettings",
                .id = "id",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .pipeline_details = "pipelineDetails",
                .pipelines_running_count = "pipelinesRunningCount",
                .role_arn = "roleArn",
                .state = "state",
                .tags = "tags",
                .vpc = "vpc",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const stop_input_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopInputDevice",
    Request: type = struct {
        input_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_input_device) } {
            return .{ .service_metadata = service_metadata, .action = stop_input_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const stop_multiplex: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/multiplexes/{MultiplexId}/stop",
        .success_code = 202,
    };

    action_name: []const u8 = "StopMultiplex",
    Request: type = struct {
        multiplex_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = stop_multiplex };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        availability_zones: ?[][]const u8 = null,
        destinations: ?[]MultiplexOutputDestination = null,
        id: ?[]const u8 = null,
        multiplex_settings: ?MultiplexSettings = null,
        name: ?[]const u8 = null,
        pipelines_running_count: ?i64 = null,
        program_count: ?i64 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .availability_zones = "availabilityZones",
                .destinations = "destinations",
                .id = "id",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
                .pipelines_running_count = "pipelinesRunningCount",
                .program_count = "programCount",
                .state = "state",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const transfer_input_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prod/inputDevices/{InputDeviceId}/transfer",
        .success_code = 200,
    };

    action_name: []const u8 = "TransferInputDevice",
    Request: type = struct {
        input_device_id: []const u8,
        target_customer_id: ?[]const u8 = null,
        target_region: ?[]const u8 = null,
        transfer_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_device_id = "InputDeviceId",
                .target_customer_id = "targetCustomerId",
                .target_region = "targetRegion",
                .transfer_message = "transferMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(transfer_input_device) } {
            return .{ .service_metadata = service_metadata, .action = transfer_input_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const update_account_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/accountConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountConfiguration",
    Request: type = struct {
        account_configuration: ?AccountConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_configuration = "accountConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_account_configuration };
        }
    },
    Response: type = struct {
        account_configuration: ?AccountConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_configuration = "accountConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/channels/{ChannelId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        cdi_input_specification: ?CdiInputSpecification = null,
        channel_id: []const u8,
        destinations: ?[]OutputDestination = null,
        encoder_settings: ?EncoderSettings = null,
        input_attachments: ?[]InputAttachment = null,
        input_specification: ?InputSpecification = null,
        log_level: ?[]const u8 = null,
        maintenance: ?struct {
            maintenance_day: ?[]const u8 = null,
            maintenance_scheduled_date: ?[]const u8 = null,
            maintenance_start_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_day = "maintenanceDay",
                    .maintenance_scheduled_date = "maintenanceScheduledDate",
                    .maintenance_start_time = "maintenanceStartTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cdi_input_specification = "cdiInputSpecification",
                .channel_id = "ChannelId",
                .destinations = "destinations",
                .encoder_settings = "encoderSettings",
                .input_attachments = "inputAttachments",
                .input_specification = "inputSpecification",
                .log_level = "logLevel",
                .maintenance = "maintenance",
                .name = "name",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        UnprocessableEntity,
    },
} = .{};
pub const update_channel_class: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/channels/{ChannelId}/channelClass",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelClass",
    Request: type = struct {
        channel_class: []const u8,
        channel_id: []const u8,
        destinations: ?[]OutputDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_class = "channelClass",
                .channel_id = "ChannelId",
                .destinations = "destinations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_class) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_class };
        }
    },
    Response: type = struct {
        channel: ?Channel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const update_input: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/inputs/{InputId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInput",
    Request: type = struct {
        destinations: ?[]InputDestinationRequest = null,
        input_devices: ?[]struct {
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        input_id: []const u8,
        input_security_groups: ?[][]const u8 = null,
        media_connect_flows: ?[]MediaConnectFlowRequest = null,
        name: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        sources: ?[]InputSourceRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destinations = "destinations",
                .input_devices = "inputDevices",
                .input_id = "InputId",
                .input_security_groups = "inputSecurityGroups",
                .media_connect_flows = "mediaConnectFlows",
                .name = "name",
                .role_arn = "roleArn",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_input) } {
            return .{ .service_metadata = service_metadata, .action = update_input };
        }
    },
    Response: type = struct {
        input: ?Input = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_input_device: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/inputDevices/{InputDeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInputDevice",
    Request: type = struct {
        hd_device_settings: ?InputDeviceConfigurableSettings = null,
        input_device_id: []const u8,
        name: ?[]const u8 = null,
        uhd_device_settings: ?InputDeviceConfigurableSettings = null,
        availability_zone: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hd_device_settings = "hdDeviceSettings",
                .input_device_id = "InputDeviceId",
                .name = "name",
                .uhd_device_settings = "uhdDeviceSettings",
                .availability_zone = "availabilityZone",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_input_device) } {
            return .{ .service_metadata = service_metadata, .action = update_input_device };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        connection_state: ?[]const u8 = null,
        device_settings_sync_state: ?[]const u8 = null,
        device_update_status: ?[]const u8 = null,
        hd_device_settings: ?InputDeviceHdSettings = null,
        id: ?[]const u8 = null,
        mac_address: ?[]const u8 = null,
        name: ?[]const u8 = null,
        network_settings: ?InputDeviceNetworkSettings = null,
        serial_number: ?[]const u8 = null,
        type: ?[]const u8 = null,
        uhd_device_settings: ?InputDeviceUhdSettings = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        availability_zone: ?[]const u8 = null,
        medialive_input_arns: ?[][]const u8 = null,
        output_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .connection_state = "connectionState",
                .device_settings_sync_state = "deviceSettingsSyncState",
                .device_update_status = "deviceUpdateStatus",
                .hd_device_settings = "hdDeviceSettings",
                .id = "id",
                .mac_address = "macAddress",
                .name = "name",
                .network_settings = "networkSettings",
                .serial_number = "serialNumber",
                .type = "type",
                .uhd_device_settings = "uhdDeviceSettings",
                .tags = "tags",
                .availability_zone = "availabilityZone",
                .medialive_input_arns = "medialiveInputArns",
                .output_type = "outputType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const update_input_security_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/inputSecurityGroups/{InputSecurityGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInputSecurityGroup",
    Request: type = struct {
        input_security_group_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        whitelist_rules: ?[]InputWhitelistRuleCidr = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_security_group_id = "InputSecurityGroupId",
                .tags = "tags",
                .whitelist_rules = "whitelistRules",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_input_security_group) } {
            return .{ .service_metadata = service_metadata, .action = update_input_security_group };
        }
    },
    Response: type = struct {
        security_group: ?InputSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_group = "securityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_multiplex: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/multiplexes/{MultiplexId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMultiplex",
    Request: type = struct {
        multiplex_id: []const u8,
        multiplex_settings: ?MultiplexSettings = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
                .multiplex_settings = "multiplexSettings",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_multiplex) } {
            return .{ .service_metadata = service_metadata, .action = update_multiplex };
        }
    },
    Response: type = struct {
        multiplex: ?Multiplex = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex = "multiplex",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        UnprocessableEntity,
    },
} = .{};
pub const update_multiplex_program: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/multiplexes/{MultiplexId}/programs/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMultiplexProgram",
    Request: type = struct {
        multiplex_id: []const u8,
        multiplex_program_settings: ?MultiplexProgramSettings = null,
        program_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_id = "MultiplexId",
                .multiplex_program_settings = "multiplexProgramSettings",
                .program_name = "ProgramName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_multiplex_program) } {
            return .{ .service_metadata = service_metadata, .action = update_multiplex_program };
        }
    },
    Response: type = struct {
        multiplex_program: ?MultiplexProgram = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .multiplex_program = "multiplexProgram",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        UnprocessableEntity,
    },
} = .{};
pub const update_reservation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prod/reservations/{ReservationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReservation",
    Request: type = struct {
        name: ?[]const u8 = null,
        renewal_settings: ?RenewalSettings = null,
        reservation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .renewal_settings = "renewalSettings",
                .reservation_id = "ReservationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_reservation) } {
            return .{ .service_metadata = service_metadata, .action = update_reservation };
        }
    },
    Response: type = struct {
        reservation: ?Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation = "reservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        Forbidden,
        GatewayTimeout,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const Reservation = struct {
    arn: ?[]const u8 = null,
    count: ?i64 = null,
    currency_code: ?[]const u8 = null,
    duration: ?i64 = null,
    duration_units: ?[]const u8 = null,
    end: ?[]const u8 = null,
    fixed_price: ?f64 = null,
    name: ?[]const u8 = null,
    offering_description: ?[]const u8 = null,
    offering_id: ?[]const u8 = null,
    offering_type: ?[]const u8 = null,
    region: ?[]const u8 = null,
    renewal_settings: ?RenewalSettings = null,
    reservation_id: ?[]const u8 = null,
    resource_specification: ?ReservationResourceSpecification = null,
    start: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    usage_price: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .count = "count",
            .currency_code = "currencyCode",
            .duration = "duration",
            .duration_units = "durationUnits",
            .end = "end",
            .fixed_price = "fixedPrice",
            .name = "name",
            .offering_description = "offeringDescription",
            .offering_id = "offeringId",
            .offering_type = "offeringType",
            .region = "region",
            .renewal_settings = "renewalSettings",
            .reservation_id = "reservationId",
            .resource_specification = "resourceSpecification",
            .start = "start",
            .state = "state",
            .tags = "tags",
            .usage_price = "usagePrice",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ReservationResourceSpecification = struct {
    channel_class: ?[]const u8 = null,
    codec: ?[]const u8 = null,
    maximum_bitrate: ?[]const u8 = null,
    maximum_framerate: ?[]const u8 = null,
    resolution: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    special_feature: ?[]const u8 = null,
    video_quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_class = "channelClass",
            .codec = "codec",
            .maximum_bitrate = "maximumBitrate",
            .maximum_framerate = "maximumFramerate",
            .resolution = "resolution",
            .resource_type = "resourceType",
            .special_feature = "specialFeature",
            .video_quality = "videoQuality",
        };
        return @field(mappings, field_name);
    }
};

pub const RenewalSettings = struct {
    automatic_renewal: ?[]const u8 = null,
    renewal_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatic_renewal = "automaticRenewal",
            .renewal_count = "renewalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgram = struct {
    channel_id: ?[]const u8 = null,
    multiplex_program_settings: ?MultiplexProgramSettings = null,
    packet_identifiers_map: ?MultiplexProgramPacketIdentifiersMap = null,
    pipeline_details: ?[]MultiplexProgramPipelineDetail = null,
    program_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "channelId",
            .multiplex_program_settings = "multiplexProgramSettings",
            .packet_identifiers_map = "packetIdentifiersMap",
            .pipeline_details = "pipelineDetails",
            .program_name = "programName",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgramPipelineDetail = struct {
    active_channel_pipeline: ?[]const u8 = null,
    pipeline_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_channel_pipeline = "activeChannelPipeline",
            .pipeline_id = "pipelineId",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgramPacketIdentifiersMap = struct {
    audio_pids: ?[]i64 = null,
    dvb_sub_pids: ?[]i64 = null,
    dvb_teletext_pid: ?i64 = null,
    etv_platform_pid: ?i64 = null,
    etv_signal_pid: ?i64 = null,
    klv_data_pids: ?[]i64 = null,
    pcr_pid: ?i64 = null,
    pmt_pid: ?i64 = null,
    private_metadata_pid: ?i64 = null,
    scte27_pids: ?[]i64 = null,
    scte35_pid: ?i64 = null,
    timed_metadata_pid: ?i64 = null,
    video_pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_pids = "audioPids",
            .dvb_sub_pids = "dvbSubPids",
            .dvb_teletext_pid = "dvbTeletextPid",
            .etv_platform_pid = "etvPlatformPid",
            .etv_signal_pid = "etvSignalPid",
            .klv_data_pids = "klvDataPids",
            .pcr_pid = "pcrPid",
            .pmt_pid = "pmtPid",
            .private_metadata_pid = "privateMetadataPid",
            .scte27_pids = "scte27Pids",
            .scte35_pid = "scte35Pid",
            .timed_metadata_pid = "timedMetadataPid",
            .video_pid = "videoPid",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgramSettings = struct {
    preferred_channel_pipeline: ?[]const u8 = null,
    program_number: i64,
    service_descriptor: ?MultiplexProgramServiceDescriptor = null,
    video_settings: ?MultiplexVideoSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preferred_channel_pipeline = "preferredChannelPipeline",
            .program_number = "programNumber",
            .service_descriptor = "serviceDescriptor",
            .video_settings = "videoSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexVideoSettings = struct {
    constant_bitrate: ?i64 = null,
    statmux_settings: ?MultiplexStatmuxVideoSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_bitrate = "constantBitrate",
            .statmux_settings = "statmuxSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexStatmuxVideoSettings = struct {
    maximum_bitrate: ?i64 = null,
    minimum_bitrate: ?i64 = null,
    priority: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_bitrate = "maximumBitrate",
            .minimum_bitrate = "minimumBitrate",
            .priority = "priority",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgramServiceDescriptor = struct {
    provider_name: []const u8,
    service_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provider_name = "providerName",
            .service_name = "serviceName",
        };
        return @field(mappings, field_name);
    }
};

pub const Multiplex = struct {
    arn: ?[]const u8 = null,
    availability_zones: ?[][]const u8 = null,
    destinations: ?[]MultiplexOutputDestination = null,
    id: ?[]const u8 = null,
    multiplex_settings: ?MultiplexSettings = null,
    name: ?[]const u8 = null,
    pipelines_running_count: ?i64 = null,
    program_count: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .availability_zones = "availabilityZones",
            .destinations = "destinations",
            .id = "id",
            .multiplex_settings = "multiplexSettings",
            .name = "name",
            .pipelines_running_count = "pipelinesRunningCount",
            .program_count = "programCount",
            .state = "state",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const MultiplexSettings = struct {
    maximum_video_buffer_delay_milliseconds: ?i64 = null,
    transport_stream_bitrate: i64,
    transport_stream_id: i64,
    transport_stream_reserved_bitrate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_video_buffer_delay_milliseconds = "maximumVideoBufferDelayMilliseconds",
            .transport_stream_bitrate = "transportStreamBitrate",
            .transport_stream_id = "transportStreamId",
            .transport_stream_reserved_bitrate = "transportStreamReservedBitrate",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexOutputDestination = struct {
    media_connect_settings: ?MultiplexMediaConnectOutputDestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_connect_settings = "mediaConnectSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexMediaConnectOutputDestinationSettings = struct {
    entitlement_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entitlement_arn = "entitlementArn",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSecurityGroup = struct {
    arn: ?[]const u8 = null,
    id: ?[]const u8 = null,
    inputs: ?[][]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    whitelist_rules: ?[]InputWhitelistRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .id = "id",
            .inputs = "inputs",
            .state = "state",
            .tags = "tags",
            .whitelist_rules = "whitelistRules",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InputWhitelistRule = struct {
    cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const InputWhitelistRuleCidr = struct {
    cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceUhdSettings = struct {
    active_input: ?[]const u8 = null,
    configured_input: ?[]const u8 = null,
    device_state: ?[]const u8 = null,
    framerate: ?f64 = null,
    height: ?i64 = null,
    max_bitrate: ?i64 = null,
    scan_type: ?[]const u8 = null,
    width: ?i64 = null,
    latency_ms: ?i64 = null,
    codec: ?[]const u8 = null,
    mediaconnect_settings: ?InputDeviceMediaConnectSettings = null,
    audio_channel_pairs: ?[]InputDeviceUhdAudioChannelPairConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_input = "activeInput",
            .configured_input = "configuredInput",
            .device_state = "deviceState",
            .framerate = "framerate",
            .height = "height",
            .max_bitrate = "maxBitrate",
            .scan_type = "scanType",
            .width = "width",
            .latency_ms = "latencyMs",
            .codec = "codec",
            .mediaconnect_settings = "mediaconnectSettings",
            .audio_channel_pairs = "audioChannelPairs",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceUhdAudioChannelPairConfig = struct {
    id: ?i64 = null,
    profile: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .profile = "profile",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceMediaConnectSettings = struct {
    flow_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,
    source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
            .role_arn = "roleArn",
            .secret_arn = "secretArn",
            .source_name = "sourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceNetworkSettings = struct {
    dns_addresses: ?[][]const u8 = null,
    gateway: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    ip_scheme: ?[]const u8 = null,
    subnet_mask: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_addresses = "dnsAddresses",
            .gateway = "gateway",
            .ip_address = "ipAddress",
            .ip_scheme = "ipScheme",
            .subnet_mask = "subnetMask",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceHdSettings = struct {
    active_input: ?[]const u8 = null,
    configured_input: ?[]const u8 = null,
    device_state: ?[]const u8 = null,
    framerate: ?f64 = null,
    height: ?i64 = null,
    max_bitrate: ?i64 = null,
    scan_type: ?[]const u8 = null,
    width: ?i64 = null,
    latency_ms: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_input = "activeInput",
            .configured_input = "configuredInput",
            .device_state = "deviceState",
            .framerate = "framerate",
            .height = "height",
            .max_bitrate = "maxBitrate",
            .scan_type = "scanType",
            .width = "width",
            .latency_ms = "latencyMs",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceConfigurableSettings = struct {
    configured_input: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    latency_ms: ?i64 = null,
    codec: ?[]const u8 = null,
    mediaconnect_settings: ?InputDeviceMediaConnectConfigurableSettings = null,
    audio_channel_pairs: ?[]InputDeviceConfigurableAudioChannelPairConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configured_input = "configuredInput",
            .max_bitrate = "maxBitrate",
            .latency_ms = "latencyMs",
            .codec = "codec",
            .mediaconnect_settings = "mediaconnectSettings",
            .audio_channel_pairs = "audioChannelPairs",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceConfigurableAudioChannelPairConfig = struct {
    id: ?i64 = null,
    profile: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .profile = "profile",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceMediaConnectConfigurableSettings = struct {
    flow_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,
    source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
            .role_arn = "roleArn",
            .secret_arn = "secretArn",
            .source_name = "sourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const Input = struct {
    arn: ?[]const u8 = null,
    attached_channels: ?[][]const u8 = null,
    destinations: ?[]InputDestination = null,
    id: ?[]const u8 = null,
    input_class: ?[]const u8 = null,
    input_devices: ?[]InputDeviceSettings = null,
    input_partner_ids: ?[][]const u8 = null,
    input_source_type: ?[]const u8 = null,
    media_connect_flows: ?[]MediaConnectFlow = null,
    name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    sources: ?[]InputSource = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .attached_channels = "attachedChannels",
            .destinations = "destinations",
            .id = "id",
            .input_class = "inputClass",
            .input_devices = "inputDevices",
            .input_partner_ids = "inputPartnerIds",
            .input_source_type = "inputSourceType",
            .media_connect_flows = "mediaConnectFlows",
            .name = "name",
            .role_arn = "roleArn",
            .security_groups = "securityGroups",
            .sources = "sources",
            .state = "state",
            .tags = "tags",
            .type = "type",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InputSource = struct {
    password_param: ?[]const u8 = null,
    url: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .password_param = "passwordParam",
            .url = "url",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaConnectFlow = struct {
    flow_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDeviceSettings = struct {
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDestination = struct {
    ip: ?[]const u8 = null,
    port: ?[]const u8 = null,
    url: ?[]const u8 = null,
    vpc: ?InputDestinationVpc = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip = "ip",
            .port = "port",
            .url = "url",
            .vpc = "vpc",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDestinationVpc = struct {
    availability_zone: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .network_interface_id = "networkInterfaceId",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSourceRequest = struct {
    password_param: ?[]const u8 = null,
    url: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .password_param = "passwordParam",
            .url = "url",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaConnectFlowRequest = struct {
    flow_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDestinationRequest = struct {
    stream_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_name = "streamName",
        };
        return @field(mappings, field_name);
    }
};

pub const Channel = struct {
    arn: ?[]const u8 = null,
    cdi_input_specification: ?CdiInputSpecification = null,
    channel_class: ?[]const u8 = null,
    destinations: ?[]OutputDestination = null,
    egress_endpoints: ?[]ChannelEgressEndpoint = null,
    encoder_settings: ?EncoderSettings = null,
    id: ?[]const u8 = null,
    input_attachments: ?[]InputAttachment = null,
    input_specification: ?InputSpecification = null,
    log_level: ?[]const u8 = null,
    maintenance: ?MaintenanceStatus = null,
    name: ?[]const u8 = null,
    pipeline_details: ?[]PipelineDetail = null,
    pipelines_running_count: ?i64 = null,
    role_arn: ?[]const u8 = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    vpc: ?VpcOutputSettingsDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .cdi_input_specification = "cdiInputSpecification",
            .channel_class = "channelClass",
            .destinations = "destinations",
            .egress_endpoints = "egressEndpoints",
            .encoder_settings = "encoderSettings",
            .id = "id",
            .input_attachments = "inputAttachments",
            .input_specification = "inputSpecification",
            .log_level = "logLevel",
            .maintenance = "maintenance",
            .name = "name",
            .pipeline_details = "pipelineDetails",
            .pipelines_running_count = "pipelinesRunningCount",
            .role_arn = "roleArn",
            .state = "state",
            .tags = "tags",
            .vpc = "vpc",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const VpcOutputSettingsDescription = struct {
    availability_zones: ?[][]const u8 = null,
    network_interface_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "availabilityZones",
            .network_interface_ids = "networkInterfaceIds",
            .security_group_ids = "securityGroupIds",
            .subnet_ids = "subnetIds",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineDetail = struct {
    active_input_attachment_name: ?[]const u8 = null,
    active_input_switch_action_name: ?[]const u8 = null,
    active_motion_graphics_action_name: ?[]const u8 = null,
    active_motion_graphics_uri: ?[]const u8 = null,
    pipeline_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_input_attachment_name = "activeInputAttachmentName",
            .active_input_switch_action_name = "activeInputSwitchActionName",
            .active_motion_graphics_action_name = "activeMotionGraphicsActionName",
            .active_motion_graphics_uri = "activeMotionGraphicsUri",
            .pipeline_id = "pipelineId",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceStatus = struct {
    maintenance_day: ?[]const u8 = null,
    maintenance_deadline: ?[]const u8 = null,
    maintenance_scheduled_date: ?[]const u8 = null,
    maintenance_start_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maintenance_day = "maintenanceDay",
            .maintenance_deadline = "maintenanceDeadline",
            .maintenance_scheduled_date = "maintenanceScheduledDate",
            .maintenance_start_time = "maintenanceStartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSpecification = struct {
    codec: ?[]const u8 = null,
    maximum_bitrate: ?[]const u8 = null,
    resolution: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec = "codec",
            .maximum_bitrate = "maximumBitrate",
            .resolution = "resolution",
        };
        return @field(mappings, field_name);
    }
};

pub const InputAttachment = struct {
    automatic_input_failover_settings: ?AutomaticInputFailoverSettings = null,
    input_attachment_name: ?[]const u8 = null,
    input_id: ?[]const u8 = null,
    input_settings: ?InputSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatic_input_failover_settings = "automaticInputFailoverSettings",
            .input_attachment_name = "inputAttachmentName",
            .input_id = "inputId",
            .input_settings = "inputSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSettings = struct {
    audio_selectors: ?[]AudioSelector = null,
    caption_selectors: ?[]CaptionSelector = null,
    deblock_filter: ?[]const u8 = null,
    denoise_filter: ?[]const u8 = null,
    filter_strength: ?i64 = null,
    input_filter: ?[]const u8 = null,
    network_input_settings: ?NetworkInputSettings = null,
    scte35_pid: ?i64 = null,
    smpte2038_data_preference: ?[]const u8 = null,
    source_end_behavior: ?[]const u8 = null,
    video_selector: ?VideoSelector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_selectors = "audioSelectors",
            .caption_selectors = "captionSelectors",
            .deblock_filter = "deblockFilter",
            .denoise_filter = "denoiseFilter",
            .filter_strength = "filterStrength",
            .input_filter = "inputFilter",
            .network_input_settings = "networkInputSettings",
            .scte35_pid = "scte35Pid",
            .smpte2038_data_preference = "smpte2038DataPreference",
            .source_end_behavior = "sourceEndBehavior",
            .video_selector = "videoSelector",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoSelector = struct {
    color_space: ?[]const u8 = null,
    color_space_settings: ?VideoSelectorColorSpaceSettings = null,
    color_space_usage: ?[]const u8 = null,
    selector_settings: ?VideoSelectorSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color_space = "colorSpace",
            .color_space_settings = "colorSpaceSettings",
            .color_space_usage = "colorSpaceUsage",
            .selector_settings = "selectorSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoSelectorSettings = struct {
    video_selector_pid: ?VideoSelectorPid = null,
    video_selector_program_id: ?VideoSelectorProgramId = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .video_selector_pid = "videoSelectorPid",
            .video_selector_program_id = "videoSelectorProgramId",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoSelectorProgramId = struct {
    program_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .program_id = "programId",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoSelectorPid = struct {
    pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pid = "pid",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoSelectorColorSpaceSettings = struct {
    hdr10_settings: ?Hdr10Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hdr10_settings = "hdr10Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const Hdr10Settings = struct {
    max_cll: ?i64 = null,
    max_fall: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_cll = "maxCll",
            .max_fall = "maxFall",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInputSettings = struct {
    hls_input_settings: ?HlsInputSettings = null,
    server_validation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hls_input_settings = "hlsInputSettings",
            .server_validation = "serverValidation",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsInputSettings = struct {
    bandwidth: ?i64 = null,
    buffer_segments: ?i64 = null,
    retries: ?i64 = null,
    retry_interval: ?i64 = null,
    scte35_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bandwidth = "bandwidth",
            .buffer_segments = "bufferSegments",
            .retries = "retries",
            .retry_interval = "retryInterval",
            .scte35_source = "scte35Source",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSelector = struct {
    language_code: ?[]const u8 = null,
    name: []const u8,
    selector_settings: ?CaptionSelectorSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_code = "languageCode",
            .name = "name",
            .selector_settings = "selectorSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSelectorSettings = struct {
    ancillary_source_settings: ?AncillarySourceSettings = null,
    arib_source_settings: ?AribSourceSettings = null,
    dvb_sub_source_settings: ?DvbSubSourceSettings = null,
    embedded_source_settings: ?EmbeddedSourceSettings = null,
    scte20_source_settings: ?Scte20SourceSettings = null,
    scte27_source_settings: ?Scte27SourceSettings = null,
    teletext_source_settings: ?TeletextSourceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ancillary_source_settings = "ancillarySourceSettings",
            .arib_source_settings = "aribSourceSettings",
            .dvb_sub_source_settings = "dvbSubSourceSettings",
            .embedded_source_settings = "embeddedSourceSettings",
            .scte20_source_settings = "scte20SourceSettings",
            .scte27_source_settings = "scte27SourceSettings",
            .teletext_source_settings = "teletextSourceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TeletextSourceSettings = struct {
    output_rectangle: ?CaptionRectangle = null,
    page_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_rectangle = "outputRectangle",
            .page_number = "pageNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionRectangle = struct {
    height: f64,
    left_offset: f64,
    top_offset: f64,
    width: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .left_offset = "leftOffset",
            .top_offset = "topOffset",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte27SourceSettings = struct {
    ocr_language: ?[]const u8 = null,
    pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ocr_language = "ocrLanguage",
            .pid = "pid",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte20SourceSettings = struct {
    convert608_to708: ?[]const u8 = null,
    source608_channel_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .convert608_to708 = "convert608To708",
            .source608_channel_number = "source608ChannelNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const EmbeddedSourceSettings = struct {
    convert608_to708: ?[]const u8 = null,
    scte20_detection: ?[]const u8 = null,
    source608_channel_number: ?i64 = null,
    source608_track_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .convert608_to708 = "convert608To708",
            .scte20_detection = "scte20Detection",
            .source608_channel_number = "source608ChannelNumber",
            .source608_track_number = "source608TrackNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSubSourceSettings = struct {
    ocr_language: ?[]const u8 = null,
    pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ocr_language = "ocrLanguage",
            .pid = "pid",
        };
        return @field(mappings, field_name);
    }
};

pub const AribSourceSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const AncillarySourceSettings = struct {
    source_ancillary_channel_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_ancillary_channel_number = "sourceAncillaryChannelNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSelector = struct {
    name: []const u8,
    selector_settings: ?AudioSelectorSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .selector_settings = "selectorSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSelectorSettings = struct {
    audio_hls_rendition_selection: ?AudioHlsRenditionSelection = null,
    audio_language_selection: ?AudioLanguageSelection = null,
    audio_pid_selection: ?AudioPidSelection = null,
    audio_track_selection: ?AudioTrackSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_hls_rendition_selection = "audioHlsRenditionSelection",
            .audio_language_selection = "audioLanguageSelection",
            .audio_pid_selection = "audioPidSelection",
            .audio_track_selection = "audioTrackSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioTrackSelection = struct {
    tracks: []AudioTrack,
    dolby_e_decode: ?AudioDolbyEDecode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tracks = "tracks",
            .dolby_e_decode = "dolbyEDecode",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioDolbyEDecode = struct {
    program_selection: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .program_selection = "programSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioTrack = struct {
    track: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .track = "track",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioPidSelection = struct {
    pid: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pid = "pid",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioLanguageSelection = struct {
    language_code: []const u8,
    language_selection_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_code = "languageCode",
            .language_selection_policy = "languageSelectionPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioHlsRenditionSelection = struct {
    group_id: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "groupId",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomaticInputFailoverSettings = struct {
    error_clear_time_msec: ?i64 = null,
    failover_conditions: ?[]FailoverCondition = null,
    input_preference: ?[]const u8 = null,
    secondary_input_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_clear_time_msec = "errorClearTimeMsec",
            .failover_conditions = "failoverConditions",
            .input_preference = "inputPreference",
            .secondary_input_id = "secondaryInputId",
        };
        return @field(mappings, field_name);
    }
};

pub const FailoverCondition = struct {
    failover_condition_settings: ?FailoverConditionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_condition_settings = "failoverConditionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const FailoverConditionSettings = struct {
    audio_silence_settings: ?AudioSilenceFailoverSettings = null,
    input_loss_settings: ?InputLossFailoverSettings = null,
    video_black_settings: ?VideoBlackFailoverSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_silence_settings = "audioSilenceSettings",
            .input_loss_settings = "inputLossSettings",
            .video_black_settings = "videoBlackSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoBlackFailoverSettings = struct {
    black_detect_threshold: ?f64 = null,
    video_black_threshold_msec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .black_detect_threshold = "blackDetectThreshold",
            .video_black_threshold_msec = "videoBlackThresholdMsec",
        };
        return @field(mappings, field_name);
    }
};

pub const InputLossFailoverSettings = struct {
    input_loss_threshold_msec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_loss_threshold_msec = "inputLossThresholdMsec",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSilenceFailoverSettings = struct {
    audio_selector_name: []const u8,
    audio_silence_threshold_msec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_selector_name = "audioSelectorName",
            .audio_silence_threshold_msec = "audioSilenceThresholdMsec",
        };
        return @field(mappings, field_name);
    }
};

pub const EncoderSettings = struct {
    audio_descriptions: []AudioDescription,
    avail_blanking: ?AvailBlanking = null,
    avail_configuration: ?AvailConfiguration = null,
    blackout_slate: ?BlackoutSlate = null,
    caption_descriptions: ?[]CaptionDescription = null,
    feature_activations: ?FeatureActivations = null,
    global_configuration: ?GlobalConfiguration = null,
    motion_graphics_configuration: ?MotionGraphicsConfiguration = null,
    nielsen_configuration: ?NielsenConfiguration = null,
    output_groups: []OutputGroup,
    timecode_config: TimecodeConfig,
    video_descriptions: []VideoDescription,
    thumbnail_configuration: ?ThumbnailConfiguration = null,
    color_correction_settings: ?ColorCorrectionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_descriptions = "audioDescriptions",
            .avail_blanking = "availBlanking",
            .avail_configuration = "availConfiguration",
            .blackout_slate = "blackoutSlate",
            .caption_descriptions = "captionDescriptions",
            .feature_activations = "featureActivations",
            .global_configuration = "globalConfiguration",
            .motion_graphics_configuration = "motionGraphicsConfiguration",
            .nielsen_configuration = "nielsenConfiguration",
            .output_groups = "outputGroups",
            .timecode_config = "timecodeConfig",
            .video_descriptions = "videoDescriptions",
            .thumbnail_configuration = "thumbnailConfiguration",
            .color_correction_settings = "colorCorrectionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorCorrectionSettings = struct {
    global_color_corrections: []ColorCorrection,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_color_corrections = "globalColorCorrections",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorCorrection = struct {
    input_color_space: []const u8,
    output_color_space: []const u8,
    uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_color_space = "inputColorSpace",
            .output_color_space = "outputColorSpace",
            .uri = "uri",
        };
        return @field(mappings, field_name);
    }
};

pub const ThumbnailConfiguration = struct {
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoDescription = struct {
    codec_settings: ?VideoCodecSettings = null,
    height: ?i64 = null,
    name: []const u8,
    respond_to_afd: ?[]const u8 = null,
    scaling_behavior: ?[]const u8 = null,
    sharpness: ?i64 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec_settings = "codecSettings",
            .height = "height",
            .name = "name",
            .respond_to_afd = "respondToAfd",
            .scaling_behavior = "scalingBehavior",
            .sharpness = "sharpness",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoCodecSettings = struct {
    frame_capture_settings: ?FrameCaptureSettings = null,
    h264_settings: ?H264Settings = null,
    h265_settings: ?H265Settings = null,
    mpeg2_settings: ?Mpeg2Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frame_capture_settings = "frameCaptureSettings",
            .h264_settings = "h264Settings",
            .h265_settings = "h265Settings",
            .mpeg2_settings = "mpeg2Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const Mpeg2Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    afd_signaling: ?[]const u8 = null,
    color_metadata: ?[]const u8 = null,
    color_space: ?[]const u8 = null,
    display_aspect_ratio: ?[]const u8 = null,
    filter_settings: ?Mpeg2FilterSettings = null,
    fixed_afd: ?[]const u8 = null,
    framerate_denominator: i64,
    framerate_numerator: i64,
    gop_closed_cadence: ?i64 = null,
    gop_num_b_frames: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    scan_type: ?[]const u8 = null,
    subgop_length: ?[]const u8 = null,
    timecode_insertion: ?[]const u8 = null,
    timecode_burnin_settings: ?TimecodeBurninSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .afd_signaling = "afdSignaling",
            .color_metadata = "colorMetadata",
            .color_space = "colorSpace",
            .display_aspect_ratio = "displayAspectRatio",
            .filter_settings = "filterSettings",
            .fixed_afd = "fixedAfd",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_num_b_frames = "gopNumBFrames",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .scan_type = "scanType",
            .subgop_length = "subgopLength",
            .timecode_insertion = "timecodeInsertion",
            .timecode_burnin_settings = "timecodeBurninSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TimecodeBurninSettings = struct {
    font_size: []const u8,
    position: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_size = "fontSize",
            .position = "position",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Mpeg2FilterSettings = struct {
    temporal_filter_settings: ?TemporalFilterSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .temporal_filter_settings = "temporalFilterSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TemporalFilterSettings = struct {
    post_filter_sharpening: ?[]const u8 = null,
    strength: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .post_filter_sharpening = "postFilterSharpening",
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const H265Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    afd_signaling: ?[]const u8 = null,
    alternative_transfer_function: ?[]const u8 = null,
    bitrate: ?i64 = null,
    buf_size: ?i64 = null,
    color_metadata: ?[]const u8 = null,
    color_space_settings: ?H265ColorSpaceSettings = null,
    filter_settings: ?H265FilterSettings = null,
    fixed_afd: ?[]const u8 = null,
    flicker_aq: ?[]const u8 = null,
    framerate_denominator: i64,
    framerate_numerator: i64,
    gop_closed_cadence: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    level: ?[]const u8 = null,
    look_ahead_rate_control: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    min_i_interval: ?i64 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    profile: ?[]const u8 = null,
    qvbr_quality_level: ?i64 = null,
    rate_control_mode: ?[]const u8 = null,
    scan_type: ?[]const u8 = null,
    scene_change_detect: ?[]const u8 = null,
    slices: ?i64 = null,
    tier: ?[]const u8 = null,
    timecode_insertion: ?[]const u8 = null,
    timecode_burnin_settings: ?TimecodeBurninSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .afd_signaling = "afdSignaling",
            .alternative_transfer_function = "alternativeTransferFunction",
            .bitrate = "bitrate",
            .buf_size = "bufSize",
            .color_metadata = "colorMetadata",
            .color_space_settings = "colorSpaceSettings",
            .filter_settings = "filterSettings",
            .fixed_afd = "fixedAfd",
            .flicker_aq = "flickerAq",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .level = "level",
            .look_ahead_rate_control = "lookAheadRateControl",
            .max_bitrate = "maxBitrate",
            .min_i_interval = "minIInterval",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .profile = "profile",
            .qvbr_quality_level = "qvbrQualityLevel",
            .rate_control_mode = "rateControlMode",
            .scan_type = "scanType",
            .scene_change_detect = "sceneChangeDetect",
            .slices = "slices",
            .tier = "tier",
            .timecode_insertion = "timecodeInsertion",
            .timecode_burnin_settings = "timecodeBurninSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const H265FilterSettings = struct {
    temporal_filter_settings: ?TemporalFilterSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .temporal_filter_settings = "temporalFilterSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const H265ColorSpaceSettings = struct {
    color_space_passthrough_settings: ?ColorSpacePassthroughSettings = null,
    dolby_vision81_settings: ?DolbyVision81Settings = null,
    hdr10_settings: ?Hdr10Settings = null,
    rec601_settings: ?Rec601Settings = null,
    rec709_settings: ?Rec709Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color_space_passthrough_settings = "colorSpacePassthroughSettings",
            .dolby_vision81_settings = "dolbyVision81Settings",
            .hdr10_settings = "hdr10Settings",
            .rec601_settings = "rec601Settings",
            .rec709_settings = "rec709Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const Rec709Settings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Rec601Settings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DolbyVision81Settings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ColorSpacePassthroughSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const H264Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    afd_signaling: ?[]const u8 = null,
    bitrate: ?i64 = null,
    buf_fill_pct: ?i64 = null,
    buf_size: ?i64 = null,
    color_metadata: ?[]const u8 = null,
    color_space_settings: ?H264ColorSpaceSettings = null,
    entropy_encoding: ?[]const u8 = null,
    filter_settings: ?H264FilterSettings = null,
    fixed_afd: ?[]const u8 = null,
    flicker_aq: ?[]const u8 = null,
    force_field_pictures: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_b_reference: ?[]const u8 = null,
    gop_closed_cadence: ?i64 = null,
    gop_num_b_frames: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    level: ?[]const u8 = null,
    look_ahead_rate_control: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    min_i_interval: ?i64 = null,
    num_ref_frames: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    profile: ?[]const u8 = null,
    quality_level: ?[]const u8 = null,
    qvbr_quality_level: ?i64 = null,
    rate_control_mode: ?[]const u8 = null,
    scan_type: ?[]const u8 = null,
    scene_change_detect: ?[]const u8 = null,
    slices: ?i64 = null,
    softness: ?i64 = null,
    spatial_aq: ?[]const u8 = null,
    subgop_length: ?[]const u8 = null,
    syntax: ?[]const u8 = null,
    temporal_aq: ?[]const u8 = null,
    timecode_insertion: ?[]const u8 = null,
    timecode_burnin_settings: ?TimecodeBurninSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .afd_signaling = "afdSignaling",
            .bitrate = "bitrate",
            .buf_fill_pct = "bufFillPct",
            .buf_size = "bufSize",
            .color_metadata = "colorMetadata",
            .color_space_settings = "colorSpaceSettings",
            .entropy_encoding = "entropyEncoding",
            .filter_settings = "filterSettings",
            .fixed_afd = "fixedAfd",
            .flicker_aq = "flickerAq",
            .force_field_pictures = "forceFieldPictures",
            .framerate_control = "framerateControl",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_b_reference = "gopBReference",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_num_b_frames = "gopNumBFrames",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .level = "level",
            .look_ahead_rate_control = "lookAheadRateControl",
            .max_bitrate = "maxBitrate",
            .min_i_interval = "minIInterval",
            .num_ref_frames = "numRefFrames",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .profile = "profile",
            .quality_level = "qualityLevel",
            .qvbr_quality_level = "qvbrQualityLevel",
            .rate_control_mode = "rateControlMode",
            .scan_type = "scanType",
            .scene_change_detect = "sceneChangeDetect",
            .slices = "slices",
            .softness = "softness",
            .spatial_aq = "spatialAq",
            .subgop_length = "subgopLength",
            .syntax = "syntax",
            .temporal_aq = "temporalAq",
            .timecode_insertion = "timecodeInsertion",
            .timecode_burnin_settings = "timecodeBurninSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const H264FilterSettings = struct {
    temporal_filter_settings: ?TemporalFilterSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .temporal_filter_settings = "temporalFilterSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const H264ColorSpaceSettings = struct {
    color_space_passthrough_settings: ?ColorSpacePassthroughSettings = null,
    rec601_settings: ?Rec601Settings = null,
    rec709_settings: ?Rec709Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color_space_passthrough_settings = "colorSpacePassthroughSettings",
            .rec601_settings = "rec601Settings",
            .rec709_settings = "rec709Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureSettings = struct {
    capture_interval: ?i64 = null,
    capture_interval_units: ?[]const u8 = null,
    timecode_burnin_settings: ?TimecodeBurninSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capture_interval = "captureInterval",
            .capture_interval_units = "captureIntervalUnits",
            .timecode_burnin_settings = "timecodeBurninSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TimecodeConfig = struct {
    source: []const u8,
    sync_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .sync_threshold = "syncThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputGroup = struct {
    name: ?[]const u8 = null,
    output_group_settings: OutputGroupSettings,
    outputs: []Output,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .output_group_settings = "outputGroupSettings",
            .outputs = "outputs",
        };
        return @field(mappings, field_name);
    }
};

pub const Output = struct {
    audio_description_names: ?[][]const u8 = null,
    caption_description_names: ?[][]const u8 = null,
    output_name: ?[]const u8 = null,
    output_settings: OutputSettings,
    video_description_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_description_names = "audioDescriptionNames",
            .caption_description_names = "captionDescriptionNames",
            .output_name = "outputName",
            .output_settings = "outputSettings",
            .video_description_name = "videoDescriptionName",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputSettings = struct {
    archive_output_settings: ?ArchiveOutputSettings = null,
    frame_capture_output_settings: ?FrameCaptureOutputSettings = null,
    hls_output_settings: ?HlsOutputSettings = null,
    media_package_output_settings: ?MediaPackageOutputSettings = null,
    ms_smooth_output_settings: ?MsSmoothOutputSettings = null,
    multiplex_output_settings: ?MultiplexOutputSettings = null,
    rtmp_output_settings: ?RtmpOutputSettings = null,
    udp_output_settings: ?UdpOutputSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archive_output_settings = "archiveOutputSettings",
            .frame_capture_output_settings = "frameCaptureOutputSettings",
            .hls_output_settings = "hlsOutputSettings",
            .media_package_output_settings = "mediaPackageOutputSettings",
            .ms_smooth_output_settings = "msSmoothOutputSettings",
            .multiplex_output_settings = "multiplexOutputSettings",
            .rtmp_output_settings = "rtmpOutputSettings",
            .udp_output_settings = "udpOutputSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const UdpOutputSettings = struct {
    buffer_msec: ?i64 = null,
    container_settings: UdpContainerSettings,
    destination: OutputLocationRef,
    fec_output_settings: ?FecOutputSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .buffer_msec = "bufferMsec",
            .container_settings = "containerSettings",
            .destination = "destination",
            .fec_output_settings = "fecOutputSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const FecOutputSettings = struct {
    column_depth: ?i64 = null,
    include_fec: ?[]const u8 = null,
    row_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_depth = "columnDepth",
            .include_fec = "includeFec",
            .row_length = "rowLength",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputLocationRef = struct {
    destination_ref_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_ref_id = "destinationRefId",
        };
        return @field(mappings, field_name);
    }
};

pub const UdpContainerSettings = struct {
    m2ts_settings: ?M2tsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .m2ts_settings = "m2tsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const M2tsSettings = struct {
    absent_input_audio_behavior: ?[]const u8 = null,
    arib: ?[]const u8 = null,
    arib_captions_pid: ?[]const u8 = null,
    arib_captions_pid_control: ?[]const u8 = null,
    audio_buffer_model: ?[]const u8 = null,
    audio_frames_per_pes: ?i64 = null,
    audio_pids: ?[]const u8 = null,
    audio_stream_type: ?[]const u8 = null,
    bitrate: ?i64 = null,
    buffer_model: ?[]const u8 = null,
    cc_descriptor: ?[]const u8 = null,
    dvb_nit_settings: ?DvbNitSettings = null,
    dvb_sdt_settings: ?DvbSdtSettings = null,
    dvb_sub_pids: ?[]const u8 = null,
    dvb_tdt_settings: ?DvbTdtSettings = null,
    dvb_teletext_pid: ?[]const u8 = null,
    ebif: ?[]const u8 = null,
    ebp_audio_interval: ?[]const u8 = null,
    ebp_lookahead_ms: ?i64 = null,
    ebp_placement: ?[]const u8 = null,
    ecm_pid: ?[]const u8 = null,
    es_rate_in_pes: ?[]const u8 = null,
    etv_platform_pid: ?[]const u8 = null,
    etv_signal_pid: ?[]const u8 = null,
    fragment_time: ?f64 = null,
    klv: ?[]const u8 = null,
    klv_data_pids: ?[]const u8 = null,
    nielsen_id3_behavior: ?[]const u8 = null,
    null_packet_bitrate: ?f64 = null,
    pat_interval: ?i64 = null,
    pcr_control: ?[]const u8 = null,
    pcr_period: ?i64 = null,
    pcr_pid: ?[]const u8 = null,
    pmt_interval: ?i64 = null,
    pmt_pid: ?[]const u8 = null,
    program_num: ?i64 = null,
    rate_mode: ?[]const u8 = null,
    scte27_pids: ?[]const u8 = null,
    scte35_control: ?[]const u8 = null,
    scte35_pid: ?[]const u8 = null,
    segmentation_markers: ?[]const u8 = null,
    segmentation_style: ?[]const u8 = null,
    segmentation_time: ?f64 = null,
    timed_metadata_behavior: ?[]const u8 = null,
    timed_metadata_pid: ?[]const u8 = null,
    transport_stream_id: ?i64 = null,
    video_pid: ?[]const u8 = null,
    scte35_preroll_pullup_milliseconds: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .absent_input_audio_behavior = "absentInputAudioBehavior",
            .arib = "arib",
            .arib_captions_pid = "aribCaptionsPid",
            .arib_captions_pid_control = "aribCaptionsPidControl",
            .audio_buffer_model = "audioBufferModel",
            .audio_frames_per_pes = "audioFramesPerPes",
            .audio_pids = "audioPids",
            .audio_stream_type = "audioStreamType",
            .bitrate = "bitrate",
            .buffer_model = "bufferModel",
            .cc_descriptor = "ccDescriptor",
            .dvb_nit_settings = "dvbNitSettings",
            .dvb_sdt_settings = "dvbSdtSettings",
            .dvb_sub_pids = "dvbSubPids",
            .dvb_tdt_settings = "dvbTdtSettings",
            .dvb_teletext_pid = "dvbTeletextPid",
            .ebif = "ebif",
            .ebp_audio_interval = "ebpAudioInterval",
            .ebp_lookahead_ms = "ebpLookaheadMs",
            .ebp_placement = "ebpPlacement",
            .ecm_pid = "ecmPid",
            .es_rate_in_pes = "esRateInPes",
            .etv_platform_pid = "etvPlatformPid",
            .etv_signal_pid = "etvSignalPid",
            .fragment_time = "fragmentTime",
            .klv = "klv",
            .klv_data_pids = "klvDataPids",
            .nielsen_id3_behavior = "nielsenId3Behavior",
            .null_packet_bitrate = "nullPacketBitrate",
            .pat_interval = "patInterval",
            .pcr_control = "pcrControl",
            .pcr_period = "pcrPeriod",
            .pcr_pid = "pcrPid",
            .pmt_interval = "pmtInterval",
            .pmt_pid = "pmtPid",
            .program_num = "programNum",
            .rate_mode = "rateMode",
            .scte27_pids = "scte27Pids",
            .scte35_control = "scte35Control",
            .scte35_pid = "scte35Pid",
            .segmentation_markers = "segmentationMarkers",
            .segmentation_style = "segmentationStyle",
            .segmentation_time = "segmentationTime",
            .timed_metadata_behavior = "timedMetadataBehavior",
            .timed_metadata_pid = "timedMetadataPid",
            .transport_stream_id = "transportStreamId",
            .video_pid = "videoPid",
            .scte35_preroll_pullup_milliseconds = "scte35PrerollPullupMilliseconds",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbTdtSettings = struct {
    rep_interval: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rep_interval = "repInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSdtSettings = struct {
    output_sdt: ?[]const u8 = null,
    rep_interval: ?i64 = null,
    service_name: ?[]const u8 = null,
    service_provider_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_sdt = "outputSdt",
            .rep_interval = "repInterval",
            .service_name = "serviceName",
            .service_provider_name = "serviceProviderName",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbNitSettings = struct {
    network_id: i64,
    network_name: []const u8,
    rep_interval: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_id = "networkId",
            .network_name = "networkName",
            .rep_interval = "repInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const RtmpOutputSettings = struct {
    certificate_mode: ?[]const u8 = null,
    connection_retry_interval: ?i64 = null,
    destination: OutputLocationRef,
    num_retries: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_mode = "certificateMode",
            .connection_retry_interval = "connectionRetryInterval",
            .destination = "destination",
            .num_retries = "numRetries",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexOutputSettings = struct {
    destination: OutputLocationRef,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const MsSmoothOutputSettings = struct {
    h265_packaging_type: ?[]const u8 = null,
    name_modifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .h265_packaging_type = "h265PackagingType",
            .name_modifier = "nameModifier",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaPackageOutputSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const HlsOutputSettings = struct {
    h265_packaging_type: ?[]const u8 = null,
    hls_settings: HlsSettings,
    name_modifier: ?[]const u8 = null,
    segment_modifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .h265_packaging_type = "h265PackagingType",
            .hls_settings = "hlsSettings",
            .name_modifier = "nameModifier",
            .segment_modifier = "segmentModifier",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsSettings = struct {
    audio_only_hls_settings: ?AudioOnlyHlsSettings = null,
    fmp4_hls_settings: ?Fmp4HlsSettings = null,
    frame_capture_hls_settings: ?FrameCaptureHlsSettings = null,
    standard_hls_settings: ?StandardHlsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_only_hls_settings = "audioOnlyHlsSettings",
            .fmp4_hls_settings = "fmp4HlsSettings",
            .frame_capture_hls_settings = "frameCaptureHlsSettings",
            .standard_hls_settings = "standardHlsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const StandardHlsSettings = struct {
    audio_rendition_sets: ?[]const u8 = null,
    m3u8_settings: M3u8Settings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_rendition_sets = "audioRenditionSets",
            .m3u8_settings = "m3u8Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const M3u8Settings = struct {
    audio_frames_per_pes: ?i64 = null,
    audio_pids: ?[]const u8 = null,
    ecm_pid: ?[]const u8 = null,
    nielsen_id3_behavior: ?[]const u8 = null,
    pat_interval: ?i64 = null,
    pcr_control: ?[]const u8 = null,
    pcr_period: ?i64 = null,
    pcr_pid: ?[]const u8 = null,
    pmt_interval: ?i64 = null,
    pmt_pid: ?[]const u8 = null,
    program_num: ?i64 = null,
    scte35_behavior: ?[]const u8 = null,
    scte35_pid: ?[]const u8 = null,
    timed_metadata_behavior: ?[]const u8 = null,
    timed_metadata_pid: ?[]const u8 = null,
    transport_stream_id: ?i64 = null,
    video_pid: ?[]const u8 = null,
    klv_behavior: ?[]const u8 = null,
    klv_data_pids: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_frames_per_pes = "audioFramesPerPes",
            .audio_pids = "audioPids",
            .ecm_pid = "ecmPid",
            .nielsen_id3_behavior = "nielsenId3Behavior",
            .pat_interval = "patInterval",
            .pcr_control = "pcrControl",
            .pcr_period = "pcrPeriod",
            .pcr_pid = "pcrPid",
            .pmt_interval = "pmtInterval",
            .pmt_pid = "pmtPid",
            .program_num = "programNum",
            .scte35_behavior = "scte35Behavior",
            .scte35_pid = "scte35Pid",
            .timed_metadata_behavior = "timedMetadataBehavior",
            .timed_metadata_pid = "timedMetadataPid",
            .transport_stream_id = "transportStreamId",
            .video_pid = "videoPid",
            .klv_behavior = "klvBehavior",
            .klv_data_pids = "klvDataPids",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureHlsSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Fmp4HlsSettings = struct {
    audio_rendition_sets: ?[]const u8 = null,
    nielsen_id3_behavior: ?[]const u8 = null,
    timed_metadata_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_rendition_sets = "audioRenditionSets",
            .nielsen_id3_behavior = "nielsenId3Behavior",
            .timed_metadata_behavior = "timedMetadataBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioOnlyHlsSettings = struct {
    audio_group_id: ?[]const u8 = null,
    audio_only_image: ?InputLocation = null,
    audio_track_type: ?[]const u8 = null,
    segment_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_group_id = "audioGroupId",
            .audio_only_image = "audioOnlyImage",
            .audio_track_type = "audioTrackType",
            .segment_type = "segmentType",
        };
        return @field(mappings, field_name);
    }
};

pub const InputLocation = struct {
    password_param: ?[]const u8 = null,
    uri: []const u8,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .password_param = "passwordParam",
            .uri = "uri",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureOutputSettings = struct {
    name_modifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name_modifier = "nameModifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveOutputSettings = struct {
    container_settings: ArchiveContainerSettings,
    extension: ?[]const u8 = null,
    name_modifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_settings = "containerSettings",
            .extension = "extension",
            .name_modifier = "nameModifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveContainerSettings = struct {
    m2ts_settings: ?M2tsSettings = null,
    raw_settings: ?RawSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .m2ts_settings = "m2tsSettings",
            .raw_settings = "rawSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const RawSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const OutputGroupSettings = struct {
    archive_group_settings: ?ArchiveGroupSettings = null,
    frame_capture_group_settings: ?FrameCaptureGroupSettings = null,
    hls_group_settings: ?HlsGroupSettings = null,
    media_package_group_settings: ?MediaPackageGroupSettings = null,
    ms_smooth_group_settings: ?MsSmoothGroupSettings = null,
    multiplex_group_settings: ?MultiplexGroupSettings = null,
    rtmp_group_settings: ?RtmpGroupSettings = null,
    udp_group_settings: ?UdpGroupSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archive_group_settings = "archiveGroupSettings",
            .frame_capture_group_settings = "frameCaptureGroupSettings",
            .hls_group_settings = "hlsGroupSettings",
            .media_package_group_settings = "mediaPackageGroupSettings",
            .ms_smooth_group_settings = "msSmoothGroupSettings",
            .multiplex_group_settings = "multiplexGroupSettings",
            .rtmp_group_settings = "rtmpGroupSettings",
            .udp_group_settings = "udpGroupSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const UdpGroupSettings = struct {
    input_loss_action: ?[]const u8 = null,
    timed_metadata_id3_frame: ?[]const u8 = null,
    timed_metadata_id3_period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_loss_action = "inputLossAction",
            .timed_metadata_id3_frame = "timedMetadataId3Frame",
            .timed_metadata_id3_period = "timedMetadataId3Period",
        };
        return @field(mappings, field_name);
    }
};

pub const RtmpGroupSettings = struct {
    ad_markers: ?[][]const u8 = null,
    authentication_scheme: ?[]const u8 = null,
    cache_full_behavior: ?[]const u8 = null,
    cache_length: ?i64 = null,
    caption_data: ?[]const u8 = null,
    input_loss_action: ?[]const u8 = null,
    restart_delay: ?i64 = null,
    include_filler_nal_units: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .authentication_scheme = "authenticationScheme",
            .cache_full_behavior = "cacheFullBehavior",
            .cache_length = "cacheLength",
            .caption_data = "captionData",
            .input_loss_action = "inputLossAction",
            .restart_delay = "restartDelay",
            .include_filler_nal_units = "includeFillerNalUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexGroupSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const MsSmoothGroupSettings = struct {
    acquisition_point_id: ?[]const u8 = null,
    audio_only_timecode_control: ?[]const u8 = null,
    certificate_mode: ?[]const u8 = null,
    connection_retry_interval: ?i64 = null,
    destination: OutputLocationRef,
    event_id: ?[]const u8 = null,
    event_id_mode: ?[]const u8 = null,
    event_stop_behavior: ?[]const u8 = null,
    filecache_duration: ?i64 = null,
    fragment_length: ?i64 = null,
    input_loss_action: ?[]const u8 = null,
    num_retries: ?i64 = null,
    restart_delay: ?i64 = null,
    segmentation_mode: ?[]const u8 = null,
    send_delay_ms: ?i64 = null,
    sparse_track_type: ?[]const u8 = null,
    stream_manifest_behavior: ?[]const u8 = null,
    timestamp_offset: ?[]const u8 = null,
    timestamp_offset_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acquisition_point_id = "acquisitionPointId",
            .audio_only_timecode_control = "audioOnlyTimecodeControl",
            .certificate_mode = "certificateMode",
            .connection_retry_interval = "connectionRetryInterval",
            .destination = "destination",
            .event_id = "eventId",
            .event_id_mode = "eventIdMode",
            .event_stop_behavior = "eventStopBehavior",
            .filecache_duration = "filecacheDuration",
            .fragment_length = "fragmentLength",
            .input_loss_action = "inputLossAction",
            .num_retries = "numRetries",
            .restart_delay = "restartDelay",
            .segmentation_mode = "segmentationMode",
            .send_delay_ms = "sendDelayMs",
            .sparse_track_type = "sparseTrackType",
            .stream_manifest_behavior = "streamManifestBehavior",
            .timestamp_offset = "timestampOffset",
            .timestamp_offset_mode = "timestampOffsetMode",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaPackageGroupSettings = struct {
    destination: OutputLocationRef,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsGroupSettings = struct {
    ad_markers: ?[][]const u8 = null,
    base_url_content: ?[]const u8 = null,
    base_url_content1: ?[]const u8 = null,
    base_url_manifest: ?[]const u8 = null,
    base_url_manifest1: ?[]const u8 = null,
    caption_language_mappings: ?[]CaptionLanguageMapping = null,
    caption_language_setting: ?[]const u8 = null,
    client_cache: ?[]const u8 = null,
    codec_specification: ?[]const u8 = null,
    constant_iv: ?[]const u8 = null,
    destination: OutputLocationRef,
    directory_structure: ?[]const u8 = null,
    discontinuity_tags: ?[]const u8 = null,
    encryption_type: ?[]const u8 = null,
    hls_cdn_settings: ?HlsCdnSettings = null,
    hls_id3_segment_tagging: ?[]const u8 = null,
    i_frame_only_playlists: ?[]const u8 = null,
    incomplete_segment_behavior: ?[]const u8 = null,
    index_n_segments: ?i64 = null,
    input_loss_action: ?[]const u8 = null,
    iv_in_manifest: ?[]const u8 = null,
    iv_source: ?[]const u8 = null,
    keep_segments: ?i64 = null,
    key_format: ?[]const u8 = null,
    key_format_versions: ?[]const u8 = null,
    key_provider_settings: ?KeyProviderSettings = null,
    manifest_compression: ?[]const u8 = null,
    manifest_duration_format: ?[]const u8 = null,
    min_segment_length: ?i64 = null,
    mode: ?[]const u8 = null,
    output_selection: ?[]const u8 = null,
    program_date_time: ?[]const u8 = null,
    program_date_time_clock: ?[]const u8 = null,
    program_date_time_period: ?i64 = null,
    redundant_manifest: ?[]const u8 = null,
    segment_length: ?i64 = null,
    segmentation_mode: ?[]const u8 = null,
    segments_per_subdirectory: ?i64 = null,
    stream_inf_resolution: ?[]const u8 = null,
    timed_metadata_id3_frame: ?[]const u8 = null,
    timed_metadata_id3_period: ?i64 = null,
    timestamp_delta_milliseconds: ?i64 = null,
    ts_file_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .base_url_content = "baseUrlContent",
            .base_url_content1 = "baseUrlContent1",
            .base_url_manifest = "baseUrlManifest",
            .base_url_manifest1 = "baseUrlManifest1",
            .caption_language_mappings = "captionLanguageMappings",
            .caption_language_setting = "captionLanguageSetting",
            .client_cache = "clientCache",
            .codec_specification = "codecSpecification",
            .constant_iv = "constantIv",
            .destination = "destination",
            .directory_structure = "directoryStructure",
            .discontinuity_tags = "discontinuityTags",
            .encryption_type = "encryptionType",
            .hls_cdn_settings = "hlsCdnSettings",
            .hls_id3_segment_tagging = "hlsId3SegmentTagging",
            .i_frame_only_playlists = "iFrameOnlyPlaylists",
            .incomplete_segment_behavior = "incompleteSegmentBehavior",
            .index_n_segments = "indexNSegments",
            .input_loss_action = "inputLossAction",
            .iv_in_manifest = "ivInManifest",
            .iv_source = "ivSource",
            .keep_segments = "keepSegments",
            .key_format = "keyFormat",
            .key_format_versions = "keyFormatVersions",
            .key_provider_settings = "keyProviderSettings",
            .manifest_compression = "manifestCompression",
            .manifest_duration_format = "manifestDurationFormat",
            .min_segment_length = "minSegmentLength",
            .mode = "mode",
            .output_selection = "outputSelection",
            .program_date_time = "programDateTime",
            .program_date_time_clock = "programDateTimeClock",
            .program_date_time_period = "programDateTimePeriod",
            .redundant_manifest = "redundantManifest",
            .segment_length = "segmentLength",
            .segmentation_mode = "segmentationMode",
            .segments_per_subdirectory = "segmentsPerSubdirectory",
            .stream_inf_resolution = "streamInfResolution",
            .timed_metadata_id3_frame = "timedMetadataId3Frame",
            .timed_metadata_id3_period = "timedMetadataId3Period",
            .timestamp_delta_milliseconds = "timestampDeltaMilliseconds",
            .ts_file_mode = "tsFileMode",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyProviderSettings = struct {
    static_key_settings: ?StaticKeySettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_key_settings = "staticKeySettings",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticKeySettings = struct {
    key_provider_server: ?InputLocation = null,
    static_key_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_provider_server = "keyProviderServer",
            .static_key_value = "staticKeyValue",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsCdnSettings = struct {
    hls_akamai_settings: ?HlsAkamaiSettings = null,
    hls_basic_put_settings: ?HlsBasicPutSettings = null,
    hls_media_store_settings: ?HlsMediaStoreSettings = null,
    hls_s3_settings: ?HlsS3Settings = null,
    hls_webdav_settings: ?HlsWebdavSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hls_akamai_settings = "hlsAkamaiSettings",
            .hls_basic_put_settings = "hlsBasicPutSettings",
            .hls_media_store_settings = "hlsMediaStoreSettings",
            .hls_s3_settings = "hlsS3Settings",
            .hls_webdav_settings = "hlsWebdavSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsWebdavSettings = struct {
    connection_retry_interval: ?i64 = null,
    filecache_duration: ?i64 = null,
    http_transfer_mode: ?[]const u8 = null,
    num_retries: ?i64 = null,
    restart_delay: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_retry_interval = "connectionRetryInterval",
            .filecache_duration = "filecacheDuration",
            .http_transfer_mode = "httpTransferMode",
            .num_retries = "numRetries",
            .restart_delay = "restartDelay",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsS3Settings = struct {
    canned_acl: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canned_acl = "cannedAcl",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsMediaStoreSettings = struct {
    connection_retry_interval: ?i64 = null,
    filecache_duration: ?i64 = null,
    media_store_storage_class: ?[]const u8 = null,
    num_retries: ?i64 = null,
    restart_delay: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_retry_interval = "connectionRetryInterval",
            .filecache_duration = "filecacheDuration",
            .media_store_storage_class = "mediaStoreStorageClass",
            .num_retries = "numRetries",
            .restart_delay = "restartDelay",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsBasicPutSettings = struct {
    connection_retry_interval: ?i64 = null,
    filecache_duration: ?i64 = null,
    num_retries: ?i64 = null,
    restart_delay: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_retry_interval = "connectionRetryInterval",
            .filecache_duration = "filecacheDuration",
            .num_retries = "numRetries",
            .restart_delay = "restartDelay",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsAkamaiSettings = struct {
    connection_retry_interval: ?i64 = null,
    filecache_duration: ?i64 = null,
    http_transfer_mode: ?[]const u8 = null,
    num_retries: ?i64 = null,
    restart_delay: ?i64 = null,
    salt: ?[]const u8 = null,
    token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_retry_interval = "connectionRetryInterval",
            .filecache_duration = "filecacheDuration",
            .http_transfer_mode = "httpTransferMode",
            .num_retries = "numRetries",
            .restart_delay = "restartDelay",
            .salt = "salt",
            .token = "token",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionLanguageMapping = struct {
    caption_channel: i64,
    language_code: []const u8,
    language_description: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caption_channel = "captionChannel",
            .language_code = "languageCode",
            .language_description = "languageDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureGroupSettings = struct {
    destination: OutputLocationRef,
    frame_capture_cdn_settings: ?FrameCaptureCdnSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "destination",
            .frame_capture_cdn_settings = "frameCaptureCdnSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureCdnSettings = struct {
    frame_capture_s3_settings: ?FrameCaptureS3Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frame_capture_s3_settings = "frameCaptureS3Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureS3Settings = struct {
    canned_acl: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canned_acl = "cannedAcl",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveGroupSettings = struct {
    archive_cdn_settings: ?ArchiveCdnSettings = null,
    destination: OutputLocationRef,
    rollover_interval: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archive_cdn_settings = "archiveCdnSettings",
            .destination = "destination",
            .rollover_interval = "rolloverInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveCdnSettings = struct {
    archive_s3_settings: ?ArchiveS3Settings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archive_s3_settings = "archiveS3Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const ArchiveS3Settings = struct {
    canned_acl: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canned_acl = "cannedAcl",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenConfiguration = struct {
    distributor_id: ?[]const u8 = null,
    nielsen_pcm_to_id3_tagging: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .distributor_id = "distributorId",
            .nielsen_pcm_to_id3_tagging = "nielsenPcmToId3Tagging",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionGraphicsConfiguration = struct {
    motion_graphics_insertion: ?[]const u8 = null,
    motion_graphics_settings: MotionGraphicsSettings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .motion_graphics_insertion = "motionGraphicsInsertion",
            .motion_graphics_settings = "motionGraphicsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionGraphicsSettings = struct {
    html_motion_graphics_settings: ?HtmlMotionGraphicsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .html_motion_graphics_settings = "htmlMotionGraphicsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const HtmlMotionGraphicsSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const GlobalConfiguration = struct {
    initial_audio_gain: ?i64 = null,
    input_end_action: ?[]const u8 = null,
    input_loss_behavior: ?InputLossBehavior = null,
    output_locking_mode: ?[]const u8 = null,
    output_timing_source: ?[]const u8 = null,
    support_low_framerate_inputs: ?[]const u8 = null,
    output_locking_settings: ?OutputLockingSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .initial_audio_gain = "initialAudioGain",
            .input_end_action = "inputEndAction",
            .input_loss_behavior = "inputLossBehavior",
            .output_locking_mode = "outputLockingMode",
            .output_timing_source = "outputTimingSource",
            .support_low_framerate_inputs = "supportLowFramerateInputs",
            .output_locking_settings = "outputLockingSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputLockingSettings = struct {
    epoch_locking_settings: ?EpochLockingSettings = null,
    pipeline_locking_settings: ?PipelineLockingSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .epoch_locking_settings = "epochLockingSettings",
            .pipeline_locking_settings = "pipelineLockingSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineLockingSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EpochLockingSettings = struct {
    custom_epoch: ?[]const u8 = null,
    jam_sync_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_epoch = "customEpoch",
            .jam_sync_time = "jamSyncTime",
        };
        return @field(mappings, field_name);
    }
};

pub const InputLossBehavior = struct {
    black_frame_msec: ?i64 = null,
    input_loss_image_color: ?[]const u8 = null,
    input_loss_image_slate: ?InputLocation = null,
    input_loss_image_type: ?[]const u8 = null,
    repeat_frame_msec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .black_frame_msec = "blackFrameMsec",
            .input_loss_image_color = "inputLossImageColor",
            .input_loss_image_slate = "inputLossImageSlate",
            .input_loss_image_type = "inputLossImageType",
            .repeat_frame_msec = "repeatFrameMsec",
        };
        return @field(mappings, field_name);
    }
};

pub const FeatureActivations = struct {
    input_prepare_schedule_actions: ?[]const u8 = null,
    output_static_image_overlay_schedule_actions: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_prepare_schedule_actions = "inputPrepareScheduleActions",
            .output_static_image_overlay_schedule_actions = "outputStaticImageOverlayScheduleActions",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionDescription = struct {
    accessibility: ?[]const u8 = null,
    caption_selector_name: []const u8,
    destination_settings: ?CaptionDestinationSettings = null,
    language_code: ?[]const u8 = null,
    language_description: ?[]const u8 = null,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accessibility = "accessibility",
            .caption_selector_name = "captionSelectorName",
            .destination_settings = "destinationSettings",
            .language_code = "languageCode",
            .language_description = "languageDescription",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionDestinationSettings = struct {
    arib_destination_settings: ?AribDestinationSettings = null,
    burn_in_destination_settings: ?BurnInDestinationSettings = null,
    dvb_sub_destination_settings: ?DvbSubDestinationSettings = null,
    ebu_tt_d_destination_settings: ?EbuTtDDestinationSettings = null,
    embedded_destination_settings: ?EmbeddedDestinationSettings = null,
    embedded_plus_scte20_destination_settings: ?EmbeddedPlusScte20DestinationSettings = null,
    rtmp_caption_info_destination_settings: ?RtmpCaptionInfoDestinationSettings = null,
    scte20_plus_embedded_destination_settings: ?Scte20PlusEmbeddedDestinationSettings = null,
    scte27_destination_settings: ?Scte27DestinationSettings = null,
    smpte_tt_destination_settings: ?SmpteTtDestinationSettings = null,
    teletext_destination_settings: ?TeletextDestinationSettings = null,
    ttml_destination_settings: ?TtmlDestinationSettings = null,
    webvtt_destination_settings: ?WebvttDestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arib_destination_settings = "aribDestinationSettings",
            .burn_in_destination_settings = "burnInDestinationSettings",
            .dvb_sub_destination_settings = "dvbSubDestinationSettings",
            .ebu_tt_d_destination_settings = "ebuTtDDestinationSettings",
            .embedded_destination_settings = "embeddedDestinationSettings",
            .embedded_plus_scte20_destination_settings = "embeddedPlusScte20DestinationSettings",
            .rtmp_caption_info_destination_settings = "rtmpCaptionInfoDestinationSettings",
            .scte20_plus_embedded_destination_settings = "scte20PlusEmbeddedDestinationSettings",
            .scte27_destination_settings = "scte27DestinationSettings",
            .smpte_tt_destination_settings = "smpteTtDestinationSettings",
            .teletext_destination_settings = "teletextDestinationSettings",
            .ttml_destination_settings = "ttmlDestinationSettings",
            .webvtt_destination_settings = "webvttDestinationSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const WebvttDestinationSettings = struct {
    style_control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .style_control = "styleControl",
        };
        return @field(mappings, field_name);
    }
};

pub const TtmlDestinationSettings = struct {
    style_control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .style_control = "styleControl",
        };
        return @field(mappings, field_name);
    }
};

pub const TeletextDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SmpteTtDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Scte27DestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Scte20PlusEmbeddedDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RtmpCaptionInfoDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EmbeddedPlusScte20DestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EmbeddedDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EbuTtDDestinationSettings = struct {
    copyright_holder: ?[]const u8 = null,
    fill_line_gap: ?[]const u8 = null,
    font_family: ?[]const u8 = null,
    style_control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .copyright_holder = "copyrightHolder",
            .fill_line_gap = "fillLineGap",
            .font_family = "fontFamily",
            .style_control = "styleControl",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSubDestinationSettings = struct {
    alignment: ?[]const u8 = null,
    background_color: ?[]const u8 = null,
    background_opacity: ?i64 = null,
    font: ?InputLocation = null,
    font_color: ?[]const u8 = null,
    font_opacity: ?i64 = null,
    font_resolution: ?i64 = null,
    font_size: ?[]const u8 = null,
    outline_color: ?[]const u8 = null,
    outline_size: ?i64 = null,
    shadow_color: ?[]const u8 = null,
    shadow_opacity: ?i64 = null,
    shadow_x_offset: ?i64 = null,
    shadow_y_offset: ?i64 = null,
    teletext_grid_control: ?[]const u8 = null,
    x_position: ?i64 = null,
    y_position: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "alignment",
            .background_color = "backgroundColor",
            .background_opacity = "backgroundOpacity",
            .font = "font",
            .font_color = "fontColor",
            .font_opacity = "fontOpacity",
            .font_resolution = "fontResolution",
            .font_size = "fontSize",
            .outline_color = "outlineColor",
            .outline_size = "outlineSize",
            .shadow_color = "shadowColor",
            .shadow_opacity = "shadowOpacity",
            .shadow_x_offset = "shadowXOffset",
            .shadow_y_offset = "shadowYOffset",
            .teletext_grid_control = "teletextGridControl",
            .x_position = "xPosition",
            .y_position = "yPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const BurnInDestinationSettings = struct {
    alignment: ?[]const u8 = null,
    background_color: ?[]const u8 = null,
    background_opacity: ?i64 = null,
    font: ?InputLocation = null,
    font_color: ?[]const u8 = null,
    font_opacity: ?i64 = null,
    font_resolution: ?i64 = null,
    font_size: ?[]const u8 = null,
    outline_color: ?[]const u8 = null,
    outline_size: ?i64 = null,
    shadow_color: ?[]const u8 = null,
    shadow_opacity: ?i64 = null,
    shadow_x_offset: ?i64 = null,
    shadow_y_offset: ?i64 = null,
    teletext_grid_control: ?[]const u8 = null,
    x_position: ?i64 = null,
    y_position: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "alignment",
            .background_color = "backgroundColor",
            .background_opacity = "backgroundOpacity",
            .font = "font",
            .font_color = "fontColor",
            .font_opacity = "fontOpacity",
            .font_resolution = "fontResolution",
            .font_size = "fontSize",
            .outline_color = "outlineColor",
            .outline_size = "outlineSize",
            .shadow_color = "shadowColor",
            .shadow_opacity = "shadowOpacity",
            .shadow_x_offset = "shadowXOffset",
            .shadow_y_offset = "shadowYOffset",
            .teletext_grid_control = "teletextGridControl",
            .x_position = "xPosition",
            .y_position = "yPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const AribDestinationSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const BlackoutSlate = struct {
    blackout_slate_image: ?InputLocation = null,
    network_end_blackout: ?[]const u8 = null,
    network_end_blackout_image: ?InputLocation = null,
    network_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blackout_slate_image = "blackoutSlateImage",
            .network_end_blackout = "networkEndBlackout",
            .network_end_blackout_image = "networkEndBlackoutImage",
            .network_id = "networkId",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailConfiguration = struct {
    avail_settings: ?AvailSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .avail_settings = "availSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailSettings = struct {
    esam: ?Esam = null,
    scte35_splice_insert: ?Scte35SpliceInsert = null,
    scte35_time_signal_apos: ?Scte35TimeSignalApos = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .esam = "esam",
            .scte35_splice_insert = "scte35SpliceInsert",
            .scte35_time_signal_apos = "scte35TimeSignalApos",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35TimeSignalApos = struct {
    ad_avail_offset: ?i64 = null,
    no_regional_blackout_flag: ?[]const u8 = null,
    web_delivery_allowed_flag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_avail_offset = "adAvailOffset",
            .no_regional_blackout_flag = "noRegionalBlackoutFlag",
            .web_delivery_allowed_flag = "webDeliveryAllowedFlag",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35SpliceInsert = struct {
    ad_avail_offset: ?i64 = null,
    no_regional_blackout_flag: ?[]const u8 = null,
    web_delivery_allowed_flag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_avail_offset = "adAvailOffset",
            .no_regional_blackout_flag = "noRegionalBlackoutFlag",
            .web_delivery_allowed_flag = "webDeliveryAllowedFlag",
        };
        return @field(mappings, field_name);
    }
};

pub const Esam = struct {
    acquisition_point_id: []const u8,
    ad_avail_offset: ?i64 = null,
    password_param: ?[]const u8 = null,
    pois_endpoint: []const u8,
    username: ?[]const u8 = null,
    zone_identity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acquisition_point_id = "acquisitionPointId",
            .ad_avail_offset = "adAvailOffset",
            .password_param = "passwordParam",
            .pois_endpoint = "poisEndpoint",
            .username = "username",
            .zone_identity = "zoneIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailBlanking = struct {
    avail_blanking_image: ?InputLocation = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .avail_blanking_image = "availBlankingImage",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioDescription = struct {
    audio_normalization_settings: ?AudioNormalizationSettings = null,
    audio_selector_name: []const u8,
    audio_type: ?[]const u8 = null,
    audio_type_control: ?[]const u8 = null,
    audio_watermarking_settings: ?AudioWatermarkSettings = null,
    codec_settings: ?AudioCodecSettings = null,
    language_code: ?[]const u8 = null,
    language_code_control: ?[]const u8 = null,
    name: []const u8,
    remix_settings: ?RemixSettings = null,
    stream_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_normalization_settings = "audioNormalizationSettings",
            .audio_selector_name = "audioSelectorName",
            .audio_type = "audioType",
            .audio_type_control = "audioTypeControl",
            .audio_watermarking_settings = "audioWatermarkingSettings",
            .codec_settings = "codecSettings",
            .language_code = "languageCode",
            .language_code_control = "languageCodeControl",
            .name = "name",
            .remix_settings = "remixSettings",
            .stream_name = "streamName",
        };
        return @field(mappings, field_name);
    }
};

pub const RemixSettings = struct {
    channel_mappings: []AudioChannelMapping,
    channels_in: ?i64 = null,
    channels_out: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_mappings = "channelMappings",
            .channels_in = "channelsIn",
            .channels_out = "channelsOut",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioChannelMapping = struct {
    input_channel_levels: []InputChannelLevel,
    output_channel: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_channel_levels = "inputChannelLevels",
            .output_channel = "outputChannel",
        };
        return @field(mappings, field_name);
    }
};

pub const InputChannelLevel = struct {
    gain: i64,
    input_channel: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gain = "gain",
            .input_channel = "inputChannel",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioCodecSettings = struct {
    aac_settings: ?AacSettings = null,
    ac3_settings: ?Ac3Settings = null,
    eac3_atmos_settings: ?Eac3AtmosSettings = null,
    eac3_settings: ?Eac3Settings = null,
    mp2_settings: ?Mp2Settings = null,
    pass_through_settings: ?PassThroughSettings = null,
    wav_settings: ?WavSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aac_settings = "aacSettings",
            .ac3_settings = "ac3Settings",
            .eac3_atmos_settings = "eac3AtmosSettings",
            .eac3_settings = "eac3Settings",
            .mp2_settings = "mp2Settings",
            .pass_through_settings = "passThroughSettings",
            .wav_settings = "wavSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const WavSettings = struct {
    bit_depth: ?f64 = null,
    coding_mode: ?[]const u8 = null,
    sample_rate: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bit_depth = "bitDepth",
            .coding_mode = "codingMode",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const PassThroughSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Mp2Settings = struct {
    bitrate: ?f64 = null,
    coding_mode: ?[]const u8 = null,
    sample_rate: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .coding_mode = "codingMode",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const Eac3Settings = struct {
    attenuation_control: ?[]const u8 = null,
    bitrate: ?f64 = null,
    bitstream_mode: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    dc_filter: ?[]const u8 = null,
    dialnorm: ?i64 = null,
    drc_line: ?[]const u8 = null,
    drc_rf: ?[]const u8 = null,
    lfe_control: ?[]const u8 = null,
    lfe_filter: ?[]const u8 = null,
    lo_ro_center_mix_level: ?f64 = null,
    lo_ro_surround_mix_level: ?f64 = null,
    lt_rt_center_mix_level: ?f64 = null,
    lt_rt_surround_mix_level: ?f64 = null,
    metadata_control: ?[]const u8 = null,
    passthrough_control: ?[]const u8 = null,
    phase_control: ?[]const u8 = null,
    stereo_downmix: ?[]const u8 = null,
    surround_ex_mode: ?[]const u8 = null,
    surround_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attenuation_control = "attenuationControl",
            .bitrate = "bitrate",
            .bitstream_mode = "bitstreamMode",
            .coding_mode = "codingMode",
            .dc_filter = "dcFilter",
            .dialnorm = "dialnorm",
            .drc_line = "drcLine",
            .drc_rf = "drcRf",
            .lfe_control = "lfeControl",
            .lfe_filter = "lfeFilter",
            .lo_ro_center_mix_level = "loRoCenterMixLevel",
            .lo_ro_surround_mix_level = "loRoSurroundMixLevel",
            .lt_rt_center_mix_level = "ltRtCenterMixLevel",
            .lt_rt_surround_mix_level = "ltRtSurroundMixLevel",
            .metadata_control = "metadataControl",
            .passthrough_control = "passthroughControl",
            .phase_control = "phaseControl",
            .stereo_downmix = "stereoDownmix",
            .surround_ex_mode = "surroundExMode",
            .surround_mode = "surroundMode",
        };
        return @field(mappings, field_name);
    }
};

pub const Eac3AtmosSettings = struct {
    bitrate: ?f64 = null,
    coding_mode: ?[]const u8 = null,
    dialnorm: ?i64 = null,
    drc_line: ?[]const u8 = null,
    drc_rf: ?[]const u8 = null,
    height_trim: ?f64 = null,
    surround_trim: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .coding_mode = "codingMode",
            .dialnorm = "dialnorm",
            .drc_line = "drcLine",
            .drc_rf = "drcRf",
            .height_trim = "heightTrim",
            .surround_trim = "surroundTrim",
        };
        return @field(mappings, field_name);
    }
};

pub const Ac3Settings = struct {
    bitrate: ?f64 = null,
    bitstream_mode: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    dialnorm: ?i64 = null,
    drc_profile: ?[]const u8 = null,
    lfe_filter: ?[]const u8 = null,
    metadata_control: ?[]const u8 = null,
    attenuation_control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .bitstream_mode = "bitstreamMode",
            .coding_mode = "codingMode",
            .dialnorm = "dialnorm",
            .drc_profile = "drcProfile",
            .lfe_filter = "lfeFilter",
            .metadata_control = "metadataControl",
            .attenuation_control = "attenuationControl",
        };
        return @field(mappings, field_name);
    }
};

pub const AacSettings = struct {
    bitrate: ?f64 = null,
    coding_mode: ?[]const u8 = null,
    input_type: ?[]const u8 = null,
    profile: ?[]const u8 = null,
    rate_control_mode: ?[]const u8 = null,
    raw_format: ?[]const u8 = null,
    sample_rate: ?f64 = null,
    spec: ?[]const u8 = null,
    vbr_quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .coding_mode = "codingMode",
            .input_type = "inputType",
            .profile = "profile",
            .rate_control_mode = "rateControlMode",
            .raw_format = "rawFormat",
            .sample_rate = "sampleRate",
            .spec = "spec",
            .vbr_quality = "vbrQuality",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioWatermarkSettings = struct {
    nielsen_watermarks_settings: ?NielsenWatermarksSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nielsen_watermarks_settings = "nielsenWatermarksSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenWatermarksSettings = struct {
    nielsen_cbet_settings: ?NielsenCBET = null,
    nielsen_distribution_type: ?[]const u8 = null,
    nielsen_naes_ii_nw_settings: ?NielsenNaesIiNw = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nielsen_cbet_settings = "nielsenCbetSettings",
            .nielsen_distribution_type = "nielsenDistributionType",
            .nielsen_naes_ii_nw_settings = "nielsenNaesIiNwSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenNaesIiNw = struct {
    check_digit_string: []const u8,
    sid: f64,
    timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .check_digit_string = "checkDigitString",
            .sid = "sid",
            .timezone = "timezone",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenCBET = struct {
    cbet_check_digit_string: []const u8,
    cbet_stepaside: []const u8,
    csid: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cbet_check_digit_string = "cbetCheckDigitString",
            .cbet_stepaside = "cbetStepaside",
            .csid = "csid",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioNormalizationSettings = struct {
    algorithm: ?[]const u8 = null,
    algorithm_control: ?[]const u8 = null,
    target_lkfs: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "algorithm",
            .algorithm_control = "algorithmControl",
            .target_lkfs = "targetLkfs",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelEgressEndpoint = struct {
    source_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_ip = "sourceIp",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDestination = struct {
    id: ?[]const u8 = null,
    media_package_settings: ?[]MediaPackageOutputDestinationSettings = null,
    multiplex_settings: ?MultiplexProgramChannelDestinationSettings = null,
    settings: ?[]OutputDestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .media_package_settings = "mediaPackageSettings",
            .multiplex_settings = "multiplexSettings",
            .settings = "settings",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDestinationSettings = struct {
    password_param: ?[]const u8 = null,
    stream_name: ?[]const u8 = null,
    url: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .password_param = "passwordParam",
            .stream_name = "streamName",
            .url = "url",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiplexProgramChannelDestinationSettings = struct {
    multiplex_id: ?[]const u8 = null,
    program_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .multiplex_id = "multiplexId",
            .program_name = "programName",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaPackageOutputDestinationSettings = struct {
    channel_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "channelId",
        };
        return @field(mappings, field_name);
    }
};

pub const CdiInputSpecification = struct {
    resolution: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolution = "resolution",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountConfiguration = struct {
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleAction = struct {
    action_name: []const u8,
    schedule_action_settings: ScheduleActionSettings,
    schedule_action_start_settings: ScheduleActionStartSettings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_name = "actionName",
            .schedule_action_settings = "scheduleActionSettings",
            .schedule_action_start_settings = "scheduleActionStartSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleActionStartSettings = struct {
    fixed_mode_schedule_action_start_settings: ?FixedModeScheduleActionStartSettings = null,
    follow_mode_schedule_action_start_settings: ?FollowModeScheduleActionStartSettings = null,
    immediate_mode_schedule_action_start_settings: ?ImmediateModeScheduleActionStartSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fixed_mode_schedule_action_start_settings = "fixedModeScheduleActionStartSettings",
            .follow_mode_schedule_action_start_settings = "followModeScheduleActionStartSettings",
            .immediate_mode_schedule_action_start_settings = "immediateModeScheduleActionStartSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ImmediateModeScheduleActionStartSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const FollowModeScheduleActionStartSettings = struct {
    follow_point: []const u8,
    reference_action_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .follow_point = "followPoint",
            .reference_action_name = "referenceActionName",
        };
        return @field(mappings, field_name);
    }
};

pub const FixedModeScheduleActionStartSettings = struct {
    time: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time = "time",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleActionSettings = struct {
    hls_id3_segment_tagging_settings: ?HlsId3SegmentTaggingScheduleActionSettings = null,
    hls_timed_metadata_settings: ?HlsTimedMetadataScheduleActionSettings = null,
    input_prepare_settings: ?InputPrepareScheduleActionSettings = null,
    input_switch_settings: ?InputSwitchScheduleActionSettings = null,
    motion_graphics_image_activate_settings: ?MotionGraphicsActivateScheduleActionSettings = null,
    motion_graphics_image_deactivate_settings: ?MotionGraphicsDeactivateScheduleActionSettings = null,
    pause_state_settings: ?PauseStateScheduleActionSettings = null,
    scte35_input_settings: ?Scte35InputScheduleActionSettings = null,
    scte35_return_to_network_settings: ?Scte35ReturnToNetworkScheduleActionSettings = null,
    scte35_splice_insert_settings: ?Scte35SpliceInsertScheduleActionSettings = null,
    scte35_time_signal_settings: ?Scte35TimeSignalScheduleActionSettings = null,
    static_image_activate_settings: ?StaticImageActivateScheduleActionSettings = null,
    static_image_deactivate_settings: ?StaticImageDeactivateScheduleActionSettings = null,
    static_image_output_activate_settings: ?StaticImageOutputActivateScheduleActionSettings = null,
    static_image_output_deactivate_settings: ?StaticImageOutputDeactivateScheduleActionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hls_id3_segment_tagging_settings = "hlsId3SegmentTaggingSettings",
            .hls_timed_metadata_settings = "hlsTimedMetadataSettings",
            .input_prepare_settings = "inputPrepareSettings",
            .input_switch_settings = "inputSwitchSettings",
            .motion_graphics_image_activate_settings = "motionGraphicsImageActivateSettings",
            .motion_graphics_image_deactivate_settings = "motionGraphicsImageDeactivateSettings",
            .pause_state_settings = "pauseStateSettings",
            .scte35_input_settings = "scte35InputSettings",
            .scte35_return_to_network_settings = "scte35ReturnToNetworkSettings",
            .scte35_splice_insert_settings = "scte35SpliceInsertSettings",
            .scte35_time_signal_settings = "scte35TimeSignalSettings",
            .static_image_activate_settings = "staticImageActivateSettings",
            .static_image_deactivate_settings = "staticImageDeactivateSettings",
            .static_image_output_activate_settings = "staticImageOutputActivateSettings",
            .static_image_output_deactivate_settings = "staticImageOutputDeactivateSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticImageOutputDeactivateScheduleActionSettings = struct {
    fade_out: ?i64 = null,
    layer: ?i64 = null,
    output_names: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fade_out = "fadeOut",
            .layer = "layer",
            .output_names = "outputNames",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticImageOutputActivateScheduleActionSettings = struct {
    duration: ?i64 = null,
    fade_in: ?i64 = null,
    fade_out: ?i64 = null,
    height: ?i64 = null,
    image: InputLocation,
    imagex: ?i64 = null,
    imagey: ?i64 = null,
    layer: ?i64 = null,
    opacity: ?i64 = null,
    output_names: [][]const u8,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .fade_in = "fadeIn",
            .fade_out = "fadeOut",
            .height = "height",
            .image = "image",
            .imagex = "imageX",
            .imagey = "imageY",
            .layer = "layer",
            .opacity = "opacity",
            .output_names = "outputNames",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticImageDeactivateScheduleActionSettings = struct {
    fade_out: ?i64 = null,
    layer: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fade_out = "fadeOut",
            .layer = "layer",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticImageActivateScheduleActionSettings = struct {
    duration: ?i64 = null,
    fade_in: ?i64 = null,
    fade_out: ?i64 = null,
    height: ?i64 = null,
    image: InputLocation,
    imagex: ?i64 = null,
    imagey: ?i64 = null,
    layer: ?i64 = null,
    opacity: ?i64 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .fade_in = "fadeIn",
            .fade_out = "fadeOut",
            .height = "height",
            .image = "image",
            .imagex = "imageX",
            .imagey = "imageY",
            .layer = "layer",
            .opacity = "opacity",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35TimeSignalScheduleActionSettings = struct {
    scte35_descriptors: []Scte35Descriptor,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scte35_descriptors = "scte35Descriptors",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35Descriptor = struct {
    scte35_descriptor_settings: Scte35DescriptorSettings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scte35_descriptor_settings = "scte35DescriptorSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35DescriptorSettings = struct {
    segmentation_descriptor_scte35_descriptor_settings: Scte35SegmentationDescriptor,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .segmentation_descriptor_scte35_descriptor_settings = "segmentationDescriptorScte35DescriptorSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35SegmentationDescriptor = struct {
    delivery_restrictions: ?Scte35DeliveryRestrictions = null,
    segment_num: ?i64 = null,
    segmentation_cancel_indicator: []const u8,
    segmentation_duration: ?i64 = null,
    segmentation_event_id: i64,
    segmentation_type_id: ?i64 = null,
    segmentation_upid: ?[]const u8 = null,
    segmentation_upid_type: ?i64 = null,
    segments_expected: ?i64 = null,
    sub_segment_num: ?i64 = null,
    sub_segments_expected: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_restrictions = "deliveryRestrictions",
            .segment_num = "segmentNum",
            .segmentation_cancel_indicator = "segmentationCancelIndicator",
            .segmentation_duration = "segmentationDuration",
            .segmentation_event_id = "segmentationEventId",
            .segmentation_type_id = "segmentationTypeId",
            .segmentation_upid = "segmentationUpid",
            .segmentation_upid_type = "segmentationUpidType",
            .segments_expected = "segmentsExpected",
            .sub_segment_num = "subSegmentNum",
            .sub_segments_expected = "subSegmentsExpected",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35DeliveryRestrictions = struct {
    archive_allowed_flag: []const u8,
    device_restrictions: []const u8,
    no_regional_blackout_flag: []const u8,
    web_delivery_allowed_flag: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .archive_allowed_flag = "archiveAllowedFlag",
            .device_restrictions = "deviceRestrictions",
            .no_regional_blackout_flag = "noRegionalBlackoutFlag",
            .web_delivery_allowed_flag = "webDeliveryAllowedFlag",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35SpliceInsertScheduleActionSettings = struct {
    duration: ?i64 = null,
    splice_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .splice_event_id = "spliceEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35ReturnToNetworkScheduleActionSettings = struct {
    splice_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .splice_event_id = "spliceEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const Scte35InputScheduleActionSettings = struct {
    input_attachment_name_reference: ?[]const u8 = null,
    mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_attachment_name_reference = "inputAttachmentNameReference",
            .mode = "mode",
        };
        return @field(mappings, field_name);
    }
};

pub const PauseStateScheduleActionSettings = struct {
    pipelines: ?[]PipelinePauseStateSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipelines = "pipelines",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelinePauseStateSettings = struct {
    pipeline_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipeline_id = "pipelineId",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionGraphicsDeactivateScheduleActionSettings = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const MotionGraphicsActivateScheduleActionSettings = struct {
    duration: ?i64 = null,
    password_param: ?[]const u8 = null,
    url: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .password_param = "passwordParam",
            .url = "url",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSwitchScheduleActionSettings = struct {
    input_attachment_name_reference: []const u8,
    input_clipping_settings: ?InputClippingSettings = null,
    url_path: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_attachment_name_reference = "inputAttachmentNameReference",
            .input_clipping_settings = "inputClippingSettings",
            .url_path = "urlPath",
        };
        return @field(mappings, field_name);
    }
};

pub const InputClippingSettings = struct {
    input_timecode_source: []const u8,
    start_timecode: ?StartTimecode = null,
    stop_timecode: ?StopTimecode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_timecode_source = "inputTimecodeSource",
            .start_timecode = "startTimecode",
            .stop_timecode = "stopTimecode",
        };
        return @field(mappings, field_name);
    }
};

pub const StopTimecode = struct {
    last_frame_clipping_behavior: ?[]const u8 = null,
    timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_frame_clipping_behavior = "lastFrameClippingBehavior",
            .timecode = "timecode",
        };
        return @field(mappings, field_name);
    }
};

pub const StartTimecode = struct {
    timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timecode = "timecode",
        };
        return @field(mappings, field_name);
    }
};

pub const InputPrepareScheduleActionSettings = struct {
    input_attachment_name_reference: ?[]const u8 = null,
    input_clipping_settings: ?InputClippingSettings = null,
    url_path: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_attachment_name_reference = "inputAttachmentNameReference",
            .input_clipping_settings = "inputClippingSettings",
            .url_path = "urlPath",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsTimedMetadataScheduleActionSettings = struct {
    id3: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id3 = "id3",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsId3SegmentTaggingScheduleActionSettings = struct {
    tag: ?[]const u8 = null,
    id3: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag = "tag",
            .id3 = "id3",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchSuccessfulResultModel = struct {
    arn: ?[]const u8 = null,
    id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .id = "id",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchFailedResultModel = struct {
    arn: ?[]const u8 = null,
    code: ?[]const u8 = null,
    id: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .code = "code",
            .id = "id",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};
