const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-12-01";
pub const sdk_id: []const u8 = "Pinpoint";
pub const arn_namespace: ?[]const u8 = "mobiletargeting";
pub const endpoint_prefix: []const u8 = "pinpoint";
pub const sigv4_name: []const u8 = "mobiletargeting";
pub const name: []const u8 = "Pinpoint";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-12-01",
    sdk_id: []const u8 = "Pinpoint",
    arn_namespace: ?[]const u8 = "mobiletargeting",
    endpoint_prefix: []const u8 = "pinpoint",
    sigv4_name: []const u8 = "mobiletargeting",
    name: []const u8 = "Pinpoint",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApp",
    Request: type = struct {
        create_application_request: struct {
            name: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "create_application_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_application_request = "CreateApplicationRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app) } {
            return .{ .service_metadata = service_metadata, .action = create_app };
        }
    },
    Response: type = struct {
        application_response: ApplicationResponse,

        pub const http_payload: []const u8 = "application_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_response = "ApplicationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_campaign: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/campaigns",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCampaign",
    Request: type = struct {
        application_id: []const u8,
        write_campaign_request: WriteCampaignRequest,

        pub const http_payload: []const u8 = "write_campaign_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .write_campaign_request = "WriteCampaignRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_campaign) } {
            return .{ .service_metadata = service_metadata, .action = create_campaign };
        }
    },
    Response: type = struct {
        campaign_response: CampaignResponse,

        pub const http_payload: []const u8 = "campaign_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_response = "CampaignResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_email_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/templates/{TemplateName}/email",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEmailTemplate",
    Request: type = struct {
        email_template_request: EmailTemplateRequest,
        template_name: []const u8,

        pub const http_payload: []const u8 = "email_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_template_request = "EmailTemplateRequest",
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_email_template) } {
            return .{ .service_metadata = service_metadata, .action = create_email_template };
        }
    },
    Response: type = struct {
        create_template_message_body: CreateTemplateMessageBody,

        pub const http_payload: []const u8 = "create_template_message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_template_message_body = "CreateTemplateMessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const create_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/jobs/export",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateExportJob",
    Request: type = struct {
        application_id: []const u8,
        export_job_request: struct {
            role_arn: []const u8,
            s3_url_prefix: []const u8,
            segment_id: ?[]const u8 = null,
            segment_version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_arn = "RoleArn",
                    .s3_url_prefix = "S3UrlPrefix",
                    .segment_id = "SegmentId",
                    .segment_version = "SegmentVersion",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "export_job_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .export_job_request = "ExportJobRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_export_job };
        }
    },
    Response: type = struct {
        export_job_response: ExportJobResponse,

        pub const http_payload: []const u8 = "export_job_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_job_response = "ExportJobResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/jobs/import",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateImportJob",
    Request: type = struct {
        application_id: []const u8,
        import_job_request: struct {
            define_segment: ?bool = null,
            external_id: ?[]const u8 = null,
            format: []const u8,
            register_endpoints: ?bool = null,
            role_arn: []const u8,
            s3_url: []const u8,
            segment_id: ?[]const u8 = null,
            segment_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .define_segment = "DefineSegment",
                    .external_id = "ExternalId",
                    .format = "Format",
                    .register_endpoints = "RegisterEndpoints",
                    .role_arn = "RoleArn",
                    .s3_url = "S3Url",
                    .segment_id = "SegmentId",
                    .segment_name = "SegmentName",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "import_job_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .import_job_request = "ImportJobRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_import_job };
        }
    },
    Response: type = struct {
        import_job_response: ImportJobResponse,

        pub const http_payload: []const u8 = "import_job_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_job_response = "ImportJobResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_in_app_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/templates/{TemplateName}/inapp",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateInAppTemplate",
    Request: type = struct {
        in_app_template_request: InAppTemplateRequest,
        template_name: []const u8,

        pub const http_payload: []const u8 = "in_app_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .in_app_template_request = "InAppTemplateRequest",
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_in_app_template) } {
            return .{ .service_metadata = service_metadata, .action = create_in_app_template };
        }
    },
    Response: type = struct {
        template_create_message_body: struct {
            arn: ?[]const u8 = null,
            message: ?[]const u8 = null,
            request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .message = "Message",
                    .request_id = "RequestID",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "template_create_message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_create_message_body = "TemplateCreateMessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const create_journey: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/journeys",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateJourney",
    Request: type = struct {
        application_id: []const u8,
        write_journey_request: WriteJourneyRequest,

        pub const http_payload: []const u8 = "write_journey_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .write_journey_request = "WriteJourneyRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_journey) } {
            return .{ .service_metadata = service_metadata, .action = create_journey };
        }
    },
    Response: type = struct {
        journey_response: JourneyResponse,

        pub const http_payload: []const u8 = "journey_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_response = "JourneyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_push_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/templates/{TemplateName}/push",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePushTemplate",
    Request: type = struct {
        push_notification_template_request: PushNotificationTemplateRequest,
        template_name: []const u8,

        pub const http_payload: []const u8 = "push_notification_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .push_notification_template_request = "PushNotificationTemplateRequest",
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_push_template) } {
            return .{ .service_metadata = service_metadata, .action = create_push_template };
        }
    },
    Response: type = struct {
        create_template_message_body: CreateTemplateMessageBody,

        pub const http_payload: []const u8 = "create_template_message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_template_message_body = "CreateTemplateMessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const create_recommender_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/recommenders",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRecommenderConfiguration",
    Request: type = struct {
        create_recommender_configuration: struct {
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            description: ?[]const u8 = null,
            name: ?[]const u8 = null,
            recommendation_provider_id_type: ?[]const u8 = null,
            recommendation_provider_role_arn: []const u8,
            recommendation_provider_uri: []const u8,
            recommendation_transformer_uri: ?[]const u8 = null,
            recommendations_display_name: ?[]const u8 = null,
            recommendations_per_message: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attributes = "Attributes",
                    .description = "Description",
                    .name = "Name",
                    .recommendation_provider_id_type = "RecommendationProviderIdType",
                    .recommendation_provider_role_arn = "RecommendationProviderRoleArn",
                    .recommendation_provider_uri = "RecommendationProviderUri",
                    .recommendation_transformer_uri = "RecommendationTransformerUri",
                    .recommendations_display_name = "RecommendationsDisplayName",
                    .recommendations_per_message = "RecommendationsPerMessage",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "create_recommender_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_recommender_configuration = "CreateRecommenderConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recommender_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_recommender_configuration };
        }
    },
    Response: type = struct {
        recommender_configuration_response: RecommenderConfigurationResponse,

        pub const http_payload: []const u8 = "recommender_configuration_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_configuration_response = "RecommenderConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_segment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/segments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSegment",
    Request: type = struct {
        application_id: []const u8,
        write_segment_request: WriteSegmentRequest,

        pub const http_payload: []const u8 = "write_segment_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .write_segment_request = "WriteSegmentRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_segment) } {
            return .{ .service_metadata = service_metadata, .action = create_segment };
        }
    },
    Response: type = struct {
        segment_response: SegmentResponse,

        pub const http_payload: []const u8 = "segment_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segment_response = "SegmentResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const create_sms_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/templates/{TemplateName}/sms",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSmsTemplate",
    Request: type = struct {
        sms_template_request: SMSTemplateRequest,
        template_name: []const u8,

        pub const http_payload: []const u8 = "sms_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_template_request = "SMSTemplateRequest",
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sms_template) } {
            return .{ .service_metadata = service_metadata, .action = create_sms_template };
        }
    },
    Response: type = struct {
        create_template_message_body: CreateTemplateMessageBody,

        pub const http_payload: []const u8 = "create_template_message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_template_message_body = "CreateTemplateMessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const create_voice_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/templates/{TemplateName}/voice",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceTemplate",
    Request: type = struct {
        template_name: []const u8,
        voice_template_request: VoiceTemplateRequest,

        pub const http_payload: []const u8 = "voice_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .voice_template_request = "VoiceTemplateRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_template) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_template };
        }
    },
    Response: type = struct {
        create_template_message_body: CreateTemplateMessageBody,

        pub const http_payload: []const u8 = "create_template_message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_template_message_body = "CreateTemplateMessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const delete_adm_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/adm",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAdmChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_adm_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_adm_channel };
        }
    },
    Response: type = struct {
        adm_channel_response: ADMChannelResponse,

        pub const http_payload: []const u8 = "adm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adm_channel_response = "ADMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_apns_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/apns",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApnsChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_apns_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_apns_channel };
        }
    },
    Response: type = struct {
        apns_channel_response: APNSChannelResponse,

        pub const http_payload: []const u8 = "apns_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_channel_response = "APNSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_apns_sandbox_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApnsSandboxChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_apns_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_apns_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_sandbox_channel_response: APNSSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_sandbox_channel_response = "APNSSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_apns_voip_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApnsVoipChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_apns_voip_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_apns_voip_channel };
        }
    },
    Response: type = struct {
        apns_voip_channel_response: APNSVoipChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_channel_response = "APNSVoipChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_apns_voip_sandbox_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApnsVoipSandboxChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_apns_voip_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_apns_voip_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_voip_sandbox_channel_response: APNSVoipSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_sandbox_channel_response = "APNSVoipSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_app: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApp",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app) } {
            return .{ .service_metadata = service_metadata, .action = delete_app };
        }
    },
    Response: type = struct {
        application_response: ApplicationResponse,

        pub const http_payload: []const u8 = "application_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_response = "ApplicationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_baidu_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/baidu",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBaiduChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_baidu_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_baidu_channel };
        }
    },
    Response: type = struct {
        baidu_channel_response: BaiduChannelResponse,

        pub const http_payload: []const u8 = "baidu_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baidu_channel_response = "BaiduChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_campaign: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCampaign",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_campaign) } {
            return .{ .service_metadata = service_metadata, .action = delete_campaign };
        }
    },
    Response: type = struct {
        campaign_response: CampaignResponse,

        pub const http_payload: []const u8 = "campaign_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_response = "CampaignResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_email_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/email",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEmailChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_channel };
        }
    },
    Response: type = struct {
        email_channel_response: EmailChannelResponse,

        pub const http_payload: []const u8 = "email_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_channel_response = "EmailChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_email_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/templates/{TemplateName}/email",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/endpoints/{EndpointId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        application_id: []const u8,
        endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {
        endpoint_response: EndpointResponse,

        pub const http_payload: []const u8 = "endpoint_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_response = "EndpointResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_event_stream: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/eventstream",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEventStream",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_stream };
        }
    },
    Response: type = struct {
        event_stream: EventStream,

        pub const http_payload: []const u8 = "event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_stream = "EventStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_gcm_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/gcm",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGcmChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_gcm_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_gcm_channel };
        }
    },
    Response: type = struct {
        gcm_channel_response: GCMChannelResponse,

        pub const http_payload: []const u8 = "gcm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gcm_channel_response = "GCMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_in_app_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/templates/{TemplateName}/inapp",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteInAppTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_in_app_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_in_app_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_journey: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJourney",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_journey) } {
            return .{ .service_metadata = service_metadata, .action = delete_journey };
        }
    },
    Response: type = struct {
        journey_response: JourneyResponse,

        pub const http_payload: []const u8 = "journey_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_response = "JourneyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_push_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/templates/{TemplateName}/push",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePushTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_push_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_push_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_recommender_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/recommenders/{RecommenderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecommenderConfiguration",
    Request: type = struct {
        recommender_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_id = "RecommenderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recommender_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_recommender_configuration };
        }
    },
    Response: type = struct {
        recommender_configuration_response: RecommenderConfigurationResponse,

        pub const http_payload: []const u8 = "recommender_configuration_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_configuration_response = "RecommenderConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_segment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSegment",
    Request: type = struct {
        application_id: []const u8,
        segment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .segment_id = "SegmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_segment) } {
            return .{ .service_metadata = service_metadata, .action = delete_segment };
        }
    },
    Response: type = struct {
        segment_response: SegmentResponse,

        pub const http_payload: []const u8 = "segment_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segment_response = "SegmentResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_sms_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/sms",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSmsChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sms_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_sms_channel };
        }
    },
    Response: type = struct {
        sms_channel_response: SMSChannelResponse,

        pub const http_payload: []const u8 = "sms_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_channel_response = "SMSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_sms_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/templates/{TemplateName}/sms",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteSmsTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sms_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_sms_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_user_endpoints: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/users/{UserId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteUserEndpoints",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_endpoints };
        }
    },
    Response: type = struct {
        endpoints_response: EndpointsResponse,

        pub const http_payload: []const u8 = "endpoints_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints_response = "EndpointsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_voice_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apps/{ApplicationId}/channels/voice",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVoiceChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_channel };
        }
    },
    Response: type = struct {
        voice_channel_response: VoiceChannelResponse,

        pub const http_payload: []const u8 = "voice_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_channel_response = "VoiceChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const delete_voice_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/templates/{TemplateName}/voice",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteVoiceTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_adm_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/adm",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAdmChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_adm_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_adm_channel };
        }
    },
    Response: type = struct {
        adm_channel_response: ADMChannelResponse,

        pub const http_payload: []const u8 = "adm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adm_channel_response = "ADMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_apns_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/apns",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApnsChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apns_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_apns_channel };
        }
    },
    Response: type = struct {
        apns_channel_response: APNSChannelResponse,

        pub const http_payload: []const u8 = "apns_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_channel_response = "APNSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_apns_sandbox_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApnsSandboxChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apns_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_apns_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_sandbox_channel_response: APNSSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_sandbox_channel_response = "APNSSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_apns_voip_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApnsVoipChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apns_voip_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_apns_voip_channel };
        }
    },
    Response: type = struct {
        apns_voip_channel_response: APNSVoipChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_channel_response = "APNSVoipChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_apns_voip_sandbox_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApnsVoipSandboxChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apns_voip_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_apns_voip_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_voip_sandbox_channel_response: APNSVoipSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_sandbox_channel_response = "APNSVoipSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_app: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApp",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app) } {
            return .{ .service_metadata = service_metadata, .action = get_app };
        }
    },
    Response: type = struct {
        application_response: ApplicationResponse,

        pub const http_payload: []const u8 = "application_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_response = "ApplicationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_application_date_range_kpi: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/kpis/daterange/{KpiName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplicationDateRangeKpi",
    Request: type = struct {
        application_id: []const u8,
        end_time: ?i64 = null,
        kpi_name: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub const http_query = .{
            .end_time = "end-time",
            .next_token = "next-token",
            .page_size = "page-size",
            .start_time = "start-time",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .end_time = "EndTime",
                .kpi_name = "KpiName",
                .next_token = "NextToken",
                .page_size = "PageSize",
                .start_time = "StartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_date_range_kpi) } {
            return .{ .service_metadata = service_metadata, .action = get_application_date_range_kpi };
        }
    },
    Response: type = struct {
        application_date_range_kpi_response: struct {
            application_id: []const u8,
            end_time: i64,
            kpi_name: []const u8,
            kpi_result: BaseKpiResult,
            next_token: ?[]const u8 = null,
            start_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .end_time = "EndTime",
                    .kpi_name = "KpiName",
                    .kpi_result = "KpiResult",
                    .next_token = "NextToken",
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "application_date_range_kpi_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_date_range_kpi_response = "ApplicationDateRangeKpiResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_application_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplicationSettings",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_application_settings };
        }
    },
    Response: type = struct {
        application_settings_resource: ApplicationSettingsResource,

        pub const http_payload: []const u8 = "application_settings_resource";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_settings_resource = "ApplicationSettingsResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_apps: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApps",
    Request: type = struct {
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_apps) } {
            return .{ .service_metadata = service_metadata, .action = get_apps };
        }
    },
    Response: type = struct {
        applications_response: struct {
            item: ?[]ApplicationResponse = null,
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "applications_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications_response = "ApplicationsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_baidu_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/baidu",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBaiduChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_baidu_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_baidu_channel };
        }
    },
    Response: type = struct {
        baidu_channel_response: BaiduChannelResponse,

        pub const http_payload: []const u8 = "baidu_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baidu_channel_response = "BaiduChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaign: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaign",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign };
        }
    },
    Response: type = struct {
        campaign_response: CampaignResponse,

        pub const http_payload: []const u8 = "campaign_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_response = "CampaignResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaign_activities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}/activities",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignActivities",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_activities) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_activities };
        }
    },
    Response: type = struct {
        activities_response: struct {
            item: []struct {
                application_id: []const u8,
                campaign_id: []const u8,
                end: ?[]const u8 = null,
                id: []const u8,
                result: ?[]const u8 = null,
                scheduled_start: ?[]const u8 = null,
                start: ?[]const u8 = null,
                state: ?[]const u8 = null,
                successful_endpoint_count: ?i64 = null,
                timezones_completed_count: ?i64 = null,
                timezones_total_count: ?i64 = null,
                total_endpoint_count: ?i64 = null,
                treatment_id: ?[]const u8 = null,
                execution_metrics: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .application_id = "ApplicationId",
                        .campaign_id = "CampaignId",
                        .end = "End",
                        .id = "Id",
                        .result = "Result",
                        .scheduled_start = "ScheduledStart",
                        .start = "Start",
                        .state = "State",
                        .successful_endpoint_count = "SuccessfulEndpointCount",
                        .timezones_completed_count = "TimezonesCompletedCount",
                        .timezones_total_count = "TimezonesTotalCount",
                        .total_endpoint_count = "TotalEndpointCount",
                        .treatment_id = "TreatmentId",
                        .execution_metrics = "ExecutionMetrics",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "execution_metrics", field_name))
                        return try serializeMap(self.execution_metrics, self.fieldNameFor("execution_metrics"), options, out_stream);
                    return false;
                }
            },
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "activities_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activities_response = "ActivitiesResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaign_date_range_kpi: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}/kpis/daterange/{KpiName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignDateRangeKpi",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,
        end_time: ?i64 = null,
        kpi_name: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub const http_query = .{
            .end_time = "end-time",
            .next_token = "next-token",
            .page_size = "page-size",
            .start_time = "start-time",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
                .end_time = "EndTime",
                .kpi_name = "KpiName",
                .next_token = "NextToken",
                .page_size = "PageSize",
                .start_time = "StartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_date_range_kpi) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_date_range_kpi };
        }
    },
    Response: type = struct {
        campaign_date_range_kpi_response: struct {
            application_id: []const u8,
            campaign_id: []const u8,
            end_time: i64,
            kpi_name: []const u8,
            kpi_result: BaseKpiResult,
            next_token: ?[]const u8 = null,
            start_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .campaign_id = "CampaignId",
                    .end_time = "EndTime",
                    .kpi_name = "KpiName",
                    .kpi_result = "KpiResult",
                    .next_token = "NextToken",
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "campaign_date_range_kpi_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_date_range_kpi_response = "CampaignDateRangeKpiResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaigns: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaigns",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaigns) } {
            return .{ .service_metadata = service_metadata, .action = get_campaigns };
        }
    },
    Response: type = struct {
        campaigns_response: CampaignsResponse,

        pub const http_payload: []const u8 = "campaigns_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaigns_response = "CampaignsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaign_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}/versions/{Version}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignVersion",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_version) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_version };
        }
    },
    Response: type = struct {
        campaign_response: CampaignResponse,

        pub const http_payload: []const u8 = "campaign_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_response = "CampaignResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_campaign_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCampaignVersions",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_campaign_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_campaign_versions };
        }
    },
    Response: type = struct {
        campaigns_response: CampaignsResponse,

        pub const http_payload: []const u8 = "campaigns_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaigns_response = "CampaignsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannels",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channels) } {
            return .{ .service_metadata = service_metadata, .action = get_channels };
        }
    },
    Response: type = struct {
        channels_response: struct {
            channels: []struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    application_id: ?[]const u8 = null,
                    creation_date: ?[]const u8 = null,
                    enabled: ?bool = null,
                    has_credential: ?bool = null,
                    id: ?[]const u8 = null,
                    is_archived: ?bool = null,
                    last_modified_by: ?[]const u8 = null,
                    last_modified_date: ?[]const u8 = null,
                    version: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .application_id = "ApplicationId",
                            .creation_date = "CreationDate",
                            .enabled = "Enabled",
                            .has_credential = "HasCredential",
                            .id = "Id",
                            .is_archived = "IsArchived",
                            .last_modified_by = "LastModifiedBy",
                            .last_modified_date = "LastModifiedDate",
                            .version = "Version",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channels = "Channels",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "channels", field_name))
                    return try serializeMap(self.channels, self.fieldNameFor("channels"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "channels_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels_response = "ChannelsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_email_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/email",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_email_channel };
        }
    },
    Response: type = struct {
        email_channel_response: EmailChannelResponse,

        pub const http_payload: []const u8 = "email_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_channel_response = "EmailChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_email_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/email",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_template) } {
            return .{ .service_metadata = service_metadata, .action = get_email_template };
        }
    },
    Response: type = struct {
        email_template_response: struct {
            arn: ?[]const u8 = null,
            creation_date: []const u8,
            default_substitutions: ?[]const u8 = null,
            html_part: ?[]const u8 = null,
            last_modified_date: []const u8,
            recommender_id: ?[]const u8 = null,
            subject: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_description: ?[]const u8 = null,
            template_name: []const u8,
            template_type: []const u8,
            text_part: ?[]const u8 = null,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .creation_date = "CreationDate",
                    .default_substitutions = "DefaultSubstitutions",
                    .html_part = "HtmlPart",
                    .last_modified_date = "LastModifiedDate",
                    .recommender_id = "RecommenderId",
                    .subject = "Subject",
                    .tags = "tags",
                    .template_description = "TemplateDescription",
                    .template_name = "TemplateName",
                    .template_type = "TemplateType",
                    .text_part = "TextPart",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "email_template_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_template_response = "EmailTemplateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/endpoints/{EndpointId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEndpoint",
    Request: type = struct {
        application_id: []const u8,
        endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_endpoint };
        }
    },
    Response: type = struct {
        endpoint_response: EndpointResponse,

        pub const http_payload: []const u8 = "endpoint_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_response = "EndpointResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_event_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/eventstream",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventStream",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_event_stream };
        }
    },
    Response: type = struct {
        event_stream: EventStream,

        pub const http_payload: []const u8 = "event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_stream = "EventStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_export_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/jobs/export/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExportJob",
    Request: type = struct {
        application_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export_job) } {
            return .{ .service_metadata = service_metadata, .action = get_export_job };
        }
    },
    Response: type = struct {
        export_job_response: ExportJobResponse,

        pub const http_payload: []const u8 = "export_job_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_job_response = "ExportJobResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_export_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/jobs/export",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExportJobs",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_export_jobs };
        }
    },
    Response: type = struct {
        export_jobs_response: ExportJobsResponse,

        pub const http_payload: []const u8 = "export_jobs_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_jobs_response = "ExportJobsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_gcm_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/gcm",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGcmChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_gcm_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_gcm_channel };
        }
    },
    Response: type = struct {
        gcm_channel_response: GCMChannelResponse,

        pub const http_payload: []const u8 = "gcm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gcm_channel_response = "GCMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/jobs/import/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImportJob",
    Request: type = struct {
        application_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import_job) } {
            return .{ .service_metadata = service_metadata, .action = get_import_job };
        }
    },
    Response: type = struct {
        import_job_response: ImportJobResponse,

        pub const http_payload: []const u8 = "import_job_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_job_response = "ImportJobResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/jobs/import",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImportJobs",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_import_jobs };
        }
    },
    Response: type = struct {
        import_jobs_response: ImportJobsResponse,

        pub const http_payload: []const u8 = "import_jobs_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_jobs_response = "ImportJobsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_in_app_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/endpoints/{EndpointId}/inappmessages",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInAppMessages",
    Request: type = struct {
        application_id: []const u8,
        endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .endpoint_id = "EndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_in_app_messages) } {
            return .{ .service_metadata = service_metadata, .action = get_in_app_messages };
        }
    },
    Response: type = struct {
        in_app_messages_response: struct {
            in_app_message_campaigns: ?[]struct {
                campaign_id: ?[]const u8 = null,
                daily_cap: ?i64 = null,
                in_app_message: ?struct {
                    content: ?[]InAppMessageContent = null,
                    custom_config: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    layout: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .content = "Content",
                            .custom_config = "CustomConfig",
                            .layout = "Layout",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "custom_config", field_name))
                            return try serializeMap(self.custom_config, self.fieldNameFor("custom_config"), options, out_stream);
                        return false;
                    }
                } = null,
                priority: ?i64 = null,
                schedule: ?struct {
                    end_date: ?[]const u8 = null,
                    event_filter: ?CampaignEventFilter = null,
                    quiet_time: ?QuietTime = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .end_date = "EndDate",
                            .event_filter = "EventFilter",
                            .quiet_time = "QuietTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                session_cap: ?i64 = null,
                total_cap: ?i64 = null,
                treatment_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .campaign_id = "CampaignId",
                        .daily_cap = "DailyCap",
                        .in_app_message = "InAppMessage",
                        .priority = "Priority",
                        .schedule = "Schedule",
                        .session_cap = "SessionCap",
                        .total_cap = "TotalCap",
                        .treatment_id = "TreatmentId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .in_app_message_campaigns = "InAppMessageCampaigns",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "in_app_messages_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .in_app_messages_response = "InAppMessagesResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_in_app_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/inapp",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInAppTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_in_app_template) } {
            return .{ .service_metadata = service_metadata, .action = get_in_app_template };
        }
    },
    Response: type = struct {
        in_app_template_response: struct {
            arn: ?[]const u8 = null,
            content: ?[]InAppMessageContent = null,
            creation_date: []const u8,
            custom_config: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            last_modified_date: []const u8,
            layout: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_description: ?[]const u8 = null,
            template_name: []const u8,
            template_type: []const u8,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .content = "Content",
                    .creation_date = "CreationDate",
                    .custom_config = "CustomConfig",
                    .last_modified_date = "LastModifiedDate",
                    .layout = "Layout",
                    .tags = "tags",
                    .template_description = "TemplateDescription",
                    .template_name = "TemplateName",
                    .template_type = "TemplateType",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "custom_config", field_name))
                    return try serializeMap(self.custom_config, self.fieldNameFor("custom_config"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "in_app_template_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .in_app_template_response = "InAppTemplateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourney",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey) } {
            return .{ .service_metadata = service_metadata, .action = get_journey };
        }
    },
    Response: type = struct {
        journey_response: JourneyResponse,

        pub const http_payload: []const u8 = "journey_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_response = "JourneyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_date_range_kpi: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/kpis/daterange/{KpiName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyDateRangeKpi",
    Request: type = struct {
        application_id: []const u8,
        end_time: ?i64 = null,
        journey_id: []const u8,
        kpi_name: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub const http_query = .{
            .end_time = "end-time",
            .next_token = "next-token",
            .page_size = "page-size",
            .start_time = "start-time",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .end_time = "EndTime",
                .journey_id = "JourneyId",
                .kpi_name = "KpiName",
                .next_token = "NextToken",
                .page_size = "PageSize",
                .start_time = "StartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_date_range_kpi) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_date_range_kpi };
        }
    },
    Response: type = struct {
        journey_date_range_kpi_response: struct {
            application_id: []const u8,
            end_time: i64,
            journey_id: []const u8,
            kpi_name: []const u8,
            kpi_result: BaseKpiResult,
            next_token: ?[]const u8 = null,
            start_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .end_time = "EndTime",
                    .journey_id = "JourneyId",
                    .kpi_name = "KpiName",
                    .kpi_result = "KpiResult",
                    .next_token = "NextToken",
                    .start_time = "StartTime",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "journey_date_range_kpi_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_date_range_kpi_response = "JourneyDateRangeKpiResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_execution_activity_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/activities/{JourneyActivityId}/execution-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyExecutionActivityMetrics",
    Request: type = struct {
        application_id: []const u8,
        journey_activity_id: []const u8,
        journey_id: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_activity_id = "JourneyActivityId",
                .journey_id = "JourneyId",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_execution_activity_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_execution_activity_metrics };
        }
    },
    Response: type = struct {
        journey_execution_activity_metrics_response: struct {
            activity_type: []const u8,
            application_id: []const u8,
            journey_activity_id: []const u8,
            journey_id: []const u8,
            last_evaluated_time: []const u8,
            metrics: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_type = "ActivityType",
                    .application_id = "ApplicationId",
                    .journey_activity_id = "JourneyActivityId",
                    .journey_id = "JourneyId",
                    .last_evaluated_time = "LastEvaluatedTime",
                    .metrics = "Metrics",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metrics", field_name))
                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "journey_execution_activity_metrics_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_execution_activity_metrics_response = "JourneyExecutionActivityMetricsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_execution_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/execution-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyExecutionMetrics",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_execution_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_execution_metrics };
        }
    },
    Response: type = struct {
        journey_execution_metrics_response: struct {
            application_id: []const u8,
            journey_id: []const u8,
            last_evaluated_time: []const u8,
            metrics: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .journey_id = "JourneyId",
                    .last_evaluated_time = "LastEvaluatedTime",
                    .metrics = "Metrics",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metrics", field_name))
                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "journey_execution_metrics_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_execution_metrics_response = "JourneyExecutionMetricsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_run_execution_activity_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/runs/{RunId}/activities/{JourneyActivityId}/execution-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyRunExecutionActivityMetrics",
    Request: type = struct {
        application_id: []const u8,
        journey_activity_id: []const u8,
        journey_id: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        run_id: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_activity_id = "JourneyActivityId",
                .journey_id = "JourneyId",
                .next_token = "NextToken",
                .page_size = "PageSize",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_run_execution_activity_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_run_execution_activity_metrics };
        }
    },
    Response: type = struct {
        journey_run_execution_activity_metrics_response: struct {
            activity_type: []const u8,
            application_id: []const u8,
            journey_activity_id: []const u8,
            journey_id: []const u8,
            last_evaluated_time: []const u8,
            metrics: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            run_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_type = "ActivityType",
                    .application_id = "ApplicationId",
                    .journey_activity_id = "JourneyActivityId",
                    .journey_id = "JourneyId",
                    .last_evaluated_time = "LastEvaluatedTime",
                    .metrics = "Metrics",
                    .run_id = "RunId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metrics", field_name))
                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "journey_run_execution_activity_metrics_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_run_execution_activity_metrics_response = "JourneyRunExecutionActivityMetricsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_run_execution_metrics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/runs/{RunId}/execution-metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyRunExecutionMetrics",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        run_id: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
                .next_token = "NextToken",
                .page_size = "PageSize",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_run_execution_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_run_execution_metrics };
        }
    },
    Response: type = struct {
        journey_run_execution_metrics_response: struct {
            application_id: []const u8,
            journey_id: []const u8,
            last_evaluated_time: []const u8,
            metrics: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            run_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .journey_id = "JourneyId",
                    .last_evaluated_time = "LastEvaluatedTime",
                    .metrics = "Metrics",
                    .run_id = "RunId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metrics", field_name))
                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "journey_run_execution_metrics_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_run_execution_metrics_response = "JourneyRunExecutionMetricsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_journey_runs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/runs",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJourneyRuns",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_journey_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_journey_runs };
        }
    },
    Response: type = struct {
        journey_runs_response: struct {
            item: []struct {
                creation_time: []const u8,
                last_update_time: []const u8,
                run_id: []const u8,
                status: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .creation_time = "CreationTime",
                        .last_update_time = "LastUpdateTime",
                        .run_id = "RunId",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            },
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "journey_runs_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_runs_response = "JourneyRunsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_push_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/push",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPushTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_push_template) } {
            return .{ .service_metadata = service_metadata, .action = get_push_template };
        }
    },
    Response: type = struct {
        push_notification_template_response: struct {
            adm: ?AndroidPushNotificationTemplate = null,
            apns: ?APNSPushNotificationTemplate = null,
            arn: ?[]const u8 = null,
            baidu: ?AndroidPushNotificationTemplate = null,
            creation_date: []const u8,
            default: ?DefaultPushNotificationTemplate = null,
            default_substitutions: ?[]const u8 = null,
            gcm: ?AndroidPushNotificationTemplate = null,
            last_modified_date: []const u8,
            recommender_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_description: ?[]const u8 = null,
            template_name: []const u8,
            template_type: []const u8,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .adm = "ADM",
                    .apns = "APNS",
                    .arn = "Arn",
                    .baidu = "Baidu",
                    .creation_date = "CreationDate",
                    .default = "Default",
                    .default_substitutions = "DefaultSubstitutions",
                    .gcm = "GCM",
                    .last_modified_date = "LastModifiedDate",
                    .recommender_id = "RecommenderId",
                    .tags = "tags",
                    .template_description = "TemplateDescription",
                    .template_name = "TemplateName",
                    .template_type = "TemplateType",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "push_notification_template_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .push_notification_template_response = "PushNotificationTemplateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_recommender_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/recommenders/{RecommenderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecommenderConfiguration",
    Request: type = struct {
        recommender_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_id = "RecommenderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommender_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_recommender_configuration };
        }
    },
    Response: type = struct {
        recommender_configuration_response: RecommenderConfigurationResponse,

        pub const http_payload: []const u8 = "recommender_configuration_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_configuration_response = "RecommenderConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_recommender_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/recommenders",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecommenderConfigurations",
    Request: type = struct {
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommender_configurations) } {
            return .{ .service_metadata = service_metadata, .action = get_recommender_configurations };
        }
    },
    Response: type = struct {
        list_recommender_configurations_response: struct {
            item: []RecommenderConfigurationResponse,
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "list_recommender_configurations_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .list_recommender_configurations_response = "ListRecommenderConfigurationsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegment",
    Request: type = struct {
        application_id: []const u8,
        segment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .segment_id = "SegmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment) } {
            return .{ .service_metadata = service_metadata, .action = get_segment };
        }
    },
    Response: type = struct {
        segment_response: SegmentResponse,

        pub const http_payload: []const u8 = "segment_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segment_response = "SegmentResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segment_export_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}/jobs/export",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegmentExportJobs",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        segment_id: []const u8,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .segment_id = "SegmentId",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_export_jobs };
        }
    },
    Response: type = struct {
        export_jobs_response: ExportJobsResponse,

        pub const http_payload: []const u8 = "export_jobs_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_jobs_response = "ExportJobsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segment_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}/jobs/import",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegmentImportJobs",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        segment_id: []const u8,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .segment_id = "SegmentId",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_import_jobs };
        }
    },
    Response: type = struct {
        import_jobs_response: ImportJobsResponse,

        pub const http_payload: []const u8 = "import_jobs_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_jobs_response = "ImportJobsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegments",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segments) } {
            return .{ .service_metadata = service_metadata, .action = get_segments };
        }
    },
    Response: type = struct {
        segments_response: SegmentsResponse,

        pub const http_payload: []const u8 = "segments_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segments_response = "SegmentsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segment_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}/versions/{Version}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegmentVersion",
    Request: type = struct {
        application_id: []const u8,
        segment_id: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .segment_id = "SegmentId",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_version) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_version };
        }
    },
    Response: type = struct {
        segment_response: SegmentResponse,

        pub const http_payload: []const u8 = "segment_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segment_response = "SegmentResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_segment_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSegmentVersions",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        segment_id: []const u8,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .segment_id = "SegmentId",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_versions };
        }
    },
    Response: type = struct {
        segments_response: SegmentsResponse,

        pub const http_payload: []const u8 = "segments_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segments_response = "SegmentsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_sms_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/sms",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSmsChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sms_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_sms_channel };
        }
    },
    Response: type = struct {
        sms_channel_response: SMSChannelResponse,

        pub const http_payload: []const u8 = "sms_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_channel_response = "SMSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_sms_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/sms",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSmsTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sms_template) } {
            return .{ .service_metadata = service_metadata, .action = get_sms_template };
        }
    },
    Response: type = struct {
        sms_template_response: struct {
            arn: ?[]const u8 = null,
            body: ?[]const u8 = null,
            creation_date: []const u8,
            default_substitutions: ?[]const u8 = null,
            last_modified_date: []const u8,
            recommender_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_description: ?[]const u8 = null,
            template_name: []const u8,
            template_type: []const u8,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .body = "Body",
                    .creation_date = "CreationDate",
                    .default_substitutions = "DefaultSubstitutions",
                    .last_modified_date = "LastModifiedDate",
                    .recommender_id = "RecommenderId",
                    .tags = "tags",
                    .template_description = "TemplateDescription",
                    .template_name = "TemplateName",
                    .template_type = "TemplateType",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "sms_template_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_template_response = "SMSTemplateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_user_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/users/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUserEndpoints",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = get_user_endpoints };
        }
    },
    Response: type = struct {
        endpoints_response: EndpointsResponse,

        pub const http_payload: []const u8 = "endpoints_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints_response = "EndpointsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_voice_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/channels/voice",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceChannel",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_channel) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_channel };
        }
    },
    Response: type = struct {
        voice_channel_response: VoiceChannelResponse,

        pub const http_payload: []const u8 = "voice_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_channel_response = "VoiceChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const get_voice_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/voice",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceTemplate",
    Request: type = struct {
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_template) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_template };
        }
    },
    Response: type = struct {
        voice_template_response: struct {
            arn: ?[]const u8 = null,
            body: ?[]const u8 = null,
            creation_date: []const u8,
            default_substitutions: ?[]const u8 = null,
            language_code: ?[]const u8 = null,
            last_modified_date: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            template_description: ?[]const u8 = null,
            template_name: []const u8,
            template_type: []const u8,
            version: ?[]const u8 = null,
            voice_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .body = "Body",
                    .creation_date = "CreationDate",
                    .default_substitutions = "DefaultSubstitutions",
                    .language_code = "LanguageCode",
                    .last_modified_date = "LastModifiedDate",
                    .tags = "tags",
                    .template_description = "TemplateDescription",
                    .template_name = "TemplateName",
                    .template_type = "TemplateType",
                    .version = "Version",
                    .voice_id = "VoiceId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "voice_template_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_template_response = "VoiceTemplateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const list_journeys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apps/{ApplicationId}/journeys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJourneys",
    Request: type = struct {
        application_id: []const u8,
        page_size: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "page-size",
            .token = "token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .page_size = "PageSize",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_journeys) } {
            return .{ .service_metadata = service_metadata, .action = list_journeys };
        }
    },
    Response: type = struct {
        journeys_response: struct {
            item: []JourneyResponse,
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "journeys_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journeys_response = "JourneysResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags_model: TagsModel,

        pub const http_payload: []const u8 = "tags_model";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags_model = "TagsModel",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        template_type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
            .prefix = "prefix",
            .template_type = "template-type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
                .prefix = "Prefix",
                .template_type = "TemplateType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_templates };
        }
    },
    Response: type = struct {
        templates_response: struct {
            item: []struct {
                arn: ?[]const u8 = null,
                creation_date: []const u8,
                default_substitutions: ?[]const u8 = null,
                last_modified_date: []const u8,
                tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                template_description: ?[]const u8 = null,
                template_name: []const u8,
                template_type: []const u8,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "Arn",
                        .creation_date = "CreationDate",
                        .default_substitutions = "DefaultSubstitutions",
                        .last_modified_date = "LastModifiedDate",
                        .tags = "tags",
                        .template_description = "TemplateDescription",
                        .template_name = "TemplateName",
                        .template_type = "TemplateType",
                        .version = "Version",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "tags", field_name))
                        return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                    return false;
                }
            },
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "templates_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .templates_response = "TemplatesResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const list_template_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/templates/{TemplateName}/{TemplateType}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateVersions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,
        template_name: []const u8,
        template_type: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .page_size = "page-size",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
                .template_name = "TemplateName",
                .template_type = "TemplateType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_template_versions };
        }
    },
    Response: type = struct {
        template_versions_response: struct {
            item: []struct {
                creation_date: []const u8,
                default_substitutions: ?[]const u8 = null,
                last_modified_date: []const u8,
                template_description: ?[]const u8 = null,
                template_name: []const u8,
                template_type: []const u8,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .creation_date = "CreationDate",
                        .default_substitutions = "DefaultSubstitutions",
                        .last_modified_date = "LastModifiedDate",
                        .template_description = "TemplateDescription",
                        .template_name = "TemplateName",
                        .template_type = "TemplateType",
                        .version = "Version",
                    };
                    return @field(mappings, field_name);
                }
            },
            message: ?[]const u8 = null,
            next_token: ?[]const u8 = null,
            request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                    .message = "Message",
                    .next_token = "NextToken",
                    .request_id = "RequestID",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "template_versions_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_versions_response = "TemplateVersionsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const phone_number_validate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/phone/number/validate",
        .success_code = 200,
    };

    action_name: []const u8 = "PhoneNumberValidate",
    Request: type = struct {
        number_validate_request: struct {
            iso_country_code: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iso_country_code = "IsoCountryCode",
                    .phone_number = "PhoneNumber",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "number_validate_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .number_validate_request = "NumberValidateRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(phone_number_validate) } {
            return .{ .service_metadata = service_metadata, .action = phone_number_validate };
        }
    },
    Response: type = struct {
        number_validate_response: struct {
            carrier: ?[]const u8 = null,
            city: ?[]const u8 = null,
            cleansed_phone_number_e164: ?[]const u8 = null,
            cleansed_phone_number_national: ?[]const u8 = null,
            country: ?[]const u8 = null,
            country_code_iso2: ?[]const u8 = null,
            country_code_numeric: ?[]const u8 = null,
            county: ?[]const u8 = null,
            original_country_code_iso2: ?[]const u8 = null,
            original_phone_number: ?[]const u8 = null,
            phone_type: ?[]const u8 = null,
            phone_type_code: ?i64 = null,
            timezone: ?[]const u8 = null,
            zip_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .carrier = "Carrier",
                    .city = "City",
                    .cleansed_phone_number_e164 = "CleansedPhoneNumberE164",
                    .cleansed_phone_number_national = "CleansedPhoneNumberNational",
                    .country = "Country",
                    .country_code_iso2 = "CountryCodeIso2",
                    .country_code_numeric = "CountryCodeNumeric",
                    .county = "County",
                    .original_country_code_iso2 = "OriginalCountryCodeIso2",
                    .original_phone_number = "OriginalPhoneNumber",
                    .phone_type = "PhoneType",
                    .phone_type_code = "PhoneTypeCode",
                    .timezone = "Timezone",
                    .zip_code = "ZipCode",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "number_validate_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .number_validate_response = "NumberValidateResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const put_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/events",
        .success_code = 202,
    };

    action_name: []const u8 = "PutEvents",
    Request: type = struct {
        application_id: []const u8,
        events_request: struct {
            batch_item: []struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    endpoint: struct {
                        address: ?[]const u8 = null,
                        attributes: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?[][]const u8 = null,
                        } = null,
                        channel_type: ?[]const u8 = null,
                        demographic: ?EndpointDemographic = null,
                        effective_date: ?[]const u8 = null,
                        endpoint_status: ?[]const u8 = null,
                        location: ?EndpointLocation = null,
                        metrics: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?f64 = null,
                        } = null,
                        opt_out: ?[]const u8 = null,
                        request_id: ?[]const u8 = null,
                        user: ?EndpointUser = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .address = "Address",
                                .attributes = "Attributes",
                                .channel_type = "ChannelType",
                                .demographic = "Demographic",
                                .effective_date = "EffectiveDate",
                                .endpoint_status = "EndpointStatus",
                                .location = "Location",
                                .metrics = "Metrics",
                                .opt_out = "OptOut",
                                .request_id = "RequestId",
                                .user = "User",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "attributes", field_name))
                                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                            if (std.mem.eql(u8, "metrics", field_name))
                                return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                            return false;
                        }
                    },
                    events: []struct {
                        key: ?[]const u8 = null,
                        value: ?struct {
                            app_package_name: ?[]const u8 = null,
                            app_title: ?[]const u8 = null,
                            app_version_code: ?[]const u8 = null,
                            attributes: ?[]struct {
                                key: ?[]const u8 = null,
                                value: ?[]const u8 = null,
                            } = null,
                            client_sdk_version: ?[]const u8 = null,
                            event_type: []const u8,
                            metrics: ?[]struct {
                                key: ?[]const u8 = null,
                                value: ?f64 = null,
                            } = null,
                            sdk_name: ?[]const u8 = null,
                            session: ?struct {
                                duration: ?i64 = null,
                                id: []const u8,
                                start_timestamp: []const u8,
                                stop_timestamp: ?[]const u8 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .duration = "Duration",
                                        .id = "Id",
                                        .start_timestamp = "StartTimestamp",
                                        .stop_timestamp = "StopTimestamp",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,
                            timestamp: []const u8,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .app_package_name = "AppPackageName",
                                    .app_title = "AppTitle",
                                    .app_version_code = "AppVersionCode",
                                    .attributes = "Attributes",
                                    .client_sdk_version = "ClientSdkVersion",
                                    .event_type = "EventType",
                                    .metrics = "Metrics",
                                    .sdk_name = "SdkName",
                                    .session = "Session",
                                    .timestamp = "Timestamp",
                                };
                                return @field(mappings, field_name);
                            }

                            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                                if (std.mem.eql(u8, "attributes", field_name))
                                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                                if (std.mem.eql(u8, "metrics", field_name))
                                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                                return false;
                            }
                        } = null,
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .endpoint = "Endpoint",
                            .events = "Events",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "events", field_name))
                            return try serializeMap(self.events, self.fieldNameFor("events"), options, out_stream);
                        return false;
                    }
                } = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_item = "BatchItem",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "batch_item", field_name))
                    return try serializeMap(self.batch_item, self.fieldNameFor("batch_item"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "events_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .events_request = "EventsRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_events) } {
            return .{ .service_metadata = service_metadata, .action = put_events };
        }
    },
    Response: type = struct {
        events_response: struct {
            results: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    endpoint_item_response: ?struct {
                        message: ?[]const u8 = null,
                        status_code: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .message = "Message",
                                .status_code = "StatusCode",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    events_item_response: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?struct {
                            message: ?[]const u8 = null,
                            status_code: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .message = "Message",
                                    .status_code = "StatusCode",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .endpoint_item_response = "EndpointItemResponse",
                            .events_item_response = "EventsItemResponse",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "events_item_response", field_name))
                            return try serializeMap(self.events_item_response, self.fieldNameFor("events_item_response"), options, out_stream);
                        return false;
                    }
                } = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .results = "Results",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "results", field_name))
                    return try serializeMap(self.results, self.fieldNameFor("results"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "events_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events_response = "EventsResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const put_event_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/eventstream",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEventStream",
    Request: type = struct {
        application_id: []const u8,
        write_event_stream: struct {
            destination_stream_arn: []const u8,
            role_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination_stream_arn = "DestinationStreamArn",
                    .role_arn = "RoleArn",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "write_event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .write_event_stream = "WriteEventStream",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_event_stream) } {
            return .{ .service_metadata = service_metadata, .action = put_event_stream };
        }
    },
    Response: type = struct {
        event_stream: EventStream,

        pub const http_payload: []const u8 = "event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_stream = "EventStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const remove_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/attributes/{AttributeType}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveAttributes",
    Request: type = struct {
        application_id: []const u8,
        attribute_type: []const u8,
        update_attributes_request: struct {
            blacklist: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blacklist = "Blacklist",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "update_attributes_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .attribute_type = "AttributeType",
                .update_attributes_request = "UpdateAttributesRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_attributes) } {
            return .{ .service_metadata = service_metadata, .action = remove_attributes };
        }
    },
    Response: type = struct {
        attributes_resource: struct {
            application_id: []const u8,
            attribute_type: []const u8,
            attributes: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .attribute_type = "AttributeType",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "attributes_resource";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes_resource = "AttributesResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const send_messages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/messages",
        .success_code = 200,
    };

    action_name: []const u8 = "SendMessages",
    Request: type = struct {
        application_id: []const u8,
        message_request: struct {
            addresses: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    body_override: ?[]const u8 = null,
                    channel_type: ?[]const u8 = null,
                    context: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    raw_content: ?[]const u8 = null,
                    substitutions: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[][]const u8 = null,
                    } = null,
                    title_override: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .body_override = "BodyOverride",
                            .channel_type = "ChannelType",
                            .context = "Context",
                            .raw_content = "RawContent",
                            .substitutions = "Substitutions",
                            .title_override = "TitleOverride",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "context", field_name))
                            return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
                        if (std.mem.eql(u8, "substitutions", field_name))
                            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
                        return false;
                    }
                } = null,
            } = null,
            context: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            endpoints: ?[]struct {
                key: ?[]const u8 = null,
                value: ?EndpointSendConfiguration = null,
            } = null,
            message_configuration: DirectMessageConfiguration,
            template_configuration: ?TemplateConfiguration = null,
            trace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .addresses = "Addresses",
                    .context = "Context",
                    .endpoints = "Endpoints",
                    .message_configuration = "MessageConfiguration",
                    .template_configuration = "TemplateConfiguration",
                    .trace_id = "TraceId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "addresses", field_name))
                    return try serializeMap(self.addresses, self.fieldNameFor("addresses"), options, out_stream);
                if (std.mem.eql(u8, "context", field_name))
                    return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
                if (std.mem.eql(u8, "endpoints", field_name))
                    return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "message_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .message_request = "MessageRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_messages) } {
            return .{ .service_metadata = service_metadata, .action = send_messages };
        }
    },
    Response: type = struct {
        message_response: MessageResponse,

        pub const http_payload: []const u8 = "message_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_response = "MessageResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const send_otp_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/otp",
        .success_code = 200,
    };

    action_name: []const u8 = "SendOTPMessage",
    Request: type = struct {
        application_id: []const u8,
        send_otp_message_request_parameters: struct {
            allowed_attempts: ?i64 = null,
            brand_name: []const u8,
            channel: []const u8,
            code_length: ?i64 = null,
            destination_identity: []const u8,
            entity_id: ?[]const u8 = null,
            language: ?[]const u8 = null,
            origination_identity: []const u8,
            reference_id: []const u8,
            template_id: ?[]const u8 = null,
            validity_period: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .allowed_attempts = "AllowedAttempts",
                    .brand_name = "BrandName",
                    .channel = "Channel",
                    .code_length = "CodeLength",
                    .destination_identity = "DestinationIdentity",
                    .entity_id = "EntityId",
                    .language = "Language",
                    .origination_identity = "OriginationIdentity",
                    .reference_id = "ReferenceId",
                    .template_id = "TemplateId",
                    .validity_period = "ValidityPeriod",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "send_otp_message_request_parameters";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .send_otp_message_request_parameters = "SendOTPMessageRequestParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_otp_message) } {
            return .{ .service_metadata = service_metadata, .action = send_otp_message };
        }
    },
    Response: type = struct {
        message_response: MessageResponse,

        pub const http_payload: []const u8 = "message_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_response = "MessageResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const send_users_messages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/users-messages",
        .success_code = 200,
    };

    action_name: []const u8 = "SendUsersMessages",
    Request: type = struct {
        application_id: []const u8,
        send_users_message_request: struct {
            context: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            message_configuration: DirectMessageConfiguration,
            template_configuration: ?TemplateConfiguration = null,
            trace_id: ?[]const u8 = null,
            users: []struct {
                key: ?[]const u8 = null,
                value: ?EndpointSendConfiguration = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .context = "Context",
                    .message_configuration = "MessageConfiguration",
                    .template_configuration = "TemplateConfiguration",
                    .trace_id = "TraceId",
                    .users = "Users",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "context", field_name))
                    return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
                if (std.mem.eql(u8, "users", field_name))
                    return try serializeMap(self.users, self.fieldNameFor("users"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "send_users_message_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .send_users_message_request = "SendUsersMessageRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_users_messages) } {
            return .{ .service_metadata = service_metadata, .action = send_users_messages };
        }
    },
    Response: type = struct {
        send_users_message_response: struct {
            application_id: []const u8,
            request_id: ?[]const u8 = null,
            result: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?EndpointMessageResult = null,
                } = null,


            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "value", field_name))
                    return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
                return false;
            }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .request_id = "RequestId",
                    .result = "Result",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "result", field_name))
                    return try serializeMap(self.result, self.fieldNameFor("result"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "send_users_message_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .send_users_message_response = "SendUsersMessageResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_model: TagsModel,

        pub const http_payload: []const u8 = "tags_model";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_model = "TagsModel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_adm_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/adm",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAdmChannel",
    Request: type = struct {
        adm_channel_request: struct {
            client_id: []const u8,
            client_secret: []const u8,
            enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_id = "ClientId",
                    .client_secret = "ClientSecret",
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        },
        application_id: []const u8,

        pub const http_payload: []const u8 = "adm_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adm_channel_request = "ADMChannelRequest",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_adm_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_adm_channel };
        }
    },
    Response: type = struct {
        adm_channel_response: ADMChannelResponse,

        pub const http_payload: []const u8 = "adm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adm_channel_response = "ADMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_apns_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/apns",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApnsChannel",
    Request: type = struct {
        apns_channel_request: struct {
            bundle_id: ?[]const u8 = null,
            certificate: ?[]const u8 = null,
            default_authentication_method: ?[]const u8 = null,
            enabled: ?bool = null,
            private_key: ?[]const u8 = null,
            team_id: ?[]const u8 = null,
            token_key: ?[]const u8 = null,
            token_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bundle_id = "BundleId",
                    .certificate = "Certificate",
                    .default_authentication_method = "DefaultAuthenticationMethod",
                    .enabled = "Enabled",
                    .private_key = "PrivateKey",
                    .team_id = "TeamId",
                    .token_key = "TokenKey",
                    .token_key_id = "TokenKeyId",
                };
                return @field(mappings, field_name);
            }
        },
        application_id: []const u8,

        pub const http_payload: []const u8 = "apns_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_channel_request = "APNSChannelRequest",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_apns_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_apns_channel };
        }
    },
    Response: type = struct {
        apns_channel_response: APNSChannelResponse,

        pub const http_payload: []const u8 = "apns_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_channel_response = "APNSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_apns_sandbox_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApnsSandboxChannel",
    Request: type = struct {
        apns_sandbox_channel_request: struct {
            bundle_id: ?[]const u8 = null,
            certificate: ?[]const u8 = null,
            default_authentication_method: ?[]const u8 = null,
            enabled: ?bool = null,
            private_key: ?[]const u8 = null,
            team_id: ?[]const u8 = null,
            token_key: ?[]const u8 = null,
            token_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bundle_id = "BundleId",
                    .certificate = "Certificate",
                    .default_authentication_method = "DefaultAuthenticationMethod",
                    .enabled = "Enabled",
                    .private_key = "PrivateKey",
                    .team_id = "TeamId",
                    .token_key = "TokenKey",
                    .token_key_id = "TokenKeyId",
                };
                return @field(mappings, field_name);
            }
        },
        application_id: []const u8,

        pub const http_payload: []const u8 = "apns_sandbox_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_sandbox_channel_request = "APNSSandboxChannelRequest",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_apns_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_apns_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_sandbox_channel_response: APNSSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_sandbox_channel_response = "APNSSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_apns_voip_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApnsVoipChannel",
    Request: type = struct {
        apns_voip_channel_request: struct {
            bundle_id: ?[]const u8 = null,
            certificate: ?[]const u8 = null,
            default_authentication_method: ?[]const u8 = null,
            enabled: ?bool = null,
            private_key: ?[]const u8 = null,
            team_id: ?[]const u8 = null,
            token_key: ?[]const u8 = null,
            token_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bundle_id = "BundleId",
                    .certificate = "Certificate",
                    .default_authentication_method = "DefaultAuthenticationMethod",
                    .enabled = "Enabled",
                    .private_key = "PrivateKey",
                    .team_id = "TeamId",
                    .token_key = "TokenKey",
                    .token_key_id = "TokenKeyId",
                };
                return @field(mappings, field_name);
            }
        },
        application_id: []const u8,

        pub const http_payload: []const u8 = "apns_voip_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_channel_request = "APNSVoipChannelRequest",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_apns_voip_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_apns_voip_channel };
        }
    },
    Response: type = struct {
        apns_voip_channel_response: APNSVoipChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_channel_response = "APNSVoipChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_apns_voip_sandbox_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/apns_voip_sandbox",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApnsVoipSandboxChannel",
    Request: type = struct {
        apns_voip_sandbox_channel_request: struct {
            bundle_id: ?[]const u8 = null,
            certificate: ?[]const u8 = null,
            default_authentication_method: ?[]const u8 = null,
            enabled: ?bool = null,
            private_key: ?[]const u8 = null,
            team_id: ?[]const u8 = null,
            token_key: ?[]const u8 = null,
            token_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bundle_id = "BundleId",
                    .certificate = "Certificate",
                    .default_authentication_method = "DefaultAuthenticationMethod",
                    .enabled = "Enabled",
                    .private_key = "PrivateKey",
                    .team_id = "TeamId",
                    .token_key = "TokenKey",
                    .token_key_id = "TokenKeyId",
                };
                return @field(mappings, field_name);
            }
        },
        application_id: []const u8,

        pub const http_payload: []const u8 = "apns_voip_sandbox_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_sandbox_channel_request = "APNSVoipSandboxChannelRequest",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_apns_voip_sandbox_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_apns_voip_sandbox_channel };
        }
    },
    Response: type = struct {
        apns_voip_sandbox_channel_response: APNSVoipSandboxChannelResponse,

        pub const http_payload: []const u8 = "apns_voip_sandbox_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apns_voip_sandbox_channel_response = "APNSVoipSandboxChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_application_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplicationSettings",
    Request: type = struct {
        application_id: []const u8,
        write_application_settings_request: struct {
            campaign_hook: ?CampaignHook = null,
            cloud_watch_metrics_enabled: ?bool = null,
            event_tagging_enabled: ?bool = null,
            limits: ?CampaignLimits = null,
            quiet_time: ?QuietTime = null,
            journey_limits: ?ApplicationSettingsJourneyLimits = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .campaign_hook = "CampaignHook",
                    .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
                    .event_tagging_enabled = "EventTaggingEnabled",
                    .limits = "Limits",
                    .quiet_time = "QuietTime",
                    .journey_limits = "JourneyLimits",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "write_application_settings_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .write_application_settings_request = "WriteApplicationSettingsRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_application_settings };
        }
    },
    Response: type = struct {
        application_settings_resource: ApplicationSettingsResource,

        pub const http_payload: []const u8 = "application_settings_resource";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_settings_resource = "ApplicationSettingsResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_baidu_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/baidu",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBaiduChannel",
    Request: type = struct {
        application_id: []const u8,
        baidu_channel_request: struct {
            api_key: []const u8,
            enabled: ?bool = null,
            secret_key: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_key = "ApiKey",
                    .enabled = "Enabled",
                    .secret_key = "SecretKey",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "baidu_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .baidu_channel_request = "BaiduChannelRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_baidu_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_baidu_channel };
        }
    },
    Response: type = struct {
        baidu_channel_response: BaiduChannelResponse,

        pub const http_payload: []const u8 = "baidu_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baidu_channel_response = "BaiduChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_campaign: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/campaigns/{CampaignId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCampaign",
    Request: type = struct {
        application_id: []const u8,
        campaign_id: []const u8,
        write_campaign_request: WriteCampaignRequest,

        pub const http_payload: []const u8 = "write_campaign_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .campaign_id = "CampaignId",
                .write_campaign_request = "WriteCampaignRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_campaign) } {
            return .{ .service_metadata = service_metadata, .action = update_campaign };
        }
    },
    Response: type = struct {
        campaign_response: CampaignResponse,

        pub const http_payload: []const u8 = "campaign_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_response = "CampaignResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_email_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/email",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEmailChannel",
    Request: type = struct {
        application_id: []const u8,
        email_channel_request: struct {
            configuration_set: ?[]const u8 = null,
            enabled: ?bool = null,
            from_address: []const u8,
            identity: []const u8,
            role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configuration_set = "ConfigurationSet",
                    .enabled = "Enabled",
                    .from_address = "FromAddress",
                    .identity = "Identity",
                    .role_arn = "RoleArn",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "email_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .email_channel_request = "EmailChannelRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_email_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_email_channel };
        }
    },
    Response: type = struct {
        email_channel_response: EmailChannelResponse,

        pub const http_payload: []const u8 = "email_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_channel_response = "EmailChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_email_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/email",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateEmailTemplate",
    Request: type = struct {
        create_new_version: ?bool = null,
        email_template_request: EmailTemplateRequest,
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .create_new_version = "create-new-version",
            .version = "version",
        };

        pub const http_payload: []const u8 = "email_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_new_version = "CreateNewVersion",
                .email_template_request = "EmailTemplateRequest",
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_email_template) } {
            return .{ .service_metadata = service_metadata, .action = update_email_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_endpoint: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/endpoints/{EndpointId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateEndpoint",
    Request: type = struct {
        application_id: []const u8,
        endpoint_id: []const u8,
        endpoint_request: struct {
            address: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            channel_type: ?[]const u8 = null,
            demographic: ?EndpointDemographic = null,
            effective_date: ?[]const u8 = null,
            endpoint_status: ?[]const u8 = null,
            location: ?EndpointLocation = null,
            metrics: ?[]struct {
                key: ?[]const u8 = null,
                value: ?f64 = null,
            } = null,
            opt_out: ?[]const u8 = null,
            request_id: ?[]const u8 = null,
            user: ?EndpointUser = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "Address",
                    .attributes = "Attributes",
                    .channel_type = "ChannelType",
                    .demographic = "Demographic",
                    .effective_date = "EffectiveDate",
                    .endpoint_status = "EndpointStatus",
                    .location = "Location",
                    .metrics = "Metrics",
                    .opt_out = "OptOut",
                    .request_id = "RequestId",
                    .user = "User",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                if (std.mem.eql(u8, "metrics", field_name))
                    return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "endpoint_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .endpoint_id = "EndpointId",
                .endpoint_request = "EndpointRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_endpoint };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_endpoints_batch: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/endpoints",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateEndpointsBatch",
    Request: type = struct {
        application_id: []const u8,
        endpoint_batch_request: struct {
            item: []struct {
                address: ?[]const u8 = null,
                attributes: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[][]const u8 = null,
                } = null,
                channel_type: ?[]const u8 = null,
                demographic: ?EndpointDemographic = null,
                effective_date: ?[]const u8 = null,
                endpoint_status: ?[]const u8 = null,
                id: ?[]const u8 = null,
                location: ?EndpointLocation = null,
                metrics: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?f64 = null,
                } = null,
                opt_out: ?[]const u8 = null,
                request_id: ?[]const u8 = null,
                user: ?EndpointUser = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .address = "Address",
                        .attributes = "Attributes",
                        .channel_type = "ChannelType",
                        .demographic = "Demographic",
                        .effective_date = "EffectiveDate",
                        .endpoint_status = "EndpointStatus",
                        .id = "Id",
                        .location = "Location",
                        .metrics = "Metrics",
                        .opt_out = "OptOut",
                        .request_id = "RequestId",
                        .user = "User",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "attributes", field_name))
                        return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                    if (std.mem.eql(u8, "metrics", field_name))
                        return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
                    return false;
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item = "Item",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "endpoint_batch_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .endpoint_batch_request = "EndpointBatchRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_endpoints_batch) } {
            return .{ .service_metadata = service_metadata, .action = update_endpoints_batch };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_gcm_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/gcm",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGcmChannel",
    Request: type = struct {
        application_id: []const u8,
        gcm_channel_request: struct {
            api_key: ?[]const u8 = null,
            default_authentication_method: ?[]const u8 = null,
            enabled: ?bool = null,
            service_json: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .api_key = "ApiKey",
                    .default_authentication_method = "DefaultAuthenticationMethod",
                    .enabled = "Enabled",
                    .service_json = "ServiceJson",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "gcm_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .gcm_channel_request = "GCMChannelRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gcm_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_gcm_channel };
        }
    },
    Response: type = struct {
        gcm_channel_response: GCMChannelResponse,

        pub const http_payload: []const u8 = "gcm_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gcm_channel_response = "GCMChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_in_app_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/inapp",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateInAppTemplate",
    Request: type = struct {
        create_new_version: ?bool = null,
        in_app_template_request: InAppTemplateRequest,
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .create_new_version = "create-new-version",
            .version = "version",
        };

        pub const http_payload: []const u8 = "in_app_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_new_version = "CreateNewVersion",
                .in_app_template_request = "InAppTemplateRequest",
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_in_app_template) } {
            return .{ .service_metadata = service_metadata, .action = update_in_app_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_journey: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJourney",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,
        write_journey_request: WriteJourneyRequest,

        pub const http_payload: []const u8 = "write_journey_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
                .write_journey_request = "WriteJourneyRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_journey) } {
            return .{ .service_metadata = service_metadata, .action = update_journey };
        }
    },
    Response: type = struct {
        journey_response: JourneyResponse,

        pub const http_payload: []const u8 = "journey_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_response = "JourneyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_journey_state: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/journeys/{JourneyId}/state",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJourneyState",
    Request: type = struct {
        application_id: []const u8,
        journey_id: []const u8,
        journey_state_request: struct {
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "journey_state_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .journey_id = "JourneyId",
                .journey_state_request = "JourneyStateRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_journey_state) } {
            return .{ .service_metadata = service_metadata, .action = update_journey_state };
        }
    },
    Response: type = struct {
        journey_response: JourneyResponse,

        pub const http_payload: []const u8 = "journey_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journey_response = "JourneyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_push_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/push",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdatePushTemplate",
    Request: type = struct {
        create_new_version: ?bool = null,
        push_notification_template_request: PushNotificationTemplateRequest,
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .create_new_version = "create-new-version",
            .version = "version",
        };

        pub const http_payload: []const u8 = "push_notification_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_new_version = "CreateNewVersion",
                .push_notification_template_request = "PushNotificationTemplateRequest",
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_push_template) } {
            return .{ .service_metadata = service_metadata, .action = update_push_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_recommender_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/recommenders/{RecommenderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecommenderConfiguration",
    Request: type = struct {
        recommender_id: []const u8,
        update_recommender_configuration: struct {
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            description: ?[]const u8 = null,
            name: ?[]const u8 = null,
            recommendation_provider_id_type: ?[]const u8 = null,
            recommendation_provider_role_arn: []const u8,
            recommendation_provider_uri: []const u8,
            recommendation_transformer_uri: ?[]const u8 = null,
            recommendations_display_name: ?[]const u8 = null,
            recommendations_per_message: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attributes = "Attributes",
                    .description = "Description",
                    .name = "Name",
                    .recommendation_provider_id_type = "RecommendationProviderIdType",
                    .recommendation_provider_role_arn = "RecommendationProviderRoleArn",
                    .recommendation_provider_uri = "RecommendationProviderUri",
                    .recommendation_transformer_uri = "RecommendationTransformerUri",
                    .recommendations_display_name = "RecommendationsDisplayName",
                    .recommendations_per_message = "RecommendationsPerMessage",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub const http_payload: []const u8 = "update_recommender_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_id = "RecommenderId",
                .update_recommender_configuration = "UpdateRecommenderConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recommender_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_recommender_configuration };
        }
    },
    Response: type = struct {
        recommender_configuration_response: RecommenderConfigurationResponse,

        pub const http_payload: []const u8 = "recommender_configuration_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_configuration_response = "RecommenderConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_segment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/segments/{SegmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSegment",
    Request: type = struct {
        application_id: []const u8,
        segment_id: []const u8,
        write_segment_request: WriteSegmentRequest,

        pub const http_payload: []const u8 = "write_segment_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .segment_id = "SegmentId",
                .write_segment_request = "WriteSegmentRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_segment) } {
            return .{ .service_metadata = service_metadata, .action = update_segment };
        }
    },
    Response: type = struct {
        segment_response: SegmentResponse,

        pub const http_payload: []const u8 = "segment_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .segment_response = "SegmentResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_sms_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/sms",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSmsChannel",
    Request: type = struct {
        application_id: []const u8,
        sms_channel_request: struct {
            enabled: ?bool = null,
            sender_id: ?[]const u8 = null,
            short_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enabled = "Enabled",
                    .sender_id = "SenderId",
                    .short_code = "ShortCode",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "sms_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .sms_channel_request = "SMSChannelRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sms_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_sms_channel };
        }
    },
    Response: type = struct {
        sms_channel_response: SMSChannelResponse,

        pub const http_payload: []const u8 = "sms_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sms_channel_response = "SMSChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_sms_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/sms",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSmsTemplate",
    Request: type = struct {
        create_new_version: ?bool = null,
        sms_template_request: SMSTemplateRequest,
        template_name: []const u8,
        version: ?[]const u8 = null,

        pub const http_query = .{
            .create_new_version = "create-new-version",
            .version = "version",
        };

        pub const http_payload: []const u8 = "sms_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_new_version = "CreateNewVersion",
                .sms_template_request = "SMSTemplateRequest",
                .template_name = "TemplateName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sms_template) } {
            return .{ .service_metadata = service_metadata, .action = update_sms_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_template_active_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/{TemplateType}/active-version",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplateActiveVersion",
    Request: type = struct {
        template_active_version_request: struct {
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        },
        template_name: []const u8,
        template_type: []const u8,

        pub const http_payload: []const u8 = "template_active_version_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_active_version_request = "TemplateActiveVersionRequest",
                .template_name = "TemplateName",
                .template_type = "TemplateType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template_active_version) } {
            return .{ .service_metadata = service_metadata, .action = update_template_active_version };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_voice_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/apps/{ApplicationId}/channels/voice",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVoiceChannel",
    Request: type = struct {
        application_id: []const u8,
        voice_channel_request: struct {
            enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "voice_channel_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .voice_channel_request = "VoiceChannelRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_channel };
        }
    },
    Response: type = struct {
        voice_channel_response: VoiceChannelResponse,

        pub const http_payload: []const u8 = "voice_channel_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_channel_response = "VoiceChannelResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const update_voice_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/templates/{TemplateName}/voice",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateVoiceTemplate",
    Request: type = struct {
        create_new_version: ?bool = null,
        template_name: []const u8,
        version: ?[]const u8 = null,
        voice_template_request: VoiceTemplateRequest,

        pub const http_query = .{
            .create_new_version = "create-new-version",
            .version = "version",
        };

        pub const http_payload: []const u8 = "voice_template_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_new_version = "CreateNewVersion",
                .template_name = "TemplateName",
                .version = "Version",
                .voice_template_request = "VoiceTemplateRequest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_template) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_template };
        }
    },
    Response: type = struct {
        message_body: MessageBody,

        pub const http_payload: []const u8 = "message_body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_body = "MessageBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};
pub const verify_otp_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apps/{ApplicationId}/verify-otp",
        .success_code = 200,
    };

    action_name: []const u8 = "VerifyOTPMessage",
    Request: type = struct {
        application_id: []const u8,
        verify_otp_message_request_parameters: struct {
            destination_identity: []const u8,
            otp: []const u8,
            reference_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination_identity = "DestinationIdentity",
                    .otp = "Otp",
                    .reference_id = "ReferenceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "verify_otp_message_request_parameters";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .verify_otp_message_request_parameters = "VerifyOTPMessageRequestParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_otp_message) } {
            return .{ .service_metadata = service_metadata, .action = verify_otp_message };
        }
    },
    Response: type = struct {
        verification_response: struct {
            valid: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .valid = "Valid",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "verification_response";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verification_response = "VerificationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        PayloadTooLarge,
        TooManyRequests,
    },
} = .{};

pub const MessageBody = struct {
    message: ?[]const u8 = null,
    request_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
            .request_id = "RequestID",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceTemplateRequest = struct {
    body: ?[]const u8 = null,
    default_substitutions: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_description: ?[]const u8 = null,
    voice_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .default_substitutions = "DefaultSubstitutions",
            .language_code = "LanguageCode",
            .tags = "tags",
            .template_description = "TemplateDescription",
            .voice_id = "VoiceId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const VoiceChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const SMSTemplateRequest = struct {
    body: ?[]const u8 = null,
    default_substitutions: ?[]const u8 = null,
    recommender_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .default_substitutions = "DefaultSubstitutions",
            .recommender_id = "RecommenderId",
            .tags = "tags",
            .template_description = "TemplateDescription",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const SMSChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    promotional_messages_per_second: ?i64 = null,
    sender_id: ?[]const u8 = null,
    short_code: ?[]const u8 = null,
    transactional_messages_per_second: ?i64 = null,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .promotional_messages_per_second = "PromotionalMessagesPerSecond",
            .sender_id = "SenderId",
            .short_code = "ShortCode",
            .transactional_messages_per_second = "TransactionalMessagesPerSecond",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentResponse = struct {
    application_id: []const u8,
    arn: []const u8,
    creation_date: []const u8,
    dimensions: ?SegmentDimensions = null,
    id: []const u8,
    import_definition: ?SegmentImportResource = null,
    last_modified_date: ?[]const u8 = null,
    name: ?[]const u8 = null,
    segment_groups: ?SegmentGroupList = null,
    segment_type: []const u8,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .arn = "Arn",
            .creation_date = "CreationDate",
            .dimensions = "Dimensions",
            .id = "Id",
            .import_definition = "ImportDefinition",
            .last_modified_date = "LastModifiedDate",
            .name = "Name",
            .segment_groups = "SegmentGroups",
            .segment_type = "SegmentType",
            .tags = "tags",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const SegmentGroupList = struct {
    groups: ?[]SegmentGroup = null,
    include: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .groups = "Groups",
            .include = "Include",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentGroup = struct {
    dimensions: ?[]SegmentDimensions = null,
    source_segments: ?[]SegmentReference = null,
    source_type: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .source_segments = "SourceSegments",
            .source_type = "SourceType",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentReference = struct {
    id: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentDimensions = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeDimension = null,
    } = null,
    behavior: ?SegmentBehaviors = null,
    demographic: ?SegmentDemographics = null,
    location: ?SegmentLocation = null,
    metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MetricDimension = null,
    } = null,
    user_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeDimension = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .behavior = "Behavior",
            .demographic = "Demographic",
            .location = "Location",
            .metrics = "Metrics",
            .user_attributes = "UserAttributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        if (std.mem.eql(u8, "metrics", field_name))
            return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
        if (std.mem.eql(u8, "user_attributes", field_name))
            return try serializeMap(self.user_attributes, self.fieldNameFor("user_attributes"), options, out_stream);
        return false;
    }
};

pub const AttributeDimension = struct {
    attribute_type: ?[]const u8 = null,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_type = "AttributeType",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDimension = struct {
    comparison_operator: []const u8,
    value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison_operator = "ComparisonOperator",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentLocation = struct {
    country: ?SetDimension = null,
    gps_point: ?GPSPointDimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country = "Country",
            .gps_point = "GPSPoint",
        };
        return @field(mappings, field_name);
    }
};

pub const GPSPointDimension = struct {
    coordinates: GPSCoordinates,
    range_in_kilometers: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .coordinates = "Coordinates",
            .range_in_kilometers = "RangeInKilometers",
        };
        return @field(mappings, field_name);
    }
};

pub const GPSCoordinates = struct {
    latitude: f64,
    longitude: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latitude = "Latitude",
            .longitude = "Longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const SetDimension = struct {
    dimension_type: ?[]const u8 = null,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_type = "DimensionType",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentDemographics = struct {
    app_version: ?SetDimension = null,
    channel: ?SetDimension = null,
    device_type: ?SetDimension = null,
    make: ?SetDimension = null,
    model: ?SetDimension = null,
    platform: ?SetDimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_version = "AppVersion",
            .channel = "Channel",
            .device_type = "DeviceType",
            .make = "Make",
            .model = "Model",
            .platform = "Platform",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentBehaviors = struct {
    recency: ?RecencyDimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recency = "Recency",
        };
        return @field(mappings, field_name);
    }
};

pub const RecencyDimension = struct {
    duration: []const u8,
    recency_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "Duration",
            .recency_type = "RecencyType",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentImportResource = struct {
    channel_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    external_id: []const u8,
    format: []const u8,
    role_arn: []const u8,
    s3_url: []const u8,
    size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_counts = "ChannelCounts",
            .external_id = "ExternalId",
            .format = "Format",
            .role_arn = "RoleArn",
            .s3_url = "S3Url",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "channel_counts", field_name))
            return try serializeMap(self.channel_counts, self.fieldNameFor("channel_counts"), options, out_stream);
        return false;
    }
};

pub const WriteSegmentRequest = struct {
    dimensions: ?SegmentDimensions = null,
    name: ?[]const u8 = null,
    segment_groups: ?SegmentGroupList = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .name = "Name",
            .segment_groups = "SegmentGroups",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RecommenderConfigurationResponse = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    creation_date: []const u8,
    description: ?[]const u8 = null,
    id: []const u8,
    last_modified_date: []const u8,
    name: ?[]const u8 = null,
    recommendation_provider_id_type: ?[]const u8 = null,
    recommendation_provider_role_arn: []const u8,
    recommendation_provider_uri: []const u8,
    recommendation_transformer_uri: ?[]const u8 = null,
    recommendations_display_name: ?[]const u8 = null,
    recommendations_per_message: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .creation_date = "CreationDate",
            .description = "Description",
            .id = "Id",
            .last_modified_date = "LastModifiedDate",
            .name = "Name",
            .recommendation_provider_id_type = "RecommendationProviderIdType",
            .recommendation_provider_role_arn = "RecommendationProviderRoleArn",
            .recommendation_provider_uri = "RecommendationProviderUri",
            .recommendation_transformer_uri = "RecommendationTransformerUri",
            .recommendations_display_name = "RecommendationsDisplayName",
            .recommendations_per_message = "RecommendationsPerMessage",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const PushNotificationTemplateRequest = struct {
    adm: ?AndroidPushNotificationTemplate = null,
    apns: ?APNSPushNotificationTemplate = null,
    baidu: ?AndroidPushNotificationTemplate = null,
    default: ?DefaultPushNotificationTemplate = null,
    default_substitutions: ?[]const u8 = null,
    gcm: ?AndroidPushNotificationTemplate = null,
    recommender_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adm = "ADM",
            .apns = "APNS",
            .baidu = "Baidu",
            .default = "Default",
            .default_substitutions = "DefaultSubstitutions",
            .gcm = "GCM",
            .recommender_id = "RecommenderId",
            .tags = "tags",
            .template_description = "TemplateDescription",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AndroidPushNotificationTemplate = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    image_icon_url: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    small_image_icon_url: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .image_icon_url = "ImageIconUrl",
            .image_url = "ImageUrl",
            .raw_content = "RawContent",
            .small_image_icon_url = "SmallImageIconUrl",
            .sound = "Sound",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultPushNotificationTemplate = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .sound = "Sound",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const APNSPushNotificationTemplate = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    media_url: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .media_url = "MediaUrl",
            .raw_content = "RawContent",
            .sound = "Sound",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyResponse = struct {
    activities: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Activity = null,
    } = null,
    application_id: []const u8,
    creation_date: ?[]const u8 = null,
    id: []const u8,
    last_modified_date: ?[]const u8 = null,
    limits: ?JourneyLimits = null,
    local_time: ?bool = null,
    name: []const u8,
    quiet_time: ?QuietTime = null,
    refresh_frequency: ?[]const u8 = null,
    schedule: ?JourneySchedule = null,
    start_activity: ?[]const u8 = null,
    start_condition: ?StartCondition = null,
    state: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    wait_for_quiet_time: ?bool = null,
    refresh_on_segment_update: ?bool = null,
    journey_channel_settings: ?JourneyChannelSettings = null,
    sending_schedule: ?bool = null,
    open_hours: ?OpenHours = null,
    closed_days: ?ClosedDays = null,
    timezone_estimation_methods: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activities = "Activities",
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .id = "Id",
            .last_modified_date = "LastModifiedDate",
            .limits = "Limits",
            .local_time = "LocalTime",
            .name = "Name",
            .quiet_time = "QuietTime",
            .refresh_frequency = "RefreshFrequency",
            .schedule = "Schedule",
            .start_activity = "StartActivity",
            .start_condition = "StartCondition",
            .state = "State",
            .tags = "tags",
            .wait_for_quiet_time = "WaitForQuietTime",
            .refresh_on_segment_update = "RefreshOnSegmentUpdate",
            .journey_channel_settings = "JourneyChannelSettings",
            .sending_schedule = "SendingSchedule",
            .open_hours = "OpenHours",
            .closed_days = "ClosedDays",
            .timezone_estimation_methods = "TimezoneEstimationMethods",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "activities", field_name))
            return try serializeMap(self.activities, self.fieldNameFor("activities"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ClosedDays = struct {
    email: ?[]ClosedDaysRule = null,
    sms: ?[]ClosedDaysRule = null,
    push: ?[]ClosedDaysRule = null,
    voice: ?[]ClosedDaysRule = null,
    custom: ?[]ClosedDaysRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .email = "EMAIL",
            .sms = "SMS",
            .push = "PUSH",
            .voice = "VOICE",
            .custom = "CUSTOM",
        };
        return @field(mappings, field_name);
    }
};

pub const ClosedDaysRule = struct {
    name: ?[]const u8 = null,
    start_date_time: ?[]const u8 = null,
    end_date_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .start_date_time = "StartDateTime",
            .end_date_time = "EndDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenHours = struct {
    email: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]OpenHoursRule = null,
    } = null,
    sms: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]OpenHoursRule = null,
    } = null,
    push: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]OpenHoursRule = null,
    } = null,
    voice: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]OpenHoursRule = null,
    } = null,
    custom: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]OpenHoursRule = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .email = "EMAIL",
            .sms = "SMS",
            .push = "PUSH",
            .voice = "VOICE",
            .custom = "CUSTOM",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "email", field_name))
            return try serializeMap(self.email, self.fieldNameFor("email"), options, out_stream);
        if (std.mem.eql(u8, "sms", field_name))
            return try serializeMap(self.sms, self.fieldNameFor("sms"), options, out_stream);
        if (std.mem.eql(u8, "push", field_name))
            return try serializeMap(self.push, self.fieldNameFor("push"), options, out_stream);
        if (std.mem.eql(u8, "voice", field_name))
            return try serializeMap(self.voice, self.fieldNameFor("voice"), options, out_stream);
        if (std.mem.eql(u8, "custom", field_name))
            return try serializeMap(self.custom, self.fieldNameFor("custom"), options, out_stream);
        return false;
    }
};

pub const OpenHoursRule = struct {
    start_time: ?[]const u8 = null,
    end_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyChannelSettings = struct {
    connect_campaign_arn: ?[]const u8 = null,
    connect_campaign_execution_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connect_campaign_arn = "ConnectCampaignArn",
            .connect_campaign_execution_role_arn = "ConnectCampaignExecutionRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StartCondition = struct {
    description: ?[]const u8 = null,
    event_start_condition: ?EventStartCondition = null,
    segment_start_condition: ?SegmentCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .event_start_condition = "EventStartCondition",
            .segment_start_condition = "SegmentStartCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const SegmentCondition = struct {
    segment_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .segment_id = "SegmentId",
        };
        return @field(mappings, field_name);
    }
};

pub const EventStartCondition = struct {
    event_filter: ?EventFilter = null,
    segment_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_filter = "EventFilter",
            .segment_id = "SegmentId",
        };
        return @field(mappings, field_name);
    }
};

pub const EventFilter = struct {
    dimensions: EventDimensions,
    filter_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .filter_type = "FilterType",
        };
        return @field(mappings, field_name);
    }
};

pub const EventDimensions = struct {
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AttributeDimension = null,
    } = null,
    event_type: ?SetDimension = null,
    metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MetricDimension = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .event_type = "EventType",
            .metrics = "Metrics",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        if (std.mem.eql(u8, "metrics", field_name))
            return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
        return false;
    }
};

pub const JourneySchedule = struct {
    end_time: ?i64 = null,
    start_time: ?i64 = null,
    timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_time = "EndTime",
            .start_time = "StartTime",
            .timezone = "Timezone",
        };
        return @field(mappings, field_name);
    }
};

pub const QuietTime = struct {
    end: ?[]const u8 = null,
    start: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end = "End",
            .start = "Start",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyLimits = struct {
    daily_cap: ?i64 = null,
    endpoint_reentry_cap: ?i64 = null,
    messages_per_second: ?i64 = null,
    endpoint_reentry_interval: ?[]const u8 = null,
    timeframe_cap: ?JourneyTimeframeCap = null,
    total_cap: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .daily_cap = "DailyCap",
            .endpoint_reentry_cap = "EndpointReentryCap",
            .messages_per_second = "MessagesPerSecond",
            .endpoint_reentry_interval = "EndpointReentryInterval",
            .timeframe_cap = "TimeframeCap",
            .total_cap = "TotalCap",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyTimeframeCap = struct {
    cap: ?i64 = null,
    days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cap = "Cap",
            .days = "Days",
        };
        return @field(mappings, field_name);
    }
};

pub const Activity = struct {
    custom: ?CustomMessageActivity = null,
    conditional_split: ?ConditionalSplitActivity = null,
    description: ?[]const u8 = null,
    email: ?EmailMessageActivity = null,
    holdout: ?HoldoutActivity = null,
    multi_condition: ?MultiConditionalSplitActivity = null,
    push: ?PushMessageActivity = null,
    random_split: ?RandomSplitActivity = null,
    sms: ?SMSMessageActivity = null,
    wait: ?WaitActivity = null,
    contact_center: ?ContactCenterActivity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom = "CUSTOM",
            .conditional_split = "ConditionalSplit",
            .description = "Description",
            .email = "EMAIL",
            .holdout = "Holdout",
            .multi_condition = "MultiCondition",
            .push = "PUSH",
            .random_split = "RandomSplit",
            .sms = "SMS",
            .wait = "Wait",
            .contact_center = "ContactCenter",
        };
        return @field(mappings, field_name);
    }
};

pub const ContactCenterActivity = struct {
    next_activity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .next_activity = "NextActivity",
        };
        return @field(mappings, field_name);
    }
};

pub const WaitActivity = struct {
    next_activity: ?[]const u8 = null,
    wait_time: ?WaitTime = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .next_activity = "NextActivity",
            .wait_time = "WaitTime",
        };
        return @field(mappings, field_name);
    }
};

pub const WaitTime = struct {
    wait_for: ?[]const u8 = null,
    wait_until: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wait_for = "WaitFor",
            .wait_until = "WaitUntil",
        };
        return @field(mappings, field_name);
    }
};

pub const SMSMessageActivity = struct {
    message_config: ?JourneySMSMessage = null,
    next_activity: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    template_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_config = "MessageConfig",
            .next_activity = "NextActivity",
            .template_name = "TemplateName",
            .template_version = "TemplateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneySMSMessage = struct {
    message_type: ?[]const u8 = null,
    origination_number: ?[]const u8 = null,
    sender_id: ?[]const u8 = null,
    entity_id: ?[]const u8 = null,
    template_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_type = "MessageType",
            .origination_number = "OriginationNumber",
            .sender_id = "SenderId",
            .entity_id = "EntityId",
            .template_id = "TemplateId",
        };
        return @field(mappings, field_name);
    }
};

pub const RandomSplitActivity = struct {
    branches: ?[]RandomSplitEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branches = "Branches",
        };
        return @field(mappings, field_name);
    }
};

pub const RandomSplitEntry = struct {
    next_activity: ?[]const u8 = null,
    percentage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .next_activity = "NextActivity",
            .percentage = "Percentage",
        };
        return @field(mappings, field_name);
    }
};

pub const PushMessageActivity = struct {
    message_config: ?JourneyPushMessage = null,
    next_activity: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    template_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_config = "MessageConfig",
            .next_activity = "NextActivity",
            .template_name = "TemplateName",
            .template_version = "TemplateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyPushMessage = struct {
    time_to_live: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_to_live = "TimeToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiConditionalSplitActivity = struct {
    branches: ?[]MultiConditionalBranch = null,
    default_activity: ?[]const u8 = null,
    evaluation_wait_time: ?WaitTime = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .branches = "Branches",
            .default_activity = "DefaultActivity",
            .evaluation_wait_time = "EvaluationWaitTime",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiConditionalBranch = struct {
    condition: ?SimpleCondition = null,
    next_activity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .next_activity = "NextActivity",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleCondition = struct {
    event_condition: ?EventCondition = null,
    segment_condition: ?SegmentCondition = null,
    segment_dimensions: ?SegmentDimensions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_condition = "EventCondition",
            .segment_condition = "SegmentCondition",
            .segment_dimensions = "segmentDimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const EventCondition = struct {
    dimensions: ?EventDimensions = null,
    message_activity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .message_activity = "MessageActivity",
        };
        return @field(mappings, field_name);
    }
};

pub const HoldoutActivity = struct {
    next_activity: ?[]const u8 = null,
    percentage: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .next_activity = "NextActivity",
            .percentage = "Percentage",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailMessageActivity = struct {
    message_config: ?JourneyEmailMessage = null,
    next_activity: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    template_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_config = "MessageConfig",
            .next_activity = "NextActivity",
            .template_name = "TemplateName",
            .template_version = "TemplateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyEmailMessage = struct {
    from_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_address = "FromAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalSplitActivity = struct {
    condition: ?Condition = null,
    evaluation_wait_time: ?WaitTime = null,
    false_activity: ?[]const u8 = null,
    true_activity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .evaluation_wait_time = "EvaluationWaitTime",
            .false_activity = "FalseActivity",
            .true_activity = "TrueActivity",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    conditions: ?[]SimpleCondition = null,
    operator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditions = "Conditions",
            .operator = "Operator",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomMessageActivity = struct {
    delivery_uri: ?[]const u8 = null,
    endpoint_types: ?[][]const u8 = null,
    message_config: ?JourneyCustomMessage = null,
    next_activity: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    template_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_uri = "DeliveryUri",
            .endpoint_types = "EndpointTypes",
            .message_config = "MessageConfig",
            .next_activity = "NextActivity",
            .template_name = "TemplateName",
            .template_version = "TemplateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const JourneyCustomMessage = struct {
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const WriteJourneyRequest = struct {
    activities: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Activity = null,
    } = null,
    creation_date: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    limits: ?JourneyLimits = null,
    local_time: ?bool = null,
    name: []const u8,
    quiet_time: ?QuietTime = null,
    refresh_frequency: ?[]const u8 = null,
    schedule: ?JourneySchedule = null,
    start_activity: ?[]const u8 = null,
    start_condition: ?StartCondition = null,
    state: ?[]const u8 = null,
    wait_for_quiet_time: ?bool = null,
    refresh_on_segment_update: ?bool = null,
    journey_channel_settings: ?JourneyChannelSettings = null,
    sending_schedule: ?bool = null,
    open_hours: ?OpenHours = null,
    closed_days: ?ClosedDays = null,
    timezone_estimation_methods: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activities = "Activities",
            .creation_date = "CreationDate",
            .last_modified_date = "LastModifiedDate",
            .limits = "Limits",
            .local_time = "LocalTime",
            .name = "Name",
            .quiet_time = "QuietTime",
            .refresh_frequency = "RefreshFrequency",
            .schedule = "Schedule",
            .start_activity = "StartActivity",
            .start_condition = "StartCondition",
            .state = "State",
            .wait_for_quiet_time = "WaitForQuietTime",
            .refresh_on_segment_update = "RefreshOnSegmentUpdate",
            .journey_channel_settings = "JourneyChannelSettings",
            .sending_schedule = "SendingSchedule",
            .open_hours = "OpenHours",
            .closed_days = "ClosedDays",
            .timezone_estimation_methods = "TimezoneEstimationMethods",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "activities", field_name))
            return try serializeMap(self.activities, self.fieldNameFor("activities"), options, out_stream);
        return false;
    }
};

pub const InAppTemplateRequest = struct {
    content: ?[]InAppMessageContent = null,
    custom_config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    layout: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content = "Content",
            .custom_config = "CustomConfig",
            .layout = "Layout",
            .tags = "tags",
            .template_description = "TemplateDescription",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_config", field_name))
            return try serializeMap(self.custom_config, self.fieldNameFor("custom_config"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InAppMessageContent = struct {
    background_color: ?[]const u8 = null,
    body_config: ?InAppMessageBodyConfig = null,
    header_config: ?InAppMessageHeaderConfig = null,
    image_url: ?[]const u8 = null,
    primary_btn: ?InAppMessageButton = null,
    secondary_btn: ?InAppMessageButton = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .background_color = "BackgroundColor",
            .body_config = "BodyConfig",
            .header_config = "HeaderConfig",
            .image_url = "ImageUrl",
            .primary_btn = "PrimaryBtn",
            .secondary_btn = "SecondaryBtn",
        };
        return @field(mappings, field_name);
    }
};

pub const InAppMessageButton = struct {
    android: ?OverrideButtonConfiguration = null,
    default_config: ?DefaultButtonConfiguration = null,
    ios: ?OverrideButtonConfiguration = null,
    web: ?OverrideButtonConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .android = "Android",
            .default_config = "DefaultConfig",
            .ios = "IOS",
            .web = "Web",
        };
        return @field(mappings, field_name);
    }
};

pub const OverrideButtonConfiguration = struct {
    button_action: []const u8,
    link: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .button_action = "ButtonAction",
            .link = "Link",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultButtonConfiguration = struct {
    background_color: ?[]const u8 = null,
    border_radius: ?i64 = null,
    button_action: []const u8,
    link: ?[]const u8 = null,
    text: []const u8,
    text_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .background_color = "BackgroundColor",
            .border_radius = "BorderRadius",
            .button_action = "ButtonAction",
            .link = "Link",
            .text = "Text",
            .text_color = "TextColor",
        };
        return @field(mappings, field_name);
    }
};

pub const InAppMessageHeaderConfig = struct {
    alignment: []const u8,
    header: []const u8,
    text_color: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "Alignment",
            .header = "Header",
            .text_color = "TextColor",
        };
        return @field(mappings, field_name);
    }
};

pub const InAppMessageBodyConfig = struct {
    alignment: []const u8,
    body: []const u8,
    text_color: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "Alignment",
            .body = "Body",
            .text_color = "TextColor",
        };
        return @field(mappings, field_name);
    }
};

pub const GCMChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    credential: ?[]const u8 = null,
    default_authentication_method: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    has_fcm_service_credentials: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .credential = "Credential",
            .default_authentication_method = "DefaultAuthenticationMethod",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .has_fcm_service_credentials = "HasFcmServiceCredentials",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointUser = struct {
    user_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    user_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_attributes = "UserAttributes",
            .user_id = "UserId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_attributes", field_name))
            return try serializeMap(self.user_attributes, self.fieldNameFor("user_attributes"), options, out_stream);
        return false;
    }
};

pub const EndpointLocation = struct {
    city: ?[]const u8 = null,
    country: ?[]const u8 = null,
    latitude: ?f64 = null,
    longitude: ?f64 = null,
    postal_code: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city = "City",
            .country = "Country",
            .latitude = "Latitude",
            .longitude = "Longitude",
            .postal_code = "PostalCode",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointDemographic = struct {
    app_version: ?[]const u8 = null,
    locale: ?[]const u8 = null,
    make: ?[]const u8 = null,
    model: ?[]const u8 = null,
    model_version: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    platform_version: ?[]const u8 = null,
    timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_version = "AppVersion",
            .locale = "Locale",
            .make = "Make",
            .model = "Model",
            .model_version = "ModelVersion",
            .platform = "Platform",
            .platform_version = "PlatformVersion",
            .timezone = "Timezone",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailTemplateRequest = struct {
    default_substitutions: ?[]const u8 = null,
    html_part: ?[]const u8 = null,
    recommender_id: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_description: ?[]const u8 = null,
    text_part: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_substitutions = "DefaultSubstitutions",
            .html_part = "HtmlPart",
            .recommender_id = "RecommenderId",
            .subject = "Subject",
            .tags = "tags",
            .template_description = "TemplateDescription",
            .text_part = "TextPart",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EmailChannelResponse = struct {
    application_id: ?[]const u8 = null,
    configuration_set: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    enabled: ?bool = null,
    from_address: ?[]const u8 = null,
    has_credential: ?bool = null,
    id: ?[]const u8 = null,
    identity: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    messages_per_second: ?i64 = null,
    platform: []const u8,
    role_arn: ?[]const u8 = null,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .configuration_set = "ConfigurationSet",
            .creation_date = "CreationDate",
            .enabled = "Enabled",
            .from_address = "FromAddress",
            .has_credential = "HasCredential",
            .id = "Id",
            .identity = "Identity",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .messages_per_second = "MessagesPerSecond",
            .platform = "Platform",
            .role_arn = "RoleArn",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignResponse = struct {
    additional_treatments: ?[]TreatmentResource = null,
    application_id: []const u8,
    arn: []const u8,
    creation_date: []const u8,
    custom_delivery_configuration: ?CustomDeliveryConfiguration = null,
    default_state: ?CampaignState = null,
    description: ?[]const u8 = null,
    holdout_percent: ?i64 = null,
    hook: ?CampaignHook = null,
    id: []const u8,
    is_paused: ?bool = null,
    last_modified_date: []const u8,
    limits: ?CampaignLimits = null,
    message_configuration: ?MessageConfiguration = null,
    name: ?[]const u8 = null,
    schedule: ?Schedule = null,
    segment_id: []const u8,
    segment_version: i64,
    state: ?CampaignState = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_configuration: ?TemplateConfiguration = null,
    treatment_description: ?[]const u8 = null,
    treatment_name: ?[]const u8 = null,
    version: ?i64 = null,
    priority: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_treatments = "AdditionalTreatments",
            .application_id = "ApplicationId",
            .arn = "Arn",
            .creation_date = "CreationDate",
            .custom_delivery_configuration = "CustomDeliveryConfiguration",
            .default_state = "DefaultState",
            .description = "Description",
            .holdout_percent = "HoldoutPercent",
            .hook = "Hook",
            .id = "Id",
            .is_paused = "IsPaused",
            .last_modified_date = "LastModifiedDate",
            .limits = "Limits",
            .message_configuration = "MessageConfiguration",
            .name = "Name",
            .schedule = "Schedule",
            .segment_id = "SegmentId",
            .segment_version = "SegmentVersion",
            .state = "State",
            .tags = "tags",
            .template_configuration = "TemplateConfiguration",
            .treatment_description = "TreatmentDescription",
            .treatment_name = "TreatmentName",
            .version = "Version",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const TemplateConfiguration = struct {
    email_template: ?Template = null,
    push_template: ?Template = null,
    sms_template: ?Template = null,
    voice_template: ?Template = null,
    in_app_template: ?Template = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .email_template = "EmailTemplate",
            .push_template = "PushTemplate",
            .sms_template = "SMSTemplate",
            .voice_template = "VoiceTemplate",
            .in_app_template = "InAppTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const Template = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignState = struct {
    campaign_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .campaign_status = "CampaignStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    end_time: ?[]const u8 = null,
    event_filter: ?CampaignEventFilter = null,
    frequency: ?[]const u8 = null,
    is_local_time: ?bool = null,
    quiet_time: ?QuietTime = null,
    start_time: []const u8,
    timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_time = "EndTime",
            .event_filter = "EventFilter",
            .frequency = "Frequency",
            .is_local_time = "IsLocalTime",
            .quiet_time = "QuietTime",
            .start_time = "StartTime",
            .timezone = "Timezone",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignEventFilter = struct {
    dimensions: EventDimensions,
    filter_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .filter_type = "FilterType",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageConfiguration = struct {
    adm_message: ?Message = null,
    apns_message: ?Message = null,
    baidu_message: ?Message = null,
    custom_message: ?CampaignCustomMessage = null,
    default_message: ?Message = null,
    email_message: ?CampaignEmailMessage = null,
    gcm_message: ?Message = null,
    sms_message: ?CampaignSmsMessage = null,
    in_app_message: ?CampaignInAppMessage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adm_message = "ADMMessage",
            .apns_message = "APNSMessage",
            .baidu_message = "BaiduMessage",
            .custom_message = "CustomMessage",
            .default_message = "DefaultMessage",
            .email_message = "EmailMessage",
            .gcm_message = "GCMMessage",
            .sms_message = "SMSMessage",
            .in_app_message = "InAppMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignInAppMessage = struct {
    body: ?[]const u8 = null,
    content: ?[]InAppMessageContent = null,
    custom_config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    layout: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .content = "Content",
            .custom_config = "CustomConfig",
            .layout = "Layout",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_config", field_name))
            return try serializeMap(self.custom_config, self.fieldNameFor("custom_config"), options, out_stream);
        return false;
    }
};

pub const CampaignSmsMessage = struct {
    body: ?[]const u8 = null,
    message_type: ?[]const u8 = null,
    origination_number: ?[]const u8 = null,
    sender_id: ?[]const u8 = null,
    entity_id: ?[]const u8 = null,
    template_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .message_type = "MessageType",
            .origination_number = "OriginationNumber",
            .sender_id = "SenderId",
            .entity_id = "EntityId",
            .template_id = "TemplateId",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    image_icon_url: ?[]const u8 = null,
    image_small_icon_url: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    json_body: ?[]const u8 = null,
    media_url: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    silent_push: ?bool = null,
    time_to_live: ?i64 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .image_icon_url = "ImageIconUrl",
            .image_small_icon_url = "ImageSmallIconUrl",
            .image_url = "ImageUrl",
            .json_body = "JsonBody",
            .media_url = "MediaUrl",
            .raw_content = "RawContent",
            .silent_push = "SilentPush",
            .time_to_live = "TimeToLive",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignEmailMessage = struct {
    body: ?[]const u8 = null,
    from_address: ?[]const u8 = null,
    html_body: ?[]const u8 = null,
    title: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .from_address = "FromAddress",
            .html_body = "HtmlBody",
            .title = "Title",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignCustomMessage = struct {
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignLimits = struct {
    daily: ?i64 = null,
    maximum_duration: ?i64 = null,
    messages_per_second: ?i64 = null,
    total: ?i64 = null,
    session: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .daily = "Daily",
            .maximum_duration = "MaximumDuration",
            .messages_per_second = "MessagesPerSecond",
            .total = "Total",
            .session = "Session",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignHook = struct {
    lambda_function_name: ?[]const u8 = null,
    mode: ?[]const u8 = null,
    web_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function_name = "LambdaFunctionName",
            .mode = "Mode",
            .web_url = "WebUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDeliveryConfiguration = struct {
    delivery_uri: []const u8,
    endpoint_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_uri = "DeliveryUri",
            .endpoint_types = "EndpointTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const TreatmentResource = struct {
    custom_delivery_configuration: ?CustomDeliveryConfiguration = null,
    id: []const u8,
    message_configuration: ?MessageConfiguration = null,
    schedule: ?Schedule = null,
    size_percent: i64,
    state: ?CampaignState = null,
    template_configuration: ?TemplateConfiguration = null,
    treatment_description: ?[]const u8 = null,
    treatment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_delivery_configuration = "CustomDeliveryConfiguration",
            .id = "Id",
            .message_configuration = "MessageConfiguration",
            .schedule = "Schedule",
            .size_percent = "SizePercent",
            .state = "State",
            .template_configuration = "TemplateConfiguration",
            .treatment_description = "TreatmentDescription",
            .treatment_name = "TreatmentName",
        };
        return @field(mappings, field_name);
    }
};

pub const WriteCampaignRequest = struct {
    additional_treatments: ?[]WriteTreatmentResource = null,
    custom_delivery_configuration: ?CustomDeliveryConfiguration = null,
    description: ?[]const u8 = null,
    holdout_percent: ?i64 = null,
    hook: ?CampaignHook = null,
    is_paused: ?bool = null,
    limits: ?CampaignLimits = null,
    message_configuration: ?MessageConfiguration = null,
    name: ?[]const u8 = null,
    schedule: ?Schedule = null,
    segment_id: ?[]const u8 = null,
    segment_version: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    template_configuration: ?TemplateConfiguration = null,
    treatment_description: ?[]const u8 = null,
    treatment_name: ?[]const u8 = null,
    priority: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_treatments = "AdditionalTreatments",
            .custom_delivery_configuration = "CustomDeliveryConfiguration",
            .description = "Description",
            .holdout_percent = "HoldoutPercent",
            .hook = "Hook",
            .is_paused = "IsPaused",
            .limits = "Limits",
            .message_configuration = "MessageConfiguration",
            .name = "Name",
            .schedule = "Schedule",
            .segment_id = "SegmentId",
            .segment_version = "SegmentVersion",
            .tags = "tags",
            .template_configuration = "TemplateConfiguration",
            .treatment_description = "TreatmentDescription",
            .treatment_name = "TreatmentName",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const WriteTreatmentResource = struct {
    custom_delivery_configuration: ?CustomDeliveryConfiguration = null,
    message_configuration: ?MessageConfiguration = null,
    schedule: ?Schedule = null,
    size_percent: i64,
    template_configuration: ?TemplateConfiguration = null,
    treatment_description: ?[]const u8 = null,
    treatment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_delivery_configuration = "CustomDeliveryConfiguration",
            .message_configuration = "MessageConfiguration",
            .schedule = "Schedule",
            .size_percent = "SizePercent",
            .template_configuration = "TemplateConfiguration",
            .treatment_description = "TreatmentDescription",
            .treatment_name = "TreatmentName",
        };
        return @field(mappings, field_name);
    }
};

pub const BaiduChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    credential: []const u8,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .credential = "Credential",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSettingsResource = struct {
    application_id: []const u8,
    campaign_hook: ?CampaignHook = null,
    last_modified_date: ?[]const u8 = null,
    limits: ?CampaignLimits = null,
    quiet_time: ?QuietTime = null,
    journey_limits: ?ApplicationSettingsJourneyLimits = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .campaign_hook = "CampaignHook",
            .last_modified_date = "LastModifiedDate",
            .limits = "Limits",
            .quiet_time = "QuietTime",
            .journey_limits = "JourneyLimits",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSettingsJourneyLimits = struct {
    daily_cap: ?i64 = null,
    timeframe_cap: ?JourneyTimeframeCap = null,
    total_cap: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .daily_cap = "DailyCap",
            .timeframe_cap = "TimeframeCap",
            .total_cap = "TotalCap",
        };
        return @field(mappings, field_name);
    }
};

pub const APNSVoipSandboxChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    default_authentication_method: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    has_token_key: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .default_authentication_method = "DefaultAuthenticationMethod",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .has_token_key = "HasTokenKey",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const APNSVoipChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    default_authentication_method: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    has_token_key: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .default_authentication_method = "DefaultAuthenticationMethod",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .has_token_key = "HasTokenKey",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const APNSSandboxChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    default_authentication_method: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    has_token_key: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .default_authentication_method = "DefaultAuthenticationMethod",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .has_token_key = "HasTokenKey",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const APNSChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    default_authentication_method: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    has_token_key: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .default_authentication_method = "DefaultAuthenticationMethod",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .has_token_key = "HasTokenKey",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const ADMChannelResponse = struct {
    application_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    enabled: ?bool = null,
    has_credential: ?bool = null,
    id: ?[]const u8 = null,
    is_archived: ?bool = null,
    last_modified_by: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    platform: []const u8,
    version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .creation_date = "CreationDate",
            .enabled = "Enabled",
            .has_credential = "HasCredential",
            .id = "Id",
            .is_archived = "IsArchived",
            .last_modified_by = "LastModifiedBy",
            .last_modified_date = "LastModifiedDate",
            .platform = "Platform",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const TagsModel = struct {
    tags: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EndpointMessageResult = struct {
    address: ?[]const u8 = null,
    delivery_status: []const u8,
    message_id: ?[]const u8 = null,
    status_code: i64,
    status_message: ?[]const u8 = null,
    updated_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .delivery_status = "DeliveryStatus",
            .message_id = "MessageId",
            .status_code = "StatusCode",
            .status_message = "StatusMessage",
            .updated_token = "UpdatedToken",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointSendConfiguration = struct {
    body_override: ?[]const u8 = null,
    context: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    raw_content: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    title_override: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body_override = "BodyOverride",
            .context = "Context",
            .raw_content = "RawContent",
            .substitutions = "Substitutions",
            .title_override = "TitleOverride",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "context", field_name))
            return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const DirectMessageConfiguration = struct {
    adm_message: ?ADMMessage = null,
    apns_message: ?APNSMessage = null,
    baidu_message: ?BaiduMessage = null,
    default_message: ?DefaultMessage = null,
    default_push_notification_message: ?DefaultPushNotificationMessage = null,
    email_message: ?EmailMessage = null,
    gcm_message: ?GCMMessage = null,
    sms_message: ?SMSMessage = null,
    voice_message: ?VoiceMessage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adm_message = "ADMMessage",
            .apns_message = "APNSMessage",
            .baidu_message = "BaiduMessage",
            .default_message = "DefaultMessage",
            .default_push_notification_message = "DefaultPushNotificationMessage",
            .email_message = "EmailMessage",
            .gcm_message = "GCMMessage",
            .sms_message = "SMSMessage",
            .voice_message = "VoiceMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceMessage = struct {
    body: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    origination_number: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    voice_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .language_code = "LanguageCode",
            .origination_number = "OriginationNumber",
            .substitutions = "Substitutions",
            .voice_id = "VoiceId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const SMSMessage = struct {
    body: ?[]const u8 = null,
    keyword: ?[]const u8 = null,
    media_url: ?[]const u8 = null,
    message_type: ?[]const u8 = null,
    origination_number: ?[]const u8 = null,
    sender_id: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    entity_id: ?[]const u8 = null,
    template_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .keyword = "Keyword",
            .media_url = "MediaUrl",
            .message_type = "MessageType",
            .origination_number = "OriginationNumber",
            .sender_id = "SenderId",
            .substitutions = "Substitutions",
            .entity_id = "EntityId",
            .template_id = "TemplateId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const GCMMessage = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    collapse_key: ?[]const u8 = null,
    data: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    icon_reference: ?[]const u8 = null,
    image_icon_url: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    preferred_authentication_method: ?[]const u8 = null,
    priority: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    restricted_package_name: ?[]const u8 = null,
    silent_push: ?bool = null,
    small_image_icon_url: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    time_to_live: ?i64 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .collapse_key = "CollapseKey",
            .data = "Data",
            .icon_reference = "IconReference",
            .image_icon_url = "ImageIconUrl",
            .image_url = "ImageUrl",
            .preferred_authentication_method = "PreferredAuthenticationMethod",
            .priority = "Priority",
            .raw_content = "RawContent",
            .restricted_package_name = "RestrictedPackageName",
            .silent_push = "SilentPush",
            .small_image_icon_url = "SmallImageIconUrl",
            .sound = "Sound",
            .substitutions = "Substitutions",
            .time_to_live = "TimeToLive",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const EmailMessage = struct {
    body: ?[]const u8 = null,
    feedback_forwarding_address: ?[]const u8 = null,
    from_address: ?[]const u8 = null,
    raw_email: ?RawEmail = null,
    reply_to_addresses: ?[][]const u8 = null,
    simple_email: ?SimpleEmail = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .feedback_forwarding_address = "FeedbackForwardingAddress",
            .from_address = "FromAddress",
            .raw_email = "RawEmail",
            .reply_to_addresses = "ReplyToAddresses",
            .simple_email = "SimpleEmail",
            .substitutions = "Substitutions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const SimpleEmail = struct {
    html_part: ?SimpleEmailPart = null,
    subject: ?SimpleEmailPart = null,
    text_part: ?SimpleEmailPart = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .html_part = "HtmlPart",
            .subject = "Subject",
            .text_part = "TextPart",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleEmailPart = struct {
    charset: ?[]const u8 = null,
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .charset = "Charset",
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const RawEmail = struct {
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultPushNotificationMessage = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    data: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    silent_push: ?bool = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .data = "Data",
            .silent_push = "SilentPush",
            .substitutions = "Substitutions",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const DefaultMessage = struct {
    body: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .body = "Body",
            .substitutions = "Substitutions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const BaiduMessage = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    data: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    icon_reference: ?[]const u8 = null,
    image_icon_url: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    silent_push: ?bool = null,
    small_image_icon_url: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    time_to_live: ?i64 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .data = "Data",
            .icon_reference = "IconReference",
            .image_icon_url = "ImageIconUrl",
            .image_url = "ImageUrl",
            .raw_content = "RawContent",
            .silent_push = "SilentPush",
            .small_image_icon_url = "SmallImageIconUrl",
            .sound = "Sound",
            .substitutions = "Substitutions",
            .time_to_live = "TimeToLive",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const APNSMessage = struct {
    apns_push_type: ?[]const u8 = null,
    action: ?[]const u8 = null,
    badge: ?i64 = null,
    body: ?[]const u8 = null,
    category: ?[]const u8 = null,
    collapse_id: ?[]const u8 = null,
    data: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    media_url: ?[]const u8 = null,
    preferred_authentication_method: ?[]const u8 = null,
    priority: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    silent_push: ?bool = null,
    sound: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    thread_id: ?[]const u8 = null,
    time_to_live: ?i64 = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apns_push_type = "APNSPushType",
            .action = "Action",
            .badge = "Badge",
            .body = "Body",
            .category = "Category",
            .collapse_id = "CollapseId",
            .data = "Data",
            .media_url = "MediaUrl",
            .preferred_authentication_method = "PreferredAuthenticationMethod",
            .priority = "Priority",
            .raw_content = "RawContent",
            .silent_push = "SilentPush",
            .sound = "Sound",
            .substitutions = "Substitutions",
            .thread_id = "ThreadId",
            .time_to_live = "TimeToLive",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const ADMMessage = struct {
    action: ?[]const u8 = null,
    body: ?[]const u8 = null,
    consolidation_key: ?[]const u8 = null,
    data: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    expires_after: ?[]const u8 = null,
    icon_reference: ?[]const u8 = null,
    image_icon_url: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    md5: ?[]const u8 = null,
    raw_content: ?[]const u8 = null,
    silent_push: ?bool = null,
    small_image_icon_url: ?[]const u8 = null,
    sound: ?[]const u8 = null,
    substitutions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    title: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .body = "Body",
            .consolidation_key = "ConsolidationKey",
            .data = "Data",
            .expires_after = "ExpiresAfter",
            .icon_reference = "IconReference",
            .image_icon_url = "ImageIconUrl",
            .image_url = "ImageUrl",
            .md5 = "MD5",
            .raw_content = "RawContent",
            .silent_push = "SilentPush",
            .small_image_icon_url = "SmallImageIconUrl",
            .sound = "Sound",
            .substitutions = "Substitutions",
            .title = "Title",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "data", field_name))
            return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
        if (std.mem.eql(u8, "substitutions", field_name))
            return try serializeMap(self.substitutions, self.fieldNameFor("substitutions"), options, out_stream);
        return false;
    }
};

pub const MessageResponse = struct {
    application_id: []const u8,
    endpoint_result: ?[]struct {
        key: ?[]const u8 = null,
        value: ?EndpointMessageResult = null,
    } = null,
    request_id: ?[]const u8 = null,
    result: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MessageResult = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .endpoint_result = "EndpointResult",
            .request_id = "RequestId",
            .result = "Result",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoint_result", field_name))
            return try serializeMap(self.endpoint_result, self.fieldNameFor("endpoint_result"), options, out_stream);
        if (std.mem.eql(u8, "result", field_name))
            return try serializeMap(self.result, self.fieldNameFor("result"), options, out_stream);
        return false;
    }
};

pub const MessageResult = struct {
    delivery_status: []const u8,
    message_id: ?[]const u8 = null,
    status_code: i64,
    status_message: ?[]const u8 = null,
    updated_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_status = "DeliveryStatus",
            .message_id = "MessageId",
            .status_code = "StatusCode",
            .status_message = "StatusMessage",
            .updated_token = "UpdatedToken",
        };
        return @field(mappings, field_name);
    }
};

pub const EventStream = struct {
    application_id: []const u8,
    destination_stream_arn: []const u8,
    external_id: ?[]const u8 = null,
    last_modified_date: ?[]const u8 = null,
    last_updated_by: ?[]const u8 = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .destination_stream_arn = "DestinationStreamArn",
            .external_id = "ExternalId",
            .last_modified_date = "LastModifiedDate",
            .last_updated_by = "LastUpdatedBy",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointsResponse = struct {
    item: []EndpointResponse,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointResponse = struct {
    address: ?[]const u8 = null,
    application_id: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    channel_type: ?[]const u8 = null,
    cohort_id: ?[]const u8 = null,
    creation_date: ?[]const u8 = null,
    demographic: ?EndpointDemographic = null,
    effective_date: ?[]const u8 = null,
    endpoint_status: ?[]const u8 = null,
    id: ?[]const u8 = null,
    location: ?EndpointLocation = null,
    metrics: ?[]struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    } = null,
    opt_out: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    user: ?EndpointUser = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .application_id = "ApplicationId",
            .attributes = "Attributes",
            .channel_type = "ChannelType",
            .cohort_id = "CohortId",
            .creation_date = "CreationDate",
            .demographic = "Demographic",
            .effective_date = "EffectiveDate",
            .endpoint_status = "EndpointStatus",
            .id = "Id",
            .location = "Location",
            .metrics = "Metrics",
            .opt_out = "OptOut",
            .request_id = "RequestId",
            .user = "User",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        if (std.mem.eql(u8, "metrics", field_name))
            return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
        return false;
    }
};

pub const SegmentsResponse = struct {
    item: []SegmentResponse,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportJobsResponse = struct {
    item: []ImportJobResponse,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportJobResponse = struct {
    application_id: []const u8,
    completed_pieces: ?i64 = null,
    completion_date: ?[]const u8 = null,
    creation_date: []const u8,
    definition: ImportJobResource,
    failed_pieces: ?i64 = null,
    failures: ?[][]const u8 = null,
    id: []const u8,
    job_status: []const u8,
    total_failures: ?i64 = null,
    total_pieces: ?i64 = null,
    total_processed: ?i64 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .completed_pieces = "CompletedPieces",
            .completion_date = "CompletionDate",
            .creation_date = "CreationDate",
            .definition = "Definition",
            .failed_pieces = "FailedPieces",
            .failures = "Failures",
            .id = "Id",
            .job_status = "JobStatus",
            .total_failures = "TotalFailures",
            .total_pieces = "TotalPieces",
            .total_processed = "TotalProcessed",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportJobResource = struct {
    define_segment: ?bool = null,
    external_id: ?[]const u8 = null,
    format: []const u8,
    register_endpoints: ?bool = null,
    role_arn: []const u8,
    s3_url: []const u8,
    segment_id: ?[]const u8 = null,
    segment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .define_segment = "DefineSegment",
            .external_id = "ExternalId",
            .format = "Format",
            .register_endpoints = "RegisterEndpoints",
            .role_arn = "RoleArn",
            .s3_url = "S3Url",
            .segment_id = "SegmentId",
            .segment_name = "SegmentName",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportJobsResponse = struct {
    item: []ExportJobResponse,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportJobResponse = struct {
    application_id: []const u8,
    completed_pieces: ?i64 = null,
    completion_date: ?[]const u8 = null,
    creation_date: []const u8,
    definition: ExportJobResource,
    failed_pieces: ?i64 = null,
    failures: ?[][]const u8 = null,
    id: []const u8,
    job_status: []const u8,
    total_failures: ?i64 = null,
    total_pieces: ?i64 = null,
    total_processed: ?i64 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "ApplicationId",
            .completed_pieces = "CompletedPieces",
            .completion_date = "CompletionDate",
            .creation_date = "CreationDate",
            .definition = "Definition",
            .failed_pieces = "FailedPieces",
            .failures = "Failures",
            .id = "Id",
            .job_status = "JobStatus",
            .total_failures = "TotalFailures",
            .total_pieces = "TotalPieces",
            .total_processed = "TotalProcessed",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportJobResource = struct {
    role_arn: []const u8,
    s3_url_prefix: []const u8,
    segment_id: ?[]const u8 = null,
    segment_version: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .s3_url_prefix = "S3UrlPrefix",
            .segment_id = "SegmentId",
            .segment_version = "SegmentVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const BaseKpiResult = struct {
    rows: []ResultRow,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rows = "Rows",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultRow = struct {
    grouped_bys: []ResultRowValue,
    values: []ResultRowValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grouped_bys = "GroupedBys",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultRowValue = struct {
    key: []const u8,
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignsResponse = struct {
    item: []CampaignResponse,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item = "Item",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationResponse = struct {
    arn: []const u8,
    id: []const u8,
    name: []const u8,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    creation_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .id = "Id",
            .name = "Name",
            .tags = "tags",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const CreateTemplateMessageBody = struct {
    arn: ?[]const u8 = null,
    message: ?[]const u8 = null,
    request_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .message = "Message",
            .request_id = "RequestID",
        };
        return @field(mappings, field_name);
    }
};
