const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-01";
pub const sdk_id: []const u8 = "QuickSight";
pub const arn_namespace: ?[]const u8 = "quicksight";
pub const endpoint_prefix: []const u8 = "quicksight";
pub const sigv4_name: []const u8 = "quicksight";
pub const name: []const u8 = "QuickSight_20180401";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-01",
    sdk_id: []const u8 = "QuickSight",
    arn_namespace: ?[]const u8 = "quicksight",
    endpoint_prefix: []const u8 = "quicksight",
    sigv4_name: []const u8 = "quicksight",
    name: []const u8 = "QuickSight_20180401",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_ingestion: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelIngestion",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        ingestion_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ingestion };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_account_customization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        account_customization: AccountCustomization,
        tags: ?[]Tag = null,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = create_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_account_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/account/{AwsAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccountSubscription",
    Request: type = struct {
        edition: []const u8,
        authentication_method: []const u8,
        aws_account_id: []const u8,
        account_name: []const u8,
        notification_email: []const u8,
        active_directory_name: ?[]const u8 = null,
        realm: ?[]const u8 = null,
        directory_id: ?[]const u8 = null,
        admin_group: ?[][]const u8 = null,
        author_group: ?[][]const u8 = null,
        reader_group: ?[][]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        contact_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edition = "Edition",
                .authentication_method = "AuthenticationMethod",
                .aws_account_id = "AwsAccountId",
                .account_name = "AccountName",
                .notification_email = "NotificationEmail",
                .active_directory_name = "ActiveDirectoryName",
                .realm = "Realm",
                .directory_id = "DirectoryId",
                .admin_group = "AdminGroup",
                .author_group = "AuthorGroup",
                .reader_group = "ReaderGroup",
                .first_name = "FirstName",
                .last_name = "LastName",
                .email_address = "EmailAddress",
                .contact_number = "ContactNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_account_subscription };
        }
    },
    Response: type = struct {
        signup_response: ?struct {
            iam_user: ?bool = null,
            user_login_name: ?[]const u8 = null,
            account_name: ?[]const u8 = null,
            directory_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iam_user = "IAMUser",
                    .user_login_name = "userLoginName",
                    .account_name = "accountName",
                    .directory_type = "directoryType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signup_response = "SignupResponse",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: ?AnalysisSourceEntity = null,
        theme_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        definition: ?AnalysisDefinition = null,
        validation_strategy: ?ValidationStrategy = null,
        folder_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .name = "Name",
                .parameters = "Parameters",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .theme_arn = "ThemeArn",
                .tags = "Tags",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
                .folder_arns = "FolderArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_analysis) } {
            return .{ .service_metadata = service_metadata, .action = create_analysis };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_dashboard: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: ?DashboardSourceEntity = null,
        tags: ?[]Tag = null,
        version_description: ?[]const u8 = null,
        dashboard_publish_options: ?DashboardPublishOptions = null,
        theme_arn: ?[]const u8 = null,
        definition: ?DashboardVersionDefinition = null,
        validation_strategy: ?ValidationStrategy = null,
        folder_arns: ?[][]const u8 = null,
        link_sharing_configuration: ?LinkSharingConfiguration = null,
        link_entities: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .name = "Name",
                .parameters = "Parameters",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .tags = "Tags",
                .version_description = "VersionDescription",
                .dashboard_publish_options = "DashboardPublishOptions",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
                .folder_arns = "FolderArns",
                .link_sharing_configuration = "LinkSharingConfiguration",
                .link_entities = "LinkEntities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = create_dashboard };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .dashboard_id = "DashboardId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_data_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        name: []const u8,
        physical_table_map: []struct {
            key: ?[]const u8 = null,
            value: ?PhysicalTable = null,
        },
        logical_table_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogicalTable = null,
        } = null,
        import_mode: []const u8,
        column_groups: ?[]ColumnGroup = null,
        field_folders: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FieldFolder = null,
        } = null,
        permissions: ?[]ResourcePermission = null,
        row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
        row_level_permission_tag_configuration: ?RowLevelPermissionTagConfiguration = null,
        column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,
        tags: ?[]Tag = null,
        data_set_usage_configuration: ?DataSetUsageConfiguration = null,
        dataset_parameters: ?[]DatasetParameter = null,
        folder_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .name = "Name",
                .physical_table_map = "PhysicalTableMap",
                .logical_table_map = "LogicalTableMap",
                .import_mode = "ImportMode",
                .column_groups = "ColumnGroups",
                .field_folders = "FieldFolders",
                .permissions = "Permissions",
                .row_level_permission_data_set = "RowLevelPermissionDataSet",
                .row_level_permission_tag_configuration = "RowLevelPermissionTagConfiguration",
                .column_level_permission_rules = "ColumnLevelPermissionRules",
                .tags = "Tags",
                .data_set_usage_configuration = "DataSetUsageConfiguration",
                .dataset_parameters = "DatasetParameters",
                .folder_arns = "FolderArns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "physical_table_map", field_name))
                return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "logical_table_map", field_name))
                return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "field_folders", field_name))
                return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_set) } {
            return .{ .service_metadata = service_metadata, .action = create_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        ingestion_arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .ingestion_arn = "IngestionArn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_data_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        name: []const u8,
        type: []const u8,
        data_source_parameters: ?DataSourceParameters = null,
        credentials: ?DataSourceCredentials = null,
        permissions: ?[]ResourcePermission = null,
        vpc_connection_properties: ?VpcConnectionProperties = null,
        ssl_properties: ?SslProperties = null,
        tags: ?[]Tag = null,
        folder_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .name = "Name",
                .type = "Type",
                .data_source_parameters = "DataSourceParameters",
                .credentials = "Credentials",
                .permissions = "Permissions",
                .vpc_connection_properties = "VpcConnectionProperties",
                .ssl_properties = "SslProperties",
                .tags = "Tags",
                .folder_arns = "FolderArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .creation_status = "CreationStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_folder: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFolder",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        name: ?[]const u8 = null,
        folder_type: ?[]const u8 = null,
        parent_folder_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        tags: ?[]Tag = null,
        sharing_model: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .name = "Name",
                .folder_type = "FolderType",
                .parent_folder_arn = "ParentFolderArn",
                .permissions = "Permissions",
                .tags = "Tags",
                .sharing_model = "SharingModel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_folder) } {
            return .{ .service_metadata = service_metadata, .action = create_folder };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        folder_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .folder_id = "FolderId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_folder_membership: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/members/{MemberType}/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFolderMembership",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        member_id: []const u8,
        member_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .member_id = "MemberId",
                .member_type = "MemberType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_folder_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_folder_membership };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_member: ?struct {
            member_id: ?[]const u8 = null,
            member_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_id = "MemberId",
                    .member_type = "MemberType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_member = "FolderMember",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        group_name: []const u8,
        description: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .description = "Description",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_group_membership: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroupMembership",
    Request: type = struct {
        member_name: []const u8,
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_group_membership };
        }
    },
    Response: type = struct {
        group_member: ?GroupMember = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_member = "GroupMember",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        assignment_status: []const u8,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = create_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        assignment_id: ?[]const u8 = null,
        assignment_status: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .assignment_id = "AssignmentId",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_ingestion: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIngestion",
    Request: type = struct {
        data_set_id: []const u8,
        ingestion_id: []const u8,
        aws_account_id: []const u8,
        ingestion_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
                .aws_account_id = "AwsAccountId",
                .ingestion_type = "IngestionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = create_ingestion };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        ingestion_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .ingestion_id = "IngestionId",
                .ingestion_status = "IngestionStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_namespace: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,
        identity_store: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .identity_store = "IdentityStore",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_namespace) } {
            return .{ .service_metadata = service_metadata, .action = create_namespace };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        capacity_region: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        identity_store: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .capacity_region = "CapacityRegion",
                .creation_status = "CreationStatus",
                .identity_store = "IdentityStore",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_refresh_schedule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRefreshSchedule",
    Request: type = struct {
        data_set_id: []const u8,
        aws_account_id: []const u8,
        schedule: RefreshSchedule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .aws_account_id = "AwsAccountId",
                .schedule = "Schedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = create_refresh_schedule };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        schedule_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .request_id = "RequestId",
                .schedule_id = "ScheduleId",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_role_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoleMembership",
    Request: type = struct {
        member_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,
        role: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .role = "Role",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_role_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_role_membership };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        name: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: ?TemplateSourceEntity = null,
        tags: ?[]Tag = null,
        version_description: ?[]const u8 = null,
        definition: ?TemplateVersionDefinition = null,
        validation_strategy: ?ValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .name = "Name",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .tags = "Tags",
                .version_description = "VersionDescription",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template) } {
            return .{ .service_metadata = service_metadata, .action = create_template };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .template_id = "TemplateId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_template_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,
        template_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .template_version_number = "TemplateVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_theme: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        name: []const u8,
        base_theme_id: []const u8,
        version_description: ?[]const u8 = null,
        configuration: ThemeConfiguration,
        permissions: ?[]ResourcePermission = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .name = "Name",
                .base_theme_id = "BaseThemeId",
                .version_description = "VersionDescription",
                .configuration = "Configuration",
                .permissions = "Permissions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_theme) } {
            return .{ .service_metadata = service_metadata, .action = create_theme };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        theme_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .theme_id = "ThemeId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_theme_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,
        theme_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
                .theme_version_number = "ThemeVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_topic: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/topics",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTopic",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        topic: TopicDetails,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .topic = "Topic",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_topic) } {
            return .{ .service_metadata = service_metadata, .action = create_topic };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        topic_id: ?[]const u8 = null,
        refresh_arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .topic_id = "TopicId",
                .refresh_arn = "RefreshArn",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_topic_refresh_schedule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTopicRefreshSchedule",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        dataset_arn: []const u8,
        dataset_name: ?[]const u8 = null,
        refresh_schedule: TopicRefreshSchedule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .dataset_arn = "DatasetArn",
                .dataset_name = "DatasetName",
                .refresh_schedule = "RefreshSchedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_topic_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = create_topic_refresh_schedule };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .dataset_arn = "DatasetArn",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_vpc_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/vpc-connections",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVPCConnection",
    Request: type = struct {
        aws_account_id: []const u8,
        vpc_connection_id: []const u8,
        name: []const u8,
        subnet_ids: [][]const u8,
        security_group_ids: [][]const u8,
        dns_resolvers: ?[][]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .vpc_connection_id = "VPCConnectionId",
                .name = "Name",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .dns_resolvers = "DnsResolvers",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_connection };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        vpc_connection_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        availability_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .vpc_connection_id = "VPCConnectionId",
                .creation_status = "CreationStatus",
                .availability_status = "AvailabilityStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_account_customization: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_customization };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_account_subscription: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/account/{AwsAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccountSubscription",
    Request: type = struct {
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_subscription };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_analysis: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        recovery_window_in_days: ?i64 = null,
        force_delete_without_recovery: ?bool = null,

        pub const http_query = .{
            .recovery_window_in_days = "recovery-window-in-days",
            .force_delete_without_recovery = "force-delete-without-recovery",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .recovery_window_in_days = "RecoveryWindowInDays",
                .force_delete_without_recovery = "ForceDeleteWithoutRecovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_analysis) } {
            return .{ .service_metadata = service_metadata, .action = delete_analysis };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        deletion_time: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .deletion_time = "DeletionTime",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_dashboard: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = delete_dashboard };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .dashboard_id = "DashboardId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_data_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_data_set_refresh_properties: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-properties",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSetRefreshProperties",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_set_refresh_properties) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_set_refresh_properties };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_data_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_folder: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFolder",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_folder) } {
            return .{ .service_metadata = service_metadata, .action = delete_folder };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        folder_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .folder_id = "FolderId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_folder_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/members/{MemberType}/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFolderMembership",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        member_id: []const u8,
        member_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .member_id = "MemberId",
                .member_type = "MemberType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_folder_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_folder_membership };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_group_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroupMembership",
    Request: type = struct {
        member_name: []const u8,
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_group_membership };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespace/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = delete_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_identity_propagation_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/identity-propagation-config/{Service}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIdentityPropagationConfig",
    Request: type = struct {
        aws_account_id: []const u8,
        service: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .service = "Service",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identity_propagation_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_identity_propagation_config };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_namespace: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_namespace) } {
            return .{ .service_metadata = service_metadata, .action = delete_namespace };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_refresh_schedule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-schedules/{ScheduleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRefreshSchedule",
    Request: type = struct {
        data_set_id: []const u8,
        aws_account_id: []const u8,
        schedule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .aws_account_id = "AwsAccountId",
                .schedule_id = "ScheduleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_refresh_schedule };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        schedule_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .request_id = "RequestId",
                .schedule_id = "ScheduleId",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_role_custom_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/custom-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoleCustomPermission",
    Request: type = struct {
        role: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role = "Role",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_role_custom_permission) } {
            return .{ .service_metadata = service_metadata, .action = delete_role_custom_permission };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_role_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoleMembership",
    Request: type = struct {
        member_name: []const u8,
        role: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .role = "Role",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_role_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_role_membership };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_template };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .arn = "Arn",
                .template_id = "TemplateId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_template_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_template_alias };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        template_id: ?[]const u8 = null,
        alias_name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .arn = "Arn",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_theme: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_theme) } {
            return .{ .service_metadata = service_metadata, .action = delete_theme };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        theme_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .request_id = "RequestId",
                .status = "Status",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_theme_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_theme_alias };
        }
    },
    Response: type = struct {
        alias_name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        theme_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_name = "AliasName",
                .arn = "Arn",
                .request_id = "RequestId",
                .status = "Status",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_topic: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTopic",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_topic) } {
            return .{ .service_metadata = service_metadata, .action = delete_topic };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        topic_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .topic_id = "TopicId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_topic_refresh_schedule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/schedules/{DatasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTopicRefreshSchedule",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        dataset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .dataset_id = "DatasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_topic_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_topic_refresh_schedule };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .dataset_arn = "DatasetArn",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_user_by_principal_id: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/user-principals/{PrincipalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUserByPrincipalId",
    Request: type = struct {
        principal_id: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_id = "PrincipalId",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_by_principal_id) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_by_principal_id };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_vpc_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/vpc-connections/{VPCConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVPCConnection",
    Request: type = struct {
        aws_account_id: []const u8,
        vpc_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .vpc_connection_id = "VPCConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_connection };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        vpc_connection_id: ?[]const u8 = null,
        deletion_status: ?[]const u8 = null,
        availability_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .vpc_connection_id = "VPCConnectionId",
                .deletion_status = "DeletionStatus",
                .availability_status = "AvailabilityStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_account_customization: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        resolved: ?bool = null,

        pub const http_query = .{
            .namespace = "namespace",
            .resolved = "resolved",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .resolved = "Resolved",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_account_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountSettings",
    Request: type = struct {
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?struct {
            account_name: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            default_namespace: ?[]const u8 = null,
            notification_email: ?[]const u8 = null,
            public_sharing_enabled: ?bool = null,
            termination_protection_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_name = "AccountName",
                    .edition = "Edition",
                    .default_namespace = "DefaultNamespace",
                    .notification_email = "NotificationEmail",
                    .public_sharing_enabled = "PublicSharingEnabled",
                    .termination_protection_enabled = "TerminationProtectionEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "AccountSettings",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_account_subscription: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account/{AwsAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountSubscription",
    Request: type = struct {
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_subscription) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_subscription };
        }
    },
    Response: type = struct {
        account_info: ?struct {
            account_name: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            notification_email: ?[]const u8 = null,
            authentication_type: ?[]const u8 = null,
            account_subscription_status: ?[]const u8 = null,
            iam_identity_center_instance_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_name = "AccountName",
                    .edition = "Edition",
                    .notification_email = "NotificationEmail",
                    .authentication_type = "AuthenticationType",
                    .account_subscription_status = "AccountSubscriptionStatus",
                    .iam_identity_center_instance_arn = "IAMIdentityCenterInstanceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_info = "AccountInfo",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_analysis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_analysis) } {
            return .{ .service_metadata = service_metadata, .action = describe_analysis };
        }
    },
    Response: type = struct {
        analysis: ?struct {
            analysis_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            errors: ?[]AnalysisError = null,
            data_set_arns: ?[][]const u8 = null,
            theme_arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            sheets: ?[]Sheet = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .analysis_id = "AnalysisId",
                    .arn = "Arn",
                    .name = "Name",
                    .status = "Status",
                    .errors = "Errors",
                    .data_set_arns = "DataSetArns",
                    .theme_arn = "ThemeArn",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .sheets = "Sheets",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis = "Analysis",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_analysis_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}/definition",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnalysisDefinition",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_analysis_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_analysis_definition };
        }
    },
    Response: type = struct {
        analysis_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        errors: ?[]AnalysisError = null,
        resource_status: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        definition: ?AnalysisDefinition = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "AnalysisId",
                .name = "Name",
                .errors = "Errors",
                .resource_status = "ResourceStatus",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_analysis_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnalysisPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_analysis_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_analysis_permissions };
        }
    },
    Response: type = struct {
        analysis_id: ?[]const u8 = null,
        analysis_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "AnalysisId",
                .analysis_arn = "AnalysisArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_asset_bundle_export_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-export-jobs/{AssetBundleExportJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetBundleExportJob",
    Request: type = struct {
        aws_account_id: []const u8,
        asset_bundle_export_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .asset_bundle_export_job_id = "AssetBundleExportJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_bundle_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_bundle_export_job };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        download_url: ?[]const u8 = null,
        errors: ?[]struct {
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .type = "Type",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        arn: ?[]const u8 = null,
        created_time: ?i64 = null,
        asset_bundle_export_job_id: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        resource_arns: ?[][]const u8 = null,
        include_all_dependencies: ?bool = null,
        export_format: ?[]const u8 = null,
        cloud_formation_override_property_configuration: ?AssetBundleCloudFormationOverridePropertyConfiguration = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        include_permissions: ?bool = null,
        include_tags: ?bool = null,
        validation_strategy: ?AssetBundleExportJobValidationStrategy = null,
        warnings: ?[]struct {
            arn: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .download_url = "DownloadUrl",
                .errors = "Errors",
                .arn = "Arn",
                .created_time = "CreatedTime",
                .asset_bundle_export_job_id = "AssetBundleExportJobId",
                .aws_account_id = "AwsAccountId",
                .resource_arns = "ResourceArns",
                .include_all_dependencies = "IncludeAllDependencies",
                .export_format = "ExportFormat",
                .cloud_formation_override_property_configuration = "CloudFormationOverridePropertyConfiguration",
                .request_id = "RequestId",
                .status = "Status",
                .include_permissions = "IncludePermissions",
                .include_tags = "IncludeTags",
                .validation_strategy = "ValidationStrategy",
                .warnings = "Warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_asset_bundle_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-import-jobs/{AssetBundleImportJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAssetBundleImportJob",
    Request: type = struct {
        aws_account_id: []const u8,
        asset_bundle_import_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .asset_bundle_import_job_id = "AssetBundleImportJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset_bundle_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset_bundle_import_job };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        errors: ?[]AssetBundleImportJobError = null,
        rollback_errors: ?[]AssetBundleImportJobError = null,
        arn: ?[]const u8 = null,
        created_time: ?i64 = null,
        asset_bundle_import_job_id: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        asset_bundle_import_source: ?struct {
            body: ?[]const u8 = null,
            s3_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .body = "Body",
                    .s3_uri = "S3Uri",
                };
                return @field(mappings, field_name);
            }
        } = null,
        override_parameters: ?AssetBundleImportJobOverrideParameters = null,
        failure_action: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        override_permissions: ?AssetBundleImportJobOverridePermissions = null,
        override_tags: ?AssetBundleImportJobOverrideTags = null,
        override_validation_strategy: ?AssetBundleImportJobOverrideValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .errors = "Errors",
                .rollback_errors = "RollbackErrors",
                .arn = "Arn",
                .created_time = "CreatedTime",
                .asset_bundle_import_job_id = "AssetBundleImportJobId",
                .aws_account_id = "AwsAccountId",
                .asset_bundle_import_source = "AssetBundleImportSource",
                .override_parameters = "OverrideParameters",
                .failure_action = "FailureAction",
                .request_id = "RequestId",
                .status = "Status",
                .override_permissions = "OverridePermissions",
                .override_tags = "OverrideTags",
                .override_validation_strategy = "OverrideValidationStrategy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard };
        }
    },
    Response: type = struct {
        dashboard: ?struct {
            dashboard_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?struct {
                created_time: ?i64 = null,
                errors: ?[]DashboardError = null,
                version_number: ?i64 = null,
                status: ?[]const u8 = null,
                arn: ?[]const u8 = null,
                source_entity_arn: ?[]const u8 = null,
                data_set_arns: ?[][]const u8 = null,
                description: ?[]const u8 = null,
                theme_arn: ?[]const u8 = null,
                sheets: ?[]Sheet = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_time = "CreatedTime",
                        .errors = "Errors",
                        .version_number = "VersionNumber",
                        .status = "Status",
                        .arn = "Arn",
                        .source_entity_arn = "SourceEntityArn",
                        .data_set_arns = "DataSetArns",
                        .description = "Description",
                        .theme_arn = "ThemeArn",
                        .sheets = "Sheets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_time: ?i64 = null,
            last_published_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            link_entities: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dashboard_id = "DashboardId",
                    .arn = "Arn",
                    .name = "Name",
                    .version = "Version",
                    .created_time = "CreatedTime",
                    .last_published_time = "LastPublishedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .link_entities = "LinkEntities",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard = "Dashboard",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/definition",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboardDefinition",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard_definition };
        }
    },
    Response: type = struct {
        dashboard_id: ?[]const u8 = null,
        errors: ?[]DashboardError = null,
        name: ?[]const u8 = null,
        resource_status: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        definition: ?DashboardVersionDefinition = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        dashboard_publish_options: ?DashboardPublishOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "DashboardId",
                .errors = "Errors",
                .name = "Name",
                .resource_status = "ResourceStatus",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .status = "Status",
                .request_id = "RequestId",
                .dashboard_publish_options = "DashboardPublishOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboardPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard_permissions };
        }
    },
    Response: type = struct {
        dashboard_id: ?[]const u8 = null,
        dashboard_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        link_sharing_configuration: ?LinkSharingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "DashboardId",
                .dashboard_arn = "DashboardArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
                .link_sharing_configuration = "LinkSharingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard_snapshot_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/snapshot-jobs/{SnapshotJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboardSnapshotJob",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        snapshot_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .snapshot_job_id = "SnapshotJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard_snapshot_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard_snapshot_job };
        }
    },
    Response: type = struct {
        aws_account_id: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        snapshot_job_id: ?[]const u8 = null,
        user_configuration: ?struct {
            anonymous_users: ?[]struct {
                row_level_permission_tag_keys: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .row_level_permission_tag_keys = "RowLevelPermissionTagKeys",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anonymous_users = "AnonymousUsers",
                };
                return @field(mappings, field_name);
            }
        } = null,
        snapshot_configuration: ?SnapshotConfiguration = null,
        arn: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        created_time: ?i64 = null,
        last_updated_time: ?i64 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .snapshot_job_id = "SnapshotJobId",
                .user_configuration = "UserConfiguration",
                .snapshot_configuration = "SnapshotConfiguration",
                .arn = "Arn",
                .job_status = "JobStatus",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard_snapshot_job_result: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/snapshot-jobs/{SnapshotJobId}/result",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboardSnapshotJobResult",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        snapshot_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .snapshot_job_id = "SnapshotJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard_snapshot_job_result) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard_snapshot_job_result };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        created_time: ?i64 = null,
        last_updated_time: ?i64 = null,
        result: ?struct {
            anonymous_users: ?[]struct {
                file_groups: ?[]struct {
                    files: ?[]SnapshotFile = null,
                    s3_results: ?[]struct {
                        s3_destination_configuration: ?SnapshotS3DestinationConfiguration = null,
                        s3_uri: ?[]const u8 = null,
                        error_info: ?[]struct {
                            error_message: ?[]const u8 = null,
                            error_type: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .error_message = "ErrorMessage",
                                    .error_type = "ErrorType",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .s3_destination_configuration = "S3DestinationConfiguration",
                                .s3_uri = "S3Uri",
                                .error_info = "ErrorInfo",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .files = "Files",
                            .s3_results = "S3Results",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .file_groups = "FileGroups",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anonymous_users = "AnonymousUsers",
                };
                return @field(mappings, field_name);
            }
        } = null,
        error_info: ?struct {
            error_message: ?[]const u8 = null,
            error_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_message = "ErrorMessage",
                    .error_type = "ErrorType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .job_status = "JobStatus",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .result = "Result",
                .error_info = "ErrorInfo",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_data_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_set };
        }
    },
    Response: type = struct {
        data_set: ?struct {
            arn: ?[]const u8 = null,
            data_set_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            physical_table_map: ?[]struct {
                key: ?[]const u8 = null,
                value: ?PhysicalTable = null,
            } = null,
            logical_table_map: ?[]struct {
                key: ?[]const u8 = null,
                value: ?LogicalTable = null,
            } = null,
            output_columns: ?[]struct {
                name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                type: ?[]const u8 = null,
                sub_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .description = "Description",
                        .type = "Type",
                        .sub_type = "SubType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_mode: ?[]const u8 = null,
            consumed_spice_capacity_in_bytes: ?i64 = null,
            column_groups: ?[]ColumnGroup = null,
            field_folders: ?[]struct {
                key: ?[]const u8 = null,
                value: ?FieldFolder = null,
            } = null,
            row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
            row_level_permission_tag_configuration: ?RowLevelPermissionTagConfiguration = null,
            column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,
            data_set_usage_configuration: ?DataSetUsageConfiguration = null,
            dataset_parameters: ?[]DatasetParameter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .data_set_id = "DataSetId",
                    .name = "Name",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .physical_table_map = "PhysicalTableMap",
                    .logical_table_map = "LogicalTableMap",
                    .output_columns = "OutputColumns",
                    .import_mode = "ImportMode",
                    .consumed_spice_capacity_in_bytes = "ConsumedSpiceCapacityInBytes",
                    .column_groups = "ColumnGroups",
                    .field_folders = "FieldFolders",
                    .row_level_permission_data_set = "RowLevelPermissionDataSet",
                    .row_level_permission_tag_configuration = "RowLevelPermissionTagConfiguration",
                    .column_level_permission_rules = "ColumnLevelPermissionRules",
                    .data_set_usage_configuration = "DataSetUsageConfiguration",
                    .dataset_parameters = "DatasetParameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "physical_table_map", field_name))
                    return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
                if (std.mem.eql(u8, "logical_table_map", field_name))
                    return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
                if (std.mem.eql(u8, "field_folders", field_name))
                    return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
                return false;
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set = "DataSet",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_set_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSetPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_set_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_set_permissions };
        }
    },
    Response: type = struct {
        data_set_arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_arn = "DataSetArn",
                .data_set_id = "DataSetId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_set_refresh_properties: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-properties",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSetRefreshProperties",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_set_refresh_properties) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_set_refresh_properties };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        data_set_refresh_properties: ?DataSetRefreshProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
                .data_set_refresh_properties = "DataSetRefreshProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source };
        }
    },
    Response: type = struct {
        data_source: ?DataSource = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "DataSource",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_source_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSourcePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source_permissions };
        }
    },
    Response: type = struct {
        data_source_arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_arn = "DataSourceArn",
                .data_source_id = "DataSourceId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_folder: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFolder",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_folder) } {
            return .{ .service_metadata = service_metadata, .action = describe_folder };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder: ?struct {
            folder_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            folder_type: ?[]const u8 = null,
            folder_path: ?[][]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            sharing_model: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .folder_id = "FolderId",
                    .arn = "Arn",
                    .name = "Name",
                    .folder_type = "FolderType",
                    .folder_path = "FolderPath",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .sharing_model = "SharingModel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder = "Folder",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_folder_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFolderPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        namespace: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .namespace = "namespace",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .namespace = "Namespace",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_folder_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_folder_permissions };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_id = "FolderId",
                .arn = "Arn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_folder_resolved_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/resolved-permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFolderResolvedPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        namespace: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .namespace = "namespace",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .namespace = "Namespace",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_folder_resolved_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_folder_resolved_permissions };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_id = "FolderId",
                .arn = "Arn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGroup",
    Request: type = struct {
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_group_membership: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGroupMembership",
    Request: type = struct {
        member_name: []const u8,
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group_membership) } {
            return .{ .service_metadata = service_metadata, .action = describe_group_membership };
        }
    },
    Response: type = struct {
        group_member: ?GroupMember = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_member = "GroupMember",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = describe_iam_policy_assignment };
        }
    },
    Response: type = struct {
        iam_policy_assignment: ?struct {
            aws_account_id: ?[]const u8 = null,
            assignment_id: ?[]const u8 = null,
            assignment_name: ?[]const u8 = null,
            policy_arn: ?[]const u8 = null,
            identities: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            assignment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "AwsAccountId",
                    .assignment_id = "AssignmentId",
                    .assignment_name = "AssignmentName",
                    .policy_arn = "PolicyArn",
                    .identities = "Identities",
                    .assignment_status = "AssignmentStatus",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "identities", field_name))
                    return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
                return false;
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_policy_assignment = "IAMPolicyAssignment",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_ingestion: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIngestion",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        ingestion_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = describe_ingestion };
        }
    },
    Response: type = struct {
        ingestion: ?Ingestion = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion = "Ingestion",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_ip_restriction: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/ip-restriction",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIpRestriction",
    Request: type = struct {
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ip_restriction) } {
            return .{ .service_metadata = service_metadata, .action = describe_ip_restriction };
        }
    },
    Response: type = struct {
        aws_account_id: ?[]const u8 = null,
        ip_restriction_rule_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enabled: ?bool = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .ip_restriction_rule_map = "IpRestrictionRuleMap",
                .enabled = "Enabled",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "ip_restriction_rule_map", field_name))
                return try serializeMap(self.ip_restriction_rule_map, self.fieldNameFor("ip_restriction_rule_map"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_namespace: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_namespace) } {
            return .{ .service_metadata = service_metadata, .action = describe_namespace };
        }
    },
    Response: type = struct {
        namespace: ?NamespaceInfoV2 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace = "Namespace",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_refresh_schedule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-schedules/{ScheduleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRefreshSchedule",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        schedule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .schedule_id = "ScheduleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_refresh_schedule };
        }
    },
    Response: type = struct {
        refresh_schedule: ?RefreshSchedule = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schedule = "RefreshSchedule",
                .status = "Status",
                .request_id = "RequestId",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_role_custom_permission: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/custom-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRoleCustomPermission",
    Request: type = struct {
        role: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role = "Role",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_role_custom_permission) } {
            return .{ .service_metadata = service_metadata, .action = describe_role_custom_permission };
        }
    },
    Response: type = struct {
        custom_permissions_name: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_permissions_name = "CustomPermissionsName",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_template };
        }
    },
    Response: type = struct {
        template: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?struct {
                created_time: ?i64 = null,
                errors: ?[]TemplateError = null,
                version_number: ?i64 = null,
                status: ?[]const u8 = null,
                data_set_configurations: ?[]DataSetConfiguration = null,
                description: ?[]const u8 = null,
                source_entity_arn: ?[]const u8 = null,
                theme_arn: ?[]const u8 = null,
                sheets: ?[]Sheet = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_time = "CreatedTime",
                        .errors = "Errors",
                        .version_number = "VersionNumber",
                        .status = "Status",
                        .data_set_configurations = "DataSetConfigurations",
                        .description = "Description",
                        .source_entity_arn = "SourceEntityArn",
                        .theme_arn = "ThemeArn",
                        .sheets = "Sheets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            template_id: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .version = "Version",
                    .template_id = "TemplateId",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "Template",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_template_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_template_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/definition",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplateDefinition",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_template_definition };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        errors: ?[]TemplateError = null,
        resource_status: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        definition: ?TemplateVersionDefinition = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .template_id = "TemplateId",
                .errors = "Errors",
                .resource_status = "ResourceStatus",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_template_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplatePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_template_permissions };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        template_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .template_arn = "TemplateArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme };
        }
    },
    Response: type = struct {
        theme: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            theme_id: ?[]const u8 = null,
            version: ?struct {
                version_number: ?i64 = null,
                arn: ?[]const u8 = null,
                description: ?[]const u8 = null,
                base_theme_id: ?[]const u8 = null,
                created_time: ?i64 = null,
                configuration: ?ThemeConfiguration = null,
                errors: ?[]struct {
                    type: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "Type",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .version_number = "VersionNumber",
                        .arn = "Arn",
                        .description = "Description",
                        .base_theme_id = "BaseThemeId",
                        .created_time = "CreatedTime",
                        .configuration = "Configuration",
                        .errors = "Errors",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .theme_id = "ThemeId",
                    .version = "Version",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme = "Theme",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThemePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme_permissions };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .theme_arn = "ThemeArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_topic: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTopic",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_topic) } {
            return .{ .service_metadata = service_metadata, .action = describe_topic };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        topic_id: ?[]const u8 = null,
        topic: ?TopicDetails = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .topic_id = "TopicId",
                .topic = "Topic",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_topic_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTopicPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_topic_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_topic_permissions };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_topic_refresh: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/refresh/{RefreshId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTopicRefresh",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        refresh_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .refresh_id = "RefreshId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_topic_refresh) } {
            return .{ .service_metadata = service_metadata, .action = describe_topic_refresh };
        }
    },
    Response: type = struct {
        refresh_details: ?struct {
            refresh_arn: ?[]const u8 = null,
            refresh_id: ?[]const u8 = null,
            refresh_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .refresh_arn = "RefreshArn",
                    .refresh_id = "RefreshId",
                    .refresh_status = "RefreshStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_details = "RefreshDetails",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_topic_refresh_schedule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/schedules/{DatasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTopicRefreshSchedule",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        dataset_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .dataset_id = "DatasetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_topic_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_topic_refresh_schedule };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        refresh_schedule: ?TopicRefreshSchedule = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .dataset_arn = "DatasetArn",
                .refresh_schedule = "RefreshSchedule",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_vpc_connection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/vpc-connections/{VPCConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVPCConnection",
    Request: type = struct {
        aws_account_id: []const u8,
        vpc_connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .vpc_connection_id = "VPCConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_connection) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_connection };
        }
    },
    Response: type = struct {
        vpc_connection: ?struct {
            vpc_connection_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            dns_resolvers: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            availability_status: ?[]const u8 = null,
            network_interfaces: ?[]NetworkInterface = null,
            role_arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_connection_id = "VPCConnectionId",
                    .arn = "Arn",
                    .name = "Name",
                    .vpc_id = "VPCId",
                    .security_group_ids = "SecurityGroupIds",
                    .dns_resolvers = "DnsResolvers",
                    .status = "Status",
                    .availability_status = "AvailabilityStatus",
                    .network_interfaces = "NetworkInterfaces",
                    .role_arn = "RoleArn",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connection = "VPCConnection",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const generate_embed_url_for_anonymous_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/embed-url/anonymous-user",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateEmbedUrlForAnonymousUser",
    Request: type = struct {
        aws_account_id: []const u8,
        session_lifetime_in_minutes: ?i64 = null,
        namespace: []const u8,
        session_tags: ?[]SessionTag = null,
        authorized_resource_arns: [][]const u8,
        experience_configuration: struct {
            dashboard: ?struct {
                initial_dashboard_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_dashboard_id = "InitialDashboardId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            dashboard_visual: ?struct {
                initial_dashboard_visual_id: DashboardVisualId,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_dashboard_visual_id = "InitialDashboardVisualId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            q_search_bar: ?struct {
                initial_topic_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_topic_id = "InitialTopicId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dashboard = "Dashboard",
                    .dashboard_visual = "DashboardVisual",
                    .q_search_bar = "QSearchBar",
                };
                return @field(mappings, field_name);
            }
        },
        allowed_domains: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .namespace = "Namespace",
                .session_tags = "SessionTags",
                .authorized_resource_arns = "AuthorizedResourceArns",
                .experience_configuration = "ExperienceConfiguration",
                .allowed_domains = "AllowedDomains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_embed_url_for_anonymous_user) } {
            return .{ .service_metadata = service_metadata, .action = generate_embed_url_for_anonymous_user };
        }
    },
    Response: type = struct {
        embed_url: []const u8,
        status: i64,
        request_id: []const u8,
        anonymous_user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
                .anonymous_user_arn = "AnonymousUserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedPricingPlan,
        UnsupportedUserEdition,
    },
} = .{};
pub const generate_embed_url_for_registered_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/embed-url/registered-user",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateEmbedUrlForRegisteredUser",
    Request: type = struct {
        aws_account_id: []const u8,
        session_lifetime_in_minutes: ?i64 = null,
        user_arn: []const u8,
        experience_configuration: struct {
            dashboard: ?struct {
                initial_dashboard_id: []const u8,
                feature_configurations: ?struct {
                    state_persistence: ?StatePersistenceConfigurations = null,
                    bookmarks: ?struct {
                        enabled: bool,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .enabled = "Enabled",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .state_persistence = "StatePersistence",
                            .bookmarks = "Bookmarks",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_dashboard_id = "InitialDashboardId",
                        .feature_configurations = "FeatureConfigurations",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            quick_sight_console: ?struct {
                initial_path: ?[]const u8 = null,
                feature_configurations: ?struct {
                    state_persistence: ?StatePersistenceConfigurations = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .state_persistence = "StatePersistence",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_path = "InitialPath",
                        .feature_configurations = "FeatureConfigurations",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            q_search_bar: ?struct {
                initial_topic_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_topic_id = "InitialTopicId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            dashboard_visual: ?struct {
                initial_dashboard_visual_id: DashboardVisualId,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .initial_dashboard_visual_id = "InitialDashboardVisualId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dashboard = "Dashboard",
                    .quick_sight_console = "QuickSightConsole",
                    .q_search_bar = "QSearchBar",
                    .dashboard_visual = "DashboardVisual",
                };
                return @field(mappings, field_name);
            }
        },
        allowed_domains: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .user_arn = "UserArn",
                .experience_configuration = "ExperienceConfiguration",
                .allowed_domains = "AllowedDomains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_embed_url_for_registered_user) } {
            return .{ .service_metadata = service_metadata, .action = generate_embed_url_for_registered_user };
        }
    },
    Response: type = struct {
        embed_url: []const u8,
        status: i64,
        request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        QuickSightUserNotFound,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedPricingPlan,
        UnsupportedUserEdition,
    },
} = .{};
pub const get_dashboard_embed_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/embed-url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDashboardEmbedUrl",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        identity_type: []const u8,
        session_lifetime_in_minutes: ?i64 = null,
        undo_redo_disabled: ?bool = null,
        reset_disabled: ?bool = null,
        state_persistence_enabled: ?bool = null,
        user_arn: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        additional_dashboard_ids: ?[][]const u8 = null,

        pub const http_query = .{
            .identity_type = "creds-type",
            .session_lifetime_in_minutes = "session-lifetime",
            .undo_redo_disabled = "undo-redo-disabled",
            .reset_disabled = "reset-disabled",
            .state_persistence_enabled = "state-persistence-enabled",
            .user_arn = "user-arn",
            .namespace = "namespace",
            .additional_dashboard_ids = "additional-dashboard-ids",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .identity_type = "IdentityType",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .undo_redo_disabled = "UndoRedoDisabled",
                .reset_disabled = "ResetDisabled",
                .state_persistence_enabled = "StatePersistenceEnabled",
                .user_arn = "UserArn",
                .namespace = "Namespace",
                .additional_dashboard_ids = "AdditionalDashboardIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dashboard_embed_url) } {
            return .{ .service_metadata = service_metadata, .action = get_dashboard_embed_url };
        }
    },
    Response: type = struct {
        embed_url: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DomainNotWhitelisted,
        IdentityTypeNotSupported,
        InternalFailure,
        InvalidParameterValue,
        QuickSightUserNotFound,
        ResourceExists,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedPricingPlan,
        UnsupportedUserEdition,
    },
} = .{};
pub const get_session_embed_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/session-embed-url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSessionEmbedUrl",
    Request: type = struct {
        aws_account_id: []const u8,
        entry_point: ?[]const u8 = null,
        session_lifetime_in_minutes: ?i64 = null,
        user_arn: ?[]const u8 = null,

        pub const http_query = .{
            .entry_point = "entry-point",
            .session_lifetime_in_minutes = "session-lifetime",
            .user_arn = "user-arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .entry_point = "EntryPoint",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .user_arn = "UserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session_embed_url) } {
            return .{ .service_metadata = service_metadata, .action = get_session_embed_url };
        }
    },
    Response: type = struct {
        embed_url: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        QuickSightUserNotFound,
        ResourceExists,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_analyses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnalyses",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_analyses) } {
            return .{ .service_metadata = service_metadata, .action = list_analyses };
        }
    },
    Response: type = struct {
        analysis_summary_list: ?[]AnalysisSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_summary_list = "AnalysisSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_asset_bundle_export_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-export-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetBundleExportJobs",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_bundle_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_bundle_export_jobs };
        }
    },
    Response: type = struct {
        asset_bundle_export_job_summary_list: ?[]struct {
            job_status: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            asset_bundle_export_job_id: ?[]const u8 = null,
            include_all_dependencies: ?bool = null,
            export_format: ?[]const u8 = null,
            include_permissions: ?bool = null,
            include_tags: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_status = "JobStatus",
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                    .asset_bundle_export_job_id = "AssetBundleExportJobId",
                    .include_all_dependencies = "IncludeAllDependencies",
                    .export_format = "ExportFormat",
                    .include_permissions = "IncludePermissions",
                    .include_tags = "IncludeTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_bundle_export_job_summary_list = "AssetBundleExportJobSummaryList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidNextToken,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_asset_bundle_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-import-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetBundleImportJobs",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_bundle_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_bundle_import_jobs };
        }
    },
    Response: type = struct {
        asset_bundle_import_job_summary_list: ?[]struct {
            job_status: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            asset_bundle_import_job_id: ?[]const u8 = null,
            failure_action: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_status = "JobStatus",
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                    .asset_bundle_import_job_id = "AssetBundleImportJobId",
                    .failure_action = "FailureAction",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .asset_bundle_import_job_summary_list = "AssetBundleImportJobSummaryList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidNextToken,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_dashboards: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDashboards",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dashboards) } {
            return .{ .service_metadata = service_metadata, .action = list_dashboards };
        }
    },
    Response: type = struct {
        dashboard_summary_list: ?[]DashboardSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_summary_list = "DashboardSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_dashboard_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDashboardVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dashboard_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_dashboard_versions };
        }
    },
    Response: type = struct {
        dashboard_version_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            version_number: ?i64 = null,
            status: ?[]const u8 = null,
            source_entity_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                    .version_number = "VersionNumber",
                    .status = "Status",
                    .source_entity_arn = "SourceEntityArn",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_version_summary_list = "DashboardVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_data_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSets",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sets };
        }
    },
    Response: type = struct {
        data_set_summaries: ?[]DataSetSummary = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_summaries = "DataSetSummaries",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
    },
} = .{};
pub const list_data_sources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        data_sources: ?[]DataSource = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_sources = "DataSources",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
    },
} = .{};
pub const list_folder_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFolderMembers",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_folder_members) } {
            return .{ .service_metadata = service_metadata, .action = list_folder_members };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_member_list: ?[]struct {
            member_id: ?[]const u8 = null,
            member_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_id = "MemberId",
                    .member_arn = "MemberArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_member_list = "FolderMemberList",
                .next_token = "NextToken",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_folders: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/folders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFolders",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_folders) } {
            return .{ .service_metadata = service_metadata, .action = list_folders };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_summary_list: ?[]FolderSummary = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_summary_list = "FolderSummaryList",
                .next_token = "NextToken",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_group_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroupMemberships",
    Request: type = struct {
        group_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_group_memberships };
        }
    },
    Response: type = struct {
        group_member_list: ?[]GroupMember = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_member_list = "GroupMemberList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        group_list: ?[]Group = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_list = "GroupList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_iam_policy_assignments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/v2/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIAMPolicyAssignments",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_status: ?[]const u8 = null,
        namespace: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .assignment_status = "assignment-status",
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_status = "AssignmentStatus",
                .namespace = "Namespace",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_iam_policy_assignments) } {
            return .{ .service_metadata = service_metadata, .action = list_iam_policy_assignments };
        }
    },
    Response: type = struct {
        iam_policy_assignments: ?[]struct {
            assignment_name: ?[]const u8 = null,
            assignment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assignment_name = "AssignmentName",
                    .assignment_status = "AssignmentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_policy_assignments = "IAMPolicyAssignments",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_iam_policy_assignments_for_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIAMPolicyAssignmentsForUser",
    Request: type = struct {
        aws_account_id: []const u8,
        user_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .user_name = "UserName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_iam_policy_assignments_for_user) } {
            return .{ .service_metadata = service_metadata, .action = list_iam_policy_assignments_for_user };
        }
    },
    Response: type = struct {
        active_assignments: ?[]struct {
            assignment_name: ?[]const u8 = null,
            policy_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assignment_name = "AssignmentName",
                    .policy_arn = "PolicyArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_assignments = "ActiveAssignments",
                .request_id = "RequestId",
                .next_token = "NextToken",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_identity_propagation_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/identity-propagation-config",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdentityPropagationConfigs",
    Request: type = struct {
        aws_account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_propagation_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_propagation_configs };
        }
    },
    Response: type = struct {
        services: ?[]struct {
            service: ?[]const u8 = null,
            authorized_targets: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "Service",
                    .authorized_targets = "AuthorizedTargets",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "Services",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_ingestions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIngestions",
    Request: type = struct {
        data_set_id: []const u8,
        next_token: ?[]const u8 = null,
        aws_account_id: []const u8,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .next_token = "NextToken",
                .aws_account_id = "AwsAccountId",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ingestions) } {
            return .{ .service_metadata = service_metadata, .action = list_ingestions };
        }
    },
    Response: type = struct {
        ingestions: ?[]Ingestion = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestions = "Ingestions",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_namespaces: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNamespaces",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_namespaces) } {
            return .{ .service_metadata = service_metadata, .action = list_namespaces };
        }
    },
    Response: type = struct {
        namespaces: ?[]NamespaceInfoV2 = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespaces = "Namespaces",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_refresh_schedules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRefreshSchedules",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_refresh_schedules) } {
            return .{ .service_metadata = service_metadata, .action = list_refresh_schedules };
        }
    },
    Response: type = struct {
        refresh_schedules: ?[]RefreshSchedule = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schedules = "RefreshSchedules",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_role_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoleMemberships",
    Request: type = struct {
        role: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role = "Role",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_role_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_role_memberships };
        }
    },
    Response: type = struct {
        members_list: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members_list = "MembersList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_template_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateAliases",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_template_aliases };
        }
    },
    Response: type = struct {
        template_alias_list: ?[]TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias_list = "TemplateAliasList",
                .status = "Status",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplates",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_templates };
        }
    },
    Response: type = struct {
        template_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            template_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            latest_version_number: ?i64 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .template_id = "TemplateId",
                    .name = "Name",
                    .latest_version_number = "LatestVersionNumber",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_summary_list = "TemplateSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_template_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_template_versions };
        }
    },
    Response: type = struct {
        template_version_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            version_number: ?i64 = null,
            created_time: ?i64 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .version_number = "VersionNumber",
                    .created_time = "CreatedTime",
                    .status = "Status",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_version_summary_list = "TemplateVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_theme_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemeAliases",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_theme_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_theme_aliases };
        }
    },
    Response: type = struct {
        theme_alias_list: ?[]ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias_list = "ThemeAliasList",
                .status = "Status",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_themes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemes",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
            .type = "type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_themes) } {
            return .{ .service_metadata = service_metadata, .action = list_themes };
        }
    },
    Response: type = struct {
        theme_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            theme_id: ?[]const u8 = null,
            latest_version_number: ?i64 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .theme_id = "ThemeId",
                    .latest_version_number = "LatestVersionNumber",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_summary_list = "ThemeSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_theme_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemeVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_theme_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_theme_versions };
        }
    },
    Response: type = struct {
        theme_version_summary_list: ?[]struct {
            version_number: ?i64 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_time: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_number = "VersionNumber",
                    .arn = "Arn",
                    .description = "Description",
                    .created_time = "CreatedTime",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_version_summary_list = "ThemeVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_topic_refresh_schedules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTopicRefreshSchedules",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_topic_refresh_schedules) } {
            return .{ .service_metadata = service_metadata, .action = list_topic_refresh_schedules };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        refresh_schedules: ?[]struct {
            dataset_id: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            refresh_schedule: ?TopicRefreshSchedule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_id = "DatasetId",
                    .dataset_arn = "DatasetArn",
                    .dataset_name = "DatasetName",
                    .refresh_schedule = "RefreshSchedule",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .refresh_schedules = "RefreshSchedules",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_topics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/topics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTopics",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_topics) } {
            return .{ .service_metadata = service_metadata, .action = list_topics };
        }
    },
    Response: type = struct {
        topics_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            topic_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .topic_id = "TopicId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topics_summaries = "TopicsSummaries",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
    },
} = .{};
pub const list_user_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserGroups",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_user_groups };
        }
    },
    Response: type = struct {
        group_list: ?[]Group = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_list = "GroupList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        user_list: ?[]User = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_list = "UserList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_vpc_connections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/vpc-connections",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVPCConnections",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_connections };
        }
    },
    Response: type = struct {
        vpc_connection_summaries: ?[]struct {
            vpc_connection_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            dns_resolvers: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            availability_status: ?[]const u8 = null,
            network_interfaces: ?[]NetworkInterface = null,
            role_arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_connection_id = "VPCConnectionId",
                    .arn = "Arn",
                    .name = "Name",
                    .vpc_id = "VPCId",
                    .security_group_ids = "SecurityGroupIds",
                    .dns_resolvers = "DnsResolvers",
                    .status = "Status",
                    .availability_status = "AvailabilityStatus",
                    .network_interfaces = "NetworkInterfaces",
                    .role_arn = "RoleArn",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_connection_summaries = "VPCConnectionSummaries",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const put_data_set_refresh_properties: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-properties",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDataSetRefreshProperties",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        data_set_refresh_properties: DataSetRefreshProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .data_set_refresh_properties = "DataSetRefreshProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_set_refresh_properties) } {
            return .{ .service_metadata = service_metadata, .action = put_data_set_refresh_properties };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const register_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterUser",
    Request: type = struct {
        identity_type: []const u8,
        email: []const u8,
        user_role: []const u8,
        iam_arn: ?[]const u8 = null,
        session_name: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,
        user_name: ?[]const u8 = null,
        custom_permissions_name: ?[]const u8 = null,
        external_login_federation_provider_type: ?[]const u8 = null,
        custom_federation_provider_url: ?[]const u8 = null,
        external_login_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .email = "Email",
                .user_role = "UserRole",
                .iam_arn = "IamArn",
                .session_name = "SessionName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .user_name = "UserName",
                .custom_permissions_name = "CustomPermissionsName",
                .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
                .custom_federation_provider_url = "CustomFederationProviderUrl",
                .external_login_id = "ExternalLoginId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_user) } {
            return .{ .service_metadata = service_metadata, .action = register_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        user_invitation_url: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .user_invitation_url = "UserInvitationUrl",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const restore_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/restore/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_analysis) } {
            return .{ .service_metadata = service_metadata, .action = restore_analysis };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_analyses: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/analyses",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAnalyses",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: ?[]const u8 = null,
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_analyses) } {
            return .{ .service_metadata = service_metadata, .action = search_analyses };
        }
    },
    Response: type = struct {
        analysis_summary_list: ?[]AnalysisSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_summary_list = "AnalysisSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_dashboards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/dashboards",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchDashboards",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: []const u8,
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_dashboards) } {
            return .{ .service_metadata = service_metadata, .action = search_dashboards };
        }
    },
    Response: type = struct {
        dashboard_summary_list: ?[]DashboardSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_summary_list = "DashboardSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_data_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchDataSets",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: []const u8,
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_data_sets) } {
            return .{ .service_metadata = service_metadata, .action = search_data_sets };
        }
    },
    Response: type = struct {
        data_set_summaries: ?[]DataSetSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_summaries = "DataSetSummaries",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_data_sources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/data-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchDataSources",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: []const u8,
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = search_data_sources };
        }
    },
    Response: type = struct {
        data_source_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            data_source_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .data_source_id = "DataSourceId",
                    .name = "Name",
                    .type = "Type",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_summaries = "DataSourceSummaries",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_folders: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/folders",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchFolders",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: ?[]const u8 = null,
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_folders) } {
            return .{ .service_metadata = service_metadata, .action = search_folders };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        folder_summary_list: ?[]FolderSummary = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .folder_summary_list = "FolderSummaryList",
                .next_token = "NextToken",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_groups: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups-search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchGroups",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,
        filters: []struct {
            operator: []const u8,
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_groups) } {
            return .{ .service_metadata = service_metadata, .action = search_groups };
        }
    },
    Response: type = struct {
        group_list: ?[]Group = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_list = "GroupList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const start_asset_bundle_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-export-jobs/export",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAssetBundleExportJob",
    Request: type = struct {
        aws_account_id: []const u8,
        asset_bundle_export_job_id: []const u8,
        resource_arns: [][]const u8,
        include_all_dependencies: ?bool = null,
        export_format: []const u8,
        cloud_formation_override_property_configuration: ?AssetBundleCloudFormationOverridePropertyConfiguration = null,
        include_permissions: ?bool = null,
        include_tags: ?bool = null,
        validation_strategy: ?AssetBundleExportJobValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .asset_bundle_export_job_id = "AssetBundleExportJobId",
                .resource_arns = "ResourceArns",
                .include_all_dependencies = "IncludeAllDependencies",
                .export_format = "ExportFormat",
                .cloud_formation_override_property_configuration = "CloudFormationOverridePropertyConfiguration",
                .include_permissions = "IncludePermissions",
                .include_tags = "IncludeTags",
                .validation_strategy = "ValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_asset_bundle_export_job) } {
            return .{ .service_metadata = service_metadata, .action = start_asset_bundle_export_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_bundle_export_job_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_bundle_export_job_id = "AssetBundleExportJobId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const start_asset_bundle_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/asset-bundle-import-jobs/import",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAssetBundleImportJob",
    Request: type = struct {
        aws_account_id: []const u8,
        asset_bundle_import_job_id: []const u8,
        asset_bundle_import_source: struct {
            body: ?[]const u8 = null,
            s3_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .body = "Body",
                    .s3_uri = "S3Uri",
                };
                return @field(mappings, field_name);
            }
        },
        override_parameters: ?AssetBundleImportJobOverrideParameters = null,
        failure_action: ?[]const u8 = null,
        override_permissions: ?AssetBundleImportJobOverridePermissions = null,
        override_tags: ?AssetBundleImportJobOverrideTags = null,
        override_validation_strategy: ?AssetBundleImportJobOverrideValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .asset_bundle_import_job_id = "AssetBundleImportJobId",
                .asset_bundle_import_source = "AssetBundleImportSource",
                .override_parameters = "OverrideParameters",
                .failure_action = "FailureAction",
                .override_permissions = "OverridePermissions",
                .override_tags = "OverrideTags",
                .override_validation_strategy = "OverrideValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_asset_bundle_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_asset_bundle_import_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        asset_bundle_import_job_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .asset_bundle_import_job_id = "AssetBundleImportJobId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const start_dashboard_snapshot_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/snapshot-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDashboardSnapshotJob",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        snapshot_job_id: []const u8,
        user_configuration: struct {
            anonymous_users: ?[]struct {
                row_level_permission_tags: ?[]SessionTag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .row_level_permission_tags = "RowLevelPermissionTags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anonymous_users = "AnonymousUsers",
                };
                return @field(mappings, field_name);
            }
        },
        snapshot_configuration: SnapshotConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .snapshot_job_id = "SnapshotJobId",
                .user_configuration = "UserConfiguration",
                .snapshot_configuration = "SnapshotConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_dashboard_snapshot_job) } {
            return .{ .service_metadata = service_metadata, .action = start_dashboard_snapshot_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        snapshot_job_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .snapshot_job_id = "SnapshotJobId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedPricingPlan,
        UnsupportedUserEdition,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "keys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_account_customization: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        account_customization: AccountCustomization,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = update_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_account_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountSettings",
    Request: type = struct {
        aws_account_id: []const u8,
        default_namespace: []const u8,
        notification_email: ?[]const u8 = null,
        termination_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .default_namespace = "DefaultNamespace",
                .notification_email = "NotificationEmail",
                .termination_protection_enabled = "TerminationProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_account_settings };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_analysis: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        source_entity: ?AnalysisSourceEntity = null,
        theme_arn: ?[]const u8 = null,
        definition: ?AnalysisDefinition = null,
        validation_strategy: ?ValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .name = "Name",
                .parameters = "Parameters",
                .source_entity = "SourceEntity",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_analysis) } {
            return .{ .service_metadata = service_metadata, .action = update_analysis };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        update_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .update_status = "UpdateStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_analysis_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnalysisPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_analysis_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_analysis_permissions };
        }
    },
    Response: type = struct {
        analysis_arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_arn = "AnalysisArn",
                .analysis_id = "AnalysisId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        name: []const u8,
        source_entity: ?DashboardSourceEntity = null,
        parameters: ?Parameters = null,
        version_description: ?[]const u8 = null,
        dashboard_publish_options: ?DashboardPublishOptions = null,
        theme_arn: ?[]const u8 = null,
        definition: ?DashboardVersionDefinition = null,
        validation_strategy: ?ValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .name = "Name",
                .source_entity = "SourceEntity",
                .parameters = "Parameters",
                .version_description = "VersionDescription",
                .dashboard_publish_options = "DashboardPublishOptions",
                .theme_arn = "ThemeArn",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .dashboard_id = "DashboardId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard_links: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/linked-entities",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboardLinks",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        link_entities: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .link_entities = "LinkEntities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard_links) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard_links };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        dashboard_arn: ?[]const u8 = null,
        link_entities: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
                .dashboard_arn = "DashboardArn",
                .link_entities = "LinkEntities",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboardPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,
        grant_link_permissions: ?[]ResourcePermission = null,
        revoke_link_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
                .grant_link_permissions = "GrantLinkPermissions",
                .revoke_link_permissions = "RevokeLinkPermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard_permissions };
        }
    },
    Response: type = struct {
        dashboard_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        link_sharing_configuration: ?LinkSharingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_arn = "DashboardArn",
                .dashboard_id = "DashboardId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
                .link_sharing_configuration = "LinkSharingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard_published_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/versions/{VersionNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboardPublishedVersion",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard_published_version) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard_published_version };
        }
    },
    Response: type = struct {
        dashboard_id: ?[]const u8 = null,
        dashboard_arn: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "DashboardId",
                .dashboard_arn = "DashboardArn",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_data_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        name: []const u8,
        physical_table_map: []struct {
            key: ?[]const u8 = null,
            value: ?PhysicalTable = null,
        },
        logical_table_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogicalTable = null,
        } = null,
        import_mode: []const u8,
        column_groups: ?[]ColumnGroup = null,
        field_folders: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FieldFolder = null,
        } = null,
        row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
        row_level_permission_tag_configuration: ?RowLevelPermissionTagConfiguration = null,
        column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,
        data_set_usage_configuration: ?DataSetUsageConfiguration = null,
        dataset_parameters: ?[]DatasetParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .name = "Name",
                .physical_table_map = "PhysicalTableMap",
                .logical_table_map = "LogicalTableMap",
                .import_mode = "ImportMode",
                .column_groups = "ColumnGroups",
                .field_folders = "FieldFolders",
                .row_level_permission_data_set = "RowLevelPermissionDataSet",
                .row_level_permission_tag_configuration = "RowLevelPermissionTagConfiguration",
                .column_level_permission_rules = "ColumnLevelPermissionRules",
                .data_set_usage_configuration = "DataSetUsageConfiguration",
                .dataset_parameters = "DatasetParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "physical_table_map", field_name))
                return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "logical_table_map", field_name))
                return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "field_folders", field_name))
                return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_set) } {
            return .{ .service_metadata = service_metadata, .action = update_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        ingestion_arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .ingestion_arn = "IngestionArn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_data_set_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSetPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_set_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_data_set_permissions };
        }
    },
    Response: type = struct {
        data_set_arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_arn = "DataSetArn",
                .data_set_id = "DataSetId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_data_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        name: []const u8,
        data_source_parameters: ?DataSourceParameters = null,
        credentials: ?DataSourceCredentials = null,
        vpc_connection_properties: ?VpcConnectionProperties = null,
        ssl_properties: ?SslProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .name = "Name",
                .data_source_parameters = "DataSourceParameters",
                .credentials = "Credentials",
                .vpc_connection_properties = "VpcConnectionProperties",
                .ssl_properties = "SslProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        update_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .update_status = "UpdateStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_data_source_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSourcePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source_permissions };
        }
    },
    Response: type = struct {
        data_source_arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_arn = "DataSourceArn",
                .data_source_id = "DataSourceId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_folder: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFolder",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_folder) } {
            return .{ .service_metadata = service_metadata, .action = update_folder };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        folder_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .folder_id = "FolderId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_folder_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/folders/{FolderId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFolderPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        folder_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .folder_id = "FolderId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_folder_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_folder_permissions };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        folder_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .folder_id = "FolderId",
                .permissions = "Permissions",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_name: []const u8,
        description: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .description = "Description",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,
        assignment_status: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = update_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        assignment_id: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        assignment_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .assignment_id = "AssignmentId",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .assignment_status = "AssignmentStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_identity_propagation_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/identity-propagation-config/{Service}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIdentityPropagationConfig",
    Request: type = struct {
        aws_account_id: []const u8,
        service: []const u8,
        authorized_targets: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .service = "Service",
                .authorized_targets = "AuthorizedTargets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_identity_propagation_config) } {
            return .{ .service_metadata = service_metadata, .action = update_identity_propagation_config };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_ip_restriction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/ip-restriction",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIpRestriction",
    Request: type = struct {
        aws_account_id: []const u8,
        ip_restriction_rule_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .ip_restriction_rule_map = "IpRestrictionRuleMap",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "ip_restriction_rule_map", field_name))
                return try serializeMap(self.ip_restriction_rule_map, self.fieldNameFor("ip_restriction_rule_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ip_restriction) } {
            return .{ .service_metadata = service_metadata, .action = update_ip_restriction };
        }
    },
    Response: type = struct {
        aws_account_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_public_sharing_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/public-sharing-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePublicSharingSettings",
    Request: type = struct {
        aws_account_id: []const u8,
        public_sharing_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .public_sharing_enabled = "PublicSharingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_public_sharing_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_public_sharing_settings };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedPricingPlan,
    },
} = .{};
pub const update_refresh_schedule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/refresh-schedules",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRefreshSchedule",
    Request: type = struct {
        data_set_id: []const u8,
        aws_account_id: []const u8,
        schedule: RefreshSchedule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .aws_account_id = "AwsAccountId",
                .schedule = "Schedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_refresh_schedule };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        schedule_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .request_id = "RequestId",
                .schedule_id = "ScheduleId",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_role_custom_permission: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/roles/{Role}/custom-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoleCustomPermission",
    Request: type = struct {
        custom_permissions_name: []const u8,
        role: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_permissions_name = "CustomPermissionsName",
                .role = "Role",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_role_custom_permission) } {
            return .{ .service_metadata = service_metadata, .action = update_role_custom_permission };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        source_entity: ?TemplateSourceEntity = null,
        version_description: ?[]const u8 = null,
        name: ?[]const u8 = null,
        definition: ?TemplateVersionDefinition = null,
        validation_strategy: ?ValidationStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .source_entity = "SourceEntity",
                .version_description = "VersionDescription",
                .name = "Name",
                .definition = "Definition",
                .validation_strategy = "ValidationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template) } {
            return .{ .service_metadata = service_metadata, .action = update_template };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .arn = "Arn",
                .version_arn = "VersionArn",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_template_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,
        template_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .template_version_number = "TemplateVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_template_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplatePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_template_permissions };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        template_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .template_arn = "TemplateArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        name: ?[]const u8 = null,
        base_theme_id: []const u8,
        version_description: ?[]const u8 = null,
        configuration: ?ThemeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .name = "Name",
                .base_theme_id = "BaseThemeId",
                .version_description = "VersionDescription",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme) } {
            return .{ .service_metadata = service_metadata, .action = update_theme };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .arn = "Arn",
                .version_arn = "VersionArn",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,
        theme_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
                .theme_version_number = "ThemeVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThemePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_theme_permissions };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .theme_arn = "ThemeArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_topic: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTopic",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        topic: TopicDetails,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .topic = "Topic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_topic) } {
            return .{ .service_metadata = service_metadata, .action = update_topic };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        refresh_arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .arn = "Arn",
                .refresh_arn = "RefreshArn",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_topic_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTopicPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_topic_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_topic_permissions };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_topic_refresh_schedule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/topics/{TopicId}/schedules/{DatasetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTopicRefreshSchedule",
    Request: type = struct {
        aws_account_id: []const u8,
        topic_id: []const u8,
        dataset_id: []const u8,
        refresh_schedule: TopicRefreshSchedule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .topic_id = "TopicId",
                .dataset_id = "DatasetId",
                .refresh_schedule = "RefreshSchedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_topic_refresh_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_topic_refresh_schedule };
        }
    },
    Response: type = struct {
        topic_id: ?[]const u8 = null,
        topic_arn: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_id = "TopicId",
                .topic_arn = "TopicArn",
                .dataset_arn = "DatasetArn",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,
        email: []const u8,
        role: []const u8,
        custom_permissions_name: ?[]const u8 = null,
        unapply_custom_permissions: ?bool = null,
        external_login_federation_provider_type: ?[]const u8 = null,
        custom_federation_provider_url: ?[]const u8 = null,
        external_login_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .email = "Email",
                .role = "Role",
                .custom_permissions_name = "CustomPermissionsName",
                .unapply_custom_permissions = "UnapplyCustomPermissions",
                .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
                .custom_federation_provider_url = "CustomFederationProviderUrl",
                .external_login_id = "ExternalLoginId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_vpc_connection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/vpc-connections/{VPCConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVPCConnection",
    Request: type = struct {
        aws_account_id: []const u8,
        vpc_connection_id: []const u8,
        name: []const u8,
        subnet_ids: [][]const u8,
        security_group_ids: [][]const u8,
        dns_resolvers: ?[][]const u8 = null,
        role_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .vpc_connection_id = "VPCConnectionId",
                .name = "Name",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .dns_resolvers = "DnsResolvers",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_connection };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        vpc_connection_id: ?[]const u8 = null,
        update_status: ?[]const u8 = null,
        availability_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .vpc_connection_id = "VPCConnectionId",
                .update_status = "UpdateStatus",
                .availability_status = "AvailabilityStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};

pub const User = struct {
    arn: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    email: ?[]const u8 = null,
    role: ?[]const u8 = null,
    identity_type: ?[]const u8 = null,
    active: ?bool = null,
    principal_id: ?[]const u8 = null,
    custom_permissions_name: ?[]const u8 = null,
    external_login_federation_provider_type: ?[]const u8 = null,
    external_login_federation_provider_url: ?[]const u8 = null,
    external_login_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .user_name = "UserName",
            .email = "Email",
            .role = "Role",
            .identity_type = "IdentityType",
            .active = "Active",
            .principal_id = "PrincipalId",
            .custom_permissions_name = "CustomPermissionsName",
            .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
            .external_login_federation_provider_url = "ExternalLoginFederationProviderUrl",
            .external_login_id = "ExternalLoginId",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicRefreshSchedule = struct {
    is_enabled: bool,
    based_on_spice_schedule: bool,
    starting_at: ?i64 = null,
    timezone: ?[]const u8 = null,
    repeat_at: ?[]const u8 = null,
    topic_schedule_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
            .based_on_spice_schedule = "BasedOnSpiceSchedule",
            .starting_at = "StartingAt",
            .timezone = "Timezone",
            .repeat_at = "RepeatAt",
            .topic_schedule_type = "TopicScheduleType",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePermission = struct {
    principal: []const u8,
    actions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicDetails = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    user_experience_version: ?[]const u8 = null,
    data_sets: ?[]DatasetMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .user_experience_version = "UserExperienceVersion",
            .data_sets = "DataSets",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetMetadata = struct {
    dataset_arn: []const u8,
    dataset_name: ?[]const u8 = null,
    dataset_description: ?[]const u8 = null,
    data_aggregation: ?DataAggregation = null,
    filters: ?[]TopicFilter = null,
    columns: ?[]TopicColumn = null,
    calculated_fields: ?[]TopicCalculatedField = null,
    named_entities: ?[]TopicNamedEntity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_arn = "DatasetArn",
            .dataset_name = "DatasetName",
            .dataset_description = "DatasetDescription",
            .data_aggregation = "DataAggregation",
            .filters = "Filters",
            .columns = "Columns",
            .calculated_fields = "CalculatedFields",
            .named_entities = "NamedEntities",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicNamedEntity = struct {
    entity_name: []const u8,
    entity_description: ?[]const u8 = null,
    entity_synonyms: ?[][]const u8 = null,
    semantic_entity_type: ?SemanticEntityType = null,
    definition: ?[]NamedEntityDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entity_name = "EntityName",
            .entity_description = "EntityDescription",
            .entity_synonyms = "EntitySynonyms",
            .semantic_entity_type = "SemanticEntityType",
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }
};

pub const NamedEntityDefinition = struct {
    field_name: ?[]const u8 = null,
    property_name: ?[]const u8 = null,
    property_role: ?[]const u8 = null,
    property_usage: ?[]const u8 = null,
    metric: ?NamedEntityDefinitionMetric = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_name = "FieldName",
            .property_name = "PropertyName",
            .property_role = "PropertyRole",
            .property_usage = "PropertyUsage",
            .metric = "Metric",
        };
        return @field(mappings, field_name);
    }
};

pub const NamedEntityDefinitionMetric = struct {
    aggregation: ?[]const u8 = null,
    aggregation_function_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregation = "Aggregation",
            .aggregation_function_parameters = "AggregationFunctionParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "aggregation_function_parameters", field_name))
            return try serializeMap(self.aggregation_function_parameters, self.fieldNameFor("aggregation_function_parameters"), options, out_stream);
        return false;
    }
};

pub const SemanticEntityType = struct {
    type_name: ?[]const u8 = null,
    sub_type_name: ?[]const u8 = null,
    type_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_name = "TypeName",
            .sub_type_name = "SubTypeName",
            .type_parameters = "TypeParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "type_parameters", field_name))
            return try serializeMap(self.type_parameters, self.fieldNameFor("type_parameters"), options, out_stream);
        return false;
    }
};

pub const TopicCalculatedField = struct {
    calculated_field_name: []const u8,
    calculated_field_description: ?[]const u8 = null,
    expression: []const u8,
    calculated_field_synonyms: ?[][]const u8 = null,
    is_included_in_topic: ?bool = null,
    disable_indexing: ?bool = null,
    column_data_role: ?[]const u8 = null,
    time_granularity: ?[]const u8 = null,
    default_formatting: ?DefaultFormatting = null,
    aggregation: ?[]const u8 = null,
    comparative_order: ?ComparativeOrder = null,
    semantic_type: ?SemanticType = null,
    allowed_aggregations: ?[][]const u8 = null,
    not_allowed_aggregations: ?[][]const u8 = null,
    never_aggregate_in_filter: ?bool = null,
    cell_value_synonyms: ?[]CellValueSynonym = null,
    non_additive: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .calculated_field_name = "CalculatedFieldName",
            .calculated_field_description = "CalculatedFieldDescription",
            .expression = "Expression",
            .calculated_field_synonyms = "CalculatedFieldSynonyms",
            .is_included_in_topic = "IsIncludedInTopic",
            .disable_indexing = "DisableIndexing",
            .column_data_role = "ColumnDataRole",
            .time_granularity = "TimeGranularity",
            .default_formatting = "DefaultFormatting",
            .aggregation = "Aggregation",
            .comparative_order = "ComparativeOrder",
            .semantic_type = "SemanticType",
            .allowed_aggregations = "AllowedAggregations",
            .not_allowed_aggregations = "NotAllowedAggregations",
            .never_aggregate_in_filter = "NeverAggregateInFilter",
            .cell_value_synonyms = "CellValueSynonyms",
            .non_additive = "NonAdditive",
        };
        return @field(mappings, field_name);
    }
};

pub const CellValueSynonym = struct {
    cell_value: ?[]const u8 = null,
    synonyms: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cell_value = "CellValue",
            .synonyms = "Synonyms",
        };
        return @field(mappings, field_name);
    }
};

pub const SemanticType = struct {
    type_name: ?[]const u8 = null,
    sub_type_name: ?[]const u8 = null,
    type_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    truthy_cell_value: ?[]const u8 = null,
    truthy_cell_value_synonyms: ?[][]const u8 = null,
    falsey_cell_value: ?[]const u8 = null,
    falsey_cell_value_synonyms: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_name = "TypeName",
            .sub_type_name = "SubTypeName",
            .type_parameters = "TypeParameters",
            .truthy_cell_value = "TruthyCellValue",
            .truthy_cell_value_synonyms = "TruthyCellValueSynonyms",
            .falsey_cell_value = "FalseyCellValue",
            .falsey_cell_value_synonyms = "FalseyCellValueSynonyms",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "type_parameters", field_name))
            return try serializeMap(self.type_parameters, self.fieldNameFor("type_parameters"), options, out_stream);
        return false;
    }
};

pub const ComparativeOrder = struct {
    use_ordering: ?[]const u8 = null,
    specifed_order: ?[][]const u8 = null,
    treat_undefined_specified_values: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .use_ordering = "UseOrdering",
            .specifed_order = "SpecifedOrder",
            .treat_undefined_specified_values = "TreatUndefinedSpecifiedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultFormatting = struct {
    display_format: ?[]const u8 = null,
    display_format_options: ?DisplayFormatOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_format = "DisplayFormat",
            .display_format_options = "DisplayFormatOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DisplayFormatOptions = struct {
    use_blank_cell_format: ?bool = null,
    blank_cell_format: ?[]const u8 = null,
    date_format: ?[]const u8 = null,
    decimal_separator: ?[]const u8 = null,
    grouping_separator: ?[]const u8 = null,
    use_grouping: ?bool = null,
    fraction_digits: ?i64 = null,
    prefix: ?[]const u8 = null,
    suffix: ?[]const u8 = null,
    unit_scaler: ?[]const u8 = null,
    negative_format: ?NegativeFormat = null,
    currency_symbol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .use_blank_cell_format = "UseBlankCellFormat",
            .blank_cell_format = "BlankCellFormat",
            .date_format = "DateFormat",
            .decimal_separator = "DecimalSeparator",
            .grouping_separator = "GroupingSeparator",
            .use_grouping = "UseGrouping",
            .fraction_digits = "FractionDigits",
            .prefix = "Prefix",
            .suffix = "Suffix",
            .unit_scaler = "UnitScaler",
            .negative_format = "NegativeFormat",
            .currency_symbol = "CurrencySymbol",
        };
        return @field(mappings, field_name);
    }
};

pub const NegativeFormat = struct {
    prefix: ?[]const u8 = null,
    suffix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .suffix = "Suffix",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicColumn = struct {
    column_name: []const u8,
    column_friendly_name: ?[]const u8 = null,
    column_description: ?[]const u8 = null,
    column_synonyms: ?[][]const u8 = null,
    column_data_role: ?[]const u8 = null,
    aggregation: ?[]const u8 = null,
    is_included_in_topic: ?bool = null,
    disable_indexing: ?bool = null,
    comparative_order: ?ComparativeOrder = null,
    semantic_type: ?SemanticType = null,
    time_granularity: ?[]const u8 = null,
    allowed_aggregations: ?[][]const u8 = null,
    not_allowed_aggregations: ?[][]const u8 = null,
    default_formatting: ?DefaultFormatting = null,
    never_aggregate_in_filter: ?bool = null,
    cell_value_synonyms: ?[]CellValueSynonym = null,
    non_additive: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_friendly_name = "ColumnFriendlyName",
            .column_description = "ColumnDescription",
            .column_synonyms = "ColumnSynonyms",
            .column_data_role = "ColumnDataRole",
            .aggregation = "Aggregation",
            .is_included_in_topic = "IsIncludedInTopic",
            .disable_indexing = "DisableIndexing",
            .comparative_order = "ComparativeOrder",
            .semantic_type = "SemanticType",
            .time_granularity = "TimeGranularity",
            .allowed_aggregations = "AllowedAggregations",
            .not_allowed_aggregations = "NotAllowedAggregations",
            .default_formatting = "DefaultFormatting",
            .never_aggregate_in_filter = "NeverAggregateInFilter",
            .cell_value_synonyms = "CellValueSynonyms",
            .non_additive = "NonAdditive",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicFilter = struct {
    filter_description: ?[]const u8 = null,
    filter_class: ?[]const u8 = null,
    filter_name: []const u8,
    filter_synonyms: ?[][]const u8 = null,
    operand_field_name: []const u8,
    filter_type: ?[]const u8 = null,
    category_filter: ?TopicCategoryFilter = null,
    numeric_equality_filter: ?TopicNumericEqualityFilter = null,
    numeric_range_filter: ?TopicNumericRangeFilter = null,
    date_range_filter: ?TopicDateRangeFilter = null,
    relative_date_filter: ?TopicRelativeDateFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_description = "FilterDescription",
            .filter_class = "FilterClass",
            .filter_name = "FilterName",
            .filter_synonyms = "FilterSynonyms",
            .operand_field_name = "OperandFieldName",
            .filter_type = "FilterType",
            .category_filter = "CategoryFilter",
            .numeric_equality_filter = "NumericEqualityFilter",
            .numeric_range_filter = "NumericRangeFilter",
            .date_range_filter = "DateRangeFilter",
            .relative_date_filter = "RelativeDateFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicRelativeDateFilter = struct {
    time_granularity: ?[]const u8 = null,
    relative_date_filter_function: ?[]const u8 = null,
    constant: ?TopicSingularFilterConstant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_granularity = "TimeGranularity",
            .relative_date_filter_function = "RelativeDateFilterFunction",
            .constant = "Constant",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicSingularFilterConstant = struct {
    constant_type: ?[]const u8 = null,
    singular_constant: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_type = "ConstantType",
            .singular_constant = "SingularConstant",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicDateRangeFilter = struct {
    inclusive: ?bool = null,
    constant: ?TopicRangeFilterConstant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inclusive = "Inclusive",
            .constant = "Constant",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicRangeFilterConstant = struct {
    constant_type: ?[]const u8 = null,
    range_constant: ?RangeConstant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_type = "ConstantType",
            .range_constant = "RangeConstant",
        };
        return @field(mappings, field_name);
    }
};

pub const RangeConstant = struct {
    minimum: ?[]const u8 = null,
    maximum: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum = "Minimum",
            .maximum = "Maximum",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicNumericRangeFilter = struct {
    inclusive: ?bool = null,
    constant: ?TopicRangeFilterConstant = null,
    aggregation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inclusive = "Inclusive",
            .constant = "Constant",
            .aggregation = "Aggregation",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicNumericEqualityFilter = struct {
    constant: ?TopicSingularFilterConstant = null,
    aggregation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant = "Constant",
            .aggregation = "Aggregation",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicCategoryFilter = struct {
    category_filter_function: ?[]const u8 = null,
    category_filter_type: ?[]const u8 = null,
    constant: ?TopicCategoryFilterConstant = null,
    inverse: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_filter_function = "CategoryFilterFunction",
            .category_filter_type = "CategoryFilterType",
            .constant = "Constant",
            .inverse = "Inverse",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicCategoryFilterConstant = struct {
    constant_type: ?[]const u8 = null,
    singular_constant: ?[]const u8 = null,
    collective_constant: ?CollectiveConstant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_type = "ConstantType",
            .singular_constant = "SingularConstant",
            .collective_constant = "CollectiveConstant",
        };
        return @field(mappings, field_name);
    }
};

pub const CollectiveConstant = struct {
    value_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_list = "ValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const DataAggregation = struct {
    dataset_row_date_granularity: ?[]const u8 = null,
    default_date_column_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_row_date_granularity = "DatasetRowDateGranularity",
            .default_date_column_name = "DefaultDateColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const ThemeAlias = struct {
    arn: ?[]const u8 = null,
    alias_name: ?[]const u8 = null,
    theme_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .alias_name = "AliasName",
            .theme_version_number = "ThemeVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const ThemeConfiguration = struct {
    data_color_palette: ?DataColorPalette = null,
    ui_color_palette: ?UIColorPalette = null,
    sheet: ?SheetStyle = null,
    typography: ?Typography = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_color_palette = "DataColorPalette",
            .ui_color_palette = "UIColorPalette",
            .sheet = "Sheet",
            .typography = "Typography",
        };
        return @field(mappings, field_name);
    }
};

pub const Typography = struct {
    font_families: ?[]Font = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_families = "FontFamilies",
        };
        return @field(mappings, field_name);
    }
};

pub const Font = struct {
    font_family: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_family = "FontFamily",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetStyle = struct {
    tile: ?TileStyle = null,
    tile_layout: ?TileLayoutStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tile = "Tile",
            .tile_layout = "TileLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const TileLayoutStyle = struct {
    gutter: ?GutterStyle = null,
    margin: ?MarginStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gutter = "Gutter",
            .margin = "Margin",
        };
        return @field(mappings, field_name);
    }
};

pub const MarginStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const GutterStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const TileStyle = struct {
    border: ?BorderStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .border = "Border",
        };
        return @field(mappings, field_name);
    }
};

pub const BorderStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const UIColorPalette = struct {
    primary_foreground: ?[]const u8 = null,
    primary_background: ?[]const u8 = null,
    secondary_foreground: ?[]const u8 = null,
    secondary_background: ?[]const u8 = null,
    accent: ?[]const u8 = null,
    accent_foreground: ?[]const u8 = null,
    danger: ?[]const u8 = null,
    danger_foreground: ?[]const u8 = null,
    warning: ?[]const u8 = null,
    warning_foreground: ?[]const u8 = null,
    success: ?[]const u8 = null,
    success_foreground: ?[]const u8 = null,
    dimension: ?[]const u8 = null,
    dimension_foreground: ?[]const u8 = null,
    measure: ?[]const u8 = null,
    measure_foreground: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_foreground = "PrimaryForeground",
            .primary_background = "PrimaryBackground",
            .secondary_foreground = "SecondaryForeground",
            .secondary_background = "SecondaryBackground",
            .accent = "Accent",
            .accent_foreground = "AccentForeground",
            .danger = "Danger",
            .danger_foreground = "DangerForeground",
            .warning = "Warning",
            .warning_foreground = "WarningForeground",
            .success = "Success",
            .success_foreground = "SuccessForeground",
            .dimension = "Dimension",
            .dimension_foreground = "DimensionForeground",
            .measure = "Measure",
            .measure_foreground = "MeasureForeground",
        };
        return @field(mappings, field_name);
    }
};

pub const DataColorPalette = struct {
    colors: ?[][]const u8 = null,
    min_max_gradient: ?[][]const u8 = null,
    empty_fill_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .colors = "Colors",
            .min_max_gradient = "MinMaxGradient",
            .empty_fill_color = "EmptyFillColor",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateAlias = struct {
    alias_name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    template_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias_name = "AliasName",
            .arn = "Arn",
            .template_version_number = "TemplateVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationStrategy = struct {
    mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateVersionDefinition = struct {
    data_set_configurations: []DataSetConfiguration,
    sheets: ?[]SheetDefinition = null,
    calculated_fields: ?[]CalculatedField = null,
    parameter_declarations: ?[]ParameterDeclaration = null,
    filter_groups: ?[]FilterGroup = null,
    column_configurations: ?[]ColumnConfiguration = null,
    analysis_defaults: ?AnalysisDefaults = null,
    options: ?AssetOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_configurations = "DataSetConfigurations",
            .sheets = "Sheets",
            .calculated_fields = "CalculatedFields",
            .parameter_declarations = "ParameterDeclarations",
            .filter_groups = "FilterGroups",
            .column_configurations = "ColumnConfigurations",
            .analysis_defaults = "AnalysisDefaults",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetOptions = struct {
    timezone: ?[]const u8 = null,
    week_start: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timezone = "Timezone",
            .week_start = "WeekStart",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisDefaults = struct {
    default_new_sheet_configuration: DefaultNewSheetConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_new_sheet_configuration = "DefaultNewSheetConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultNewSheetConfiguration = struct {
    interactive_layout_configuration: ?DefaultInteractiveLayoutConfiguration = null,
    paginated_layout_configuration: ?DefaultPaginatedLayoutConfiguration = null,
    sheet_content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interactive_layout_configuration = "InteractiveLayoutConfiguration",
            .paginated_layout_configuration = "PaginatedLayoutConfiguration",
            .sheet_content_type = "SheetContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultPaginatedLayoutConfiguration = struct {
    section_based: ?DefaultSectionBasedLayoutConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .section_based = "SectionBased",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultSectionBasedLayoutConfiguration = struct {
    canvas_size_options: SectionBasedLayoutCanvasSizeOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionBasedLayoutCanvasSizeOptions = struct {
    paper_canvas_size_options: ?SectionBasedLayoutPaperCanvasSizeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .paper_canvas_size_options = "PaperCanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionBasedLayoutPaperCanvasSizeOptions = struct {
    paper_size: ?[]const u8 = null,
    paper_orientation: ?[]const u8 = null,
    paper_margin: ?Spacing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .paper_size = "PaperSize",
            .paper_orientation = "PaperOrientation",
            .paper_margin = "PaperMargin",
        };
        return @field(mappings, field_name);
    }
};

pub const Spacing = struct {
    top: ?[]const u8 = null,
    bottom: ?[]const u8 = null,
    left: ?[]const u8 = null,
    right: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .top = "Top",
            .bottom = "Bottom",
            .left = "Left",
            .right = "Right",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultInteractiveLayoutConfiguration = struct {
    grid: ?DefaultGridLayoutConfiguration = null,
    free_form: ?DefaultFreeFormLayoutConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grid = "Grid",
            .free_form = "FreeForm",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultFreeFormLayoutConfiguration = struct {
    canvas_size_options: FreeFormLayoutCanvasSizeOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutCanvasSizeOptions = struct {
    screen_canvas_size_options: ?FreeFormLayoutScreenCanvasSizeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .screen_canvas_size_options = "ScreenCanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutScreenCanvasSizeOptions = struct {
    optimized_view_port_width: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .optimized_view_port_width = "OptimizedViewPortWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultGridLayoutConfiguration = struct {
    canvas_size_options: GridLayoutCanvasSizeOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const GridLayoutCanvasSizeOptions = struct {
    screen_canvas_size_options: ?GridLayoutScreenCanvasSizeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .screen_canvas_size_options = "ScreenCanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const GridLayoutScreenCanvasSizeOptions = struct {
    resize_option: []const u8,
    optimized_view_port_width: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resize_option = "ResizeOption",
            .optimized_view_port_width = "OptimizedViewPortWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnConfiguration = struct {
    column: ColumnIdentifier,
    format_configuration: ?FormatConfiguration = null,
    role: ?[]const u8 = null,
    colors_configuration: ?ColorsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .format_configuration = "FormatConfiguration",
            .role = "Role",
            .colors_configuration = "ColorsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorsConfiguration = struct {
    custom_colors: ?[]CustomColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_colors = "CustomColors",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomColor = struct {
    field_value: ?[]const u8 = null,
    color: []const u8,
    special_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_value = "FieldValue",
            .color = "Color",
            .special_value = "SpecialValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FormatConfiguration = struct {
    string_format_configuration: ?StringFormatConfiguration = null,
    number_format_configuration: ?NumberFormatConfiguration = null,
    date_time_format_configuration: ?DateTimeFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_format_configuration = "StringFormatConfiguration",
            .number_format_configuration = "NumberFormatConfiguration",
            .date_time_format_configuration = "DateTimeFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeFormatConfiguration = struct {
    date_time_format: ?[]const u8 = null,
    null_value_format_configuration: ?NullValueFormatConfiguration = null,
    numeric_format_configuration: ?NumericFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date_time_format = "DateTimeFormat",
            .null_value_format_configuration = "NullValueFormatConfiguration",
            .numeric_format_configuration = "NumericFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericFormatConfiguration = struct {
    number_display_format_configuration: ?NumberDisplayFormatConfiguration = null,
    currency_display_format_configuration: ?CurrencyDisplayFormatConfiguration = null,
    percentage_display_format_configuration: ?PercentageDisplayFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_display_format_configuration = "NumberDisplayFormatConfiguration",
            .currency_display_format_configuration = "CurrencyDisplayFormatConfiguration",
            .percentage_display_format_configuration = "PercentageDisplayFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const PercentageDisplayFormatConfiguration = struct {
    prefix: ?[]const u8 = null,
    suffix: ?[]const u8 = null,
    separator_configuration: ?NumericSeparatorConfiguration = null,
    decimal_places_configuration: ?DecimalPlacesConfiguration = null,
    negative_value_configuration: ?NegativeValueConfiguration = null,
    null_value_format_configuration: ?NullValueFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .suffix = "Suffix",
            .separator_configuration = "SeparatorConfiguration",
            .decimal_places_configuration = "DecimalPlacesConfiguration",
            .negative_value_configuration = "NegativeValueConfiguration",
            .null_value_format_configuration = "NullValueFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NullValueFormatConfiguration = struct {
    null_string: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .null_string = "NullString",
        };
        return @field(mappings, field_name);
    }
};

pub const NegativeValueConfiguration = struct {
    display_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_mode = "DisplayMode",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalPlacesConfiguration = struct {
    decimal_places: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decimal_places = "DecimalPlaces",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericSeparatorConfiguration = struct {
    decimal_separator: ?[]const u8 = null,
    thousands_separator: ?ThousandSeparatorOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decimal_separator = "DecimalSeparator",
            .thousands_separator = "ThousandsSeparator",
        };
        return @field(mappings, field_name);
    }
};

pub const ThousandSeparatorOptions = struct {
    symbol: ?[]const u8 = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .symbol = "Symbol",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const CurrencyDisplayFormatConfiguration = struct {
    prefix: ?[]const u8 = null,
    suffix: ?[]const u8 = null,
    separator_configuration: ?NumericSeparatorConfiguration = null,
    symbol: ?[]const u8 = null,
    decimal_places_configuration: ?DecimalPlacesConfiguration = null,
    number_scale: ?[]const u8 = null,
    negative_value_configuration: ?NegativeValueConfiguration = null,
    null_value_format_configuration: ?NullValueFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .suffix = "Suffix",
            .separator_configuration = "SeparatorConfiguration",
            .symbol = "Symbol",
            .decimal_places_configuration = "DecimalPlacesConfiguration",
            .number_scale = "NumberScale",
            .negative_value_configuration = "NegativeValueConfiguration",
            .null_value_format_configuration = "NullValueFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberDisplayFormatConfiguration = struct {
    prefix: ?[]const u8 = null,
    suffix: ?[]const u8 = null,
    separator_configuration: ?NumericSeparatorConfiguration = null,
    decimal_places_configuration: ?DecimalPlacesConfiguration = null,
    number_scale: ?[]const u8 = null,
    negative_value_configuration: ?NegativeValueConfiguration = null,
    null_value_format_configuration: ?NullValueFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .suffix = "Suffix",
            .separator_configuration = "SeparatorConfiguration",
            .decimal_places_configuration = "DecimalPlacesConfiguration",
            .number_scale = "NumberScale",
            .negative_value_configuration = "NegativeValueConfiguration",
            .null_value_format_configuration = "NullValueFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberFormatConfiguration = struct {
    format_configuration: ?NumericFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const StringFormatConfiguration = struct {
    null_value_format_configuration: ?NullValueFormatConfiguration = null,
    numeric_format_configuration: ?NumericFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .null_value_format_configuration = "NullValueFormatConfiguration",
            .numeric_format_configuration = "NumericFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnIdentifier = struct {
    data_set_identifier: []const u8,
    column_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier = "DataSetIdentifier",
            .column_name = "ColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterGroup = struct {
    filter_group_id: []const u8,
    filters: []Filter,
    scope_configuration: FilterScopeConfiguration,
    status: ?[]const u8 = null,
    cross_dataset: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_group_id = "FilterGroupId",
            .filters = "Filters",
            .scope_configuration = "ScopeConfiguration",
            .status = "Status",
            .cross_dataset = "CrossDataset",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterScopeConfiguration = struct {
    selected_sheets: ?SelectedSheetsFilterScopeConfiguration = null,
    all_sheets: ?AllSheetsFilterScopeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_sheets = "SelectedSheets",
            .all_sheets = "AllSheets",
        };
        return @field(mappings, field_name);
    }
};

pub const AllSheetsFilterScopeConfiguration = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SelectedSheetsFilterScopeConfiguration = struct {
    sheet_visual_scoping_configurations: ?[]SheetVisualScopingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_visual_scoping_configurations = "SheetVisualScopingConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetVisualScopingConfiguration = struct {
    sheet_id: []const u8,
    scope: []const u8,
    visual_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_id = "SheetId",
            .scope = "Scope",
            .visual_ids = "VisualIds",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    category_filter: ?CategoryFilter = null,
    numeric_range_filter: ?NumericRangeFilter = null,
    numeric_equality_filter: ?NumericEqualityFilter = null,
    time_equality_filter: ?TimeEqualityFilter = null,
    time_range_filter: ?TimeRangeFilter = null,
    relative_dates_filter: ?RelativeDatesFilter = null,
    top_bottom_filter: ?TopBottomFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_filter = "CategoryFilter",
            .numeric_range_filter = "NumericRangeFilter",
            .numeric_equality_filter = "NumericEqualityFilter",
            .time_equality_filter = "TimeEqualityFilter",
            .time_range_filter = "TimeRangeFilter",
            .relative_dates_filter = "RelativeDatesFilter",
            .top_bottom_filter = "TopBottomFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const TopBottomFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    limit: ?i64 = null,
    aggregation_sort_configurations: []AggregationSortConfiguration,
    time_granularity: ?[]const u8 = null,
    parameter_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .limit = "Limit",
            .aggregation_sort_configurations = "AggregationSortConfigurations",
            .time_granularity = "TimeGranularity",
            .parameter_name = "ParameterName",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregationSortConfiguration = struct {
    column: ColumnIdentifier,
    sort_direction: []const u8,
    aggregation_function: ?AggregationFunction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .sort_direction = "SortDirection",
            .aggregation_function = "AggregationFunction",
        };
        return @field(mappings, field_name);
    }
};

pub const AggregationFunction = struct {
    numerical_aggregation_function: ?NumericalAggregationFunction = null,
    categorical_aggregation_function: ?[]const u8 = null,
    date_aggregation_function: ?[]const u8 = null,
    attribute_aggregation_function: ?AttributeAggregationFunction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numerical_aggregation_function = "NumericalAggregationFunction",
            .categorical_aggregation_function = "CategoricalAggregationFunction",
            .date_aggregation_function = "DateAggregationFunction",
            .attribute_aggregation_function = "AttributeAggregationFunction",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeAggregationFunction = struct {
    simple_attribute_aggregation: ?[]const u8 = null,
    value_for_multiple_values: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_attribute_aggregation = "SimpleAttributeAggregation",
            .value_for_multiple_values = "ValueForMultipleValues",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericalAggregationFunction = struct {
    simple_numerical_aggregation: ?[]const u8 = null,
    percentile_aggregation: ?PercentileAggregation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_numerical_aggregation = "SimpleNumericalAggregation",
            .percentile_aggregation = "PercentileAggregation",
        };
        return @field(mappings, field_name);
    }
};

pub const PercentileAggregation = struct {
    percentile_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percentile_value = "PercentileValue",
        };
        return @field(mappings, field_name);
    }
};

pub const RelativeDatesFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    anchor_date_configuration: AnchorDateConfiguration,
    minimum_granularity: ?[]const u8 = null,
    time_granularity: []const u8,
    relative_date_type: []const u8,
    relative_date_value: ?i64 = null,
    parameter_name: ?[]const u8 = null,
    null_option: []const u8,
    exclude_period_configuration: ?ExcludePeriodConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .anchor_date_configuration = "AnchorDateConfiguration",
            .minimum_granularity = "MinimumGranularity",
            .time_granularity = "TimeGranularity",
            .relative_date_type = "RelativeDateType",
            .relative_date_value = "RelativeDateValue",
            .parameter_name = "ParameterName",
            .null_option = "NullOption",
            .exclude_period_configuration = "ExcludePeriodConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ExcludePeriodConfiguration = struct {
    amount: i64,
    granularity: []const u8,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "Amount",
            .granularity = "Granularity",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AnchorDateConfiguration = struct {
    anchor_option: ?[]const u8 = null,
    parameter_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .anchor_option = "AnchorOption",
            .parameter_name = "ParameterName",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeRangeFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    include_minimum: ?bool = null,
    include_maximum: ?bool = null,
    range_minimum_value: ?TimeRangeFilterValue = null,
    range_maximum_value: ?TimeRangeFilterValue = null,
    null_option: []const u8,
    exclude_period_configuration: ?ExcludePeriodConfiguration = null,
    time_granularity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .include_minimum = "IncludeMinimum",
            .include_maximum = "IncludeMaximum",
            .range_minimum_value = "RangeMinimumValue",
            .range_maximum_value = "RangeMaximumValue",
            .null_option = "NullOption",
            .exclude_period_configuration = "ExcludePeriodConfiguration",
            .time_granularity = "TimeGranularity",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeRangeFilterValue = struct {
    static_value: ?i64 = null,
    rolling_date: ?RollingDateConfiguration = null,
    parameter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_value = "StaticValue",
            .rolling_date = "RollingDate",
            .parameter = "Parameter",
        };
        return @field(mappings, field_name);
    }
};

pub const RollingDateConfiguration = struct {
    data_set_identifier: ?[]const u8 = null,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier = "DataSetIdentifier",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeEqualityFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    value: ?i64 = null,
    parameter_name: ?[]const u8 = null,
    time_granularity: ?[]const u8 = null,
    rolling_date: ?RollingDateConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .value = "Value",
            .parameter_name = "ParameterName",
            .time_granularity = "TimeGranularity",
            .rolling_date = "RollingDate",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericEqualityFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    value: ?f64 = null,
    select_all_options: ?[]const u8 = null,
    match_operator: []const u8,
    aggregation_function: ?AggregationFunction = null,
    parameter_name: ?[]const u8 = null,
    null_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .value = "Value",
            .select_all_options = "SelectAllOptions",
            .match_operator = "MatchOperator",
            .aggregation_function = "AggregationFunction",
            .parameter_name = "ParameterName",
            .null_option = "NullOption",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericRangeFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    include_minimum: ?bool = null,
    include_maximum: ?bool = null,
    range_minimum: ?NumericRangeFilterValue = null,
    range_maximum: ?NumericRangeFilterValue = null,
    select_all_options: ?[]const u8 = null,
    aggregation_function: ?AggregationFunction = null,
    null_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .include_minimum = "IncludeMinimum",
            .include_maximum = "IncludeMaximum",
            .range_minimum = "RangeMinimum",
            .range_maximum = "RangeMaximum",
            .select_all_options = "SelectAllOptions",
            .aggregation_function = "AggregationFunction",
            .null_option = "NullOption",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericRangeFilterValue = struct {
    static_value: ?f64 = null,
    parameter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_value = "StaticValue",
            .parameter = "Parameter",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoryFilter = struct {
    filter_id: []const u8,
    column: ColumnIdentifier,
    configuration: CategoryFilterConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_id = "FilterId",
            .column = "Column",
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoryFilterConfiguration = struct {
    filter_list_configuration: ?FilterListConfiguration = null,
    custom_filter_list_configuration: ?CustomFilterListConfiguration = null,
    custom_filter_configuration: ?CustomFilterConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_list_configuration = "FilterListConfiguration",
            .custom_filter_list_configuration = "CustomFilterListConfiguration",
            .custom_filter_configuration = "CustomFilterConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomFilterConfiguration = struct {
    match_operator: []const u8,
    category_value: ?[]const u8 = null,
    select_all_options: ?[]const u8 = null,
    parameter_name: ?[]const u8 = null,
    null_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_operator = "MatchOperator",
            .category_value = "CategoryValue",
            .select_all_options = "SelectAllOptions",
            .parameter_name = "ParameterName",
            .null_option = "NullOption",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomFilterListConfiguration = struct {
    match_operator: []const u8,
    category_values: ?[][]const u8 = null,
    select_all_options: ?[]const u8 = null,
    null_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_operator = "MatchOperator",
            .category_values = "CategoryValues",
            .select_all_options = "SelectAllOptions",
            .null_option = "NullOption",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterListConfiguration = struct {
    match_operator: []const u8,
    category_values: ?[][]const u8 = null,
    select_all_options: ?[]const u8 = null,
    null_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_operator = "MatchOperator",
            .category_values = "CategoryValues",
            .select_all_options = "SelectAllOptions",
            .null_option = "NullOption",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterDeclaration = struct {
    string_parameter_declaration: ?StringParameterDeclaration = null,
    decimal_parameter_declaration: ?DecimalParameterDeclaration = null,
    integer_parameter_declaration: ?IntegerParameterDeclaration = null,
    date_time_parameter_declaration: ?DateTimeParameterDeclaration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_parameter_declaration = "StringParameterDeclaration",
            .decimal_parameter_declaration = "DecimalParameterDeclaration",
            .integer_parameter_declaration = "IntegerParameterDeclaration",
            .date_time_parameter_declaration = "DateTimeParameterDeclaration",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeParameterDeclaration = struct {
    name: []const u8,
    default_values: ?DateTimeDefaultValues = null,
    time_granularity: ?[]const u8 = null,
    value_when_unset: ?DateTimeValueWhenUnsetConfiguration = null,
    mapped_data_set_parameters: ?[]MappedDataSetParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .default_values = "DefaultValues",
            .time_granularity = "TimeGranularity",
            .value_when_unset = "ValueWhenUnset",
            .mapped_data_set_parameters = "MappedDataSetParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const MappedDataSetParameter = struct {
    data_set_identifier: []const u8,
    data_set_parameter_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier = "DataSetIdentifier",
            .data_set_parameter_name = "DataSetParameterName",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeValueWhenUnsetConfiguration = struct {
    value_when_unset_option: ?[]const u8 = null,
    custom_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_when_unset_option = "ValueWhenUnsetOption",
            .custom_value = "CustomValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeDefaultValues = struct {
    dynamic_value: ?DynamicDefaultValue = null,
    static_values: ?[]i64 = null,
    rolling_date: ?RollingDateConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_value = "DynamicValue",
            .static_values = "StaticValues",
            .rolling_date = "RollingDate",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamicDefaultValue = struct {
    user_name_column: ?ColumnIdentifier = null,
    group_name_column: ?ColumnIdentifier = null,
    default_value_column: ColumnIdentifier,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name_column = "UserNameColumn",
            .group_name_column = "GroupNameColumn",
            .default_value_column = "DefaultValueColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameterDeclaration = struct {
    parameter_value_type: []const u8,
    name: []const u8,
    default_values: ?IntegerDefaultValues = null,
    value_when_unset: ?IntegerValueWhenUnsetConfiguration = null,
    mapped_data_set_parameters: ?[]MappedDataSetParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_value_type = "ParameterValueType",
            .name = "Name",
            .default_values = "DefaultValues",
            .value_when_unset = "ValueWhenUnset",
            .mapped_data_set_parameters = "MappedDataSetParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerValueWhenUnsetConfiguration = struct {
    value_when_unset_option: ?[]const u8 = null,
    custom_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_when_unset_option = "ValueWhenUnsetOption",
            .custom_value = "CustomValue",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerDefaultValues = struct {
    dynamic_value: ?DynamicDefaultValue = null,
    static_values: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_value = "DynamicValue",
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalParameterDeclaration = struct {
    parameter_value_type: []const u8,
    name: []const u8,
    default_values: ?DecimalDefaultValues = null,
    value_when_unset: ?DecimalValueWhenUnsetConfiguration = null,
    mapped_data_set_parameters: ?[]MappedDataSetParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_value_type = "ParameterValueType",
            .name = "Name",
            .default_values = "DefaultValues",
            .value_when_unset = "ValueWhenUnset",
            .mapped_data_set_parameters = "MappedDataSetParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalValueWhenUnsetConfiguration = struct {
    value_when_unset_option: ?[]const u8 = null,
    custom_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_when_unset_option = "ValueWhenUnsetOption",
            .custom_value = "CustomValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalDefaultValues = struct {
    dynamic_value: ?DynamicDefaultValue = null,
    static_values: ?[]f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_value = "DynamicValue",
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const StringParameterDeclaration = struct {
    parameter_value_type: []const u8,
    name: []const u8,
    default_values: ?StringDefaultValues = null,
    value_when_unset: ?StringValueWhenUnsetConfiguration = null,
    mapped_data_set_parameters: ?[]MappedDataSetParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_value_type = "ParameterValueType",
            .name = "Name",
            .default_values = "DefaultValues",
            .value_when_unset = "ValueWhenUnset",
            .mapped_data_set_parameters = "MappedDataSetParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const StringValueWhenUnsetConfiguration = struct {
    value_when_unset_option: ?[]const u8 = null,
    custom_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_when_unset_option = "ValueWhenUnsetOption",
            .custom_value = "CustomValue",
        };
        return @field(mappings, field_name);
    }
};

pub const StringDefaultValues = struct {
    dynamic_value: ?DynamicDefaultValue = null,
    static_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dynamic_value = "DynamicValue",
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedField = struct {
    data_set_identifier: []const u8,
    name: []const u8,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier = "DataSetIdentifier",
            .name = "Name",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetDefinition = struct {
    sheet_id: []const u8,
    title: ?[]const u8 = null,
    description: ?[]const u8 = null,
    name: ?[]const u8 = null,
    parameter_controls: ?[]ParameterControl = null,
    filter_controls: ?[]FilterControl = null,
    visuals: ?[]Visual = null,
    text_boxes: ?[]SheetTextBox = null,
    layouts: ?[]Layout = null,
    sheet_control_layouts: ?[]SheetControlLayout = null,
    content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_id = "SheetId",
            .title = "Title",
            .description = "Description",
            .name = "Name",
            .parameter_controls = "ParameterControls",
            .filter_controls = "FilterControls",
            .visuals = "Visuals",
            .text_boxes = "TextBoxes",
            .layouts = "Layouts",
            .sheet_control_layouts = "SheetControlLayouts",
            .content_type = "ContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetControlLayout = struct {
    configuration: SheetControlLayoutConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetControlLayoutConfiguration = struct {
    grid_layout: ?GridLayoutConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grid_layout = "GridLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const GridLayoutConfiguration = struct {
    elements: []GridLayoutElement,
    canvas_size_options: ?GridLayoutCanvasSizeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elements = "Elements",
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const GridLayoutElement = struct {
    element_id: []const u8,
    element_type: []const u8,
    column_index: ?i64 = null,
    column_span: i64,
    row_index: ?i64 = null,
    row_span: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .element_id = "ElementId",
            .element_type = "ElementType",
            .column_index = "ColumnIndex",
            .column_span = "ColumnSpan",
            .row_index = "RowIndex",
            .row_span = "RowSpan",
        };
        return @field(mappings, field_name);
    }
};

pub const Layout = struct {
    configuration: LayoutConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const LayoutConfiguration = struct {
    grid_layout: ?GridLayoutConfiguration = null,
    free_form_layout: ?FreeFormLayoutConfiguration = null,
    section_based_layout: ?SectionBasedLayoutConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grid_layout = "GridLayout",
            .free_form_layout = "FreeFormLayout",
            .section_based_layout = "SectionBasedLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionBasedLayoutConfiguration = struct {
    header_sections: []HeaderFooterSectionConfiguration,
    body_sections: []BodySectionConfiguration,
    footer_sections: []HeaderFooterSectionConfiguration,
    canvas_size_options: SectionBasedLayoutCanvasSizeOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_sections = "HeaderSections",
            .body_sections = "BodySections",
            .footer_sections = "FooterSections",
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const HeaderFooterSectionConfiguration = struct {
    section_id: []const u8,
    layout: SectionLayoutConfiguration,
    style: ?SectionStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .section_id = "SectionId",
            .layout = "Layout",
            .style = "Style",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionStyle = struct {
    height: ?[]const u8 = null,
    padding: ?Spacing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "Height",
            .padding = "Padding",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionLayoutConfiguration = struct {
    free_form_layout: FreeFormSectionLayoutConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .free_form_layout = "FreeFormLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormSectionLayoutConfiguration = struct {
    elements: []FreeFormLayoutElement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elements = "Elements",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutElement = struct {
    element_id: []const u8,
    element_type: []const u8,
    x_axis_location: []const u8,
    y_axis_location: []const u8,
    width: []const u8,
    height: []const u8,
    visibility: ?[]const u8 = null,
    rendering_rules: ?[]SheetElementRenderingRule = null,
    border_style: ?FreeFormLayoutElementBorderStyle = null,
    selected_border_style: ?FreeFormLayoutElementBorderStyle = null,
    background_style: ?FreeFormLayoutElementBackgroundStyle = null,
    loading_animation: ?LoadingAnimation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .element_id = "ElementId",
            .element_type = "ElementType",
            .x_axis_location = "XAxisLocation",
            .y_axis_location = "YAxisLocation",
            .width = "Width",
            .height = "Height",
            .visibility = "Visibility",
            .rendering_rules = "RenderingRules",
            .border_style = "BorderStyle",
            .selected_border_style = "SelectedBorderStyle",
            .background_style = "BackgroundStyle",
            .loading_animation = "LoadingAnimation",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadingAnimation = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutElementBackgroundStyle = struct {
    visibility: ?[]const u8 = null,
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutElementBorderStyle = struct {
    visibility: ?[]const u8 = null,
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetElementRenderingRule = struct {
    expression: []const u8,
    configuration_overrides: SheetElementConfigurationOverrides,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .configuration_overrides = "ConfigurationOverrides",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetElementConfigurationOverrides = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const BodySectionConfiguration = struct {
    section_id: []const u8,
    content: BodySectionContent,
    style: ?SectionStyle = null,
    page_break_configuration: ?SectionPageBreakConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .section_id = "SectionId",
            .content = "Content",
            .style = "Style",
            .page_break_configuration = "PageBreakConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionPageBreakConfiguration = struct {
    after: ?SectionAfterPageBreak = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after = "After",
        };
        return @field(mappings, field_name);
    }
};

pub const SectionAfterPageBreak = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const BodySectionContent = struct {
    layout: ?SectionLayoutConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .layout = "Layout",
        };
        return @field(mappings, field_name);
    }
};

pub const FreeFormLayoutConfiguration = struct {
    elements: []FreeFormLayoutElement,
    canvas_size_options: ?FreeFormLayoutCanvasSizeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elements = "Elements",
            .canvas_size_options = "CanvasSizeOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetTextBox = struct {
    sheet_text_box_id: []const u8,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_text_box_id = "SheetTextBoxId",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const Visual = struct {
    table_visual: ?TableVisual = null,
    pivot_table_visual: ?PivotTableVisual = null,
    bar_chart_visual: ?BarChartVisual = null,
    kpi_visual: ?KPIVisual = null,
    pie_chart_visual: ?PieChartVisual = null,
    gauge_chart_visual: ?GaugeChartVisual = null,
    line_chart_visual: ?LineChartVisual = null,
    heat_map_visual: ?HeatMapVisual = null,
    tree_map_visual: ?TreeMapVisual = null,
    geospatial_map_visual: ?GeospatialMapVisual = null,
    filled_map_visual: ?FilledMapVisual = null,
    funnel_chart_visual: ?FunnelChartVisual = null,
    scatter_plot_visual: ?ScatterPlotVisual = null,
    combo_chart_visual: ?ComboChartVisual = null,
    box_plot_visual: ?BoxPlotVisual = null,
    waterfall_visual: ?WaterfallVisual = null,
    histogram_visual: ?HistogramVisual = null,
    word_cloud_visual: ?WordCloudVisual = null,
    insight_visual: ?InsightVisual = null,
    sankey_diagram_visual: ?SankeyDiagramVisual = null,
    custom_content_visual: ?CustomContentVisual = null,
    empty_visual: ?EmptyVisual = null,
    radar_chart_visual: ?RadarChartVisual = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_visual = "TableVisual",
            .pivot_table_visual = "PivotTableVisual",
            .bar_chart_visual = "BarChartVisual",
            .kpi_visual = "KPIVisual",
            .pie_chart_visual = "PieChartVisual",
            .gauge_chart_visual = "GaugeChartVisual",
            .line_chart_visual = "LineChartVisual",
            .heat_map_visual = "HeatMapVisual",
            .tree_map_visual = "TreeMapVisual",
            .geospatial_map_visual = "GeospatialMapVisual",
            .filled_map_visual = "FilledMapVisual",
            .funnel_chart_visual = "FunnelChartVisual",
            .scatter_plot_visual = "ScatterPlotVisual",
            .combo_chart_visual = "ComboChartVisual",
            .box_plot_visual = "BoxPlotVisual",
            .waterfall_visual = "WaterfallVisual",
            .histogram_visual = "HistogramVisual",
            .word_cloud_visual = "WordCloudVisual",
            .insight_visual = "InsightVisual",
            .sankey_diagram_visual = "SankeyDiagramVisual",
            .custom_content_visual = "CustomContentVisual",
            .empty_visual = "EmptyVisual",
            .radar_chart_visual = "RadarChartVisual",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?RadarChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnHierarchy = struct {
    explicit_hierarchy: ?ExplicitHierarchy = null,
    date_time_hierarchy: ?DateTimeHierarchy = null,
    predefined_hierarchy: ?PredefinedHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .explicit_hierarchy = "ExplicitHierarchy",
            .date_time_hierarchy = "DateTimeHierarchy",
            .predefined_hierarchy = "PredefinedHierarchy",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedHierarchy = struct {
    hierarchy_id: []const u8,
    columns: []ColumnIdentifier,
    drill_down_filters: ?[]DrillDownFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hierarchy_id = "HierarchyId",
            .columns = "Columns",
            .drill_down_filters = "DrillDownFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const DrillDownFilter = struct {
    numeric_equality_filter: ?NumericEqualityDrillDownFilter = null,
    category_filter: ?CategoryDrillDownFilter = null,
    time_range_filter: ?TimeRangeDrillDownFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numeric_equality_filter = "NumericEqualityFilter",
            .category_filter = "CategoryFilter",
            .time_range_filter = "TimeRangeFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeRangeDrillDownFilter = struct {
    column: ColumnIdentifier,
    range_minimum: i64,
    range_maximum: i64,
    time_granularity: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .range_minimum = "RangeMinimum",
            .range_maximum = "RangeMaximum",
            .time_granularity = "TimeGranularity",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoryDrillDownFilter = struct {
    column: ColumnIdentifier,
    category_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .category_values = "CategoryValues",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericEqualityDrillDownFilter = struct {
    column: ColumnIdentifier,
    value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeHierarchy = struct {
    hierarchy_id: []const u8,
    drill_down_filters: ?[]DrillDownFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hierarchy_id = "HierarchyId",
            .drill_down_filters = "DrillDownFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const ExplicitHierarchy = struct {
    hierarchy_id: []const u8,
    columns: []ColumnIdentifier,
    drill_down_filters: ?[]DrillDownFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hierarchy_id = "HierarchyId",
            .columns = "Columns",
            .drill_down_filters = "DrillDownFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualCustomAction = struct {
    custom_action_id: []const u8,
    name: []const u8,
    status: ?[]const u8 = null,
    trigger: []const u8,
    action_operations: []VisualCustomActionOperation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_action_id = "CustomActionId",
            .name = "Name",
            .status = "Status",
            .trigger = "Trigger",
            .action_operations = "ActionOperations",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualCustomActionOperation = struct {
    filter_operation: ?CustomActionFilterOperation = null,
    navigation_operation: ?CustomActionNavigationOperation = null,
    url_operation: ?CustomActionURLOperation = null,
    set_parameters_operation: ?CustomActionSetParametersOperation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_operation = "FilterOperation",
            .navigation_operation = "NavigationOperation",
            .url_operation = "URLOperation",
            .set_parameters_operation = "SetParametersOperation",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomActionSetParametersOperation = struct {
    parameter_value_configurations: []SetParameterValueConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_value_configurations = "ParameterValueConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const SetParameterValueConfiguration = struct {
    destination_parameter_name: []const u8,
    value: DestinationParameterValueConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_parameter_name = "DestinationParameterName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationParameterValueConfiguration = struct {
    custom_values_configuration: ?CustomValuesConfiguration = null,
    select_all_value_options: ?[]const u8 = null,
    source_parameter_name: ?[]const u8 = null,
    source_field: ?[]const u8 = null,
    source_column: ?ColumnIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_values_configuration = "CustomValuesConfiguration",
            .select_all_value_options = "SelectAllValueOptions",
            .source_parameter_name = "SourceParameterName",
            .source_field = "SourceField",
            .source_column = "SourceColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomValuesConfiguration = struct {
    include_null_value: ?bool = null,
    custom_values: CustomParameterValues,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .include_null_value = "IncludeNullValue",
            .custom_values = "CustomValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomParameterValues = struct {
    string_values: ?[][]const u8 = null,
    integer_values: ?[]i64 = null,
    decimal_values: ?[]f64 = null,
    date_time_values: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_values = "StringValues",
            .integer_values = "IntegerValues",
            .decimal_values = "DecimalValues",
            .date_time_values = "DateTimeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomActionURLOperation = struct {
    url_template: []const u8,
    url_target: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url_template = "URLTemplate",
            .url_target = "URLTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomActionNavigationOperation = struct {
    local_navigation_configuration: ?LocalNavigationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_navigation_configuration = "LocalNavigationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LocalNavigationConfiguration = struct {
    target_sheet_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_sheet_id = "TargetSheetId",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomActionFilterOperation = struct {
    selected_fields_configuration: FilterOperationSelectedFieldsConfiguration,
    target_visuals_configuration: FilterOperationTargetVisualsConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_fields_configuration = "SelectedFieldsConfiguration",
            .target_visuals_configuration = "TargetVisualsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterOperationTargetVisualsConfiguration = struct {
    same_sheet_target_visual_configuration: ?SameSheetTargetVisualConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .same_sheet_target_visual_configuration = "SameSheetTargetVisualConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SameSheetTargetVisualConfiguration = struct {
    target_visuals: ?[][]const u8 = null,
    target_visual_options: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_visuals = "TargetVisuals",
            .target_visual_options = "TargetVisualOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterOperationSelectedFieldsConfiguration = struct {
    selected_fields: ?[][]const u8 = null,
    selected_field_options: ?[]const u8 = null,
    selected_columns: ?[]ColumnIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_fields = "SelectedFields",
            .selected_field_options = "SelectedFieldOptions",
            .selected_columns = "SelectedColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartConfiguration = struct {
    field_wells: ?RadarChartFieldWells = null,
    sort_configuration: ?RadarChartSortConfiguration = null,
    shape: ?[]const u8 = null,
    base_series_settings: ?RadarChartSeriesSettings = null,
    start_angle: ?f64 = null,
    visual_palette: ?VisualPalette = null,
    alternate_band_colors_visibility: ?[]const u8 = null,
    alternate_band_even_color: ?[]const u8 = null,
    alternate_band_odd_color: ?[]const u8 = null,
    category_axis: ?AxisDisplayOptions = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    color_axis: ?AxisDisplayOptions = null,
    color_label_options: ?ChartAxisLabelOptions = null,
    legend: ?LegendOptions = null,
    axes_range_scale: ?[]const u8 = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .shape = "Shape",
            .base_series_settings = "BaseSeriesSettings",
            .start_angle = "StartAngle",
            .visual_palette = "VisualPalette",
            .alternate_band_colors_visibility = "AlternateBandColorsVisibility",
            .alternate_band_even_color = "AlternateBandEvenColor",
            .alternate_band_odd_color = "AlternateBandOddColor",
            .category_axis = "CategoryAxis",
            .category_label_options = "CategoryLabelOptions",
            .color_axis = "ColorAxis",
            .color_label_options = "ColorLabelOptions",
            .legend = "Legend",
            .axes_range_scale = "AxesRangeScale",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualInteractionOptions = struct {
    visual_menu_option: ?VisualMenuOption = null,
    context_menu_option: ?ContextMenuOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_menu_option = "VisualMenuOption",
            .context_menu_option = "ContextMenuOption",
        };
        return @field(mappings, field_name);
    }
};

pub const ContextMenuOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualMenuOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const LegendOptions = struct {
    visibility: ?[]const u8 = null,
    title: ?LabelOptions = null,
    position: ?[]const u8 = null,
    width: ?[]const u8 = null,
    height: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .title = "Title",
            .position = "Position",
            .width = "Width",
            .height = "Height",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelOptions = struct {
    visibility: ?[]const u8 = null,
    font_configuration: ?FontConfiguration = null,
    custom_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .font_configuration = "FontConfiguration",
            .custom_label = "CustomLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const FontConfiguration = struct {
    font_size: ?FontSize = null,
    font_decoration: ?[]const u8 = null,
    font_color: ?[]const u8 = null,
    font_weight: ?FontWeight = null,
    font_style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_size = "FontSize",
            .font_decoration = "FontDecoration",
            .font_color = "FontColor",
            .font_weight = "FontWeight",
            .font_style = "FontStyle",
        };
        return @field(mappings, field_name);
    }
};

pub const FontWeight = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const FontSize = struct {
    relative: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relative = "Relative",
        };
        return @field(mappings, field_name);
    }
};

pub const ChartAxisLabelOptions = struct {
    visibility: ?[]const u8 = null,
    sort_icon_visibility: ?[]const u8 = null,
    axis_label_options: ?[]AxisLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .sort_icon_visibility = "SortIconVisibility",
            .axis_label_options = "AxisLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisLabelOptions = struct {
    font_configuration: ?FontConfiguration = null,
    custom_label: ?[]const u8 = null,
    apply_to: ?AxisLabelReferenceOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_configuration = "FontConfiguration",
            .custom_label = "CustomLabel",
            .apply_to = "ApplyTo",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisLabelReferenceOptions = struct {
    field_id: []const u8,
    column: ColumnIdentifier,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisDisplayOptions = struct {
    tick_label_options: ?AxisTickLabelOptions = null,
    axis_line_visibility: ?[]const u8 = null,
    grid_line_visibility: ?[]const u8 = null,
    data_options: ?AxisDataOptions = null,
    scrollbar_options: ?ScrollBarOptions = null,
    axis_offset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tick_label_options = "TickLabelOptions",
            .axis_line_visibility = "AxisLineVisibility",
            .grid_line_visibility = "GridLineVisibility",
            .data_options = "DataOptions",
            .scrollbar_options = "ScrollbarOptions",
            .axis_offset = "AxisOffset",
        };
        return @field(mappings, field_name);
    }
};

pub const ScrollBarOptions = struct {
    visibility: ?[]const u8 = null,
    visible_range: ?VisibleRangeOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .visible_range = "VisibleRange",
        };
        return @field(mappings, field_name);
    }
};

pub const VisibleRangeOptions = struct {
    percent_range: ?PercentVisibleRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percent_range = "PercentRange",
        };
        return @field(mappings, field_name);
    }
};

pub const PercentVisibleRange = struct {
    from: ?f64 = null,
    to: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .to = "To",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisDataOptions = struct {
    numeric_axis_options: ?NumericAxisOptions = null,
    date_axis_options: ?DateAxisOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numeric_axis_options = "NumericAxisOptions",
            .date_axis_options = "DateAxisOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DateAxisOptions = struct {
    missing_date_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .missing_date_visibility = "MissingDateVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericAxisOptions = struct {
    scale: ?AxisScale = null,
    range: ?AxisDisplayRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scale = "Scale",
            .range = "Range",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisDisplayRange = struct {
    min_max: ?AxisDisplayMinMaxRange = null,
    data_driven: ?AxisDisplayDataDrivenRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_max = "MinMax",
            .data_driven = "DataDriven",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisDisplayDataDrivenRange = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const AxisDisplayMinMaxRange = struct {
    minimum: ?f64 = null,
    maximum: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum = "Minimum",
            .maximum = "Maximum",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisScale = struct {
    linear: ?AxisLinearScale = null,
    logarithmic: ?AxisLogarithmicScale = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .linear = "Linear",
            .logarithmic = "Logarithmic",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisLogarithmicScale = struct {
    base: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base = "Base",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisLinearScale = struct {
    step_count: ?i64 = null,
    step_size: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_count = "StepCount",
            .step_size = "StepSize",
        };
        return @field(mappings, field_name);
    }
};

pub const AxisTickLabelOptions = struct {
    label_options: ?LabelOptions = null,
    rotation_angle: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label_options = "LabelOptions",
            .rotation_angle = "RotationAngle",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualPalette = struct {
    chart_color: ?[]const u8 = null,
    color_map: ?[]DataPathColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .chart_color = "ChartColor",
            .color_map = "ColorMap",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPathColor = struct {
    element: DataPathValue,
    color: []const u8,
    time_granularity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .element = "Element",
            .color = "Color",
            .time_granularity = "TimeGranularity",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPathValue = struct {
    field_id: ?[]const u8 = null,
    field_value: ?[]const u8 = null,
    data_path_type: ?DataPathType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .field_value = "FieldValue",
            .data_path_type = "DataPathType",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPathType = struct {
    pivot_table_data_path_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pivot_table_data_path_type = "PivotTableDataPathType",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartSeriesSettings = struct {
    area_style_settings: ?RadarChartAreaStyleSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .area_style_settings = "AreaStyleSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartAreaStyleSettings = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit: ?ItemsLimitConfiguration = null,
    color_sort: ?[]FieldSortOptions = null,
    color_items_limit: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit = "CategoryItemsLimit",
            .color_sort = "ColorSort",
            .color_items_limit = "ColorItemsLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const ItemsLimitConfiguration = struct {
    items_limit: ?i64 = null,
    other_categories: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items_limit = "ItemsLimit",
            .other_categories = "OtherCategories",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldSortOptions = struct {
    field_sort: ?FieldSort = null,
    column_sort: ?ColumnSort = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_sort = "FieldSort",
            .column_sort = "ColumnSort",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnSort = struct {
    sort_by: ColumnIdentifier,
    direction: []const u8,
    aggregation_function: ?AggregationFunction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sort_by = "SortBy",
            .direction = "Direction",
            .aggregation_function = "AggregationFunction",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldSort = struct {
    field_id: []const u8,
    direction: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .direction = "Direction",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartFieldWells = struct {
    radar_chart_aggregated_field_wells: ?RadarChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .radar_chart_aggregated_field_wells = "RadarChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const RadarChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    color: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .color = "Color",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const MeasureField = struct {
    numerical_measure_field: ?NumericalMeasureField = null,
    categorical_measure_field: ?CategoricalMeasureField = null,
    date_measure_field: ?DateMeasureField = null,
    calculated_measure_field: ?CalculatedMeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numerical_measure_field = "NumericalMeasureField",
            .categorical_measure_field = "CategoricalMeasureField",
            .date_measure_field = "DateMeasureField",
            .calculated_measure_field = "CalculatedMeasureField",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedMeasureField = struct {
    field_id: []const u8,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const DateMeasureField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    aggregation_function: ?[]const u8 = null,
    format_configuration: ?DateTimeFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .aggregation_function = "AggregationFunction",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalMeasureField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    aggregation_function: ?[]const u8 = null,
    format_configuration: ?StringFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .aggregation_function = "AggregationFunction",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericalMeasureField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    aggregation_function: ?NumericalAggregationFunction = null,
    format_configuration: ?NumberFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .aggregation_function = "AggregationFunction",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionField = struct {
    numerical_dimension_field: ?NumericalDimensionField = null,
    categorical_dimension_field: ?CategoricalDimensionField = null,
    date_dimension_field: ?DateDimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numerical_dimension_field = "NumericalDimensionField",
            .categorical_dimension_field = "CategoricalDimensionField",
            .date_dimension_field = "DateDimensionField",
        };
        return @field(mappings, field_name);
    }
};

pub const DateDimensionField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    date_granularity: ?[]const u8 = null,
    hierarchy_id: ?[]const u8 = null,
    format_configuration: ?DateTimeFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .date_granularity = "DateGranularity",
            .hierarchy_id = "HierarchyId",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalDimensionField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    hierarchy_id: ?[]const u8 = null,
    format_configuration: ?StringFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .hierarchy_id = "HierarchyId",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericalDimensionField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    hierarchy_id: ?[]const u8 = null,
    format_configuration: ?NumberFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .hierarchy_id = "HierarchyId",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualSubtitleLabelOptions = struct {
    visibility: ?[]const u8 = null,
    format_text: ?LongFormatText = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .format_text = "FormatText",
        };
        return @field(mappings, field_name);
    }
};

pub const LongFormatText = struct {
    plain_text: ?[]const u8 = null,
    rich_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plain_text = "PlainText",
            .rich_text = "RichText",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualTitleLabelOptions = struct {
    visibility: ?[]const u8 = null,
    format_text: ?ShortFormatText = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .format_text = "FormatText",
        };
        return @field(mappings, field_name);
    }
};

pub const ShortFormatText = struct {
    plain_text: ?[]const u8 = null,
    rich_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plain_text = "PlainText",
            .rich_text = "RichText",
        };
        return @field(mappings, field_name);
    }
};

pub const EmptyVisual = struct {
    visual_id: []const u8,
    data_set_identifier: []const u8,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .data_set_identifier = "DataSetIdentifier",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomContentVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?CustomContentConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    data_set_identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .data_set_identifier = "DataSetIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomContentConfiguration = struct {
    content_url: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    image_scaling: ?[]const u8 = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_url = "ContentUrl",
            .content_type = "ContentType",
            .image_scaling = "ImageScaling",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const SankeyDiagramVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?SankeyDiagramChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const SankeyDiagramChartConfiguration = struct {
    field_wells: ?SankeyDiagramFieldWells = null,
    sort_configuration: ?SankeyDiagramSortConfiguration = null,
    data_labels: ?DataLabelOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .data_labels = "DataLabels",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLabelOptions = struct {
    visibility: ?[]const u8 = null,
    category_label_visibility: ?[]const u8 = null,
    measure_label_visibility: ?[]const u8 = null,
    data_label_types: ?[]DataLabelType = null,
    position: ?[]const u8 = null,
    label_content: ?[]const u8 = null,
    label_font_configuration: ?FontConfiguration = null,
    label_color: ?[]const u8 = null,
    overlap: ?[]const u8 = null,
    totals_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .category_label_visibility = "CategoryLabelVisibility",
            .measure_label_visibility = "MeasureLabelVisibility",
            .data_label_types = "DataLabelTypes",
            .position = "Position",
            .label_content = "LabelContent",
            .label_font_configuration = "LabelFontConfiguration",
            .label_color = "LabelColor",
            .overlap = "Overlap",
            .totals_visibility = "TotalsVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLabelType = struct {
    field_label_type: ?FieldLabelType = null,
    data_path_label_type: ?DataPathLabelType = null,
    range_ends_label_type: ?RangeEndsLabelType = null,
    minimum_label_type: ?MinimumLabelType = null,
    maximum_label_type: ?MaximumLabelType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_label_type = "FieldLabelType",
            .data_path_label_type = "DataPathLabelType",
            .range_ends_label_type = "RangeEndsLabelType",
            .minimum_label_type = "MinimumLabelType",
            .maximum_label_type = "MaximumLabelType",
        };
        return @field(mappings, field_name);
    }
};

pub const MaximumLabelType = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const MinimumLabelType = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const RangeEndsLabelType = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPathLabelType = struct {
    field_id: ?[]const u8 = null,
    field_value: ?[]const u8 = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .field_value = "FieldValue",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldLabelType = struct {
    field_id: ?[]const u8 = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const SankeyDiagramSortConfiguration = struct {
    weight_sort: ?[]FieldSortOptions = null,
    source_items_limit: ?ItemsLimitConfiguration = null,
    destination_items_limit: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .weight_sort = "WeightSort",
            .source_items_limit = "SourceItemsLimit",
            .destination_items_limit = "DestinationItemsLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const SankeyDiagramFieldWells = struct {
    sankey_diagram_aggregated_field_wells: ?SankeyDiagramAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sankey_diagram_aggregated_field_wells = "SankeyDiagramAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const SankeyDiagramAggregatedFieldWells = struct {
    source: ?[]DimensionField = null,
    destination: ?[]DimensionField = null,
    weight: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .destination = "Destination",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    insight_configuration: ?InsightConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    data_set_identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .insight_configuration = "InsightConfiguration",
            .actions = "Actions",
            .data_set_identifier = "DataSetIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightConfiguration = struct {
    computations: ?[]Computation = null,
    custom_narrative: ?CustomNarrativeOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computations = "Computations",
            .custom_narrative = "CustomNarrative",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomNarrativeOptions = struct {
    narrative: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .narrative = "Narrative",
        };
        return @field(mappings, field_name);
    }
};

pub const Computation = struct {
    top_bottom_ranked: ?TopBottomRankedComputation = null,
    top_bottom_movers: ?TopBottomMoversComputation = null,
    total_aggregation: ?TotalAggregationComputation = null,
    maximum_minimum: ?MaximumMinimumComputation = null,
    metric_comparison: ?MetricComparisonComputation = null,
    period_over_period: ?PeriodOverPeriodComputation = null,
    period_to_date: ?PeriodToDateComputation = null,
    growth_rate: ?GrowthRateComputation = null,
    unique_values: ?UniqueValuesComputation = null,
    forecast: ?ForecastComputation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .top_bottom_ranked = "TopBottomRanked",
            .top_bottom_movers = "TopBottomMovers",
            .total_aggregation = "TotalAggregation",
            .maximum_minimum = "MaximumMinimum",
            .metric_comparison = "MetricComparison",
            .period_over_period = "PeriodOverPeriod",
            .period_to_date = "PeriodToDate",
            .growth_rate = "GrowthRate",
            .unique_values = "UniqueValues",
            .forecast = "Forecast",
        };
        return @field(mappings, field_name);
    }
};

pub const ForecastComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    value: ?MeasureField = null,
    periods_forward: ?i64 = null,
    periods_backward: ?i64 = null,
    upper_boundary: ?f64 = null,
    lower_boundary: ?f64 = null,
    prediction_interval: ?i64 = null,
    seasonality: ?[]const u8 = null,
    custom_seasonality_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .value = "Value",
            .periods_forward = "PeriodsForward",
            .periods_backward = "PeriodsBackward",
            .upper_boundary = "UpperBoundary",
            .lower_boundary = "LowerBoundary",
            .prediction_interval = "PredictionInterval",
            .seasonality = "Seasonality",
            .custom_seasonality_value = "CustomSeasonalityValue",
        };
        return @field(mappings, field_name);
    }
};

pub const UniqueValuesComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    category: ?DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .category = "Category",
        };
        return @field(mappings, field_name);
    }
};

pub const GrowthRateComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    value: ?MeasureField = null,
    period_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .value = "Value",
            .period_size = "PeriodSize",
        };
        return @field(mappings, field_name);
    }
};

pub const PeriodToDateComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    value: ?MeasureField = null,
    period_time_granularity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .value = "Value",
            .period_time_granularity = "PeriodTimeGranularity",
        };
        return @field(mappings, field_name);
    }
};

pub const PeriodOverPeriodComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    value: ?MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricComparisonComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    from_value: ?MeasureField = null,
    target_value: ?MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .from_value = "FromValue",
            .target_value = "TargetValue",
        };
        return @field(mappings, field_name);
    }
};

pub const MaximumMinimumComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    value: ?MeasureField = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .value = "Value",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalAggregationComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    value: ?MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TopBottomMoversComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    time: ?DimensionField = null,
    category: ?DimensionField = null,
    value: ?MeasureField = null,
    mover_size: ?i64 = null,
    sort_order: ?[]const u8 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .time = "Time",
            .category = "Category",
            .value = "Value",
            .mover_size = "MoverSize",
            .sort_order = "SortOrder",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const TopBottomRankedComputation = struct {
    computation_id: []const u8,
    name: ?[]const u8 = null,
    category: ?DimensionField = null,
    value: ?MeasureField = null,
    result_size: ?i64 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computation_id = "ComputationId",
            .name = "Name",
            .category = "Category",
            .value = "Value",
            .result_size = "ResultSize",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?WordCloudChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudChartConfiguration = struct {
    field_wells: ?WordCloudFieldWells = null,
    sort_configuration: ?WordCloudSortConfiguration = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    word_cloud_options: ?WordCloudOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .category_label_options = "CategoryLabelOptions",
            .word_cloud_options = "WordCloudOptions",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudOptions = struct {
    word_orientation: ?[]const u8 = null,
    word_scaling: ?[]const u8 = null,
    cloud_layout: ?[]const u8 = null,
    word_casing: ?[]const u8 = null,
    word_padding: ?[]const u8 = null,
    maximum_string_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .word_orientation = "WordOrientation",
            .word_scaling = "WordScaling",
            .cloud_layout = "CloudLayout",
            .word_casing = "WordCasing",
            .word_padding = "WordPadding",
            .maximum_string_length = "MaximumStringLength",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudSortConfiguration = struct {
    category_items_limit: ?ItemsLimitConfiguration = null,
    category_sort: ?[]FieldSortOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_items_limit = "CategoryItemsLimit",
            .category_sort = "CategorySort",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudFieldWells = struct {
    word_cloud_aggregated_field_wells: ?WordCloudAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .word_cloud_aggregated_field_wells = "WordCloudAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const WordCloudAggregatedFieldWells = struct {
    group_by: ?[]DimensionField = null,
    size: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_by = "GroupBy",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?HistogramConfiguration = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramConfiguration = struct {
    field_wells: ?HistogramFieldWells = null,
    x_axis_display_options: ?AxisDisplayOptions = null,
    x_axis_label_options: ?ChartAxisLabelOptions = null,
    y_axis_display_options: ?AxisDisplayOptions = null,
    bin_options: ?HistogramBinOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .x_axis_display_options = "XAxisDisplayOptions",
            .x_axis_label_options = "XAxisLabelOptions",
            .y_axis_display_options = "YAxisDisplayOptions",
            .bin_options = "BinOptions",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const TooltipOptions = struct {
    tooltip_visibility: ?[]const u8 = null,
    selected_tooltip_type: ?[]const u8 = null,
    field_based_tooltip: ?FieldBasedTooltip = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tooltip_visibility = "TooltipVisibility",
            .selected_tooltip_type = "SelectedTooltipType",
            .field_based_tooltip = "FieldBasedTooltip",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldBasedTooltip = struct {
    aggregation_visibility: ?[]const u8 = null,
    tooltip_title_type: ?[]const u8 = null,
    tooltip_fields: ?[]TooltipItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggregation_visibility = "AggregationVisibility",
            .tooltip_title_type = "TooltipTitleType",
            .tooltip_fields = "TooltipFields",
        };
        return @field(mappings, field_name);
    }
};

pub const TooltipItem = struct {
    field_tooltip_item: ?FieldTooltipItem = null,
    column_tooltip_item: ?ColumnTooltipItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_tooltip_item = "FieldTooltipItem",
            .column_tooltip_item = "ColumnTooltipItem",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnTooltipItem = struct {
    column: ColumnIdentifier,
    label: ?[]const u8 = null,
    visibility: ?[]const u8 = null,
    aggregation: ?AggregationFunction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .label = "Label",
            .visibility = "Visibility",
            .aggregation = "Aggregation",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldTooltipItem = struct {
    field_id: []const u8,
    label: ?[]const u8 = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .label = "Label",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramBinOptions = struct {
    selected_bin_type: ?[]const u8 = null,
    bin_count: ?BinCountOptions = null,
    bin_width: ?BinWidthOptions = null,
    start_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_bin_type = "SelectedBinType",
            .bin_count = "BinCount",
            .bin_width = "BinWidth",
            .start_value = "StartValue",
        };
        return @field(mappings, field_name);
    }
};

pub const BinWidthOptions = struct {
    value: ?f64 = null,
    bin_count_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .bin_count_limit = "BinCountLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const BinCountOptions = struct {
    value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramFieldWells = struct {
    histogram_aggregated_field_wells: ?HistogramAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .histogram_aggregated_field_wells = "HistogramAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramAggregatedFieldWells = struct {
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?WaterfallChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartConfiguration = struct {
    field_wells: ?WaterfallChartFieldWells = null,
    sort_configuration: ?WaterfallChartSortConfiguration = null,
    waterfall_chart_options: ?WaterfallChartOptions = null,
    category_axis_label_options: ?ChartAxisLabelOptions = null,
    category_axis_display_options: ?AxisDisplayOptions = null,
    primary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    primary_y_axis_display_options: ?AxisDisplayOptions = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    visual_palette: ?VisualPalette = null,
    color_configuration: ?WaterfallChartColorConfiguration = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .waterfall_chart_options = "WaterfallChartOptions",
            .category_axis_label_options = "CategoryAxisLabelOptions",
            .category_axis_display_options = "CategoryAxisDisplayOptions",
            .primary_y_axis_label_options = "PrimaryYAxisLabelOptions",
            .primary_y_axis_display_options = "PrimaryYAxisDisplayOptions",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .visual_palette = "VisualPalette",
            .color_configuration = "ColorConfiguration",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartColorConfiguration = struct {
    group_color_configuration: ?WaterfallChartGroupColorConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_color_configuration = "GroupColorConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartGroupColorConfiguration = struct {
    positive_bar_color: ?[]const u8 = null,
    negative_bar_color: ?[]const u8 = null,
    total_bar_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .positive_bar_color = "PositiveBarColor",
            .negative_bar_color = "NegativeBarColor",
            .total_bar_color = "TotalBarColor",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartOptions = struct {
    total_bar_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_bar_label = "TotalBarLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    breakdown_items_limit: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .breakdown_items_limit = "BreakdownItemsLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartFieldWells = struct {
    waterfall_chart_aggregated_field_wells: ?WaterfallChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waterfall_chart_aggregated_field_wells = "WaterfallChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const WaterfallChartAggregatedFieldWells = struct {
    categories: ?[]DimensionField = null,
    values: ?[]MeasureField = null,
    breakdowns: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .categories = "Categories",
            .values = "Values",
            .breakdowns = "Breakdowns",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?BoxPlotChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotChartConfiguration = struct {
    field_wells: ?BoxPlotFieldWells = null,
    sort_configuration: ?BoxPlotSortConfiguration = null,
    box_plot_options: ?BoxPlotOptions = null,
    category_axis: ?AxisDisplayOptions = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    primary_y_axis_display_options: ?AxisDisplayOptions = null,
    primary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    legend: ?LegendOptions = null,
    tooltip: ?TooltipOptions = null,
    reference_lines: ?[]ReferenceLine = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .box_plot_options = "BoxPlotOptions",
            .category_axis = "CategoryAxis",
            .category_label_options = "CategoryLabelOptions",
            .primary_y_axis_display_options = "PrimaryYAxisDisplayOptions",
            .primary_y_axis_label_options = "PrimaryYAxisLabelOptions",
            .legend = "Legend",
            .tooltip = "Tooltip",
            .reference_lines = "ReferenceLines",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLine = struct {
    status: ?[]const u8 = null,
    data_configuration: ReferenceLineDataConfiguration,
    style_configuration: ?ReferenceLineStyleConfiguration = null,
    label_configuration: ?ReferenceLineLabelConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .data_configuration = "DataConfiguration",
            .style_configuration = "StyleConfiguration",
            .label_configuration = "LabelConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineLabelConfiguration = struct {
    value_label_configuration: ?ReferenceLineValueLabelConfiguration = null,
    custom_label_configuration: ?ReferenceLineCustomLabelConfiguration = null,
    font_configuration: ?FontConfiguration = null,
    font_color: ?[]const u8 = null,
    horizontal_position: ?[]const u8 = null,
    vertical_position: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_label_configuration = "ValueLabelConfiguration",
            .custom_label_configuration = "CustomLabelConfiguration",
            .font_configuration = "FontConfiguration",
            .font_color = "FontColor",
            .horizontal_position = "HorizontalPosition",
            .vertical_position = "VerticalPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineCustomLabelConfiguration = struct {
    custom_label: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_label = "CustomLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineValueLabelConfiguration = struct {
    relative_position: ?[]const u8 = null,
    format_configuration: ?NumericFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relative_position = "RelativePosition",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineStyleConfiguration = struct {
    pattern: ?[]const u8 = null,
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern = "Pattern",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineDataConfiguration = struct {
    static_configuration: ?ReferenceLineStaticDataConfiguration = null,
    dynamic_configuration: ?ReferenceLineDynamicDataConfiguration = null,
    axis_binding: ?[]const u8 = null,
    series_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_configuration = "StaticConfiguration",
            .dynamic_configuration = "DynamicConfiguration",
            .axis_binding = "AxisBinding",
            .series_type = "SeriesType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineDynamicDataConfiguration = struct {
    column: ColumnIdentifier,
    measure_aggregation_function: ?AggregationFunction = null,
    calculation: NumericalAggregationFunction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .measure_aggregation_function = "MeasureAggregationFunction",
            .calculation = "Calculation",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceLineStaticDataConfiguration = struct {
    value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotOptions = struct {
    style_options: ?BoxPlotStyleOptions = null,
    outlier_visibility: ?[]const u8 = null,
    all_data_points_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .style_options = "StyleOptions",
            .outlier_visibility = "OutlierVisibility",
            .all_data_points_visibility = "AllDataPointsVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotStyleOptions = struct {
    fill_style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fill_style = "FillStyle",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    pagination_configuration: ?PaginationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .pagination_configuration = "PaginationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const PaginationConfiguration = struct {
    page_size: i64,
    page_number: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_size = "PageSize",
            .page_number = "PageNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotFieldWells = struct {
    box_plot_aggregated_field_wells: ?BoxPlotAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .box_plot_aggregated_field_wells = "BoxPlotAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const BoxPlotAggregatedFieldWells = struct {
    group_by: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_by = "GroupBy",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ComboChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?ComboChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const ComboChartConfiguration = struct {
    field_wells: ?ComboChartFieldWells = null,
    sort_configuration: ?ComboChartSortConfiguration = null,
    bars_arrangement: ?[]const u8 = null,
    category_axis: ?AxisDisplayOptions = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    primary_y_axis_display_options: ?AxisDisplayOptions = null,
    primary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    secondary_y_axis_display_options: ?AxisDisplayOptions = null,
    secondary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    single_axis_options: ?SingleAxisOptions = null,
    color_label_options: ?ChartAxisLabelOptions = null,
    legend: ?LegendOptions = null,
    bar_data_labels: ?DataLabelOptions = null,
    line_data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    reference_lines: ?[]ReferenceLine = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .bars_arrangement = "BarsArrangement",
            .category_axis = "CategoryAxis",
            .category_label_options = "CategoryLabelOptions",
            .primary_y_axis_display_options = "PrimaryYAxisDisplayOptions",
            .primary_y_axis_label_options = "PrimaryYAxisLabelOptions",
            .secondary_y_axis_display_options = "SecondaryYAxisDisplayOptions",
            .secondary_y_axis_label_options = "SecondaryYAxisLabelOptions",
            .single_axis_options = "SingleAxisOptions",
            .color_label_options = "ColorLabelOptions",
            .legend = "Legend",
            .bar_data_labels = "BarDataLabels",
            .line_data_labels = "LineDataLabels",
            .tooltip = "Tooltip",
            .reference_lines = "ReferenceLines",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const SingleAxisOptions = struct {
    y_axis_options: ?YAxisOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .y_axis_options = "YAxisOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const YAxisOptions = struct {
    y_axis: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .y_axis = "YAxis",
        };
        return @field(mappings, field_name);
    }
};

pub const ComboChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit: ?ItemsLimitConfiguration = null,
    color_sort: ?[]FieldSortOptions = null,
    color_items_limit: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit = "CategoryItemsLimit",
            .color_sort = "ColorSort",
            .color_items_limit = "ColorItemsLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const ComboChartFieldWells = struct {
    combo_chart_aggregated_field_wells: ?ComboChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .combo_chart_aggregated_field_wells = "ComboChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const ComboChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    bar_values: ?[]MeasureField = null,
    colors: ?[]DimensionField = null,
    line_values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .bar_values = "BarValues",
            .colors = "Colors",
            .line_values = "LineValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?ScatterPlotConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotConfiguration = struct {
    field_wells: ?ScatterPlotFieldWells = null,
    sort_configuration: ?ScatterPlotSortConfiguration = null,
    x_axis_label_options: ?ChartAxisLabelOptions = null,
    x_axis_display_options: ?AxisDisplayOptions = null,
    y_axis_label_options: ?ChartAxisLabelOptions = null,
    y_axis_display_options: ?AxisDisplayOptions = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .x_axis_label_options = "XAxisLabelOptions",
            .x_axis_display_options = "XAxisDisplayOptions",
            .y_axis_label_options = "YAxisLabelOptions",
            .y_axis_display_options = "YAxisDisplayOptions",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotSortConfiguration = struct {
    scatter_plot_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scatter_plot_limit_configuration = "ScatterPlotLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotFieldWells = struct {
    scatter_plot_categorically_aggregated_field_wells: ?ScatterPlotCategoricallyAggregatedFieldWells = null,
    scatter_plot_unaggregated_field_wells: ?ScatterPlotUnaggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scatter_plot_categorically_aggregated_field_wells = "ScatterPlotCategoricallyAggregatedFieldWells",
            .scatter_plot_unaggregated_field_wells = "ScatterPlotUnaggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotUnaggregatedFieldWells = struct {
    x_axis: ?[]DimensionField = null,
    y_axis: ?[]DimensionField = null,
    size: ?[]MeasureField = null,
    category: ?[]DimensionField = null,
    label: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x_axis = "XAxis",
            .y_axis = "YAxis",
            .size = "Size",
            .category = "Category",
            .label = "Label",
        };
        return @field(mappings, field_name);
    }
};

pub const ScatterPlotCategoricallyAggregatedFieldWells = struct {
    x_axis: ?[]MeasureField = null,
    y_axis: ?[]MeasureField = null,
    category: ?[]DimensionField = null,
    size: ?[]MeasureField = null,
    label: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x_axis = "XAxis",
            .y_axis = "YAxis",
            .category = "Category",
            .size = "Size",
            .label = "Label",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?FunnelChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartConfiguration = struct {
    field_wells: ?FunnelChartFieldWells = null,
    sort_configuration: ?FunnelChartSortConfiguration = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    value_label_options: ?ChartAxisLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    data_label_options: ?FunnelChartDataLabelOptions = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .category_label_options = "CategoryLabelOptions",
            .value_label_options = "ValueLabelOptions",
            .tooltip = "Tooltip",
            .data_label_options = "DataLabelOptions",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartDataLabelOptions = struct {
    visibility: ?[]const u8 = null,
    category_label_visibility: ?[]const u8 = null,
    measure_label_visibility: ?[]const u8 = null,
    position: ?[]const u8 = null,
    label_font_configuration: ?FontConfiguration = null,
    label_color: ?[]const u8 = null,
    measure_data_label_style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .category_label_visibility = "CategoryLabelVisibility",
            .measure_label_visibility = "MeasureLabelVisibility",
            .position = "Position",
            .label_font_configuration = "LabelFontConfiguration",
            .label_color = "LabelColor",
            .measure_data_label_style = "MeasureDataLabelStyle",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit = "CategoryItemsLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartFieldWells = struct {
    funnel_chart_aggregated_field_wells: ?FunnelChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .funnel_chart_aggregated_field_wells = "FunnelChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const FunnelChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?FilledMapConfiguration = null,
    conditional_formatting: ?FilledMapConditionalFormatting = null,
    column_hierarchies: ?[]ColumnHierarchy = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .conditional_formatting = "ConditionalFormatting",
            .column_hierarchies = "ColumnHierarchies",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapConditionalFormatting = struct {
    conditional_formatting_options: []FilledMapConditionalFormattingOption,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditional_formatting_options = "ConditionalFormattingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapConditionalFormattingOption = struct {
    shape: FilledMapShapeConditionalFormatting,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shape = "Shape",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapShapeConditionalFormatting = struct {
    field_id: []const u8,
    format: ?ShapeConditionalFormat = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .format = "Format",
        };
        return @field(mappings, field_name);
    }
};

pub const ShapeConditionalFormat = struct {
    background_color: ConditionalFormattingColor,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .background_color = "BackgroundColor",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingColor = struct {
    solid: ?ConditionalFormattingSolidColor = null,
    gradient: ?ConditionalFormattingGradientColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .solid = "Solid",
            .gradient = "Gradient",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingGradientColor = struct {
    expression: []const u8,
    color: GradientColor,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const GradientColor = struct {
    stops: ?[]GradientStop = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stops = "Stops",
        };
        return @field(mappings, field_name);
    }
};

pub const GradientStop = struct {
    gradient_offset: f64,
    data_value: ?f64 = null,
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gradient_offset = "GradientOffset",
            .data_value = "DataValue",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingSolidColor = struct {
    expression: []const u8,
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapConfiguration = struct {
    field_wells: ?FilledMapFieldWells = null,
    sort_configuration: ?FilledMapSortConfiguration = null,
    legend: ?LegendOptions = null,
    tooltip: ?TooltipOptions = null,
    window_options: ?GeospatialWindowOptions = null,
    map_style_options: ?GeospatialMapStyleOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .legend = "Legend",
            .tooltip = "Tooltip",
            .window_options = "WindowOptions",
            .map_style_options = "MapStyleOptions",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialMapStyleOptions = struct {
    base_map_style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_map_style = "BaseMapStyle",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialWindowOptions = struct {
    bounds: ?GeospatialCoordinateBounds = null,
    map_zoom_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounds = "Bounds",
            .map_zoom_mode = "MapZoomMode",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialCoordinateBounds = struct {
    north: f64,
    south: f64,
    west: f64,
    east: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .north = "North",
            .south = "South",
            .west = "West",
            .east = "East",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapFieldWells = struct {
    filled_map_aggregated_field_wells: ?FilledMapAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filled_map_aggregated_field_wells = "FilledMapAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const FilledMapAggregatedFieldWells = struct {
    geospatial: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geospatial = "Geospatial",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialMapVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?GeospatialMapConfiguration = null,
    column_hierarchies: ?[]ColumnHierarchy = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .column_hierarchies = "ColumnHierarchies",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialMapConfiguration = struct {
    field_wells: ?GeospatialMapFieldWells = null,
    legend: ?LegendOptions = null,
    tooltip: ?TooltipOptions = null,
    window_options: ?GeospatialWindowOptions = null,
    map_style_options: ?GeospatialMapStyleOptions = null,
    point_style_options: ?GeospatialPointStyleOptions = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .legend = "Legend",
            .tooltip = "Tooltip",
            .window_options = "WindowOptions",
            .map_style_options = "MapStyleOptions",
            .point_style_options = "PointStyleOptions",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialPointStyleOptions = struct {
    selected_point_style: ?[]const u8 = null,
    cluster_marker_configuration: ?ClusterMarkerConfiguration = null,
    heatmap_configuration: ?GeospatialHeatmapConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_point_style = "SelectedPointStyle",
            .cluster_marker_configuration = "ClusterMarkerConfiguration",
            .heatmap_configuration = "HeatmapConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialHeatmapConfiguration = struct {
    heatmap_color: ?GeospatialHeatmapColorScale = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .heatmap_color = "HeatmapColor",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialHeatmapColorScale = struct {
    colors: ?[]GeospatialHeatmapDataColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .colors = "Colors",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialHeatmapDataColor = struct {
    color: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterMarkerConfiguration = struct {
    cluster_marker: ?ClusterMarker = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_marker = "ClusterMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterMarker = struct {
    simple_cluster_marker: ?SimpleClusterMarker = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_cluster_marker = "SimpleClusterMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleClusterMarker = struct {
    color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color = "Color",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialMapFieldWells = struct {
    geospatial_map_aggregated_field_wells: ?GeospatialMapAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geospatial_map_aggregated_field_wells = "GeospatialMapAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const GeospatialMapAggregatedFieldWells = struct {
    geospatial: ?[]DimensionField = null,
    values: ?[]MeasureField = null,
    colors: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geospatial = "Geospatial",
            .values = "Values",
            .colors = "Colors",
        };
        return @field(mappings, field_name);
    }
};

pub const TreeMapVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?TreeMapConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const TreeMapConfiguration = struct {
    field_wells: ?TreeMapFieldWells = null,
    sort_configuration: ?TreeMapSortConfiguration = null,
    group_label_options: ?ChartAxisLabelOptions = null,
    size_label_options: ?ChartAxisLabelOptions = null,
    color_label_options: ?ChartAxisLabelOptions = null,
    color_scale: ?ColorScale = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .group_label_options = "GroupLabelOptions",
            .size_label_options = "SizeLabelOptions",
            .color_label_options = "ColorLabelOptions",
            .color_scale = "ColorScale",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorScale = struct {
    colors: []DataColor,
    color_fill_type: []const u8,
    null_value_color: ?DataColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .colors = "Colors",
            .color_fill_type = "ColorFillType",
            .null_value_color = "NullValueColor",
        };
        return @field(mappings, field_name);
    }
};

pub const DataColor = struct {
    color: ?[]const u8 = null,
    data_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color = "Color",
            .data_value = "DataValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TreeMapSortConfiguration = struct {
    tree_map_sort: ?[]FieldSortOptions = null,
    tree_map_group_items_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tree_map_sort = "TreeMapSort",
            .tree_map_group_items_limit_configuration = "TreeMapGroupItemsLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TreeMapFieldWells = struct {
    tree_map_aggregated_field_wells: ?TreeMapAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tree_map_aggregated_field_wells = "TreeMapAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const TreeMapAggregatedFieldWells = struct {
    groups: ?[]DimensionField = null,
    sizes: ?[]MeasureField = null,
    colors: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .groups = "Groups",
            .sizes = "Sizes",
            .colors = "Colors",
        };
        return @field(mappings, field_name);
    }
};

pub const HeatMapVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?HeatMapConfiguration = null,
    column_hierarchies: ?[]ColumnHierarchy = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .column_hierarchies = "ColumnHierarchies",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const HeatMapConfiguration = struct {
    field_wells: ?HeatMapFieldWells = null,
    sort_configuration: ?HeatMapSortConfiguration = null,
    row_label_options: ?ChartAxisLabelOptions = null,
    column_label_options: ?ChartAxisLabelOptions = null,
    color_scale: ?ColorScale = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .row_label_options = "RowLabelOptions",
            .column_label_options = "ColumnLabelOptions",
            .color_scale = "ColorScale",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const HeatMapSortConfiguration = struct {
    heat_map_row_sort: ?[]FieldSortOptions = null,
    heat_map_column_sort: ?[]FieldSortOptions = null,
    heat_map_row_items_limit_configuration: ?ItemsLimitConfiguration = null,
    heat_map_column_items_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .heat_map_row_sort = "HeatMapRowSort",
            .heat_map_column_sort = "HeatMapColumnSort",
            .heat_map_row_items_limit_configuration = "HeatMapRowItemsLimitConfiguration",
            .heat_map_column_items_limit_configuration = "HeatMapColumnItemsLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const HeatMapFieldWells = struct {
    heat_map_aggregated_field_wells: ?HeatMapAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .heat_map_aggregated_field_wells = "HeatMapAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const HeatMapAggregatedFieldWells = struct {
    rows: ?[]DimensionField = null,
    columns: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rows = "Rows",
            .columns = "Columns",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?LineChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartConfiguration = struct {
    field_wells: ?LineChartFieldWells = null,
    sort_configuration: ?LineChartSortConfiguration = null,
    forecast_configurations: ?[]ForecastConfiguration = null,
    type: ?[]const u8 = null,
    small_multiples_options: ?SmallMultiplesOptions = null,
    x_axis_display_options: ?AxisDisplayOptions = null,
    x_axis_label_options: ?ChartAxisLabelOptions = null,
    primary_y_axis_display_options: ?LineSeriesAxisDisplayOptions = null,
    primary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    secondary_y_axis_display_options: ?LineSeriesAxisDisplayOptions = null,
    secondary_y_axis_label_options: ?ChartAxisLabelOptions = null,
    single_axis_options: ?SingleAxisOptions = null,
    default_series_settings: ?LineChartDefaultSeriesSettings = null,
    series: ?[]SeriesItem = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    reference_lines: ?[]ReferenceLine = null,
    tooltip: ?TooltipOptions = null,
    contribution_analysis_defaults: ?[]ContributionAnalysisDefault = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .forecast_configurations = "ForecastConfigurations",
            .type = "Type",
            .small_multiples_options = "SmallMultiplesOptions",
            .x_axis_display_options = "XAxisDisplayOptions",
            .x_axis_label_options = "XAxisLabelOptions",
            .primary_y_axis_display_options = "PrimaryYAxisDisplayOptions",
            .primary_y_axis_label_options = "PrimaryYAxisLabelOptions",
            .secondary_y_axis_display_options = "SecondaryYAxisDisplayOptions",
            .secondary_y_axis_label_options = "SecondaryYAxisLabelOptions",
            .single_axis_options = "SingleAxisOptions",
            .default_series_settings = "DefaultSeriesSettings",
            .series = "Series",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .reference_lines = "ReferenceLines",
            .tooltip = "Tooltip",
            .contribution_analysis_defaults = "ContributionAnalysisDefaults",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const ContributionAnalysisDefault = struct {
    measure_field_id: []const u8,
    contributor_dimensions: []ColumnIdentifier,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .measure_field_id = "MeasureFieldId",
            .contributor_dimensions = "ContributorDimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const SeriesItem = struct {
    field_series_item: ?FieldSeriesItem = null,
    data_field_series_item: ?DataFieldSeriesItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_series_item = "FieldSeriesItem",
            .data_field_series_item = "DataFieldSeriesItem",
        };
        return @field(mappings, field_name);
    }
};

pub const DataFieldSeriesItem = struct {
    field_id: []const u8,
    field_value: ?[]const u8 = null,
    axis_binding: []const u8,
    settings: ?LineChartSeriesSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .field_value = "FieldValue",
            .axis_binding = "AxisBinding",
            .settings = "Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartSeriesSettings = struct {
    line_style_settings: ?LineChartLineStyleSettings = null,
    marker_style_settings: ?LineChartMarkerStyleSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_style_settings = "LineStyleSettings",
            .marker_style_settings = "MarkerStyleSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartMarkerStyleSettings = struct {
    marker_visibility: ?[]const u8 = null,
    marker_shape: ?[]const u8 = null,
    marker_size: ?[]const u8 = null,
    marker_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marker_visibility = "MarkerVisibility",
            .marker_shape = "MarkerShape",
            .marker_size = "MarkerSize",
            .marker_color = "MarkerColor",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartLineStyleSettings = struct {
    line_visibility: ?[]const u8 = null,
    line_interpolation: ?[]const u8 = null,
    line_style: ?[]const u8 = null,
    line_width: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_visibility = "LineVisibility",
            .line_interpolation = "LineInterpolation",
            .line_style = "LineStyle",
            .line_width = "LineWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldSeriesItem = struct {
    field_id: []const u8,
    axis_binding: []const u8,
    settings: ?LineChartSeriesSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .axis_binding = "AxisBinding",
            .settings = "Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartDefaultSeriesSettings = struct {
    axis_binding: ?[]const u8 = null,
    line_style_settings: ?LineChartLineStyleSettings = null,
    marker_style_settings: ?LineChartMarkerStyleSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .axis_binding = "AxisBinding",
            .line_style_settings = "LineStyleSettings",
            .marker_style_settings = "MarkerStyleSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const LineSeriesAxisDisplayOptions = struct {
    axis_options: ?AxisDisplayOptions = null,
    missing_data_configurations: ?[]MissingDataConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .axis_options = "AxisOptions",
            .missing_data_configurations = "MissingDataConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const MissingDataConfiguration = struct {
    treatment_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .treatment_option = "TreatmentOption",
        };
        return @field(mappings, field_name);
    }
};

pub const SmallMultiplesOptions = struct {
    max_visible_rows: ?i64 = null,
    max_visible_columns: ?i64 = null,
    panel_configuration: ?PanelConfiguration = null,
    x_axis: ?SmallMultiplesAxisProperties = null,
    y_axis: ?SmallMultiplesAxisProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_visible_rows = "MaxVisibleRows",
            .max_visible_columns = "MaxVisibleColumns",
            .panel_configuration = "PanelConfiguration",
            .x_axis = "XAxis",
            .y_axis = "YAxis",
        };
        return @field(mappings, field_name);
    }
};

pub const SmallMultiplesAxisProperties = struct {
    scale: ?[]const u8 = null,
    placement: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scale = "Scale",
            .placement = "Placement",
        };
        return @field(mappings, field_name);
    }
};

pub const PanelConfiguration = struct {
    title: ?PanelTitleOptions = null,
    border_visibility: ?[]const u8 = null,
    border_thickness: ?[]const u8 = null,
    border_style: ?[]const u8 = null,
    border_color: ?[]const u8 = null,
    gutter_visibility: ?[]const u8 = null,
    gutter_spacing: ?[]const u8 = null,
    background_visibility: ?[]const u8 = null,
    background_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "Title",
            .border_visibility = "BorderVisibility",
            .border_thickness = "BorderThickness",
            .border_style = "BorderStyle",
            .border_color = "BorderColor",
            .gutter_visibility = "GutterVisibility",
            .gutter_spacing = "GutterSpacing",
            .background_visibility = "BackgroundVisibility",
            .background_color = "BackgroundColor",
        };
        return @field(mappings, field_name);
    }
};

pub const PanelTitleOptions = struct {
    visibility: ?[]const u8 = null,
    font_configuration: ?FontConfiguration = null,
    horizontal_text_alignment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .font_configuration = "FontConfiguration",
            .horizontal_text_alignment = "HorizontalTextAlignment",
        };
        return @field(mappings, field_name);
    }
};

pub const ForecastConfiguration = struct {
    forecast_properties: ?TimeBasedForecastProperties = null,
    scenario: ?ForecastScenario = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forecast_properties = "ForecastProperties",
            .scenario = "Scenario",
        };
        return @field(mappings, field_name);
    }
};

pub const ForecastScenario = struct {
    what_if_point_scenario: ?WhatIfPointScenario = null,
    what_if_range_scenario: ?WhatIfRangeScenario = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .what_if_point_scenario = "WhatIfPointScenario",
            .what_if_range_scenario = "WhatIfRangeScenario",
        };
        return @field(mappings, field_name);
    }
};

pub const WhatIfRangeScenario = struct {
    start_date: i64,
    end_date: i64,
    value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const WhatIfPointScenario = struct {
    date: i64,
    value: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeBasedForecastProperties = struct {
    periods_forward: ?i64 = null,
    periods_backward: ?i64 = null,
    upper_boundary: ?f64 = null,
    lower_boundary: ?f64 = null,
    prediction_interval: ?i64 = null,
    seasonality: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .periods_forward = "PeriodsForward",
            .periods_backward = "PeriodsBackward",
            .upper_boundary = "UpperBoundary",
            .lower_boundary = "LowerBoundary",
            .prediction_interval = "PredictionInterval",
            .seasonality = "Seasonality",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit_configuration: ?ItemsLimitConfiguration = null,
    color_items_limit_configuration: ?ItemsLimitConfiguration = null,
    small_multiples_sort: ?[]FieldSortOptions = null,
    small_multiples_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit_configuration = "CategoryItemsLimitConfiguration",
            .color_items_limit_configuration = "ColorItemsLimitConfiguration",
            .small_multiples_sort = "SmallMultiplesSort",
            .small_multiples_limit_configuration = "SmallMultiplesLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartFieldWells = struct {
    line_chart_aggregated_field_wells: ?LineChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_chart_aggregated_field_wells = "LineChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const LineChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    values: ?[]MeasureField = null,
    colors: ?[]DimensionField = null,
    small_multiples: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .values = "Values",
            .colors = "Colors",
            .small_multiples = "SmallMultiples",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?GaugeChartConfiguration = null,
    conditional_formatting: ?GaugeChartConditionalFormatting = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .conditional_formatting = "ConditionalFormatting",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartConditionalFormatting = struct {
    conditional_formatting_options: ?[]GaugeChartConditionalFormattingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditional_formatting_options = "ConditionalFormattingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartConditionalFormattingOption = struct {
    primary_value: ?GaugeChartPrimaryValueConditionalFormatting = null,
    arc: ?GaugeChartArcConditionalFormatting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_value = "PrimaryValue",
            .arc = "Arc",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartArcConditionalFormatting = struct {
    foreground_color: ?ConditionalFormattingColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .foreground_color = "ForegroundColor",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartPrimaryValueConditionalFormatting = struct {
    text_color: ?ConditionalFormattingColor = null,
    icon: ?ConditionalFormattingIcon = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_color = "TextColor",
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingIcon = struct {
    icon_set: ?ConditionalFormattingIconSet = null,
    custom_condition: ?ConditionalFormattingCustomIconCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .icon_set = "IconSet",
            .custom_condition = "CustomCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingCustomIconCondition = struct {
    expression: []const u8,
    icon_options: ConditionalFormattingCustomIconOptions,
    color: ?[]const u8 = null,
    display_configuration: ?ConditionalFormattingIconDisplayConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .icon_options = "IconOptions",
            .color = "Color",
            .display_configuration = "DisplayConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingIconDisplayConfiguration = struct {
    icon_display_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .icon_display_option = "IconDisplayOption",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingCustomIconOptions = struct {
    icon: ?[]const u8 = null,
    unicode_icon: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .icon = "Icon",
            .unicode_icon = "UnicodeIcon",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionalFormattingIconSet = struct {
    expression: []const u8,
    icon_set_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .icon_set_type = "IconSetType",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartConfiguration = struct {
    field_wells: ?GaugeChartFieldWells = null,
    gauge_chart_options: ?GaugeChartOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip_options: ?TooltipOptions = null,
    visual_palette: ?VisualPalette = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .gauge_chart_options = "GaugeChartOptions",
            .data_labels = "DataLabels",
            .tooltip_options = "TooltipOptions",
            .visual_palette = "VisualPalette",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartOptions = struct {
    primary_value_display_type: ?[]const u8 = null,
    comparison: ?ComparisonConfiguration = null,
    arc_axis: ?ArcAxisConfiguration = null,
    arc: ?ArcConfiguration = null,
    primary_value_font_configuration: ?FontConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_value_display_type = "PrimaryValueDisplayType",
            .comparison = "Comparison",
            .arc_axis = "ArcAxis",
            .arc = "Arc",
            .primary_value_font_configuration = "PrimaryValueFontConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ArcConfiguration = struct {
    arc_angle: ?f64 = null,
    arc_thickness: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arc_angle = "ArcAngle",
            .arc_thickness = "ArcThickness",
        };
        return @field(mappings, field_name);
    }
};

pub const ArcAxisConfiguration = struct {
    range: ?ArcAxisDisplayRange = null,
    reserve_range: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .range = "Range",
            .reserve_range = "ReserveRange",
        };
        return @field(mappings, field_name);
    }
};

pub const ArcAxisDisplayRange = struct {
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const ComparisonConfiguration = struct {
    comparison_method: ?[]const u8 = null,
    comparison_format: ?ComparisonFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison_method = "ComparisonMethod",
            .comparison_format = "ComparisonFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const ComparisonFormatConfiguration = struct {
    number_display_format_configuration: ?NumberDisplayFormatConfiguration = null,
    percentage_display_format_configuration: ?PercentageDisplayFormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_display_format_configuration = "NumberDisplayFormatConfiguration",
            .percentage_display_format_configuration = "PercentageDisplayFormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const GaugeChartFieldWells = struct {
    values: ?[]MeasureField = null,
    target_values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .target_values = "TargetValues",
        };
        return @field(mappings, field_name);
    }
};

pub const PieChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?PieChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const PieChartConfiguration = struct {
    field_wells: ?PieChartFieldWells = null,
    sort_configuration: ?PieChartSortConfiguration = null,
    donut_options: ?DonutOptions = null,
    small_multiples_options: ?SmallMultiplesOptions = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    value_label_options: ?ChartAxisLabelOptions = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    visual_palette: ?VisualPalette = null,
    contribution_analysis_defaults: ?[]ContributionAnalysisDefault = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .donut_options = "DonutOptions",
            .small_multiples_options = "SmallMultiplesOptions",
            .category_label_options = "CategoryLabelOptions",
            .value_label_options = "ValueLabelOptions",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .visual_palette = "VisualPalette",
            .contribution_analysis_defaults = "ContributionAnalysisDefaults",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const DonutOptions = struct {
    arc_options: ?ArcOptions = null,
    donut_center_options: ?DonutCenterOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arc_options = "ArcOptions",
            .donut_center_options = "DonutCenterOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DonutCenterOptions = struct {
    label_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label_visibility = "LabelVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const ArcOptions = struct {
    arc_thickness: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arc_thickness = "ArcThickness",
        };
        return @field(mappings, field_name);
    }
};

pub const PieChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit: ?ItemsLimitConfiguration = null,
    small_multiples_sort: ?[]FieldSortOptions = null,
    small_multiples_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit = "CategoryItemsLimit",
            .small_multiples_sort = "SmallMultiplesSort",
            .small_multiples_limit_configuration = "SmallMultiplesLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const PieChartFieldWells = struct {
    pie_chart_aggregated_field_wells: ?PieChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pie_chart_aggregated_field_wells = "PieChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const PieChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    values: ?[]MeasureField = null,
    small_multiples: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .values = "Values",
            .small_multiples = "SmallMultiples",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?KPIConfiguration = null,
    conditional_formatting: ?KPIConditionalFormatting = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .conditional_formatting = "ConditionalFormatting",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIConditionalFormatting = struct {
    conditional_formatting_options: ?[]KPIConditionalFormattingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditional_formatting_options = "ConditionalFormattingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIConditionalFormattingOption = struct {
    primary_value: ?KPIPrimaryValueConditionalFormatting = null,
    progress_bar: ?KPIProgressBarConditionalFormatting = null,
    actual_value: ?KPIActualValueConditionalFormatting = null,
    comparison_value: ?KPIComparisonValueConditionalFormatting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_value = "PrimaryValue",
            .progress_bar = "ProgressBar",
            .actual_value = "ActualValue",
            .comparison_value = "ComparisonValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIComparisonValueConditionalFormatting = struct {
    text_color: ?ConditionalFormattingColor = null,
    icon: ?ConditionalFormattingIcon = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_color = "TextColor",
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIActualValueConditionalFormatting = struct {
    text_color: ?ConditionalFormattingColor = null,
    icon: ?ConditionalFormattingIcon = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_color = "TextColor",
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIProgressBarConditionalFormatting = struct {
    foreground_color: ?ConditionalFormattingColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .foreground_color = "ForegroundColor",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIPrimaryValueConditionalFormatting = struct {
    text_color: ?ConditionalFormattingColor = null,
    icon: ?ConditionalFormattingIcon = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_color = "TextColor",
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIConfiguration = struct {
    field_wells: ?KPIFieldWells = null,
    sort_configuration: ?KPISortConfiguration = null,
    kpi_options: ?KPIOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .kpi_options = "KPIOptions",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIOptions = struct {
    progress_bar: ?ProgressBarOptions = null,
    trend_arrows: ?TrendArrowOptions = null,
    secondary_value: ?SecondaryValueOptions = null,
    comparison: ?ComparisonConfiguration = null,
    primary_value_display_type: ?[]const u8 = null,
    primary_value_font_configuration: ?FontConfiguration = null,
    secondary_value_font_configuration: ?FontConfiguration = null,
    sparkline: ?KPISparklineOptions = null,
    visual_layout_options: ?KPIVisualLayoutOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .progress_bar = "ProgressBar",
            .trend_arrows = "TrendArrows",
            .secondary_value = "SecondaryValue",
            .comparison = "Comparison",
            .primary_value_display_type = "PrimaryValueDisplayType",
            .primary_value_font_configuration = "PrimaryValueFontConfiguration",
            .secondary_value_font_configuration = "SecondaryValueFontConfiguration",
            .sparkline = "Sparkline",
            .visual_layout_options = "VisualLayoutOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIVisualLayoutOptions = struct {
    standard_layout: ?KPIVisualStandardLayout = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standard_layout = "StandardLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIVisualStandardLayout = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const KPISparklineOptions = struct {
    visibility: ?[]const u8 = null,
    type: []const u8,
    color: ?[]const u8 = null,
    tooltip_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .type = "Type",
            .color = "Color",
            .tooltip_visibility = "TooltipVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const SecondaryValueOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const TrendArrowOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const ProgressBarOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const KPISortConfiguration = struct {
    trend_group_sort: ?[]FieldSortOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trend_group_sort = "TrendGroupSort",
        };
        return @field(mappings, field_name);
    }
};

pub const KPIFieldWells = struct {
    values: ?[]MeasureField = null,
    target_values: ?[]MeasureField = null,
    trend_groups: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .target_values = "TargetValues",
            .trend_groups = "TrendGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const BarChartVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?BarChartConfiguration = null,
    actions: ?[]VisualCustomAction = null,
    column_hierarchies: ?[]ColumnHierarchy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .actions = "Actions",
            .column_hierarchies = "ColumnHierarchies",
        };
        return @field(mappings, field_name);
    }
};

pub const BarChartConfiguration = struct {
    field_wells: ?BarChartFieldWells = null,
    sort_configuration: ?BarChartSortConfiguration = null,
    orientation: ?[]const u8 = null,
    bars_arrangement: ?[]const u8 = null,
    visual_palette: ?VisualPalette = null,
    small_multiples_options: ?SmallMultiplesOptions = null,
    category_axis: ?AxisDisplayOptions = null,
    category_label_options: ?ChartAxisLabelOptions = null,
    value_axis: ?AxisDisplayOptions = null,
    value_label_options: ?ChartAxisLabelOptions = null,
    color_label_options: ?ChartAxisLabelOptions = null,
    legend: ?LegendOptions = null,
    data_labels: ?DataLabelOptions = null,
    tooltip: ?TooltipOptions = null,
    reference_lines: ?[]ReferenceLine = null,
    contribution_analysis_defaults: ?[]ContributionAnalysisDefault = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .orientation = "Orientation",
            .bars_arrangement = "BarsArrangement",
            .visual_palette = "VisualPalette",
            .small_multiples_options = "SmallMultiplesOptions",
            .category_axis = "CategoryAxis",
            .category_label_options = "CategoryLabelOptions",
            .value_axis = "ValueAxis",
            .value_label_options = "ValueLabelOptions",
            .color_label_options = "ColorLabelOptions",
            .legend = "Legend",
            .data_labels = "DataLabels",
            .tooltip = "Tooltip",
            .reference_lines = "ReferenceLines",
            .contribution_analysis_defaults = "ContributionAnalysisDefaults",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const BarChartSortConfiguration = struct {
    category_sort: ?[]FieldSortOptions = null,
    category_items_limit: ?ItemsLimitConfiguration = null,
    color_sort: ?[]FieldSortOptions = null,
    color_items_limit: ?ItemsLimitConfiguration = null,
    small_multiples_sort: ?[]FieldSortOptions = null,
    small_multiples_limit_configuration: ?ItemsLimitConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_sort = "CategorySort",
            .category_items_limit = "CategoryItemsLimit",
            .color_sort = "ColorSort",
            .color_items_limit = "ColorItemsLimit",
            .small_multiples_sort = "SmallMultiplesSort",
            .small_multiples_limit_configuration = "SmallMultiplesLimitConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const BarChartFieldWells = struct {
    bar_chart_aggregated_field_wells: ?BarChartAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bar_chart_aggregated_field_wells = "BarChartAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const BarChartAggregatedFieldWells = struct {
    category: ?[]DimensionField = null,
    values: ?[]MeasureField = null,
    colors: ?[]DimensionField = null,
    small_multiples: ?[]DimensionField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .values = "Values",
            .colors = "Colors",
            .small_multiples = "SmallMultiples",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?PivotTableConfiguration = null,
    conditional_formatting: ?PivotTableConditionalFormatting = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .conditional_formatting = "ConditionalFormatting",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableConditionalFormatting = struct {
    conditional_formatting_options: ?[]PivotTableConditionalFormattingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditional_formatting_options = "ConditionalFormattingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableConditionalFormattingOption = struct {
    cell: ?PivotTableCellConditionalFormatting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cell = "Cell",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableCellConditionalFormatting = struct {
    field_id: []const u8,
    text_format: ?TextConditionalFormat = null,
    scope: ?PivotTableConditionalFormattingScope = null,
    scopes: ?[]PivotTableConditionalFormattingScope = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .text_format = "TextFormat",
            .scope = "Scope",
            .scopes = "Scopes",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableConditionalFormattingScope = struct {
    role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role = "Role",
        };
        return @field(mappings, field_name);
    }
};

pub const TextConditionalFormat = struct {
    background_color: ?ConditionalFormattingColor = null,
    text_color: ?ConditionalFormattingColor = null,
    icon: ?ConditionalFormattingIcon = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .background_color = "BackgroundColor",
            .text_color = "TextColor",
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableConfiguration = struct {
    field_wells: ?PivotTableFieldWells = null,
    sort_configuration: ?PivotTableSortConfiguration = null,
    table_options: ?PivotTableOptions = null,
    total_options: ?PivotTableTotalOptions = null,
    field_options: ?PivotTableFieldOptions = null,
    paginated_report_options: ?PivotTablePaginatedReportOptions = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .table_options = "TableOptions",
            .total_options = "TotalOptions",
            .field_options = "FieldOptions",
            .paginated_report_options = "PaginatedReportOptions",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTablePaginatedReportOptions = struct {
    vertical_overflow_visibility: ?[]const u8 = null,
    overflow_column_header_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vertical_overflow_visibility = "VerticalOverflowVisibility",
            .overflow_column_header_visibility = "OverflowColumnHeaderVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldOptions = struct {
    selected_field_options: ?[]PivotTableFieldOption = null,
    data_path_options: ?[]PivotTableDataPathOption = null,
    collapse_state_options: ?[]PivotTableFieldCollapseStateOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_field_options = "SelectedFieldOptions",
            .data_path_options = "DataPathOptions",
            .collapse_state_options = "CollapseStateOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldCollapseStateOption = struct {
    target: PivotTableFieldCollapseStateTarget,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target = "Target",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldCollapseStateTarget = struct {
    field_id: ?[]const u8 = null,
    field_data_path_values: ?[]DataPathValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .field_data_path_values = "FieldDataPathValues",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableDataPathOption = struct {
    data_path_list: []DataPathValue,
    width: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_path_list = "DataPathList",
            .width = "Width",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldOption = struct {
    field_id: []const u8,
    custom_label: ?[]const u8 = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .custom_label = "CustomLabel",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableTotalOptions = struct {
    row_subtotal_options: ?SubtotalOptions = null,
    column_subtotal_options: ?SubtotalOptions = null,
    row_total_options: ?PivotTotalOptions = null,
    column_total_options: ?PivotTotalOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .row_subtotal_options = "RowSubtotalOptions",
            .column_subtotal_options = "ColumnSubtotalOptions",
            .row_total_options = "RowTotalOptions",
            .column_total_options = "ColumnTotalOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTotalOptions = struct {
    totals_visibility: ?[]const u8 = null,
    placement: ?[]const u8 = null,
    scroll_status: ?[]const u8 = null,
    custom_label: ?[]const u8 = null,
    total_cell_style: ?TableCellStyle = null,
    value_cell_style: ?TableCellStyle = null,
    metric_header_cell_style: ?TableCellStyle = null,
    total_aggregation_options: ?[]TotalAggregationOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .totals_visibility = "TotalsVisibility",
            .placement = "Placement",
            .scroll_status = "ScrollStatus",
            .custom_label = "CustomLabel",
            .total_cell_style = "TotalCellStyle",
            .value_cell_style = "ValueCellStyle",
            .metric_header_cell_style = "MetricHeaderCellStyle",
            .total_aggregation_options = "TotalAggregationOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalAggregationOption = struct {
    field_id: []const u8,
    total_aggregation_function: TotalAggregationFunction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .total_aggregation_function = "TotalAggregationFunction",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalAggregationFunction = struct {
    simple_total_aggregation_function: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_total_aggregation_function = "SimpleTotalAggregationFunction",
        };
        return @field(mappings, field_name);
    }
};

pub const TableCellStyle = struct {
    visibility: ?[]const u8 = null,
    font_configuration: ?FontConfiguration = null,
    text_wrap: ?[]const u8 = null,
    horizontal_text_alignment: ?[]const u8 = null,
    vertical_text_alignment: ?[]const u8 = null,
    background_color: ?[]const u8 = null,
    height: ?i64 = null,
    border: ?GlobalTableBorderOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .font_configuration = "FontConfiguration",
            .text_wrap = "TextWrap",
            .horizontal_text_alignment = "HorizontalTextAlignment",
            .vertical_text_alignment = "VerticalTextAlignment",
            .background_color = "BackgroundColor",
            .height = "Height",
            .border = "Border",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalTableBorderOptions = struct {
    uniform_border: ?TableBorderOptions = null,
    side_specific_border: ?TableSideBorderOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uniform_border = "UniformBorder",
            .side_specific_border = "SideSpecificBorder",
        };
        return @field(mappings, field_name);
    }
};

pub const TableSideBorderOptions = struct {
    inner_vertical: ?TableBorderOptions = null,
    inner_horizontal: ?TableBorderOptions = null,
    left: ?TableBorderOptions = null,
    right: ?TableBorderOptions = null,
    top: ?TableBorderOptions = null,
    bottom: ?TableBorderOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inner_vertical = "InnerVertical",
            .inner_horizontal = "InnerHorizontal",
            .left = "Left",
            .right = "Right",
            .top = "Top",
            .bottom = "Bottom",
        };
        return @field(mappings, field_name);
    }
};

pub const TableBorderOptions = struct {
    color: ?[]const u8 = null,
    thickness: ?i64 = null,
    style: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color = "Color",
            .thickness = "Thickness",
            .style = "Style",
        };
        return @field(mappings, field_name);
    }
};

pub const SubtotalOptions = struct {
    totals_visibility: ?[]const u8 = null,
    custom_label: ?[]const u8 = null,
    field_level: ?[]const u8 = null,
    field_level_options: ?[]PivotTableFieldSubtotalOptions = null,
    total_cell_style: ?TableCellStyle = null,
    value_cell_style: ?TableCellStyle = null,
    metric_header_cell_style: ?TableCellStyle = null,
    style_targets: ?[]TableStyleTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .totals_visibility = "TotalsVisibility",
            .custom_label = "CustomLabel",
            .field_level = "FieldLevel",
            .field_level_options = "FieldLevelOptions",
            .total_cell_style = "TotalCellStyle",
            .value_cell_style = "ValueCellStyle",
            .metric_header_cell_style = "MetricHeaderCellStyle",
            .style_targets = "StyleTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const TableStyleTarget = struct {
    cell_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cell_type = "CellType",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldSubtotalOptions = struct {
    field_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableOptions = struct {
    metric_placement: ?[]const u8 = null,
    single_metric_visibility: ?[]const u8 = null,
    column_names_visibility: ?[]const u8 = null,
    toggle_buttons_visibility: ?[]const u8 = null,
    column_header_style: ?TableCellStyle = null,
    row_header_style: ?TableCellStyle = null,
    cell_style: ?TableCellStyle = null,
    row_field_names_style: ?TableCellStyle = null,
    row_alternate_color_options: ?RowAlternateColorOptions = null,
    collapsed_row_dimensions_visibility: ?[]const u8 = null,
    rows_layout: ?[]const u8 = null,
    rows_label_options: ?PivotTableRowsLabelOptions = null,
    default_cell_width: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_placement = "MetricPlacement",
            .single_metric_visibility = "SingleMetricVisibility",
            .column_names_visibility = "ColumnNamesVisibility",
            .toggle_buttons_visibility = "ToggleButtonsVisibility",
            .column_header_style = "ColumnHeaderStyle",
            .row_header_style = "RowHeaderStyle",
            .cell_style = "CellStyle",
            .row_field_names_style = "RowFieldNamesStyle",
            .row_alternate_color_options = "RowAlternateColorOptions",
            .collapsed_row_dimensions_visibility = "CollapsedRowDimensionsVisibility",
            .rows_layout = "RowsLayout",
            .rows_label_options = "RowsLabelOptions",
            .default_cell_width = "DefaultCellWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableRowsLabelOptions = struct {
    visibility: ?[]const u8 = null,
    custom_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .custom_label = "CustomLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const RowAlternateColorOptions = struct {
    status: ?[]const u8 = null,
    row_alternate_colors: ?[][]const u8 = null,
    use_primary_background_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .row_alternate_colors = "RowAlternateColors",
            .use_primary_background_color = "UsePrimaryBackgroundColor",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableSortConfiguration = struct {
    field_sort_options: ?[]PivotFieldSortOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_sort_options = "FieldSortOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotFieldSortOptions = struct {
    field_id: []const u8,
    sort_by: PivotTableSortBy,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .sort_by = "SortBy",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableSortBy = struct {
    field: ?FieldSort = null,
    column: ?ColumnSort = null,
    data_path: ?DataPathSort = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field = "Field",
            .column = "Column",
            .data_path = "DataPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPathSort = struct {
    direction: []const u8,
    sort_paths: []DataPathValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .direction = "Direction",
            .sort_paths = "SortPaths",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableFieldWells = struct {
    pivot_table_aggregated_field_wells: ?PivotTableAggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pivot_table_aggregated_field_wells = "PivotTableAggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const PivotTableAggregatedFieldWells = struct {
    rows: ?[]DimensionField = null,
    columns: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rows = "Rows",
            .columns = "Columns",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const TableVisual = struct {
    visual_id: []const u8,
    title: ?VisualTitleLabelOptions = null,
    subtitle: ?VisualSubtitleLabelOptions = null,
    chart_configuration: ?TableConfiguration = null,
    conditional_formatting: ?TableConditionalFormatting = null,
    actions: ?[]VisualCustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visual_id = "VisualId",
            .title = "Title",
            .subtitle = "Subtitle",
            .chart_configuration = "ChartConfiguration",
            .conditional_formatting = "ConditionalFormatting",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableConditionalFormatting = struct {
    conditional_formatting_options: ?[]TableConditionalFormattingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conditional_formatting_options = "ConditionalFormattingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableConditionalFormattingOption = struct {
    cell: ?TableCellConditionalFormatting = null,
    row: ?TableRowConditionalFormatting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cell = "Cell",
            .row = "Row",
        };
        return @field(mappings, field_name);
    }
};

pub const TableRowConditionalFormatting = struct {
    background_color: ?ConditionalFormattingColor = null,
    text_color: ?ConditionalFormattingColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .background_color = "BackgroundColor",
            .text_color = "TextColor",
        };
        return @field(mappings, field_name);
    }
};

pub const TableCellConditionalFormatting = struct {
    field_id: []const u8,
    text_format: ?TextConditionalFormat = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .text_format = "TextFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const TableConfiguration = struct {
    field_wells: ?TableFieldWells = null,
    sort_configuration: ?TableSortConfiguration = null,
    table_options: ?TableOptions = null,
    total_options: ?TotalOptions = null,
    field_options: ?TableFieldOptions = null,
    paginated_report_options: ?TablePaginatedReportOptions = null,
    table_inline_visualizations: ?[]TableInlineVisualization = null,
    interactions: ?VisualInteractionOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_wells = "FieldWells",
            .sort_configuration = "SortConfiguration",
            .table_options = "TableOptions",
            .total_options = "TotalOptions",
            .field_options = "FieldOptions",
            .paginated_report_options = "PaginatedReportOptions",
            .table_inline_visualizations = "TableInlineVisualizations",
            .interactions = "Interactions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableInlineVisualization = struct {
    data_bars: ?DataBarsOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_bars = "DataBars",
        };
        return @field(mappings, field_name);
    }
};

pub const DataBarsOptions = struct {
    field_id: []const u8,
    positive_color: ?[]const u8 = null,
    negative_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .positive_color = "PositiveColor",
            .negative_color = "NegativeColor",
        };
        return @field(mappings, field_name);
    }
};

pub const TablePaginatedReportOptions = struct {
    vertical_overflow_visibility: ?[]const u8 = null,
    overflow_column_header_visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vertical_overflow_visibility = "VerticalOverflowVisibility",
            .overflow_column_header_visibility = "OverflowColumnHeaderVisibility",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldOptions = struct {
    selected_field_options: ?[]TableFieldOption = null,
    order: ?[][]const u8 = null,
    pinned_field_options: ?TablePinnedFieldOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_field_options = "SelectedFieldOptions",
            .order = "Order",
            .pinned_field_options = "PinnedFieldOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TablePinnedFieldOptions = struct {
    pinned_left_fields: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pinned_left_fields = "PinnedLeftFields",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldOption = struct {
    field_id: []const u8,
    width: ?[]const u8 = null,
    custom_label: ?[]const u8 = null,
    visibility: ?[]const u8 = null,
    url_styling: ?TableFieldURLConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .width = "Width",
            .custom_label = "CustomLabel",
            .visibility = "Visibility",
            .url_styling = "URLStyling",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldURLConfiguration = struct {
    link_configuration: ?TableFieldLinkConfiguration = null,
    image_configuration: ?TableFieldImageConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .link_configuration = "LinkConfiguration",
            .image_configuration = "ImageConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldImageConfiguration = struct {
    sizing_options: ?TableCellImageSizingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sizing_options = "SizingOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableCellImageSizingConfiguration = struct {
    table_cell_image_scaling_configuration: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_cell_image_scaling_configuration = "TableCellImageScalingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldLinkConfiguration = struct {
    target: []const u8,
    content: TableFieldLinkContentConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target = "Target",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldLinkContentConfiguration = struct {
    custom_text_content: ?TableFieldCustomTextContent = null,
    custom_icon_content: ?TableFieldCustomIconContent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_text_content = "CustomTextContent",
            .custom_icon_content = "CustomIconContent",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldCustomIconContent = struct {
    icon: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .icon = "Icon",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldCustomTextContent = struct {
    value: ?[]const u8 = null,
    font_configuration: FontConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .font_configuration = "FontConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TotalOptions = struct {
    totals_visibility: ?[]const u8 = null,
    placement: ?[]const u8 = null,
    scroll_status: ?[]const u8 = null,
    custom_label: ?[]const u8 = null,
    total_cell_style: ?TableCellStyle = null,
    total_aggregation_options: ?[]TotalAggregationOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .totals_visibility = "TotalsVisibility",
            .placement = "Placement",
            .scroll_status = "ScrollStatus",
            .custom_label = "CustomLabel",
            .total_cell_style = "TotalCellStyle",
            .total_aggregation_options = "TotalAggregationOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableOptions = struct {
    orientation: ?[]const u8 = null,
    header_style: ?TableCellStyle = null,
    cell_style: ?TableCellStyle = null,
    row_alternate_color_options: ?RowAlternateColorOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .orientation = "Orientation",
            .header_style = "HeaderStyle",
            .cell_style = "CellStyle",
            .row_alternate_color_options = "RowAlternateColorOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TableSortConfiguration = struct {
    row_sort: ?[]FieldSortOptions = null,
    pagination_configuration: ?PaginationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .row_sort = "RowSort",
            .pagination_configuration = "PaginationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TableFieldWells = struct {
    table_aggregated_field_wells: ?TableAggregatedFieldWells = null,
    table_unaggregated_field_wells: ?TableUnaggregatedFieldWells = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_aggregated_field_wells = "TableAggregatedFieldWells",
            .table_unaggregated_field_wells = "TableUnaggregatedFieldWells",
        };
        return @field(mappings, field_name);
    }
};

pub const TableUnaggregatedFieldWells = struct {
    values: ?[]UnaggregatedField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const UnaggregatedField = struct {
    field_id: []const u8,
    column: ColumnIdentifier,
    format_configuration: ?FormatConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_id = "FieldId",
            .column = "Column",
            .format_configuration = "FormatConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TableAggregatedFieldWells = struct {
    group_by: ?[]DimensionField = null,
    values: ?[]MeasureField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_by = "GroupBy",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterControl = struct {
    date_time_picker: ?FilterDateTimePickerControl = null,
    list: ?FilterListControl = null,
    dropdown: ?FilterDropDownControl = null,
    text_field: ?FilterTextFieldControl = null,
    text_area: ?FilterTextAreaControl = null,
    slider: ?FilterSliderControl = null,
    relative_date_time: ?FilterRelativeDateTimeControl = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date_time_picker = "DateTimePicker",
            .list = "List",
            .dropdown = "Dropdown",
            .text_field = "TextField",
            .text_area = "TextArea",
            .slider = "Slider",
            .relative_date_time = "RelativeDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterRelativeDateTimeControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?RelativeDateTimeControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const RelativeDateTimeControlDisplayOptions = struct {
    title_options: ?LabelOptions = null,
    date_time_format: ?[]const u8 = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title_options = "TitleOptions",
            .date_time_format = "DateTimeFormat",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetControlInfoIconLabelOptions = struct {
    visibility: ?[]const u8 = null,
    info_icon_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
            .info_icon_text = "InfoIconText",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterSliderControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?SliderControlDisplayOptions = null,
    type: ?[]const u8 = null,
    maximum_value: f64,
    minimum_value: f64,
    step_size: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
            .type = "Type",
            .maximum_value = "MaximumValue",
            .minimum_value = "MinimumValue",
            .step_size = "StepSize",
        };
        return @field(mappings, field_name);
    }
};

pub const SliderControlDisplayOptions = struct {
    title_options: ?LabelOptions = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title_options = "TitleOptions",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterTextAreaControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    delimiter: ?[]const u8 = null,
    display_options: ?TextAreaControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .delimiter = "Delimiter",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TextAreaControlDisplayOptions = struct {
    title_options: ?LabelOptions = null,
    placeholder_options: ?TextControlPlaceholderOptions = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title_options = "TitleOptions",
            .placeholder_options = "PlaceholderOptions",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TextControlPlaceholderOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterTextFieldControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?TextFieldControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TextFieldControlDisplayOptions = struct {
    title_options: ?LabelOptions = null,
    placeholder_options: ?TextControlPlaceholderOptions = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title_options = "TitleOptions",
            .placeholder_options = "PlaceholderOptions",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterDropDownControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?DropDownControlDisplayOptions = null,
    type: ?[]const u8 = null,
    selectable_values: ?FilterSelectableValues = null,
    cascading_control_configuration: ?CascadingControlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
            .type = "Type",
            .selectable_values = "SelectableValues",
            .cascading_control_configuration = "CascadingControlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CascadingControlConfiguration = struct {
    source_controls: ?[]CascadingControlSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_controls = "SourceControls",
        };
        return @field(mappings, field_name);
    }
};

pub const CascadingControlSource = struct {
    source_sheet_control_id: ?[]const u8 = null,
    column_to_match: ?ColumnIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_sheet_control_id = "SourceSheetControlId",
            .column_to_match = "ColumnToMatch",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterSelectableValues = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DropDownControlDisplayOptions = struct {
    select_all_options: ?ListControlSelectAllOptions = null,
    title_options: ?LabelOptions = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .select_all_options = "SelectAllOptions",
            .title_options = "TitleOptions",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ListControlSelectAllOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterListControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?ListControlDisplayOptions = null,
    type: ?[]const u8 = null,
    selectable_values: ?FilterSelectableValues = null,
    cascading_control_configuration: ?CascadingControlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
            .type = "Type",
            .selectable_values = "SelectableValues",
            .cascading_control_configuration = "CascadingControlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ListControlDisplayOptions = struct {
    search_options: ?ListControlSearchOptions = null,
    select_all_options: ?ListControlSelectAllOptions = null,
    title_options: ?LabelOptions = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .search_options = "SearchOptions",
            .select_all_options = "SelectAllOptions",
            .title_options = "TitleOptions",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ListControlSearchOptions = struct {
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterDateTimePickerControl = struct {
    filter_control_id: []const u8,
    title: []const u8,
    source_filter_id: []const u8,
    display_options: ?DateTimePickerControlDisplayOptions = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_control_id = "FilterControlId",
            .title = "Title",
            .source_filter_id = "SourceFilterId",
            .display_options = "DisplayOptions",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimePickerControlDisplayOptions = struct {
    title_options: ?LabelOptions = null,
    date_time_format: ?[]const u8 = null,
    info_icon_label_options: ?SheetControlInfoIconLabelOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title_options = "TitleOptions",
            .date_time_format = "DateTimeFormat",
            .info_icon_label_options = "InfoIconLabelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterControl = struct {
    date_time_picker: ?ParameterDateTimePickerControl = null,
    list: ?ParameterListControl = null,
    dropdown: ?ParameterDropDownControl = null,
    text_field: ?ParameterTextFieldControl = null,
    text_area: ?ParameterTextAreaControl = null,
    slider: ?ParameterSliderControl = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date_time_picker = "DateTimePicker",
            .list = "List",
            .dropdown = "Dropdown",
            .text_field = "TextField",
            .text_area = "TextArea",
            .slider = "Slider",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterSliderControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    display_options: ?SliderControlDisplayOptions = null,
    maximum_value: f64,
    minimum_value: f64,
    step_size: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .display_options = "DisplayOptions",
            .maximum_value = "MaximumValue",
            .minimum_value = "MinimumValue",
            .step_size = "StepSize",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterTextAreaControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    delimiter: ?[]const u8 = null,
    display_options: ?TextAreaControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .delimiter = "Delimiter",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterTextFieldControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    display_options: ?TextFieldControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterDropDownControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    display_options: ?DropDownControlDisplayOptions = null,
    type: ?[]const u8 = null,
    selectable_values: ?ParameterSelectableValues = null,
    cascading_control_configuration: ?CascadingControlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .display_options = "DisplayOptions",
            .type = "Type",
            .selectable_values = "SelectableValues",
            .cascading_control_configuration = "CascadingControlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterSelectableValues = struct {
    values: ?[][]const u8 = null,
    link_to_data_set_column: ?ColumnIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .link_to_data_set_column = "LinkToDataSetColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterListControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    display_options: ?ListControlDisplayOptions = null,
    type: ?[]const u8 = null,
    selectable_values: ?ParameterSelectableValues = null,
    cascading_control_configuration: ?CascadingControlConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .display_options = "DisplayOptions",
            .type = "Type",
            .selectable_values = "SelectableValues",
            .cascading_control_configuration = "CascadingControlConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterDateTimePickerControl = struct {
    parameter_control_id: []const u8,
    title: []const u8,
    source_parameter_name: []const u8,
    display_options: ?DateTimePickerControlDisplayOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_control_id = "ParameterControlId",
            .title = "Title",
            .source_parameter_name = "SourceParameterName",
            .display_options = "DisplayOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetConfiguration = struct {
    placeholder: ?[]const u8 = null,
    data_set_schema: ?DataSetSchema = null,
    column_group_schema_list: ?[]ColumnGroupSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .placeholder = "Placeholder",
            .data_set_schema = "DataSetSchema",
            .column_group_schema_list = "ColumnGroupSchemaList",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnGroupSchema = struct {
    name: ?[]const u8 = null,
    column_group_column_schema_list: ?[]ColumnGroupColumnSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .column_group_column_schema_list = "ColumnGroupColumnSchemaList",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnGroupColumnSchema = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetSchema = struct {
    column_schema_list: ?[]ColumnSchema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_schema_list = "ColumnSchemaList",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnSchema = struct {
    name: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    geographic_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data_type = "DataType",
            .geographic_role = "GeographicRole",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceEntity = struct {
    source_analysis: ?TemplateSourceAnalysis = null,
    source_template: ?TemplateSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_analysis = "SourceAnalysis",
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceTemplate = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceAnalysis = struct {
    arn: []const u8,
    data_set_references: []DataSetReference,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .data_set_references = "DataSetReferences",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetReference = struct {
    data_set_placeholder: []const u8,
    data_set_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_placeholder = "DataSetPlaceholder",
            .data_set_arn = "DataSetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshSchedule = struct {
    schedule_id: []const u8,
    schedule_frequency: RefreshFrequency,
    start_after_date_time: ?i64 = null,
    refresh_type: []const u8,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_id = "ScheduleId",
            .schedule_frequency = "ScheduleFrequency",
            .start_after_date_time = "StartAfterDateTime",
            .refresh_type = "RefreshType",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshFrequency = struct {
    interval: []const u8,
    refresh_on_day: ?ScheduleRefreshOnEntity = null,
    timezone: ?[]const u8 = null,
    time_of_the_day: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval = "Interval",
            .refresh_on_day = "RefreshOnDay",
            .timezone = "Timezone",
            .time_of_the_day = "TimeOfTheDay",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleRefreshOnEntity = struct {
    day_of_week: ?[]const u8 = null,
    day_of_month: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_week = "DayOfWeek",
            .day_of_month = "DayOfMonth",
        };
        return @field(mappings, field_name);
    }
};

pub const Group = struct {
    arn: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .group_name = "GroupName",
            .description = "Description",
            .principal_id = "PrincipalId",
        };
        return @field(mappings, field_name);
    }
};

pub const SslProperties = struct {
    disable_ssl: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_ssl = "DisableSsl",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConnectionProperties = struct {
    vpc_connection_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connection_arn = "VpcConnectionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceCredentials = struct {
    credential_pair: ?CredentialPair = null,
    copy_source_arn: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credential_pair = "CredentialPair",
            .copy_source_arn = "CopySourceArn",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CredentialPair = struct {
    username: []const u8,
    password: []const u8,
    alternate_data_source_parameters: ?[]DataSourceParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .alternate_data_source_parameters = "AlternateDataSourceParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceParameters = union {
    amazon_elasticsearch_parameters: ?AmazonElasticsearchParameters,
    athena_parameters: ?AthenaParameters,
    aurora_parameters: ?AuroraParameters,
    aurora_postgre_sql_parameters: ?AuroraPostgreSqlParameters,
    aws_iot_analytics_parameters: ?AwsIotAnalyticsParameters,
    jira_parameters: ?JiraParameters,
    maria_db_parameters: ?MariaDbParameters,
    my_sql_parameters: ?MySqlParameters,
    oracle_parameters: ?OracleParameters,
    postgre_sql_parameters: ?PostgreSqlParameters,
    presto_parameters: ?PrestoParameters,
    rds_parameters: ?RdsParameters,
    redshift_parameters: ?RedshiftParameters,
    s3_parameters: ?S3Parameters,
    service_now_parameters: ?ServiceNowParameters,
    snowflake_parameters: ?SnowflakeParameters,
    spark_parameters: ?SparkParameters,
    sql_server_parameters: ?SqlServerParameters,
    teradata_parameters: ?TeradataParameters,
    twitter_parameters: ?TwitterParameters,
    amazon_open_search_parameters: ?AmazonOpenSearchParameters,
    exasol_parameters: ?ExasolParameters,
    databricks_parameters: ?DatabricksParameters,
    starburst_parameters: ?StarburstParameters,
    trino_parameters: ?TrinoParameters,
    big_query_parameters: ?BigQueryParameters,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_elasticsearch_parameters = "AmazonElasticsearchParameters",
            .athena_parameters = "AthenaParameters",
            .aurora_parameters = "AuroraParameters",
            .aurora_postgre_sql_parameters = "AuroraPostgreSqlParameters",
            .aws_iot_analytics_parameters = "AwsIotAnalyticsParameters",
            .jira_parameters = "JiraParameters",
            .maria_db_parameters = "MariaDbParameters",
            .my_sql_parameters = "MySqlParameters",
            .oracle_parameters = "OracleParameters",
            .postgre_sql_parameters = "PostgreSqlParameters",
            .presto_parameters = "PrestoParameters",
            .rds_parameters = "RdsParameters",
            .redshift_parameters = "RedshiftParameters",
            .s3_parameters = "S3Parameters",
            .service_now_parameters = "ServiceNowParameters",
            .snowflake_parameters = "SnowflakeParameters",
            .spark_parameters = "SparkParameters",
            .sql_server_parameters = "SqlServerParameters",
            .teradata_parameters = "TeradataParameters",
            .twitter_parameters = "TwitterParameters",
            .amazon_open_search_parameters = "AmazonOpenSearchParameters",
            .exasol_parameters = "ExasolParameters",
            .databricks_parameters = "DatabricksParameters",
            .starburst_parameters = "StarburstParameters",
            .trino_parameters = "TrinoParameters",
            .big_query_parameters = "BigQueryParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const BigQueryParameters = struct {
    project_id: []const u8,
    data_set_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .project_id = "ProjectId",
            .data_set_region = "DataSetRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const TrinoParameters = struct {
    host: []const u8,
    port: i64,
    catalog: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .catalog = "Catalog",
        };
        return @field(mappings, field_name);
    }
};

pub const StarburstParameters = struct {
    host: []const u8,
    port: i64,
    catalog: []const u8,
    product_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .catalog = "Catalog",
            .product_type = "ProductType",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabricksParameters = struct {
    host: []const u8,
    port: i64,
    sql_endpoint_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .sql_endpoint_path = "SqlEndpointPath",
        };
        return @field(mappings, field_name);
    }
};

pub const ExasolParameters = struct {
    host: []const u8,
    port: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonOpenSearchParameters = struct {
    domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
        };
        return @field(mappings, field_name);
    }
};

pub const TwitterParameters = struct {
    query: []const u8,
    max_rows: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query = "Query",
            .max_rows = "MaxRows",
        };
        return @field(mappings, field_name);
    }
};

pub const TeradataParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlServerParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkParameters = struct {
    host: []const u8,
    port: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeParameters = struct {
    host: []const u8,
    database: []const u8,
    warehouse: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .database = "Database",
            .warehouse = "Warehouse",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowParameters = struct {
    site_base_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_base_url = "SiteBaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Parameters = struct {
    manifest_file_location: ManifestFileLocation,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_file_location = "ManifestFileLocation",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestFileLocation = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftParameters = struct {
    host: ?[]const u8 = null,
    port: ?i64 = null,
    database: []const u8,
    cluster_id: ?[]const u8 = null,
    iam_parameters: ?RedshiftIAMParameters = null,
    identity_center_configuration: ?IdentityCenterConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
            .cluster_id = "ClusterId",
            .iam_parameters = "IAMParameters",
            .identity_center_configuration = "IdentityCenterConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityCenterConfiguration = struct {
    enable_identity_propagation: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_identity_propagation = "EnableIdentityPropagation",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftIAMParameters = struct {
    role_arn: []const u8,
    database_user: []const u8,
    database_groups: ?[][]const u8 = null,
    auto_create_database_user: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .database_user = "DatabaseUser",
            .database_groups = "DatabaseGroups",
            .auto_create_database_user = "AutoCreateDatabaseUser",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsParameters = struct {
    instance_id: []const u8,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const PrestoParameters = struct {
    host: []const u8,
    port: i64,
    catalog: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .catalog = "Catalog",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const MySqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const MariaDbParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const JiraParameters = struct {
    site_base_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_base_url = "SiteBaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIotAnalyticsParameters = struct {
    data_set_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_name = "DataSetName",
        };
        return @field(mappings, field_name);
    }
};

pub const AuroraPostgreSqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const AuroraParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const AthenaParameters = struct {
    work_group: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .work_group = "WorkGroup",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonElasticsearchParameters = struct {
    domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetParameter = struct {
    string_dataset_parameter: ?StringDatasetParameter = null,
    decimal_dataset_parameter: ?DecimalDatasetParameter = null,
    integer_dataset_parameter: ?IntegerDatasetParameter = null,
    date_time_dataset_parameter: ?DateTimeDatasetParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_dataset_parameter = "StringDatasetParameter",
            .decimal_dataset_parameter = "DecimalDatasetParameter",
            .integer_dataset_parameter = "IntegerDatasetParameter",
            .date_time_dataset_parameter = "DateTimeDatasetParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeDatasetParameter = struct {
    id: []const u8,
    name: []const u8,
    value_type: []const u8,
    time_granularity: ?[]const u8 = null,
    default_values: ?DateTimeDatasetParameterDefaultValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .value_type = "ValueType",
            .time_granularity = "TimeGranularity",
            .default_values = "DefaultValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeDatasetParameterDefaultValues = struct {
    static_values: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerDatasetParameter = struct {
    id: []const u8,
    name: []const u8,
    value_type: []const u8,
    default_values: ?IntegerDatasetParameterDefaultValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .value_type = "ValueType",
            .default_values = "DefaultValues",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerDatasetParameterDefaultValues = struct {
    static_values: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalDatasetParameter = struct {
    id: []const u8,
    name: []const u8,
    value_type: []const u8,
    default_values: ?DecimalDatasetParameterDefaultValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .value_type = "ValueType",
            .default_values = "DefaultValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalDatasetParameterDefaultValues = struct {
    static_values: ?[]f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const StringDatasetParameter = struct {
    id: []const u8,
    name: []const u8,
    value_type: []const u8,
    default_values: ?StringDatasetParameterDefaultValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .value_type = "ValueType",
            .default_values = "DefaultValues",
        };
        return @field(mappings, field_name);
    }
};

pub const StringDatasetParameterDefaultValues = struct {
    static_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_values = "StaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetUsageConfiguration = struct {
    disable_use_as_direct_query_source: ?bool = null,
    disable_use_as_imported_source: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_use_as_direct_query_source = "DisableUseAsDirectQuerySource",
            .disable_use_as_imported_source = "DisableUseAsImportedSource",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnLevelPermissionRule = struct {
    principals: ?[][]const u8 = null,
    column_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principals = "Principals",
            .column_names = "ColumnNames",
        };
        return @field(mappings, field_name);
    }
};

pub const RowLevelPermissionTagConfiguration = struct {
    status: ?[]const u8 = null,
    tag_rules: []RowLevelPermissionTagRule,
    tag_rule_configurations: ?[][][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .tag_rules = "TagRules",
            .tag_rule_configurations = "TagRuleConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const RowLevelPermissionTagRule = struct {
    tag_key: []const u8,
    column_name: []const u8,
    tag_multi_value_delimiter: ?[]const u8 = null,
    match_all_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .column_name = "ColumnName",
            .tag_multi_value_delimiter = "TagMultiValueDelimiter",
            .match_all_value = "MatchAllValue",
        };
        return @field(mappings, field_name);
    }
};

pub const RowLevelPermissionDataSet = struct {
    namespace: ?[]const u8 = null,
    arn: []const u8,
    permission_policy: []const u8,
    format_version: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .arn = "Arn",
            .permission_policy = "PermissionPolicy",
            .format_version = "FormatVersion",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldFolder = struct {
    description: ?[]const u8 = null,
    columns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .columns = "columns",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnGroup = struct {
    geo_spatial_column_group: ?GeoSpatialColumnGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geo_spatial_column_group = "GeoSpatialColumnGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoSpatialColumnGroup = struct {
    name: []const u8,
    country_code: ?[]const u8 = null,
    columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .country_code = "CountryCode",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const LogicalTable = struct {
    alias: []const u8,
    data_transforms: ?[]TransformOperation = null,
    source: LogicalTableSource,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias = "Alias",
            .data_transforms = "DataTransforms",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const LogicalTableSource = struct {
    join_instruction: ?JoinInstruction = null,
    physical_table_id: ?[]const u8 = null,
    data_set_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .join_instruction = "JoinInstruction",
            .physical_table_id = "PhysicalTableId",
            .data_set_arn = "DataSetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinInstruction = struct {
    left_operand: []const u8,
    right_operand: []const u8,
    left_join_key_properties: ?JoinKeyProperties = null,
    right_join_key_properties: ?JoinKeyProperties = null,
    type: []const u8,
    on_clause: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .left_operand = "LeftOperand",
            .right_operand = "RightOperand",
            .left_join_key_properties = "LeftJoinKeyProperties",
            .right_join_key_properties = "RightJoinKeyProperties",
            .type = "Type",
            .on_clause = "OnClause",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinKeyProperties = struct {
    unique_key: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unique_key = "UniqueKey",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformOperation = union {
    project_operation: ?ProjectOperation,
    filter_operation: ?FilterOperation,
    create_columns_operation: ?CreateColumnsOperation,
    rename_column_operation: ?RenameColumnOperation,
    cast_column_type_operation: ?CastColumnTypeOperation,
    tag_column_operation: ?TagColumnOperation,
    untag_column_operation: ?UntagColumnOperation,
    override_dataset_parameter_operation: ?OverrideDatasetParameterOperation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .project_operation = "ProjectOperation",
            .filter_operation = "FilterOperation",
            .create_columns_operation = "CreateColumnsOperation",
            .rename_column_operation = "RenameColumnOperation",
            .cast_column_type_operation = "CastColumnTypeOperation",
            .tag_column_operation = "TagColumnOperation",
            .untag_column_operation = "UntagColumnOperation",
            .override_dataset_parameter_operation = "OverrideDatasetParameterOperation",
        };
        return @field(mappings, field_name);
    }
};

pub const OverrideDatasetParameterOperation = struct {
    parameter_name: []const u8,
    new_parameter_name: ?[]const u8 = null,
    new_default_values: ?NewDefaultValues = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .new_parameter_name = "NewParameterName",
            .new_default_values = "NewDefaultValues",
        };
        return @field(mappings, field_name);
    }
};

pub const NewDefaultValues = struct {
    string_static_values: ?[][]const u8 = null,
    decimal_static_values: ?[]f64 = null,
    date_time_static_values: ?[]i64 = null,
    integer_static_values: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_static_values = "StringStaticValues",
            .decimal_static_values = "DecimalStaticValues",
            .date_time_static_values = "DateTimeStaticValues",
            .integer_static_values = "IntegerStaticValues",
        };
        return @field(mappings, field_name);
    }
};

pub const UntagColumnOperation = struct {
    column_name: []const u8,
    tag_names: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .tag_names = "TagNames",
        };
        return @field(mappings, field_name);
    }
};

pub const TagColumnOperation = struct {
    column_name: []const u8,
    tags: []ColumnTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnTag = struct {
    column_geographic_role: ?[]const u8 = null,
    column_description: ?ColumnDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_geographic_role = "ColumnGeographicRole",
            .column_description = "ColumnDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnDescription = struct {
    text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
        };
        return @field(mappings, field_name);
    }
};

pub const CastColumnTypeOperation = struct {
    column_name: []const u8,
    new_column_type: []const u8,
    sub_type: ?[]const u8 = null,
    format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .new_column_type = "NewColumnType",
            .sub_type = "SubType",
            .format = "Format",
        };
        return @field(mappings, field_name);
    }
};

pub const RenameColumnOperation = struct {
    column_name: []const u8,
    new_column_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .new_column_name = "NewColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateColumnsOperation = struct {
    columns: []CalculatedColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedColumn = struct {
    column_name: []const u8,
    column_id: []const u8,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_id = "ColumnId",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterOperation = struct {
    condition_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition_expression = "ConditionExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const ProjectOperation = struct {
    projected_columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .projected_columns = "ProjectedColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const PhysicalTable = union {
    relational_table: ?RelationalTable,
    custom_sql: ?CustomSql,
    s3_source: ?S3Source,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relational_table = "RelationalTable",
            .custom_sql = "CustomSql",
            .s3_source = "S3Source",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Source = struct {
    data_source_arn: []const u8,
    upload_settings: ?UploadSettings = null,
    input_columns: []InputColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .upload_settings = "UploadSettings",
            .input_columns = "InputColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const InputColumn = struct {
    name: []const u8,
    type: []const u8,
    sub_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .sub_type = "SubType",
        };
        return @field(mappings, field_name);
    }
};

pub const UploadSettings = struct {
    format: ?[]const u8 = null,
    start_from_row: ?i64 = null,
    contains_header: ?bool = null,
    text_qualifier: ?[]const u8 = null,
    delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .start_from_row = "StartFromRow",
            .contains_header = "ContainsHeader",
            .text_qualifier = "TextQualifier",
            .delimiter = "Delimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomSql = struct {
    data_source_arn: []const u8,
    name: []const u8,
    sql_query: []const u8,
    columns: ?[]InputColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .name = "Name",
            .sql_query = "SqlQuery",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const RelationalTable = struct {
    data_source_arn: []const u8,
    catalog: ?[]const u8 = null,
    schema: ?[]const u8 = null,
    name: []const u8,
    input_columns: []InputColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .catalog = "Catalog",
            .schema = "Schema",
            .name = "Name",
            .input_columns = "InputColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkSharingConfiguration = struct {
    permissions: ?[]ResourcePermission = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardVersionDefinition = struct {
    data_set_identifier_declarations: []DataSetIdentifierDeclaration,
    sheets: ?[]SheetDefinition = null,
    calculated_fields: ?[]CalculatedField = null,
    parameter_declarations: ?[]ParameterDeclaration = null,
    filter_groups: ?[]FilterGroup = null,
    column_configurations: ?[]ColumnConfiguration = null,
    analysis_defaults: ?AnalysisDefaults = null,
    options: ?AssetOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier_declarations = "DataSetIdentifierDeclarations",
            .sheets = "Sheets",
            .calculated_fields = "CalculatedFields",
            .parameter_declarations = "ParameterDeclarations",
            .filter_groups = "FilterGroups",
            .column_configurations = "ColumnConfigurations",
            .analysis_defaults = "AnalysisDefaults",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetIdentifierDeclaration = struct {
    identifier: []const u8,
    data_set_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .data_set_arn = "DataSetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardPublishOptions = struct {
    ad_hoc_filtering_option: ?AdHocFilteringOption = null,
    export_to_csv_option: ?ExportToCSVOption = null,
    sheet_controls_option: ?SheetControlsOption = null,
    visual_publish_options: ?DashboardVisualPublishOptions = null,
    sheet_layout_element_maximization_option: ?SheetLayoutElementMaximizationOption = null,
    visual_menu_option: ?VisualMenuOption = null,
    visual_axis_sort_option: ?VisualAxisSortOption = null,
    export_with_hidden_fields_option: ?ExportWithHiddenFieldsOption = null,
    data_point_drill_up_down_option: ?DataPointDrillUpDownOption = null,
    data_point_menu_label_option: ?DataPointMenuLabelOption = null,
    data_point_tooltip_option: ?DataPointTooltipOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_hoc_filtering_option = "AdHocFilteringOption",
            .export_to_csv_option = "ExportToCSVOption",
            .sheet_controls_option = "SheetControlsOption",
            .visual_publish_options = "VisualPublishOptions",
            .sheet_layout_element_maximization_option = "SheetLayoutElementMaximizationOption",
            .visual_menu_option = "VisualMenuOption",
            .visual_axis_sort_option = "VisualAxisSortOption",
            .export_with_hidden_fields_option = "ExportWithHiddenFieldsOption",
            .data_point_drill_up_down_option = "DataPointDrillUpDownOption",
            .data_point_menu_label_option = "DataPointMenuLabelOption",
            .data_point_tooltip_option = "DataPointTooltipOption",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPointTooltipOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPointMenuLabelOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPointDrillUpDownOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportWithHiddenFieldsOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const VisualAxisSortOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetLayoutElementMaximizationOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardVisualPublishOptions = struct {
    export_hidden_fields_option: ?ExportHiddenFieldsOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .export_hidden_fields_option = "ExportHiddenFieldsOption",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportHiddenFieldsOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetControlsOption = struct {
    visibility_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility_state = "VisibilityState",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportToCSVOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AdHocFilteringOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameters = struct {
    string_parameters: ?[]StringParameter = null,
    integer_parameters: ?[]IntegerParameter = null,
    decimal_parameters: ?[]DecimalParameter = null,
    date_time_parameters: ?[]DateTimeParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_parameters = "StringParameters",
            .integer_parameters = "IntegerParameters",
            .decimal_parameters = "DecimalParameters",
            .date_time_parameters = "DateTimeParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeParameter = struct {
    name: []const u8,
    values: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalParameter = struct {
    name: []const u8,
    values: []f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameter = struct {
    name: []const u8,
    values: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const StringParameter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSourceEntity = struct {
    source_template: ?DashboardSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSourceTemplate = struct {
    data_set_references: []DataSetReference,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_references = "DataSetReferences",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisDefinition = struct {
    data_set_identifier_declarations: []DataSetIdentifierDeclaration,
    sheets: ?[]SheetDefinition = null,
    calculated_fields: ?[]CalculatedField = null,
    parameter_declarations: ?[]ParameterDeclaration = null,
    filter_groups: ?[]FilterGroup = null,
    column_configurations: ?[]ColumnConfiguration = null,
    analysis_defaults: ?AnalysisDefaults = null,
    options: ?AssetOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_identifier_declarations = "DataSetIdentifierDeclarations",
            .sheets = "Sheets",
            .calculated_fields = "CalculatedFields",
            .parameter_declarations = "ParameterDeclarations",
            .filter_groups = "FilterGroups",
            .column_configurations = "ColumnConfigurations",
            .analysis_defaults = "AnalysisDefaults",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSourceEntity = struct {
    source_template: ?AnalysisSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSourceTemplate = struct {
    data_set_references: []DataSetReference,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_references = "DataSetReferences",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountCustomization = struct {
    default_theme: ?[]const u8 = null,
    default_email_customization_template: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_theme = "DefaultTheme",
            .default_email_customization_template = "DefaultEmailCustomizationTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotConfiguration = struct {
    file_groups: []SnapshotFileGroup,
    destination_configuration: ?SnapshotDestinationConfiguration = null,
    parameters: ?Parameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_groups = "FileGroups",
            .destination_configuration = "DestinationConfiguration",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotDestinationConfiguration = struct {
    s3_destinations: ?[]SnapshotS3DestinationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_destinations = "S3Destinations",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotS3DestinationConfiguration = struct {
    bucket_configuration: S3BucketConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_configuration = "BucketConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketConfiguration = struct {
    bucket_name: []const u8,
    bucket_prefix: []const u8,
    bucket_region: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .bucket_prefix = "BucketPrefix",
            .bucket_region = "BucketRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotFileGroup = struct {
    files: ?[]SnapshotFile = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .files = "Files",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotFile = struct {
    sheet_selections: []SnapshotFileSheetSelection,
    format_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_selections = "SheetSelections",
            .format_type = "FormatType",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotFileSheetSelection = struct {
    sheet_id: []const u8,
    selection_scope: []const u8,
    visual_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_id = "SheetId",
            .selection_scope = "SelectionScope",
            .visual_ids = "VisualIds",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionTag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobOverrideValidationStrategy = struct {
    strict_mode_for_all_resources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strict_mode_for_all_resources = "StrictModeForAllResources",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobOverrideTags = struct {
    vpc_connections: ?[]AssetBundleImportJobVPCConnectionOverrideTags = null,
    data_sources: ?[]AssetBundleImportJobDataSourceOverrideTags = null,
    data_sets: ?[]AssetBundleImportJobDataSetOverrideTags = null,
    themes: ?[]AssetBundleImportJobThemeOverrideTags = null,
    analyses: ?[]AssetBundleImportJobAnalysisOverrideTags = null,
    dashboards: ?[]AssetBundleImportJobDashboardOverrideTags = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connections = "VPCConnections",
            .data_sources = "DataSources",
            .data_sets = "DataSets",
            .themes = "Themes",
            .analyses = "Analyses",
            .dashboards = "Dashboards",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDashboardOverrideTags = struct {
    dashboard_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dashboard_ids = "DashboardIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobAnalysisOverrideTags = struct {
    analysis_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analysis_ids = "AnalysisIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobThemeOverrideTags = struct {
    theme_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .theme_ids = "ThemeIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSetOverrideTags = struct {
    data_set_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_ids = "DataSetIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSourceOverrideTags = struct {
    data_source_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_ids = "DataSourceIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobVPCConnectionOverrideTags = struct {
    vpc_connection_ids: [][]const u8,
    tags: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connection_ids = "VPCConnectionIds",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobOverridePermissions = struct {
    data_sources: ?[]AssetBundleImportJobDataSourceOverridePermissions = null,
    data_sets: ?[]AssetBundleImportJobDataSetOverridePermissions = null,
    themes: ?[]AssetBundleImportJobThemeOverridePermissions = null,
    analyses: ?[]AssetBundleImportJobAnalysisOverridePermissions = null,
    dashboards: ?[]AssetBundleImportJobDashboardOverridePermissions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_sources = "DataSources",
            .data_sets = "DataSets",
            .themes = "Themes",
            .analyses = "Analyses",
            .dashboards = "Dashboards",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDashboardOverridePermissions = struct {
    dashboard_ids: [][]const u8,
    permissions: ?AssetBundleResourcePermissions = null,
    link_sharing_configuration: ?AssetBundleResourceLinkSharingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dashboard_ids = "DashboardIds",
            .permissions = "Permissions",
            .link_sharing_configuration = "LinkSharingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleResourceLinkSharingConfiguration = struct {
    permissions: ?AssetBundleResourcePermissions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleResourcePermissions = struct {
    principals: [][]const u8,
    actions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principals = "Principals",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobAnalysisOverridePermissions = struct {
    analysis_ids: [][]const u8,
    permissions: AssetBundleResourcePermissions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analysis_ids = "AnalysisIds",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobThemeOverridePermissions = struct {
    theme_ids: [][]const u8,
    permissions: AssetBundleResourcePermissions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .theme_ids = "ThemeIds",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSetOverridePermissions = struct {
    data_set_ids: [][]const u8,
    permissions: AssetBundleResourcePermissions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_ids = "DataSetIds",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSourceOverridePermissions = struct {
    data_source_ids: [][]const u8,
    permissions: AssetBundleResourcePermissions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_ids = "DataSourceIds",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobOverrideParameters = struct {
    resource_id_override_configuration: ?AssetBundleImportJobResourceIdOverrideConfiguration = null,
    vpc_connections: ?[]AssetBundleImportJobVPCConnectionOverrideParameters = null,
    refresh_schedules: ?[]AssetBundleImportJobRefreshScheduleOverrideParameters = null,
    data_sources: ?[]AssetBundleImportJobDataSourceOverrideParameters = null,
    data_sets: ?[]AssetBundleImportJobDataSetOverrideParameters = null,
    themes: ?[]AssetBundleImportJobThemeOverrideParameters = null,
    analyses: ?[]AssetBundleImportJobAnalysisOverrideParameters = null,
    dashboards: ?[]AssetBundleImportJobDashboardOverrideParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id_override_configuration = "ResourceIdOverrideConfiguration",
            .vpc_connections = "VPCConnections",
            .refresh_schedules = "RefreshSchedules",
            .data_sources = "DataSources",
            .data_sets = "DataSets",
            .themes = "Themes",
            .analyses = "Analyses",
            .dashboards = "Dashboards",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDashboardOverrideParameters = struct {
    dashboard_id: []const u8,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dashboard_id = "DashboardId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobAnalysisOverrideParameters = struct {
    analysis_id: []const u8,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analysis_id = "AnalysisId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobThemeOverrideParameters = struct {
    theme_id: []const u8,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .theme_id = "ThemeId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSetOverrideParameters = struct {
    data_set_id: []const u8,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_id = "DataSetId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSourceOverrideParameters = struct {
    data_source_id: []const u8,
    name: ?[]const u8 = null,
    data_source_parameters: ?DataSourceParameters = null,
    vpc_connection_properties: ?VpcConnectionProperties = null,
    ssl_properties: ?SslProperties = null,
    credentials: ?AssetBundleImportJobDataSourceCredentials = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_id = "DataSourceId",
            .name = "Name",
            .data_source_parameters = "DataSourceParameters",
            .vpc_connection_properties = "VpcConnectionProperties",
            .ssl_properties = "SslProperties",
            .credentials = "Credentials",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSourceCredentials = struct {
    credential_pair: ?AssetBundleImportJobDataSourceCredentialPair = null,
    secret_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credential_pair = "CredentialPair",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobDataSourceCredentialPair = struct {
    username: []const u8,
    password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobRefreshScheduleOverrideParameters = struct {
    data_set_id: []const u8,
    schedule_id: []const u8,
    start_after_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_id = "DataSetId",
            .schedule_id = "ScheduleId",
            .start_after_date_time = "StartAfterDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobVPCConnectionOverrideParameters = struct {
    vpc_connection_id: []const u8,
    name: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    dns_resolvers: ?[][]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connection_id = "VPCConnectionId",
            .name = "Name",
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
            .dns_resolvers = "DnsResolvers",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobResourceIdOverrideConfiguration = struct {
    prefix_for_all_resources: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_for_all_resources = "PrefixForAllResources",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobValidationStrategy = struct {
    strict_mode_for_all_resources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strict_mode_for_all_resources = "StrictModeForAllResources",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleCloudFormationOverridePropertyConfiguration = struct {
    resource_id_override_configuration: ?AssetBundleExportJobResourceIdOverrideConfiguration = null,
    vpc_connections: ?[]AssetBundleExportJobVPCConnectionOverrideProperties = null,
    refresh_schedules: ?[]AssetBundleExportJobRefreshScheduleOverrideProperties = null,
    data_sources: ?[]AssetBundleExportJobDataSourceOverrideProperties = null,
    data_sets: ?[]AssetBundleExportJobDataSetOverrideProperties = null,
    themes: ?[]AssetBundleExportJobThemeOverrideProperties = null,
    analyses: ?[]AssetBundleExportJobAnalysisOverrideProperties = null,
    dashboards: ?[]AssetBundleExportJobDashboardOverrideProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id_override_configuration = "ResourceIdOverrideConfiguration",
            .vpc_connections = "VPCConnections",
            .refresh_schedules = "RefreshSchedules",
            .data_sources = "DataSources",
            .data_sets = "DataSets",
            .themes = "Themes",
            .analyses = "Analyses",
            .dashboards = "Dashboards",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobDashboardOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobAnalysisOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobThemeOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobDataSetOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobDataSourceOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobRefreshScheduleOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobVPCConnectionOverrideProperties = struct {
    arn: []const u8,
    properties: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleExportJobResourceIdOverrideConfiguration = struct {
    prefix_for_all_resources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_for_all_resources = "PrefixForAllResources",
        };
        return @field(mappings, field_name);
    }
};

pub const FolderSummary = struct {
    arn: ?[]const u8 = null,
    folder_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    folder_type: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    sharing_model: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .folder_id = "FolderId",
            .name = "Name",
            .folder_type = "FolderType",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .sharing_model = "SharingModel",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetSummary = struct {
    arn: ?[]const u8 = null,
    data_set_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    import_mode: ?[]const u8 = null,
    row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
    row_level_permission_tag_configuration_applied: ?bool = null,
    column_level_permission_rules_applied: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .data_set_id = "DataSetId",
            .name = "Name",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .import_mode = "ImportMode",
            .row_level_permission_data_set = "RowLevelPermissionDataSet",
            .row_level_permission_tag_configuration_applied = "RowLevelPermissionTagConfigurationApplied",
            .column_level_permission_rules_applied = "ColumnLevelPermissionRulesApplied",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSummary = struct {
    arn: ?[]const u8 = null,
    dashboard_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    published_version_number: ?i64 = null,
    last_published_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .dashboard_id = "DashboardId",
            .name = "Name",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .published_version_number = "PublishedVersionNumber",
            .last_published_time = "LastPublishedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSummary = struct {
    arn: ?[]const u8 = null,
    analysis_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .analysis_id = "AnalysisId",
            .name = "Name",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetRefreshProperties = struct {
    refresh_configuration: RefreshConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .refresh_configuration = "RefreshConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshConfiguration = struct {
    incremental_refresh: IncrementalRefresh,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .incremental_refresh = "IncrementalRefresh",
        };
        return @field(mappings, field_name);
    }
};

pub const IncrementalRefresh = struct {
    lookback_window: LookbackWindow,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lookback_window = "LookbackWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const LookbackWindow = struct {
    column_name: []const u8,
    size: i64,
    size_unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .size = "Size",
            .size_unit = "SizeUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    subnet_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    status: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .availability_zone = "AvailabilityZone",
            .error_message = "ErrorMessage",
            .status = "Status",
            .network_interface_id = "NetworkInterfaceId",
        };
        return @field(mappings, field_name);
    }
};

pub const NamespaceInfoV2 = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    capacity_region: ?[]const u8 = null,
    creation_status: ?[]const u8 = null,
    identity_store: ?[]const u8 = null,
    namespace_error: ?NamespaceError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .capacity_region = "CapacityRegion",
            .creation_status = "CreationStatus",
            .identity_store = "IdentityStore",
            .namespace_error = "NamespaceError",
        };
        return @field(mappings, field_name);
    }
};

pub const NamespaceError = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Ingestion = struct {
    arn: []const u8,
    ingestion_id: ?[]const u8 = null,
    ingestion_status: []const u8,
    error_info: ?ErrorInfo = null,
    row_info: ?RowInfo = null,
    queue_info: ?QueueInfo = null,
    created_time: i64,
    ingestion_time_in_seconds: ?i64 = null,
    ingestion_size_in_bytes: ?i64 = null,
    request_source: ?[]const u8 = null,
    request_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .ingestion_id = "IngestionId",
            .ingestion_status = "IngestionStatus",
            .error_info = "ErrorInfo",
            .row_info = "RowInfo",
            .queue_info = "QueueInfo",
            .created_time = "CreatedTime",
            .ingestion_time_in_seconds = "IngestionTimeInSeconds",
            .ingestion_size_in_bytes = "IngestionSizeInBytes",
            .request_source = "RequestSource",
            .request_type = "RequestType",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueInfo = struct {
    waiting_on_ingestion: []const u8,
    queued_ingestion: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waiting_on_ingestion = "WaitingOnIngestion",
            .queued_ingestion = "QueuedIngestion",
        };
        return @field(mappings, field_name);
    }
};

pub const RowInfo = struct {
    rows_ingested: ?i64 = null,
    rows_dropped: ?i64 = null,
    total_rows_in_dataset: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rows_ingested = "RowsIngested",
            .rows_dropped = "RowsDropped",
            .total_rows_in_dataset = "TotalRowsInDataset",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorInfo = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupMember = struct {
    arn: ?[]const u8 = null,
    member_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .member_name = "MemberName",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    arn: ?[]const u8 = null,
    data_source_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    data_source_parameters: ?DataSourceParameters = null,
    alternate_data_source_parameters: ?[]DataSourceParameters = null,
    vpc_connection_properties: ?VpcConnectionProperties = null,
    ssl_properties: ?SslProperties = null,
    error_info: ?DataSourceErrorInfo = null,
    secret_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .data_source_id = "DataSourceId",
            .name = "Name",
            .type = "Type",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .data_source_parameters = "DataSourceParameters",
            .alternate_data_source_parameters = "AlternateDataSourceParameters",
            .vpc_connection_properties = "VpcConnectionProperties",
            .ssl_properties = "SslProperties",
            .error_info = "ErrorInfo",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceErrorInfo = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardVisualId = struct {
    dashboard_id: []const u8,
    sheet_id: []const u8,
    visual_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dashboard_id = "DashboardId",
            .sheet_id = "SheetId",
            .visual_id = "VisualId",
        };
        return @field(mappings, field_name);
    }
};

pub const StatePersistenceConfigurations = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateError = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,
    violated_entities: ?[]Entity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
            .violated_entities = "ViolatedEntities",
        };
        return @field(mappings, field_name);
    }
};

pub const Entity = struct {
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const Sheet = struct {
    sheet_id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_id = "SheetId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardError = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,
    violated_entities: ?[]Entity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
            .violated_entities = "ViolatedEntities",
        };
        return @field(mappings, field_name);
    }
};

pub const AssetBundleImportJobError = struct {
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisError = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,
    violated_entities: ?[]Entity = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
            .violated_entities = "ViolatedEntities",
        };
        return @field(mappings, field_name);
    }
};
