const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-12-01";
pub const sdk_id: []const u8 = "Redshift";
pub const arn_namespace: ?[]const u8 = "redshift";
pub const endpoint_prefix: []const u8 = "redshift";
pub const sigv4_name: []const u8 = "redshift";
pub const name: []const u8 = "RedshiftServiceVersion20121201";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2012-12-01",
    sdk_id: []const u8 = "Redshift",
    arn_namespace: ?[]const u8 = "redshift",
    endpoint_prefix: []const u8 = "redshift",
    sigv4_name: []const u8 = "redshift",
    name: []const u8 = "RedshiftServiceVersion20121201",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const accept_reserved_node_exchange: struct {
    action_name: []const u8 = "AcceptReservedNodeExchange",
    Request: type = struct {
        reserved_node_id: []const u8,
        target_reserved_node_offering_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_id = "ReservedNodeId",
                .target_reserved_node_offering_id = "TargetReservedNodeOfferingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_reserved_node_exchange) } {
            return .{ .service_metadata = service_metadata, .action = accept_reserved_node_exchange };
        }
    },
    Response: type = struct {
        exchanged_reserved_node: ?ReservedNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exchanged_reserved_node = "ExchangedReservedNode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceUnavailable,
        InvalidReservedNodeState,
        ReservedNodeAlreadyExists,
        ReservedNodeAlreadyMigrated,
        ReservedNodeNotFound,
        ReservedNodeOfferingNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const add_partner: struct {
    action_name: []const u8 = "AddPartner",
    Request: type = struct {
        account_id: []const u8,
        cluster_identifier: []const u8,
        database_name: []const u8,
        partner_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .cluster_identifier = "ClusterIdentifier",
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_partner) } {
            return .{ .service_metadata = service_metadata, .action = add_partner };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        partner_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        PartnerNotFound,
        UnauthorizedPartnerIntegration,
        UnsupportedOperation,
    },
} = .{};
pub const associate_data_share_consumer: struct {
    action_name: []const u8 = "AssociateDataShareConsumer",
    Request: type = struct {
        data_share_arn: []const u8,
        associate_entire_account: ?bool = null,
        consumer_arn: ?[]const u8 = null,
        consumer_region: ?[]const u8 = null,
        allow_writes: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .associate_entire_account = "AssociateEntireAccount",
                .consumer_arn = "ConsumerArn",
                .consumer_region = "ConsumerRegion",
                .allow_writes = "AllowWrites",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_data_share_consumer) } {
            return .{ .service_metadata = service_metadata, .action = associate_data_share_consumer };
        }
    },
    Response: type = struct {
        data_share_arn: ?[]const u8 = null,
        producer_arn: ?[]const u8 = null,
        allow_publicly_accessible_consumers: ?bool = null,
        data_share_associations: ?[]DataShareAssociation = null,
        managed_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .producer_arn = "ProducerArn",
                .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
                .data_share_associations = "DataShareAssociations",
                .managed_by = "ManagedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
        InvalidNamespace,
    },
} = .{};
pub const authorize_cluster_security_group_ingress: struct {
    action_name: []const u8 = "AuthorizeClusterSecurityGroupIngress",
    Request: type = struct {
        cluster_security_group_name: []const u8,
        cidrip: ?[]const u8 = null,
        ec2_security_group_name: ?[]const u8 = null,
        ec2_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group_name = "ClusterSecurityGroupName",
                .cidrip = "CIDRIP",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_cluster_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = authorize_cluster_security_group_ingress };
        }
    },
    Response: type = struct {
        cluster_security_group: ?ClusterSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group = "ClusterSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationAlreadyExists,
        AuthorizationQuotaExceeded,
        ClusterSecurityGroupNotFound,
        InvalidClusterSecurityGroupState,
    },
} = .{};
pub const authorize_data_share: struct {
    action_name: []const u8 = "AuthorizeDataShare",
    Request: type = struct {
        data_share_arn: []const u8,
        consumer_identifier: []const u8,
        allow_writes: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .consumer_identifier = "ConsumerIdentifier",
                .allow_writes = "AllowWrites",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_data_share) } {
            return .{ .service_metadata = service_metadata, .action = authorize_data_share };
        }
    },
    Response: type = struct {
        data_share_arn: ?[]const u8 = null,
        producer_arn: ?[]const u8 = null,
        allow_publicly_accessible_consumers: ?bool = null,
        data_share_associations: ?[]DataShareAssociation = null,
        managed_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .producer_arn = "ProducerArn",
                .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
                .data_share_associations = "DataShareAssociations",
                .managed_by = "ManagedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
    },
} = .{};
pub const authorize_endpoint_access: struct {
    action_name: []const u8 = "AuthorizeEndpointAccess",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        account: []const u8,
        vpc_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .account = "Account",
                .vpc_ids = "VpcIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = authorize_endpoint_access };
        }
    },
    Response: type = struct {
        grantor: ?[]const u8 = null,
        grantee: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        authorize_time: ?i64 = null,
        cluster_status: ?[]const u8 = null,
        status: ?[]const u8 = null,
        allowed_all_vp_cs: ?bool = null,
        allowed_vp_cs: ?[][]const u8 = null,
        endpoint_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grantor = "Grantor",
                .grantee = "Grantee",
                .cluster_identifier = "ClusterIdentifier",
                .authorize_time = "AuthorizeTime",
                .cluster_status = "ClusterStatus",
                .status = "Status",
                .allowed_all_vp_cs = "AllowedAllVPCs",
                .allowed_vp_cs = "AllowedVPCs",
                .endpoint_count = "EndpointCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        EndpointAuthorizationAlreadyExists,
        EndpointAuthorizationsPerClusterLimitExceeded,
        InvalidAuthorizationState,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const authorize_snapshot_access: struct {
    action_name: []const u8 = "AuthorizeSnapshotAccess",
    Request: type = struct {
        snapshot_identifier: ?[]const u8 = null,
        snapshot_arn: ?[]const u8 = null,
        snapshot_cluster_identifier: ?[]const u8 = null,
        account_with_restore_access: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_arn = "SnapshotArn",
                .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
                .account_with_restore_access = "AccountWithRestoreAccess",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_snapshot_access) } {
            return .{ .service_metadata = service_metadata, .action = authorize_snapshot_access };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationAlreadyExists,
        AuthorizationQuotaExceeded,
        ClusterSnapshotNotFound,
        DependentServiceRequestThrottling,
        InvalidClusterSnapshotState,
        LimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const batch_delete_cluster_snapshots: struct {
    action_name: []const u8 = "BatchDeleteClusterSnapshots",
    Request: type = struct {
        identifiers: []DeleteClusterSnapshotMessage,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifiers = "Identifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_cluster_snapshots };
        }
    },
    Response: type = struct {
        resources: ?[][]const u8 = null,
        errors: ?[]SnapshotErrorMessage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BatchDeleteRequestSizeExceeded,
    },
} = .{};
pub const batch_modify_cluster_snapshots: struct {
    action_name: []const u8 = "BatchModifyClusterSnapshots",
    Request: type = struct {
        snapshot_identifier_list: [][]const u8,
        manual_snapshot_retention_period: ?i64 = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier_list = "SnapshotIdentifierList",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_modify_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = batch_modify_cluster_snapshots };
        }
    },
    Response: type = struct {
        resources: ?[][]const u8 = null,
        errors: ?[]SnapshotErrorMessage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BatchModifyClusterSnapshotsLimitExceeded,
        InvalidRetentionPeriod,
    },
} = .{};
pub const cancel_resize: struct {
    action_name: []const u8 = "CancelResize",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_resize) } {
            return .{ .service_metadata = service_metadata, .action = cancel_resize };
        }
    },
    Response: type = struct {
        target_node_type: ?[]const u8 = null,
        target_number_of_nodes: ?i64 = null,
        target_cluster_type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        import_tables_completed: ?[][]const u8 = null,
        import_tables_in_progress: ?[][]const u8 = null,
        import_tables_not_started: ?[][]const u8 = null,
        avg_resize_rate_in_mega_bytes_per_second: ?f64 = null,
        total_resize_data_in_mega_bytes: ?i64 = null,
        progress_in_mega_bytes: ?i64 = null,
        elapsed_time_in_seconds: ?i64 = null,
        estimated_time_to_completion_in_seconds: ?i64 = null,
        resize_type: ?[]const u8 = null,
        message: ?[]const u8 = null,
        target_encryption_type: ?[]const u8 = null,
        data_transfer_progress_percent: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_node_type = "TargetNodeType",
                .target_number_of_nodes = "TargetNumberOfNodes",
                .target_cluster_type = "TargetClusterType",
                .status = "Status",
                .import_tables_completed = "ImportTablesCompleted",
                .import_tables_in_progress = "ImportTablesInProgress",
                .import_tables_not_started = "ImportTablesNotStarted",
                .avg_resize_rate_in_mega_bytes_per_second = "AvgResizeRateInMegaBytesPerSecond",
                .total_resize_data_in_mega_bytes = "TotalResizeDataInMegaBytes",
                .progress_in_mega_bytes = "ProgressInMegaBytes",
                .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
                .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
                .resize_type = "ResizeType",
                .message = "Message",
                .target_encryption_type = "TargetEncryptionType",
                .data_transfer_progress_percent = "DataTransferProgressPercent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        ResizeNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const copy_cluster_snapshot: struct {
    action_name: []const u8 = "CopyClusterSnapshot",
    Request: type = struct {
        source_snapshot_identifier: []const u8,
        source_snapshot_cluster_identifier: ?[]const u8 = null,
        target_snapshot_identifier: []const u8,
        manual_snapshot_retention_period: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_snapshot_identifier = "SourceSnapshotIdentifier",
                .source_snapshot_cluster_identifier = "SourceSnapshotClusterIdentifier",
                .target_snapshot_identifier = "TargetSnapshotIdentifier",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotAlreadyExists,
        ClusterSnapshotNotFound,
        ClusterSnapshotQuotaExceeded,
        InvalidClusterSnapshotState,
        InvalidRetentionPeriod,
    },
} = .{};
pub const create_authentication_profile: struct {
    action_name: []const u8 = "CreateAuthenticationProfile",
    Request: type = struct {
        authentication_profile_name: []const u8,
        authentication_profile_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
                .authentication_profile_content = "AuthenticationProfileContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_authentication_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_authentication_profile };
        }
    },
    Response: type = struct {
        authentication_profile_name: ?[]const u8 = null,
        authentication_profile_content: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
                .authentication_profile_content = "AuthenticationProfileContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationProfileAlreadyExists,
        AuthenticationProfileQuotaExceeded,
        InvalidAuthenticationProfileRequest,
    },
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        db_name: ?[]const u8 = null,
        cluster_identifier: []const u8,
        cluster_type: ?[]const u8 = null,
        node_type: []const u8,
        master_username: []const u8,
        master_user_password: ?[]const u8 = null,
        cluster_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        cluster_subnet_group_name: ?[]const u8 = null,
        availability_zone: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        cluster_parameter_group_name: ?[]const u8 = null,
        automated_snapshot_retention_period: ?i64 = null,
        manual_snapshot_retention_period: ?i64 = null,
        port: ?i64 = null,
        cluster_version: ?[]const u8 = null,
        allow_version_upgrade: ?bool = null,
        number_of_nodes: ?i64 = null,
        publicly_accessible: ?bool = null,
        encrypted: ?bool = null,
        hsm_client_certificate_identifier: ?[]const u8 = null,
        hsm_configuration_identifier: ?[]const u8 = null,
        elastic_ip: ?[]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        enhanced_vpc_routing: ?bool = null,
        additional_info: ?[]const u8 = null,
        iam_roles: ?[][]const u8 = null,
        maintenance_track_name: ?[]const u8 = null,
        snapshot_schedule_identifier: ?[]const u8 = null,
        availability_zone_relocation: ?bool = null,
        aqua_configuration_status: ?[]const u8 = null,
        default_iam_role_arn: ?[]const u8 = null,
        load_sample_data: ?[]const u8 = null,
        manage_master_password: ?bool = null,
        master_password_secret_kms_key_id: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        multi_az: ?bool = null,
        redshift_idc_application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_name = "DBName",
                .cluster_identifier = "ClusterIdentifier",
                .cluster_type = "ClusterType",
                .node_type = "NodeType",
                .master_username = "MasterUsername",
                .master_user_password = "MasterUserPassword",
                .cluster_security_groups = "ClusterSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
                .availability_zone = "AvailabilityZone",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .cluster_parameter_group_name = "ClusterParameterGroupName",
                .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .port = "Port",
                .cluster_version = "ClusterVersion",
                .allow_version_upgrade = "AllowVersionUpgrade",
                .number_of_nodes = "NumberOfNodes",
                .publicly_accessible = "PubliclyAccessible",
                .encrypted = "Encrypted",
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
                .elastic_ip = "ElasticIp",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .enhanced_vpc_routing = "EnhancedVpcRouting",
                .additional_info = "AdditionalInfo",
                .iam_roles = "IamRoles",
                .maintenance_track_name = "MaintenanceTrackName",
                .snapshot_schedule_identifier = "SnapshotScheduleIdentifier",
                .availability_zone_relocation = "AvailabilityZoneRelocation",
                .aqua_configuration_status = "AquaConfigurationStatus",
                .default_iam_role_arn = "DefaultIamRoleArn",
                .load_sample_data = "LoadSampleData",
                .manage_master_password = "ManageMasterPassword",
                .master_password_secret_kms_key_id = "MasterPasswordSecretKmsKeyId",
                .ip_address_type = "IpAddressType",
                .multi_az = "MultiAZ",
                .redshift_idc_application_arn = "RedshiftIdcApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterAlreadyExists,
        ClusterParameterGroupNotFound,
        ClusterQuotaExceeded,
        ClusterSecurityGroupNotFound,
        ClusterSubnetGroupNotFound,
        DependentServiceRequestThrottling,
        HsmClientCertificateNotFound,
        HsmConfigurationNotFound,
        InsufficientClusterCapacity,
        InvalidClusterSubnetGroupState,
        InvalidClusterTrack,
        InvalidElasticIp,
        InvalidRetentionPeriod,
        InvalidSubnet,
        InvalidTag,
        InvalidVPCNetworkState,
        Ipv6CidrBlockNotFound,
        LimitExceeded,
        NumberOfNodesPerClusterLimitExceeded,
        NumberOfNodesQuotaExceeded,
        RedshiftIdcApplicationNotExists,
        SnapshotScheduleNotFound,
        TagLimitExceeded,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const create_cluster_parameter_group: struct {
    action_name: []const u8 = "CreateClusterParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        parameter_group_family: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameter_group_family = "ParameterGroupFamily",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster_parameter_group };
        }
    },
    Response: type = struct {
        cluster_parameter_group: ?ClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_parameter_group = "ClusterParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterParameterGroupAlreadyExists,
        ClusterParameterGroupQuotaExceeded,
        InvalidTag,
        TagLimitExceeded,
    },
} = .{};
pub const create_cluster_security_group: struct {
    action_name: []const u8 = "CreateClusterSecurityGroup",
    Request: type = struct {
        cluster_security_group_name: []const u8,
        description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group_name = "ClusterSecurityGroupName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster_security_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster_security_group };
        }
    },
    Response: type = struct {
        cluster_security_group: ?ClusterSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group = "ClusterSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSecurityGroupAlreadyExists,
        ClusterSecurityGroupQuotaExceeded,
        InvalidTag,
        TagLimitExceeded,
    },
} = .{};
pub const create_cluster_snapshot: struct {
    action_name: []const u8 = "CreateClusterSnapshot",
    Request: type = struct {
        snapshot_identifier: []const u8,
        cluster_identifier: []const u8,
        manual_snapshot_retention_period: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier = "SnapshotIdentifier",
                .cluster_identifier = "ClusterIdentifier",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotAlreadyExists,
        ClusterSnapshotQuotaExceeded,
        InvalidClusterState,
        InvalidRetentionPeriod,
        InvalidTag,
        TagLimitExceeded,
    },
} = .{};
pub const create_cluster_subnet_group: struct {
    action_name: []const u8 = "CreateClusterSubnetGroup",
    Request: type = struct {
        cluster_subnet_group_name: []const u8,
        description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster_subnet_group };
        }
    },
    Response: type = struct {
        cluster_subnet_group: ?ClusterSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group = "ClusterSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSubnetGroupAlreadyExists,
        ClusterSubnetGroupQuotaExceeded,
        ClusterSubnetQuotaExceeded,
        DependentServiceRequestThrottling,
        InvalidSubnet,
        InvalidTag,
        TagLimitExceeded,
        UnauthorizedOperation,
    },
} = .{};
pub const create_custom_domain_association: struct {
    action_name: []const u8 = "CreateCustomDomainAssociation",
    Request: type = struct {
        custom_domain_name: []const u8,
        custom_domain_certificate_arn: []const u8,
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "CustomDomainName",
                .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_domain_association };
        }
    },
    Response: type = struct {
        custom_domain_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        custom_domain_cert_expiry_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "CustomDomainName",
                .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                .cluster_identifier = "ClusterIdentifier",
                .custom_domain_cert_expiry_time = "CustomDomainCertExpiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        CustomCnameAssociation,
        UnsupportedOperation,
    },
} = .{};
pub const create_endpoint_access: struct {
    action_name: []const u8 = "CreateEndpointAccess",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        resource_owner: ?[]const u8 = null,
        endpoint_name: []const u8,
        subnet_group_name: []const u8,
        vpc_security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .resource_owner = "ResourceOwner",
                .endpoint_name = "EndpointName",
                .subnet_group_name = "SubnetGroupName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint_access };
        }
    },
    Response: type = struct {
        cluster_identifier: ?[]const u8 = null,
        resource_owner: ?[]const u8 = null,
        subnet_group_name: ?[]const u8 = null,
        endpoint_status: ?[]const u8 = null,
        endpoint_name: ?[]const u8 = null,
        endpoint_create_time: ?i64 = null,
        port: ?i64 = null,
        address: ?[]const u8 = null,
        vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
        vpc_endpoint: ?VpcEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .resource_owner = "ResourceOwner",
                .subnet_group_name = "SubnetGroupName",
                .endpoint_status = "EndpointStatus",
                .endpoint_name = "EndpointName",
                .endpoint_create_time = "EndpointCreateTime",
                .port = "Port",
                .address = "Address",
                .vpc_security_groups = "VpcSecurityGroups",
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessToClusterDenied,
        ClusterNotFound,
        ClusterSubnetGroupNotFound,
        EndpointAlreadyExists,
        EndpointsPerAuthorizationLimitExceeded,
        EndpointsPerClusterLimitExceeded,
        InvalidClusterSecurityGroupState,
        InvalidClusterState,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const create_event_subscription: struct {
    action_name: []const u8 = "CreateEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: []const u8,
        source_type: ?[]const u8 = null,
        source_ids: ?[][]const u8 = null,
        event_categories: ?[][]const u8 = null,
        severity: ?[]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .source_ids = "SourceIds",
                .event_categories = "EventCategories",
                .severity = "Severity",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EventSubscriptionQuotaExceeded,
        InvalidTag,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SourceNotFound,
        SubscriptionAlreadyExist,
        SubscriptionCategoryNotFound,
        SubscriptionEventIdNotFound,
        SubscriptionSeverityNotFound,
        TagLimitExceeded,
    },
} = .{};
pub const create_hsm_client_certificate: struct {
    action_name: []const u8 = "CreateHsmClientCertificate",
    Request: type = struct {
        hsm_client_certificate_identifier: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hsm_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = create_hsm_client_certificate };
        }
    },
    Response: type = struct {
        hsm_client_certificate: ?HsmClientCertificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_client_certificate = "HsmClientCertificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HsmClientCertificateAlreadyExists,
        HsmClientCertificateQuotaExceeded,
        InvalidTag,
        TagLimitExceeded,
    },
} = .{};
pub const create_hsm_configuration: struct {
    action_name: []const u8 = "CreateHsmConfiguration",
    Request: type = struct {
        hsm_configuration_identifier: []const u8,
        description: []const u8,
        hsm_ip_address: []const u8,
        hsm_partition_name: []const u8,
        hsm_partition_password: []const u8,
        hsm_server_public_certificate: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
                .description = "Description",
                .hsm_ip_address = "HsmIpAddress",
                .hsm_partition_name = "HsmPartitionName",
                .hsm_partition_password = "HsmPartitionPassword",
                .hsm_server_public_certificate = "HsmServerPublicCertificate",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hsm_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_hsm_configuration };
        }
    },
    Response: type = struct {
        hsm_configuration: ?HsmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_configuration = "HsmConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HsmConfigurationAlreadyExists,
        HsmConfigurationQuotaExceeded,
        InvalidTag,
        TagLimitExceeded,
    },
} = .{};
pub const create_redshift_idc_application: struct {
    action_name: []const u8 = "CreateRedshiftIdcApplication",
    Request: type = struct {
        idc_instance_arn: []const u8,
        redshift_idc_application_name: []const u8,
        identity_namespace: ?[]const u8 = null,
        idc_display_name: []const u8,
        iam_role_arn: []const u8,
        authorized_token_issuer_list: ?[]AuthorizedTokenIssuer = null,
        service_integrations: ?[]ServiceIntegrationsUnion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .idc_instance_arn = "IdcInstanceArn",
                .redshift_idc_application_name = "RedshiftIdcApplicationName",
                .identity_namespace = "IdentityNamespace",
                .idc_display_name = "IdcDisplayName",
                .iam_role_arn = "IamRoleArn",
                .authorized_token_issuer_list = "AuthorizedTokenIssuerList",
                .service_integrations = "ServiceIntegrations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_redshift_idc_application) } {
            return .{ .service_metadata = service_metadata, .action = create_redshift_idc_application };
        }
    },
    Response: type = struct {
        redshift_idc_application: ?RedshiftIdcApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_application = "RedshiftIdcApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceAccessDenied,
        DependentServiceUnavailable,
        RedshiftIdcApplicationAlreadyExists,
        RedshiftIdcApplicationQuotaExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_scheduled_action: struct {
    action_name: []const u8 = "CreateScheduledAction",
    Request: type = struct {
        scheduled_action_name: []const u8,
        target_action: ScheduledActionType,
        schedule: []const u8,
        iam_role: []const u8,
        scheduled_action_description: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        enable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
                .target_action = "TargetAction",
                .schedule = "Schedule",
                .iam_role = "IamRole",
                .scheduled_action_description = "ScheduledActionDescription",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .enable = "Enable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = create_scheduled_action };
        }
    },
    Response: type = struct {
        scheduled_action_name: ?[]const u8 = null,
        target_action: ?ScheduledActionType = null,
        schedule: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,
        scheduled_action_description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        next_invocations: ?[]i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
                .target_action = "TargetAction",
                .schedule = "Schedule",
                .iam_role = "IamRole",
                .scheduled_action_description = "ScheduledActionDescription",
                .state = "State",
                .next_invocations = "NextInvocations",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidScheduledAction,
        InvalidSchedule,
        ScheduledActionAlreadyExists,
        ScheduledActionQuotaExceeded,
        ScheduledActionTypeUnsupported,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const create_snapshot_copy_grant: struct {
    action_name: []const u8 = "CreateSnapshotCopyGrant",
    Request: type = struct {
        snapshot_copy_grant_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_copy_grant_name = "SnapshotCopyGrantName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot_copy_grant) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot_copy_grant };
        }
    },
    Response: type = struct {
        snapshot_copy_grant: ?SnapshotCopyGrant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_copy_grant = "SnapshotCopyGrant",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceRequestThrottling,
        InvalidTag,
        LimitExceeded,
        SnapshotCopyGrantAlreadyExists,
        SnapshotCopyGrantQuotaExceeded,
        TagLimitExceeded,
    },
} = .{};
pub const create_snapshot_schedule: struct {
    action_name: []const u8 = "CreateSnapshotSchedule",
    Request: type = struct {
        schedule_definitions: ?[][]const u8 = null,
        schedule_identifier: ?[]const u8 = null,
        schedule_description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        dry_run: ?bool = null,
        next_invocations: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedule_definitions = "ScheduleDefinitions",
                .schedule_identifier = "ScheduleIdentifier",
                .schedule_description = "ScheduleDescription",
                .tags = "Tags",
                .dry_run = "DryRun",
                .next_invocations = "NextInvocations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot_schedule };
        }
    },
    Response: type = struct {
        schedule_definitions: ?[][]const u8 = null,
        schedule_identifier: ?[]const u8 = null,
        schedule_description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        next_invocations: ?[]i64 = null,
        associated_cluster_count: ?i64 = null,
        associated_clusters: ?[]ClusterAssociatedToSchedule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedule_definitions = "ScheduleDefinitions",
                .schedule_identifier = "ScheduleIdentifier",
                .schedule_description = "ScheduleDescription",
                .tags = "Tags",
                .next_invocations = "NextInvocations",
                .associated_cluster_count = "AssociatedClusterCount",
                .associated_clusters = "AssociatedClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSchedule,
        InvalidTag,
        ScheduleDefinitionTypeUnsupported,
        SnapshotScheduleAlreadyExists,
        SnapshotScheduleQuotaExceeded,
        TagLimitExceeded,
    },
} = .{};
pub const create_tags: struct {
    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        resource_name: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidClusterState,
        InvalidTag,
        ResourceNotFound,
        TagLimitExceeded,
    },
} = .{};
pub const create_usage_limit: struct {
    action_name: []const u8 = "CreateUsageLimit",
    Request: type = struct {
        cluster_identifier: []const u8,
        feature_type: []const u8,
        limit_type: []const u8,
        amount: i64,
        period: ?[]const u8 = null,
        breach_action: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .feature_type = "FeatureType",
                .limit_type = "LimitType",
                .amount = "Amount",
                .period = "Period",
                .breach_action = "BreachAction",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_usage_limit) } {
            return .{ .service_metadata = service_metadata, .action = create_usage_limit };
        }
    },
    Response: type = struct {
        usage_limit_id: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        feature_type: ?[]const u8 = null,
        limit_type: ?[]const u8 = null,
        amount: ?i64 = null,
        period: ?[]const u8 = null,
        breach_action: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limit_id = "UsageLimitId",
                .cluster_identifier = "ClusterIdentifier",
                .feature_type = "FeatureType",
                .limit_type = "LimitType",
                .amount = "Amount",
                .period = "Period",
                .breach_action = "BreachAction",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidUsageLimit,
        LimitExceeded,
        TagLimitExceeded,
        UnsupportedOperation,
        UsageLimitAlreadyExists,
    },
} = .{};
pub const deauthorize_data_share: struct {
    action_name: []const u8 = "DeauthorizeDataShare",
    Request: type = struct {
        data_share_arn: []const u8,
        consumer_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .consumer_identifier = "ConsumerIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deauthorize_data_share) } {
            return .{ .service_metadata = service_metadata, .action = deauthorize_data_share };
        }
    },
    Response: type = struct {
        data_share_arn: ?[]const u8 = null,
        producer_arn: ?[]const u8 = null,
        allow_publicly_accessible_consumers: ?bool = null,
        data_share_associations: ?[]DataShareAssociation = null,
        managed_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .producer_arn = "ProducerArn",
                .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
                .data_share_associations = "DataShareAssociations",
                .managed_by = "ManagedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
    },
} = .{};
pub const delete_authentication_profile: struct {
    action_name: []const u8 = "DeleteAuthenticationProfile",
    Request: type = struct {
        authentication_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_authentication_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_authentication_profile };
        }
    },
    Response: type = struct {
        authentication_profile_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationProfileNotFound,
        InvalidAuthenticationProfileRequest,
    },
} = .{};
pub const delete_cluster: struct {
    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_identifier: []const u8,
        skip_final_cluster_snapshot: ?bool = null,
        final_cluster_snapshot_identifier: ?[]const u8 = null,
        final_cluster_snapshot_retention_period: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .skip_final_cluster_snapshot = "SkipFinalClusterSnapshot",
                .final_cluster_snapshot_identifier = "FinalClusterSnapshotIdentifier",
                .final_cluster_snapshot_retention_period = "FinalClusterSnapshotRetentionPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotAlreadyExists,
        ClusterSnapshotQuotaExceeded,
        InvalidClusterState,
        InvalidRetentionPeriod,
    },
} = .{};
pub const delete_cluster_parameter_group: struct {
    action_name: []const u8 = "DeleteClusterParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster_parameter_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ClusterParameterGroupNotFound,
        InvalidClusterParameterGroupState,
    },
} = .{};
pub const delete_cluster_security_group: struct {
    action_name: []const u8 = "DeleteClusterSecurityGroup",
    Request: type = struct {
        cluster_security_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group_name = "ClusterSecurityGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster_security_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster_security_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ClusterSecurityGroupNotFound,
        InvalidClusterSecurityGroupState,
    },
} = .{};
pub const delete_cluster_snapshot: struct {
    action_name: []const u8 = "DeleteClusterSnapshot",
    Request: type = struct {
        snapshot_identifier: []const u8,
        snapshot_cluster_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSnapshotNotFound,
        InvalidClusterSnapshotState,
    },
} = .{};
pub const delete_cluster_subnet_group: struct {
    action_name: []const u8 = "DeleteClusterSubnetGroup",
    Request: type = struct {
        cluster_subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster_subnet_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ClusterSubnetGroupNotFound,
        InvalidClusterSubnetGroupState,
        InvalidClusterSubnetState,
    },
} = .{};
pub const delete_custom_domain_association: struct {
    action_name: []const u8 = "DeleteCustomDomainAssociation",
    Request: type = struct {
        cluster_identifier: []const u8,
        custom_domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .custom_domain_name = "CustomDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_domain_association };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ClusterNotFound,
        CustomCnameAssociation,
        CustomDomainAssociationNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const delete_endpoint_access: struct {
    action_name: []const u8 = "DeleteEndpointAccess",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint_access };
        }
    },
    Response: type = struct {
        cluster_identifier: ?[]const u8 = null,
        resource_owner: ?[]const u8 = null,
        subnet_group_name: ?[]const u8 = null,
        endpoint_status: ?[]const u8 = null,
        endpoint_name: ?[]const u8 = null,
        endpoint_create_time: ?i64 = null,
        port: ?i64 = null,
        address: ?[]const u8 = null,
        vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
        vpc_endpoint: ?VpcEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .resource_owner = "ResourceOwner",
                .subnet_group_name = "SubnetGroupName",
                .endpoint_status = "EndpointStatus",
                .endpoint_name = "EndpointName",
                .endpoint_create_time = "EndpointCreateTime",
                .port = "Port",
                .address = "Address",
                .vpc_security_groups = "VpcSecurityGroups",
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        EndpointNotFound,
        InvalidClusterSecurityGroupState,
        InvalidClusterState,
        InvalidEndpointState,
    },
} = .{};
pub const delete_event_subscription: struct {
    action_name: []const u8 = "DeleteEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_subscription };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidSubscriptionState,
        SubscriptionNotFound,
    },
} = .{};
pub const delete_hsm_client_certificate: struct {
    action_name: []const u8 = "DeleteHsmClientCertificate",
    Request: type = struct {
        hsm_client_certificate_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hsm_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_hsm_client_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        HsmClientCertificateNotFound,
        InvalidHsmClientCertificateState,
    },
} = .{};
pub const delete_hsm_configuration: struct {
    action_name: []const u8 = "DeleteHsmConfiguration",
    Request: type = struct {
        hsm_configuration_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hsm_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_hsm_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        HsmConfigurationNotFound,
        InvalidHsmConfigurationState,
    },
} = .{};
pub const delete_partner: struct {
    action_name: []const u8 = "DeletePartner",
    Request: type = struct {
        account_id: []const u8,
        cluster_identifier: []const u8,
        database_name: []const u8,
        partner_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .cluster_identifier = "ClusterIdentifier",
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partner) } {
            return .{ .service_metadata = service_metadata, .action = delete_partner };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        partner_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        PartnerNotFound,
        UnauthorizedPartnerIntegration,
        UnsupportedOperation,
    },
} = .{};
pub const delete_redshift_idc_application: struct {
    action_name: []const u8 = "DeleteRedshiftIdcApplication",
    Request: type = struct {
        redshift_idc_application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_application_arn = "RedshiftIdcApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_redshift_idc_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_redshift_idc_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DependentServiceAccessDenied,
        DependentServiceUnavailable,
        RedshiftIdcApplicationNotExists,
        UnsupportedOperation,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const delete_scheduled_action: struct {
    action_name: []const u8 = "DeleteScheduledAction",
    Request: type = struct {
        scheduled_action_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_scheduled_action };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ScheduledActionNotFound,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_snapshot_copy_grant: struct {
    action_name: []const u8 = "DeleteSnapshotCopyGrant",
    Request: type = struct {
        snapshot_copy_grant_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_copy_grant_name = "SnapshotCopyGrantName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot_copy_grant) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot_copy_grant };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidSnapshotCopyGrantState,
        SnapshotCopyGrantNotFound,
    },
} = .{};
pub const delete_snapshot_schedule: struct {
    action_name: []const u8 = "DeleteSnapshotSchedule",
    Request: type = struct {
        schedule_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedule_identifier = "ScheduleIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot_schedule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidClusterSnapshotScheduleState,
        SnapshotScheduleNotFound,
    },
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_name: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidTag,
        ResourceNotFound,
    },
} = .{};
pub const delete_usage_limit: struct {
    action_name: []const u8 = "DeleteUsageLimit",
    Request: type = struct {
        usage_limit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limit_id = "UsageLimitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_usage_limit) } {
            return .{ .service_metadata = service_metadata, .action = delete_usage_limit };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        UnsupportedOperation,
        UsageLimitNotFound,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {
        attribute_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_names = "AttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_attributes: ?[]struct {
            attribute_name: ?[]const u8 = null,
            attribute_values: ?[]struct {
                attribute_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attribute_value = "AttributeValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "AttributeName",
                    .attribute_values = "AttributeValues",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_attributes = "AccountAttributes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_authentication_profiles: struct {
    action_name: []const u8 = "DescribeAuthenticationProfiles",
    Request: type = struct {
        authentication_profile_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_authentication_profiles) } {
            return .{ .service_metadata = service_metadata, .action = describe_authentication_profiles };
        }
    },
    Response: type = struct {
        authentication_profiles: ?[]struct {
            authentication_profile_name: ?[]const u8 = null,
            authentication_profile_content: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authentication_profile_name = "AuthenticationProfileName",
                    .authentication_profile_content = "AuthenticationProfileContent",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profiles = "AuthenticationProfiles",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationProfileNotFound,
        InvalidAuthenticationProfileRequest,
    },
} = .{};
pub const describe_cluster_db_revisions: struct {
    action_name: []const u8 = "DescribeClusterDbRevisions",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_db_revisions) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_db_revisions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cluster_db_revisions: ?[]struct {
            cluster_identifier: ?[]const u8 = null,
            current_database_revision: ?[]const u8 = null,
            database_revision_release_date: ?i64 = null,
            revision_targets: ?[]struct {
                database_revision: ?[]const u8 = null,
                description: ?[]const u8 = null,
                database_revision_release_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .database_revision = "DatabaseRevision",
                        .description = "Description",
                        .database_revision_release_date = "DatabaseRevisionReleaseDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_identifier = "ClusterIdentifier",
                    .current_database_revision = "CurrentDatabaseRevision",
                    .database_revision_release_date = "DatabaseRevisionReleaseDate",
                    .revision_targets = "RevisionTargets",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cluster_db_revisions = "ClusterDbRevisions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
    },
} = .{};
pub const describe_cluster_parameter_groups: struct {
    action_name: []const u8 = "DescribeClusterParameterGroups",
    Request: type = struct {
        parameter_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_parameter_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        parameter_groups: ?[]ClusterParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .parameter_groups = "ParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterParameterGroupNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_cluster_parameters: struct {
    action_name: []const u8 = "DescribeClusterParameters",
    Request: type = struct {
        parameter_group_name: []const u8,
        source: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .source = "Source",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterParameterGroupNotFound,
    },
} = .{};
pub const describe_clusters: struct {
    action_name: []const u8 = "DescribeClusters",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_clusters };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        clusters: ?[]Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .clusters = "Clusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_cluster_security_groups: struct {
    action_name: []const u8 = "DescribeClusterSecurityGroups",
    Request: type = struct {
        cluster_security_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group_name = "ClusterSecurityGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_security_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_security_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cluster_security_groups: ?[]ClusterSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cluster_security_groups = "ClusterSecurityGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSecurityGroupNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_cluster_snapshots: struct {
    action_name: []const u8 = "DescribeClusterSnapshots",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        snapshot_identifier: ?[]const u8 = null,
        snapshot_arn: ?[]const u8 = null,
        snapshot_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,
        cluster_exists: ?bool = null,
        sorting_entities: ?[]struct {
            attribute: []const u8,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "Attribute",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_arn = "SnapshotArn",
                .snapshot_type = "SnapshotType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .owner_account = "OwnerAccount",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
                .cluster_exists = "ClusterExists",
                .sorting_entities = "SortingEntities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_snapshots };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        snapshots: ?[]Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .snapshots = "Snapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotNotFound,
        InvalidTag,
        UnsupportedOperation,
    },
} = .{};
pub const describe_cluster_subnet_groups: struct {
    action_name: []const u8 = "DescribeClusterSubnetGroups",
    Request: type = struct {
        cluster_subnet_group_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cluster_subnet_groups: ?[]ClusterSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cluster_subnet_groups = "ClusterSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSubnetGroupNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_cluster_tracks: struct {
    action_name: []const u8 = "DescribeClusterTracks",
    Request: type = struct {
        maintenance_track_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .maintenance_track_name = "MaintenanceTrackName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_tracks) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_tracks };
        }
    },
    Response: type = struct {
        maintenance_tracks: ?[]struct {
            maintenance_track_name: ?[]const u8 = null,
            database_version: ?[]const u8 = null,
            update_targets: ?[]struct {
                maintenance_track_name: ?[]const u8 = null,
                database_version: ?[]const u8 = null,
                supported_operations: ?[]struct {
                    operation_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .operation_name = "OperationName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .maintenance_track_name = "MaintenanceTrackName",
                        .database_version = "DatabaseVersion",
                        .supported_operations = "SupportedOperations",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_track_name = "MaintenanceTrackName",
                    .database_version = "DatabaseVersion",
                    .update_targets = "UpdateTargets",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .maintenance_tracks = "MaintenanceTracks",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidClusterTrack,
        UnauthorizedOperation,
    },
} = .{};
pub const describe_cluster_versions: struct {
    action_name: []const u8 = "DescribeClusterVersions",
    Request: type = struct {
        cluster_version: ?[]const u8 = null,
        cluster_parameter_group_family: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_version = "ClusterVersion",
                .cluster_parameter_group_family = "ClusterParameterGroupFamily",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_versions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        cluster_versions: ?[]struct {
            cluster_version: ?[]const u8 = null,
            cluster_parameter_group_family: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_version = "ClusterVersion",
                    .cluster_parameter_group_family = "ClusterParameterGroupFamily",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .cluster_versions = "ClusterVersions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_custom_domain_associations: struct {
    action_name: []const u8 = "DescribeCustomDomainAssociations",
    Request: type = struct {
        custom_domain_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "CustomDomainName",
                .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_custom_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_custom_domain_associations };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        associations: ?[]struct {
            custom_domain_certificate_arn: ?[]const u8 = null,
            custom_domain_certificate_expiry_date: ?i64 = null,
            certificate_associations: ?[]struct {
                custom_domain_name: ?[]const u8 = null,
                cluster_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .custom_domain_name = "CustomDomainName",
                        .cluster_identifier = "ClusterIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                    .custom_domain_certificate_expiry_date = "CustomDomainCertificateExpiryDate",
                    .certificate_associations = "CertificateAssociations",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .associations = "Associations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomDomainAssociationNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_data_shares: struct {
    action_name: []const u8 = "DescribeDataShares",
    Request: type = struct {
        data_share_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_shares) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_shares };
        }
    },
    Response: type = struct {
        data_shares: ?[]DataShare = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_shares = "DataShares",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
    },
} = .{};
pub const describe_data_shares_for_consumer: struct {
    action_name: []const u8 = "DescribeDataSharesForConsumer",
    Request: type = struct {
        consumer_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .consumer_arn = "ConsumerArn",
                .status = "Status",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_shares_for_consumer) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_shares_for_consumer };
        }
    },
    Response: type = struct {
        data_shares: ?[]DataShare = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_shares = "DataShares",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNamespace,
    },
} = .{};
pub const describe_data_shares_for_producer: struct {
    action_name: []const u8 = "DescribeDataSharesForProducer",
    Request: type = struct {
        producer_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .producer_arn = "ProducerArn",
                .status = "Status",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_shares_for_producer) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_shares_for_producer };
        }
    },
    Response: type = struct {
        data_shares: ?[]DataShare = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_shares = "DataShares",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNamespace,
    },
} = .{};
pub const describe_default_cluster_parameters: struct {
    action_name: []const u8 = "DescribeDefaultClusterParameters",
    Request: type = struct {
        parameter_group_family: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_family = "ParameterGroupFamily",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_default_cluster_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_default_cluster_parameters };
        }
    },
    Response: type = struct {
        default_cluster_parameters: ?struct {
            parameter_group_family: ?[]const u8 = null,
            marker: ?[]const u8 = null,
            parameters: ?[]Parameter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parameter_group_family = "ParameterGroupFamily",
                    .marker = "Marker",
                    .parameters = "Parameters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_cluster_parameters = "DefaultClusterParameters",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_endpoint_access: struct {
    action_name: []const u8 = "DescribeEndpointAccess",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        resource_owner: ?[]const u8 = null,
        endpoint_name: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .resource_owner = "ResourceOwner",
                .endpoint_name = "EndpointName",
                .vpc_id = "VpcId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_access };
        }
    },
    Response: type = struct {
        endpoint_access_list: ?[]EndpointAccess = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_access_list = "EndpointAccessList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        EndpointNotFound,
        InvalidClusterState,
    },
} = .{};
pub const describe_endpoint_authorization: struct {
    action_name: []const u8 = "DescribeEndpointAuthorization",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        account: ?[]const u8 = null,
        grantee: ?bool = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .account = "Account",
                .grantee = "Grantee",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_authorization) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_authorization };
        }
    },
    Response: type = struct {
        endpoint_authorization_list: ?[]EndpointAuthorization = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_authorization_list = "EndpointAuthorizationList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_event_categories: struct {
    action_name: []const u8 = "DescribeEventCategories",
    Request: type = struct {
        source_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_categories) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_categories };
        }
    },
    Response: type = struct {
        event_categories_map_list: ?[]struct {
            source_type: ?[]const u8 = null,
            events: ?[]struct {
                event_id: ?[]const u8 = null,
                event_categories: ?[][]const u8 = null,
                event_description: ?[]const u8 = null,
                severity: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_id = "EventId",
                        .event_categories = "EventCategories",
                        .event_description = "EventDescription",
                        .severity = "Severity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_type = "SourceType",
                    .events = "Events",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_categories_map_list = "EventCategoriesMapList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,
            severity: ?[]const u8 = null,
            date: ?i64 = null,
            event_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .event_categories = "EventCategories",
                    .severity = "Severity",
                    .date = "Date",
                    .event_id = "EventId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_subscriptions: struct {
    action_name: []const u8 = "DescribeEventSubscriptions",
    Request: type = struct {
        subscription_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_subscriptions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        event_subscriptions_list: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .event_subscriptions_list = "EventSubscriptionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTag,
        SubscriptionNotFound,
    },
} = .{};
pub const describe_hsm_client_certificates: struct {
    action_name: []const u8 = "DescribeHsmClientCertificates",
    Request: type = struct {
        hsm_client_certificate_identifier: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hsm_client_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_hsm_client_certificates };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        hsm_client_certificates: ?[]HsmClientCertificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .hsm_client_certificates = "HsmClientCertificates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HsmClientCertificateNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_hsm_configurations: struct {
    action_name: []const u8 = "DescribeHsmConfigurations",
    Request: type = struct {
        hsm_configuration_identifier: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hsm_configurations) } {
            return .{ .service_metadata = service_metadata, .action = describe_hsm_configurations };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        hsm_configurations: ?[]HsmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .hsm_configurations = "HsmConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HsmConfigurationNotFound,
        InvalidTag,
    },
} = .{};
pub const describe_inbound_integrations: struct {
    action_name: []const u8 = "DescribeInboundIntegrations",
    Request: type = struct {
        integration_arn: ?[]const u8 = null,
        target_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .integration_arn = "IntegrationArn",
                .target_arn = "TargetArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inbound_integrations) } {
            return .{ .service_metadata = service_metadata, .action = describe_inbound_integrations };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        inbound_integrations: ?[]struct {
            integration_arn: ?[]const u8 = null,
            source_arn: ?[]const u8 = null,
            target_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            errors: ?[]struct {
                error_code: []const u8,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            create_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .integration_arn = "IntegrationArn",
                    .source_arn = "SourceArn",
                    .target_arn = "TargetArn",
                    .status = "Status",
                    .errors = "Errors",
                    .create_time = "CreateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .inbound_integrations = "InboundIntegrations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IntegrationNotFound,
        InvalidNamespace,
        UnsupportedOperation,
    },
} = .{};
pub const describe_logging_status: struct {
    action_name: []const u8 = "DescribeLoggingStatus",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_logging_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_logging_status };
        }
    },
    Response: type = struct {
        logging_enabled: ?bool = null,
        bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        last_successful_delivery_time: ?i64 = null,
        last_failure_time: ?i64 = null,
        last_failure_message: ?[]const u8 = null,
        log_destination_type: ?[]const u8 = null,
        log_exports: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_enabled = "LoggingEnabled",
                .bucket_name = "BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .last_successful_delivery_time = "LastSuccessfulDeliveryTime",
                .last_failure_time = "LastFailureTime",
                .last_failure_message = "LastFailureMessage",
                .log_destination_type = "LogDestinationType",
                .log_exports = "LogExports",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_node_configuration_options: struct {
    action_name: []const u8 = "DescribeNodeConfigurationOptions",
    Request: type = struct {
        action_type: []const u8,
        cluster_identifier: ?[]const u8 = null,
        snapshot_identifier: ?[]const u8 = null,
        snapshot_arn: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            operator: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .operator = "Operator",
                    .values = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "ActionType",
                .cluster_identifier = "ClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_arn = "SnapshotArn",
                .owner_account = "OwnerAccount",
                .filters = "Filter",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_node_configuration_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_node_configuration_options };
        }
    },
    Response: type = struct {
        node_configuration_option_list: ?[]struct {
            node_type: ?[]const u8 = null,
            number_of_nodes: ?i64 = null,
            estimated_disk_utilization_percent: ?f64 = null,
            mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_type = "NodeType",
                    .number_of_nodes = "NumberOfNodes",
                    .estimated_disk_utilization_percent = "EstimatedDiskUtilizationPercent",
                    .mode = "Mode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_configuration_option_list = "NodeConfigurationOptionList",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessToSnapshotDenied,
        ClusterNotFound,
        ClusterSnapshotNotFound,
        InvalidClusterSnapshotState,
        UnsupportedOperation,
    },
} = .{};
pub const describe_orderable_cluster_options: struct {
    action_name: []const u8 = "DescribeOrderableClusterOptions",
    Request: type = struct {
        cluster_version: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_version = "ClusterVersion",
                .node_type = "NodeType",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_orderable_cluster_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_orderable_cluster_options };
        }
    },
    Response: type = struct {
        orderable_cluster_options: ?[]struct {
            cluster_version: ?[]const u8 = null,
            cluster_type: ?[]const u8 = null,
            node_type: ?[]const u8 = null,
            availability_zones: ?[]AvailabilityZone = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_version = "ClusterVersion",
                    .cluster_type = "ClusterType",
                    .node_type = "NodeType",
                    .availability_zones = "AvailabilityZones",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orderable_cluster_options = "OrderableClusterOptions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_partners: struct {
    action_name: []const u8 = "DescribePartners",
    Request: type = struct {
        account_id: []const u8,
        cluster_identifier: []const u8,
        database_name: ?[]const u8 = null,
        partner_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .cluster_identifier = "ClusterIdentifier",
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_partners) } {
            return .{ .service_metadata = service_metadata, .action = describe_partners };
        }
    },
    Response: type = struct {
        partner_integration_info_list: ?[]struct {
            database_name: ?[]const u8 = null,
            partner_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_name = "DatabaseName",
                    .partner_name = "PartnerName",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_integration_info_list = "PartnerIntegrationInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnauthorizedPartnerIntegration,
        UnsupportedOperation,
    },
} = .{};
pub const describe_redshift_idc_applications: struct {
    action_name: []const u8 = "DescribeRedshiftIdcApplications",
    Request: type = struct {
        redshift_idc_application_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_application_arn = "RedshiftIdcApplicationArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_redshift_idc_applications) } {
            return .{ .service_metadata = service_metadata, .action = describe_redshift_idc_applications };
        }
    },
    Response: type = struct {
        redshift_idc_applications: ?[]RedshiftIdcApplication = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_applications = "RedshiftIdcApplications",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceAccessDenied,
        DependentServiceUnavailable,
        RedshiftIdcApplicationNotExists,
        UnsupportedOperation,
    },
} = .{};
pub const describe_reserved_node_exchange_status: struct {
    action_name: []const u8 = "DescribeReservedNodeExchangeStatus",
    Request: type = struct {
        reserved_node_id: ?[]const u8 = null,
        reserved_node_exchange_request_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_id = "ReservedNodeId",
                .reserved_node_exchange_request_id = "ReservedNodeExchangeRequestId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_node_exchange_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_node_exchange_status };
        }
    },
    Response: type = struct {
        reserved_node_exchange_status_details: ?[]ReservedNodeExchangeStatus = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_exchange_status_details = "ReservedNodeExchangeStatusDetails",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ReservedNodeExchangeNotFound,
        ReservedNodeNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_reserved_node_offerings: struct {
    action_name: []const u8 = "DescribeReservedNodeOfferings",
    Request: type = struct {
        reserved_node_offering_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_offering_id = "ReservedNodeOfferingId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_node_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_node_offerings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_node_offerings: ?[]ReservedNodeOffering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_node_offerings = "ReservedNodeOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceUnavailable,
        ReservedNodeOfferingNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_reserved_nodes: struct {
    action_name: []const u8 = "DescribeReservedNodes",
    Request: type = struct {
        reserved_node_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_id = "ReservedNodeId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_nodes) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_nodes };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_nodes: ?[]ReservedNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_nodes = "ReservedNodes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceUnavailable,
        ReservedNodeNotFound,
    },
} = .{};
pub const describe_resize: struct {
    action_name: []const u8 = "DescribeResize",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resize) } {
            return .{ .service_metadata = service_metadata, .action = describe_resize };
        }
    },
    Response: type = struct {
        target_node_type: ?[]const u8 = null,
        target_number_of_nodes: ?i64 = null,
        target_cluster_type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        import_tables_completed: ?[][]const u8 = null,
        import_tables_in_progress: ?[][]const u8 = null,
        import_tables_not_started: ?[][]const u8 = null,
        avg_resize_rate_in_mega_bytes_per_second: ?f64 = null,
        total_resize_data_in_mega_bytes: ?i64 = null,
        progress_in_mega_bytes: ?i64 = null,
        elapsed_time_in_seconds: ?i64 = null,
        estimated_time_to_completion_in_seconds: ?i64 = null,
        resize_type: ?[]const u8 = null,
        message: ?[]const u8 = null,
        target_encryption_type: ?[]const u8 = null,
        data_transfer_progress_percent: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_node_type = "TargetNodeType",
                .target_number_of_nodes = "TargetNumberOfNodes",
                .target_cluster_type = "TargetClusterType",
                .status = "Status",
                .import_tables_completed = "ImportTablesCompleted",
                .import_tables_in_progress = "ImportTablesInProgress",
                .import_tables_not_started = "ImportTablesNotStarted",
                .avg_resize_rate_in_mega_bytes_per_second = "AvgResizeRateInMegaBytesPerSecond",
                .total_resize_data_in_mega_bytes = "TotalResizeDataInMegaBytes",
                .progress_in_mega_bytes = "ProgressInMegaBytes",
                .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
                .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
                .resize_type = "ResizeType",
                .message = "Message",
                .target_encryption_type = "TargetEncryptionType",
                .data_transfer_progress_percent = "DataTransferProgressPercent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ResizeNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_scheduled_actions: struct {
    action_name: []const u8 = "DescribeScheduledActions",
    Request: type = struct {
        scheduled_action_name: ?[]const u8 = null,
        target_action_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        active: ?bool = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
                .target_action_type = "TargetActionType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .active = "Active",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_actions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        scheduled_actions: ?[]ScheduledAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .scheduled_actions = "ScheduledActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ScheduledActionNotFound,
        UnauthorizedOperation,
    },
} = .{};
pub const describe_snapshot_copy_grants: struct {
    action_name: []const u8 = "DescribeSnapshotCopyGrants",
    Request: type = struct {
        snapshot_copy_grant_name: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_copy_grant_name = "SnapshotCopyGrantName",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshot_copy_grants) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshot_copy_grants };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        snapshot_copy_grants: ?[]SnapshotCopyGrant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .snapshot_copy_grants = "SnapshotCopyGrants",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTag,
        SnapshotCopyGrantNotFound,
    },
} = .{};
pub const describe_snapshot_schedules: struct {
    action_name: []const u8 = "DescribeSnapshotSchedules",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        schedule_identifier: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .schedule_identifier = "ScheduleIdentifier",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshot_schedules) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshot_schedules };
        }
    },
    Response: type = struct {
        snapshot_schedules: ?[]SnapshotSchedule = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_schedules = "SnapshotSchedules",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_storage: struct {
    action_name: []const u8 = "DescribeStorage",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storage) } {
            return .{ .service_metadata = service_metadata, .action = describe_storage };
        }
    },
    Response: type = struct {
        total_backup_size_in_mega_bytes: ?f64 = null,
        total_provisioned_storage_in_mega_bytes: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .total_backup_size_in_mega_bytes = "TotalBackupSizeInMegaBytes",
                .total_provisioned_storage_in_mega_bytes = "TotalProvisionedStorageInMegaBytes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_table_restore_status: struct {
    action_name: []const u8 = "DescribeTableRestoreStatus",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        table_restore_request_id: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .table_restore_request_id = "TableRestoreRequestId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table_restore_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_table_restore_status };
        }
    },
    Response: type = struct {
        table_restore_status_details: ?[]TableRestoreStatus = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_restore_status_details = "TableRestoreStatusDetails",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        TableRestoreNotFound,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_name: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_name = "ResourceName",
                .resource_type = "ResourceType",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        tagged_resources: ?[]struct {
            tag: ?Tag = null,
            resource_name: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag = "Tag",
                    .resource_name = "ResourceName",
                    .resource_type = "ResourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tagged_resources = "TaggedResources",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTag,
        ResourceNotFound,
    },
} = .{};
pub const describe_usage_limits: struct {
    action_name: []const u8 = "DescribeUsageLimits",
    Request: type = struct {
        usage_limit_id: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        feature_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        tag_keys: ?[][]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limit_id = "UsageLimitId",
                .cluster_identifier = "ClusterIdentifier",
                .feature_type = "FeatureType",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .tag_keys = "TagKeys",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_usage_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_usage_limits };
        }
    },
    Response: type = struct {
        usage_limits: ?[]UsageLimit = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limits = "UsageLimits",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const disable_logging: struct {
    action_name: []const u8 = "DisableLogging",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_logging) } {
            return .{ .service_metadata = service_metadata, .action = disable_logging };
        }
    },
    Response: type = struct {
        logging_enabled: ?bool = null,
        bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        last_successful_delivery_time: ?i64 = null,
        last_failure_time: ?i64 = null,
        last_failure_message: ?[]const u8 = null,
        log_destination_type: ?[]const u8 = null,
        log_exports: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_enabled = "LoggingEnabled",
                .bucket_name = "BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .last_successful_delivery_time = "LastSuccessfulDeliveryTime",
                .last_failure_time = "LastFailureTime",
                .last_failure_message = "LastFailureMessage",
                .log_destination_type = "LogDestinationType",
                .log_exports = "LogExports",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const disable_snapshot_copy: struct {
    action_name: []const u8 = "DisableSnapshotCopy",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_snapshot_copy) } {
            return .{ .service_metadata = service_metadata, .action = disable_snapshot_copy };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        SnapshotCopyAlreadyDisabled,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const disassociate_data_share_consumer: struct {
    action_name: []const u8 = "DisassociateDataShareConsumer",
    Request: type = struct {
        data_share_arn: []const u8,
        disassociate_entire_account: ?bool = null,
        consumer_arn: ?[]const u8 = null,
        consumer_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .disassociate_entire_account = "DisassociateEntireAccount",
                .consumer_arn = "ConsumerArn",
                .consumer_region = "ConsumerRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_data_share_consumer) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_data_share_consumer };
        }
    },
    Response: type = struct {
        data_share_arn: ?[]const u8 = null,
        producer_arn: ?[]const u8 = null,
        allow_publicly_accessible_consumers: ?bool = null,
        data_share_associations: ?[]DataShareAssociation = null,
        managed_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .producer_arn = "ProducerArn",
                .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
                .data_share_associations = "DataShareAssociations",
                .managed_by = "ManagedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
        InvalidNamespace,
    },
} = .{};
pub const enable_logging: struct {
    action_name: []const u8 = "EnableLogging",
    Request: type = struct {
        cluster_identifier: []const u8,
        bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        log_destination_type: ?[]const u8 = null,
        log_exports: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .bucket_name = "BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .log_destination_type = "LogDestinationType",
                .log_exports = "LogExports",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_logging) } {
            return .{ .service_metadata = service_metadata, .action = enable_logging };
        }
    },
    Response: type = struct {
        logging_enabled: ?bool = null,
        bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        last_successful_delivery_time: ?i64 = null,
        last_failure_time: ?i64 = null,
        last_failure_message: ?[]const u8 = null,
        log_destination_type: ?[]const u8 = null,
        log_exports: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_enabled = "LoggingEnabled",
                .bucket_name = "BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .last_successful_delivery_time = "LastSuccessfulDeliveryTime",
                .last_failure_time = "LastFailureTime",
                .last_failure_message = "LastFailureMessage",
                .log_destination_type = "LogDestinationType",
                .log_exports = "LogExports",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BucketNotFound,
        ClusterNotFound,
        InsufficientS3BucketPolicy,
        InvalidClusterState,
        InvalidS3BucketName,
        InvalidS3KeyPrefix,
        UnsupportedOperation,
    },
} = .{};
pub const enable_snapshot_copy: struct {
    action_name: []const u8 = "EnableSnapshotCopy",
    Request: type = struct {
        cluster_identifier: []const u8,
        destination_region: []const u8,
        retention_period: ?i64 = null,
        snapshot_copy_grant_name: ?[]const u8 = null,
        manual_snapshot_retention_period: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .destination_region = "DestinationRegion",
                .retention_period = "RetentionPeriod",
                .snapshot_copy_grant_name = "SnapshotCopyGrantName",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_snapshot_copy) } {
            return .{ .service_metadata = service_metadata, .action = enable_snapshot_copy };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        CopyToRegionDisabled,
        DependentServiceRequestThrottling,
        IncompatibleOrderableOptions,
        InvalidClusterState,
        InvalidRetentionPeriod,
        LimitExceeded,
        SnapshotCopyAlreadyEnabled,
        SnapshotCopyGrantNotFound,
        UnauthorizedOperation,
        UnknownSnapshotCopyRegion,
    },
} = .{};
pub const failover_primary_compute: struct {
    action_name: []const u8 = "FailoverPrimaryCompute",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_primary_compute) } {
            return .{ .service_metadata = service_metadata, .action = failover_primary_compute };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const get_cluster_credentials: struct {
    action_name: []const u8 = "GetClusterCredentials",
    Request: type = struct {
        db_user: []const u8,
        db_name: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        duration_seconds: ?i64 = null,
        auto_create: ?bool = null,
        db_groups: ?[][]const u8 = null,
        custom_domain_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_user = "DbUser",
                .db_name = "DbName",
                .cluster_identifier = "ClusterIdentifier",
                .duration_seconds = "DurationSeconds",
                .auto_create = "AutoCreate",
                .db_groups = "DbGroups",
                .custom_domain_name = "CustomDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cluster_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_cluster_credentials };
        }
    },
    Response: type = struct {
        db_user: ?[]const u8 = null,
        db_password: ?[]const u8 = null,
        expiration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_user = "DbUser",
                .db_password = "DbPassword",
                .expiration = "Expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_cluster_credentials_with_iam: struct {
    action_name: []const u8 = "GetClusterCredentialsWithIAM",
    Request: type = struct {
        db_name: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        duration_seconds: ?i64 = null,
        custom_domain_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_name = "DbName",
                .cluster_identifier = "ClusterIdentifier",
                .duration_seconds = "DurationSeconds",
                .custom_domain_name = "CustomDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cluster_credentials_with_iam) } {
            return .{ .service_metadata = service_metadata, .action = get_cluster_credentials_with_iam };
        }
    },
    Response: type = struct {
        db_user: ?[]const u8 = null,
        db_password: ?[]const u8 = null,
        expiration: ?i64 = null,
        next_refresh_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_user = "DbUser",
                .db_password = "DbPassword",
                .expiration = "Expiration",
                .next_refresh_time = "NextRefreshTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_reserved_node_exchange_configuration_options: struct {
    action_name: []const u8 = "GetReservedNodeExchangeConfigurationOptions",
    Request: type = struct {
        action_type: []const u8,
        cluster_identifier: ?[]const u8 = null,
        snapshot_identifier: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "ActionType",
                .cluster_identifier = "ClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reserved_node_exchange_configuration_options) } {
            return .{ .service_metadata = service_metadata, .action = get_reserved_node_exchange_configuration_options };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_node_configuration_option_list: ?[]struct {
            source_reserved_node: ?ReservedNode = null,
            target_reserved_node_count: ?i64 = null,
            target_reserved_node_offering: ?ReservedNodeOffering = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_reserved_node = "SourceReservedNode",
                    .target_reserved_node_count = "TargetReservedNodeCount",
                    .target_reserved_node_offering = "TargetReservedNodeOffering",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_node_configuration_option_list = "ReservedNodeConfigurationOptionList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotNotFound,
        DependentServiceUnavailable,
        InvalidReservedNodeState,
        ReservedNodeAlreadyMigrated,
        ReservedNodeNotFound,
        ReservedNodeOfferingNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_reserved_node_exchange_offerings: struct {
    action_name: []const u8 = "GetReservedNodeExchangeOfferings",
    Request: type = struct {
        reserved_node_id: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_id = "ReservedNodeId",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reserved_node_exchange_offerings) } {
            return .{ .service_metadata = service_metadata, .action = get_reserved_node_exchange_offerings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        reserved_node_offerings: ?[]ReservedNodeOffering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .reserved_node_offerings = "ReservedNodeOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceUnavailable,
        InvalidReservedNodeState,
        ReservedNodeAlreadyMigrated,
        ReservedNodeNotFound,
        ReservedNodeOfferingNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPolicy,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const list_recommendations: struct {
    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        namespace_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .namespace_arn = "NamespaceArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        recommendations: ?[]struct {
            id: ?[]const u8 = null,
            cluster_identifier: ?[]const u8 = null,
            namespace_arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            recommendation_type: ?[]const u8 = null,
            title: ?[]const u8 = null,
            description: ?[]const u8 = null,
            observation: ?[]const u8 = null,
            impact_ranking: ?[]const u8 = null,
            recommendation_text: ?[]const u8 = null,
            recommended_actions: ?[]struct {
                text: ?[]const u8 = null,
                database: ?[]const u8 = null,
                command: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "Text",
                        .database = "Database",
                        .command = "Command",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            reference_links: ?[]struct {
                text: ?[]const u8 = null,
                link: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "Text",
                        .link = "Link",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .cluster_identifier = "ClusterIdentifier",
                    .namespace_arn = "NamespaceArn",
                    .created_at = "CreatedAt",
                    .recommendation_type = "RecommendationType",
                    .title = "Title",
                    .description = "Description",
                    .observation = "Observation",
                    .impact_ranking = "ImpactRanking",
                    .recommendation_text = "RecommendationText",
                    .recommended_actions = "RecommendedActions",
                    .reference_links = "ReferenceLinks",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendations = "Recommendations",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const modify_aqua_configuration: struct {
    action_name: []const u8 = "ModifyAquaConfiguration",
    Request: type = struct {
        cluster_identifier: []const u8,
        aqua_configuration_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .aqua_configuration_status = "AquaConfigurationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_aqua_configuration) } {
            return .{ .service_metadata = service_metadata, .action = modify_aqua_configuration };
        }
    },
    Response: type = struct {
        aqua_configuration: ?AquaConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aqua_configuration = "AquaConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const modify_authentication_profile: struct {
    action_name: []const u8 = "ModifyAuthenticationProfile",
    Request: type = struct {
        authentication_profile_name: []const u8,
        authentication_profile_content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
                .authentication_profile_content = "AuthenticationProfileContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_authentication_profile) } {
            return .{ .service_metadata = service_metadata, .action = modify_authentication_profile };
        }
    },
    Response: type = struct {
        authentication_profile_name: ?[]const u8 = null,
        authentication_profile_content: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_profile_name = "AuthenticationProfileName",
                .authentication_profile_content = "AuthenticationProfileContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthenticationProfileNotFound,
        AuthenticationProfileQuotaExceeded,
        InvalidAuthenticationProfileRequest,
    },
} = .{};
pub const modify_cluster: struct {
    action_name: []const u8 = "ModifyCluster",
    Request: type = struct {
        cluster_identifier: []const u8,
        cluster_type: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        number_of_nodes: ?i64 = null,
        cluster_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        master_user_password: ?[]const u8 = null,
        cluster_parameter_group_name: ?[]const u8 = null,
        automated_snapshot_retention_period: ?i64 = null,
        manual_snapshot_retention_period: ?i64 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        cluster_version: ?[]const u8 = null,
        allow_version_upgrade: ?bool = null,
        hsm_client_certificate_identifier: ?[]const u8 = null,
        hsm_configuration_identifier: ?[]const u8 = null,
        new_cluster_identifier: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        elastic_ip: ?[]const u8 = null,
        enhanced_vpc_routing: ?bool = null,
        maintenance_track_name: ?[]const u8 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        availability_zone_relocation: ?bool = null,
        availability_zone: ?[]const u8 = null,
        port: ?i64 = null,
        manage_master_password: ?bool = null,
        master_password_secret_kms_key_id: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        multi_az: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .cluster_type = "ClusterType",
                .node_type = "NodeType",
                .number_of_nodes = "NumberOfNodes",
                .cluster_security_groups = "ClusterSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .master_user_password = "MasterUserPassword",
                .cluster_parameter_group_name = "ClusterParameterGroupName",
                .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .cluster_version = "ClusterVersion",
                .allow_version_upgrade = "AllowVersionUpgrade",
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
                .new_cluster_identifier = "NewClusterIdentifier",
                .publicly_accessible = "PubliclyAccessible",
                .elastic_ip = "ElasticIp",
                .enhanced_vpc_routing = "EnhancedVpcRouting",
                .maintenance_track_name = "MaintenanceTrackName",
                .encrypted = "Encrypted",
                .kms_key_id = "KmsKeyId",
                .availability_zone_relocation = "AvailabilityZoneRelocation",
                .availability_zone = "AvailabilityZone",
                .port = "Port",
                .manage_master_password = "ManageMasterPassword",
                .master_password_secret_kms_key_id = "MasterPasswordSecretKmsKeyId",
                .ip_address_type = "IpAddressType",
                .multi_az = "MultiAZ",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterAlreadyExists,
        ClusterNotFound,
        ClusterParameterGroupNotFound,
        ClusterSecurityGroupNotFound,
        CustomCnameAssociation,
        DependentServiceRequestThrottling,
        HsmClientCertificateNotFound,
        HsmConfigurationNotFound,
        InsufficientClusterCapacity,
        InvalidClusterSecurityGroupState,
        InvalidClusterState,
        InvalidClusterTrack,
        InvalidElasticIp,
        InvalidRetentionPeriod,
        Ipv6CidrBlockNotFound,
        LimitExceeded,
        NumberOfNodesPerClusterLimitExceeded,
        NumberOfNodesQuotaExceeded,
        TableLimitExceeded,
        UnauthorizedOperation,
        UnsupportedOperation,
        UnsupportedOption,
    },
} = .{};
pub const modify_cluster_db_revision: struct {
    action_name: []const u8 = "ModifyClusterDbRevision",
    Request: type = struct {
        cluster_identifier: []const u8,
        revision_target: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .revision_target = "RevisionTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_db_revision) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_db_revision };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterOnLatestRevision,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const modify_cluster_iam_roles: struct {
    action_name: []const u8 = "ModifyClusterIamRoles",
    Request: type = struct {
        cluster_identifier: []const u8,
        add_iam_roles: ?[][]const u8 = null,
        remove_iam_roles: ?[][]const u8 = null,
        default_iam_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .add_iam_roles = "AddIamRoles",
                .remove_iam_roles = "RemoveIamRoles",
                .default_iam_role_arn = "DefaultIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_iam_roles) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_iam_roles };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
    },
} = .{};
pub const modify_cluster_maintenance: struct {
    action_name: []const u8 = "ModifyClusterMaintenance",
    Request: type = struct {
        cluster_identifier: []const u8,
        defer_maintenance: ?bool = null,
        defer_maintenance_identifier: ?[]const u8 = null,
        defer_maintenance_start_time: ?i64 = null,
        defer_maintenance_end_time: ?i64 = null,
        defer_maintenance_duration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .defer_maintenance = "DeferMaintenance",
                .defer_maintenance_identifier = "DeferMaintenanceIdentifier",
                .defer_maintenance_start_time = "DeferMaintenanceStartTime",
                .defer_maintenance_end_time = "DeferMaintenanceEndTime",
                .defer_maintenance_duration = "DeferMaintenanceDuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_maintenance) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_maintenance };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
    },
} = .{};
pub const modify_cluster_parameter_group: struct {
    action_name: []const u8 = "ModifyClusterParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        parameters: []Parameter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group_name: ?[]const u8 = null,
        parameter_group_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameter_group_status = "ParameterGroupStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterParameterGroupNotFound,
        InvalidClusterParameterGroupState,
    },
} = .{};
pub const modify_cluster_snapshot: struct {
    action_name: []const u8 = "ModifyClusterSnapshot",
    Request: type = struct {
        snapshot_identifier: []const u8,
        manual_snapshot_retention_period: ?i64 = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier = "SnapshotIdentifier",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSnapshotNotFound,
        InvalidClusterSnapshotState,
        InvalidRetentionPeriod,
    },
} = .{};
pub const modify_cluster_snapshot_schedule: struct {
    action_name: []const u8 = "ModifyClusterSnapshotSchedule",
    Request: type = struct {
        cluster_identifier: []const u8,
        schedule_identifier: ?[]const u8 = null,
        disassociate_schedule: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .schedule_identifier = "ScheduleIdentifier",
                .disassociate_schedule = "DisassociateSchedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_snapshot_schedule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterSnapshotScheduleState,
        SnapshotScheduleNotFound,
    },
} = .{};
pub const modify_cluster_subnet_group: struct {
    action_name: []const u8 = "ModifyClusterSubnetGroup",
    Request: type = struct {
        cluster_subnet_group_name: []const u8,
        description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_cluster_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_cluster_subnet_group };
        }
    },
    Response: type = struct {
        cluster_subnet_group: ?ClusterSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_subnet_group = "ClusterSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterSubnetGroupNotFound,
        ClusterSubnetQuotaExceeded,
        DependentServiceRequestThrottling,
        InvalidSubnet,
        SubnetAlreadyInUse,
        UnauthorizedOperation,
    },
} = .{};
pub const modify_custom_domain_association: struct {
    action_name: []const u8 = "ModifyCustomDomainAssociation",
    Request: type = struct {
        custom_domain_name: []const u8,
        custom_domain_certificate_arn: []const u8,
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "CustomDomainName",
                .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = modify_custom_domain_association };
        }
    },
    Response: type = struct {
        custom_domain_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        custom_domain_cert_expiry_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "CustomDomainName",
                .custom_domain_certificate_arn = "CustomDomainCertificateArn",
                .cluster_identifier = "ClusterIdentifier",
                .custom_domain_cert_expiry_time = "CustomDomainCertExpiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        CustomCnameAssociation,
        CustomDomainAssociationNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const modify_endpoint_access: struct {
    action_name: []const u8 = "ModifyEndpointAccess",
    Request: type = struct {
        endpoint_name: []const u8,
        vpc_security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = modify_endpoint_access };
        }
    },
    Response: type = struct {
        cluster_identifier: ?[]const u8 = null,
        resource_owner: ?[]const u8 = null,
        subnet_group_name: ?[]const u8 = null,
        endpoint_status: ?[]const u8 = null,
        endpoint_name: ?[]const u8 = null,
        endpoint_create_time: ?i64 = null,
        port: ?i64 = null,
        address: ?[]const u8 = null,
        vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
        vpc_endpoint: ?VpcEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .resource_owner = "ResourceOwner",
                .subnet_group_name = "SubnetGroupName",
                .endpoint_status = "EndpointStatus",
                .endpoint_name = "EndpointName",
                .endpoint_create_time = "EndpointCreateTime",
                .port = "Port",
                .address = "Address",
                .vpc_security_groups = "VpcSecurityGroups",
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        EndpointNotFound,
        InvalidClusterSecurityGroupState,
        InvalidClusterState,
        InvalidEndpointState,
        UnauthorizedOperation,
    },
} = .{};
pub const modify_event_subscription: struct {
    action_name: []const u8 = "ModifyEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        source_ids: ?[][]const u8 = null,
        event_categories: ?[][]const u8 = null,
        severity: ?[]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .source_ids = "SourceIds",
                .event_categories = "EventCategories",
                .severity = "Severity",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = modify_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSubscriptionState,
        SNSInvalidTopic,
        SNSNoAuthorization,
        SNSTopicArnNotFound,
        SourceNotFound,
        SubscriptionCategoryNotFound,
        SubscriptionEventIdNotFound,
        SubscriptionNotFound,
        SubscriptionSeverityNotFound,
    },
} = .{};
pub const modify_redshift_idc_application: struct {
    action_name: []const u8 = "ModifyRedshiftIdcApplication",
    Request: type = struct {
        redshift_idc_application_arn: []const u8,
        identity_namespace: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,
        idc_display_name: ?[]const u8 = null,
        authorized_token_issuer_list: ?[]AuthorizedTokenIssuer = null,
        service_integrations: ?[]ServiceIntegrationsUnion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_application_arn = "RedshiftIdcApplicationArn",
                .identity_namespace = "IdentityNamespace",
                .iam_role_arn = "IamRoleArn",
                .idc_display_name = "IdcDisplayName",
                .authorized_token_issuer_list = "AuthorizedTokenIssuerList",
                .service_integrations = "ServiceIntegrations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_redshift_idc_application) } {
            return .{ .service_metadata = service_metadata, .action = modify_redshift_idc_application };
        }
    },
    Response: type = struct {
        redshift_idc_application: ?RedshiftIdcApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redshift_idc_application = "RedshiftIdcApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependentServiceAccessDenied,
        DependentServiceUnavailable,
        RedshiftIdcApplicationNotExists,
        UnsupportedOperation,
    },
} = .{};
pub const modify_scheduled_action: struct {
    action_name: []const u8 = "ModifyScheduledAction",
    Request: type = struct {
        scheduled_action_name: []const u8,
        target_action: ?ScheduledActionType = null,
        schedule: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,
        scheduled_action_description: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        enable: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
                .target_action = "TargetAction",
                .schedule = "Schedule",
                .iam_role = "IamRole",
                .scheduled_action_description = "ScheduledActionDescription",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .enable = "Enable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = modify_scheduled_action };
        }
    },
    Response: type = struct {
        scheduled_action_name: ?[]const u8 = null,
        target_action: ?ScheduledActionType = null,
        schedule: ?[]const u8 = null,
        iam_role: ?[]const u8 = null,
        scheduled_action_description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        next_invocations: ?[]i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action_name = "ScheduledActionName",
                .target_action = "TargetAction",
                .schedule = "Schedule",
                .iam_role = "IamRole",
                .scheduled_action_description = "ScheduledActionDescription",
                .state = "State",
                .next_invocations = "NextInvocations",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidScheduledAction,
        InvalidSchedule,
        ScheduledActionNotFound,
        ScheduledActionTypeUnsupported,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const modify_snapshot_copy_retention_period: struct {
    action_name: []const u8 = "ModifySnapshotCopyRetentionPeriod",
    Request: type = struct {
        cluster_identifier: []const u8,
        retention_period: i64,
        manual: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .retention_period = "RetentionPeriod",
                .manual = "Manual",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_snapshot_copy_retention_period) } {
            return .{ .service_metadata = service_metadata, .action = modify_snapshot_copy_retention_period };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidRetentionPeriod,
        SnapshotCopyDisabled,
        UnauthorizedOperation,
    },
} = .{};
pub const modify_snapshot_schedule: struct {
    action_name: []const u8 = "ModifySnapshotSchedule",
    Request: type = struct {
        schedule_identifier: []const u8,
        schedule_definitions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedule_identifier = "ScheduleIdentifier",
                .schedule_definitions = "ScheduleDefinitions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = modify_snapshot_schedule };
        }
    },
    Response: type = struct {
        schedule_definitions: ?[][]const u8 = null,
        schedule_identifier: ?[]const u8 = null,
        schedule_description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        next_invocations: ?[]i64 = null,
        associated_cluster_count: ?i64 = null,
        associated_clusters: ?[]ClusterAssociatedToSchedule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schedule_definitions = "ScheduleDefinitions",
                .schedule_identifier = "ScheduleIdentifier",
                .schedule_description = "ScheduleDescription",
                .tags = "Tags",
                .next_invocations = "NextInvocations",
                .associated_cluster_count = "AssociatedClusterCount",
                .associated_clusters = "AssociatedClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSchedule,
        SnapshotScheduleNotFound,
        SnapshotScheduleUpdateInProgress,
    },
} = .{};
pub const modify_usage_limit: struct {
    action_name: []const u8 = "ModifyUsageLimit",
    Request: type = struct {
        usage_limit_id: []const u8,
        amount: ?i64 = null,
        breach_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limit_id = "UsageLimitId",
                .amount = "Amount",
                .breach_action = "BreachAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_usage_limit) } {
            return .{ .service_metadata = service_metadata, .action = modify_usage_limit };
        }
    },
    Response: type = struct {
        usage_limit_id: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        feature_type: ?[]const u8 = null,
        limit_type: ?[]const u8 = null,
        amount: ?i64 = null,
        period: ?[]const u8 = null,
        breach_action: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_limit_id = "UsageLimitId",
                .cluster_identifier = "ClusterIdentifier",
                .feature_type = "FeatureType",
                .limit_type = "LimitType",
                .amount = "Amount",
                .period = "Period",
                .breach_action = "BreachAction",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidUsageLimit,
        UnsupportedOperation,
        UsageLimitNotFound,
    },
} = .{};
pub const pause_cluster: struct {
    action_name: []const u8 = "PauseCluster",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(pause_cluster) } {
            return .{ .service_metadata = service_metadata, .action = pause_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const purchase_reserved_node_offering: struct {
    action_name: []const u8 = "PurchaseReservedNodeOffering",
    Request: type = struct {
        reserved_node_offering_id: []const u8,
        node_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node_offering_id = "ReservedNodeOfferingId",
                .node_count = "NodeCount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_node_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_node_offering };
        }
    },
    Response: type = struct {
        reserved_node: ?ReservedNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node = "ReservedNode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ReservedNodeAlreadyExists,
        ReservedNodeOfferingNotFound,
        ReservedNodeQuotaExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictPolicyUpdate,
        InvalidPolicy,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const reboot_cluster: struct {
    action_name: []const u8 = "RebootCluster",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_cluster) } {
            return .{ .service_metadata = service_metadata, .action = reboot_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
    },
} = .{};
pub const reject_data_share: struct {
    action_name: []const u8 = "RejectDataShare",
    Request: type = struct {
        data_share_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_data_share) } {
            return .{ .service_metadata = service_metadata, .action = reject_data_share };
        }
    },
    Response: type = struct {
        data_share_arn: ?[]const u8 = null,
        producer_arn: ?[]const u8 = null,
        allow_publicly_accessible_consumers: ?bool = null,
        data_share_associations: ?[]DataShareAssociation = null,
        managed_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_share_arn = "DataShareArn",
                .producer_arn = "ProducerArn",
                .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
                .data_share_associations = "DataShareAssociations",
                .managed_by = "ManagedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDataShare,
    },
} = .{};
pub const reset_cluster_parameter_group: struct {
    action_name: []const u8 = "ResetClusterParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        reset_all_parameters: ?bool = null,
        parameters: ?[]Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .reset_all_parameters = "ResetAllParameters",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_cluster_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_cluster_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group_name: ?[]const u8 = null,
        parameter_group_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameter_group_status = "ParameterGroupStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterParameterGroupNotFound,
        InvalidClusterParameterGroupState,
    },
} = .{};
pub const resize_cluster: struct {
    action_name: []const u8 = "ResizeCluster",
    Request: type = struct {
        cluster_identifier: []const u8,
        cluster_type: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        number_of_nodes: ?i64 = null,
        classic: ?bool = null,
        reserved_node_id: ?[]const u8 = null,
        target_reserved_node_offering_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .cluster_type = "ClusterType",
                .node_type = "NodeType",
                .number_of_nodes = "NumberOfNodes",
                .classic = "Classic",
                .reserved_node_id = "ReservedNodeId",
                .target_reserved_node_offering_id = "TargetReservedNodeOfferingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resize_cluster) } {
            return .{ .service_metadata = service_metadata, .action = resize_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        DependentServiceUnavailable,
        InsufficientClusterCapacity,
        InvalidClusterState,
        InvalidReservedNodeState,
        LimitExceeded,
        NumberOfNodesPerClusterLimitExceeded,
        NumberOfNodesQuotaExceeded,
        ReservedNodeAlreadyExists,
        ReservedNodeAlreadyMigrated,
        ReservedNodeNotFound,
        ReservedNodeOfferingNotFound,
        UnauthorizedOperation,
        UnsupportedOperation,
        UnsupportedOption,
    },
} = .{};
pub const restore_from_cluster_snapshot: struct {
    action_name: []const u8 = "RestoreFromClusterSnapshot",
    Request: type = struct {
        cluster_identifier: []const u8,
        snapshot_identifier: ?[]const u8 = null,
        snapshot_arn: ?[]const u8 = null,
        snapshot_cluster_identifier: ?[]const u8 = null,
        port: ?i64 = null,
        availability_zone: ?[]const u8 = null,
        allow_version_upgrade: ?bool = null,
        cluster_subnet_group_name: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        owner_account: ?[]const u8 = null,
        hsm_client_certificate_identifier: ?[]const u8 = null,
        hsm_configuration_identifier: ?[]const u8 = null,
        elastic_ip: ?[]const u8 = null,
        cluster_parameter_group_name: ?[]const u8 = null,
        cluster_security_groups: ?[][]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        automated_snapshot_retention_period: ?i64 = null,
        manual_snapshot_retention_period: ?i64 = null,
        kms_key_id: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        enhanced_vpc_routing: ?bool = null,
        additional_info: ?[]const u8 = null,
        iam_roles: ?[][]const u8 = null,
        maintenance_track_name: ?[]const u8 = null,
        snapshot_schedule_identifier: ?[]const u8 = null,
        number_of_nodes: ?i64 = null,
        availability_zone_relocation: ?bool = null,
        aqua_configuration_status: ?[]const u8 = null,
        default_iam_role_arn: ?[]const u8 = null,
        reserved_node_id: ?[]const u8 = null,
        target_reserved_node_offering_id: ?[]const u8 = null,
        encrypted: ?bool = null,
        manage_master_password: ?bool = null,
        master_password_secret_kms_key_id: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        multi_az: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_arn = "SnapshotArn",
                .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
                .port = "Port",
                .availability_zone = "AvailabilityZone",
                .allow_version_upgrade = "AllowVersionUpgrade",
                .cluster_subnet_group_name = "ClusterSubnetGroupName",
                .publicly_accessible = "PubliclyAccessible",
                .owner_account = "OwnerAccount",
                .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
                .hsm_configuration_identifier = "HsmConfigurationIdentifier",
                .elastic_ip = "ElasticIp",
                .cluster_parameter_group_name = "ClusterParameterGroupName",
                .cluster_security_groups = "ClusterSecurityGroups",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
                .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
                .kms_key_id = "KmsKeyId",
                .node_type = "NodeType",
                .enhanced_vpc_routing = "EnhancedVpcRouting",
                .additional_info = "AdditionalInfo",
                .iam_roles = "IamRoles",
                .maintenance_track_name = "MaintenanceTrackName",
                .snapshot_schedule_identifier = "SnapshotScheduleIdentifier",
                .number_of_nodes = "NumberOfNodes",
                .availability_zone_relocation = "AvailabilityZoneRelocation",
                .aqua_configuration_status = "AquaConfigurationStatus",
                .default_iam_role_arn = "DefaultIamRoleArn",
                .reserved_node_id = "ReservedNodeId",
                .target_reserved_node_offering_id = "TargetReservedNodeOfferingId",
                .encrypted = "Encrypted",
                .manage_master_password = "ManageMasterPassword",
                .master_password_secret_kms_key_id = "MasterPasswordSecretKmsKeyId",
                .ip_address_type = "IpAddressType",
                .multi_az = "MultiAZ",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_from_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_from_cluster_snapshot };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessToSnapshotDenied,
        ClusterAlreadyExists,
        ClusterParameterGroupNotFound,
        ClusterQuotaExceeded,
        ClusterSecurityGroupNotFound,
        ClusterSnapshotNotFound,
        ClusterSubnetGroupNotFound,
        DependentServiceRequestThrottling,
        DependentServiceUnavailable,
        HsmClientCertificateNotFound,
        HsmConfigurationNotFound,
        InsufficientClusterCapacity,
        InvalidClusterSnapshotState,
        InvalidClusterSubnetGroupState,
        InvalidClusterTrack,
        InvalidElasticIp,
        InvalidReservedNodeState,
        InvalidRestore,
        InvalidSubnet,
        InvalidTag,
        InvalidVPCNetworkState,
        Ipv6CidrBlockNotFound,
        LimitExceeded,
        NumberOfNodesPerClusterLimitExceeded,
        NumberOfNodesQuotaExceeded,
        ReservedNodeAlreadyExists,
        ReservedNodeAlreadyMigrated,
        ReservedNodeNotFound,
        ReservedNodeOfferingNotFound,
        SnapshotScheduleNotFound,
        TagLimitExceeded,
        UnauthorizedOperation,
        UnsupportedOperation,
    },
} = .{};
pub const restore_table_from_cluster_snapshot: struct {
    action_name: []const u8 = "RestoreTableFromClusterSnapshot",
    Request: type = struct {
        cluster_identifier: []const u8,
        snapshot_identifier: []const u8,
        source_database_name: []const u8,
        source_schema_name: ?[]const u8 = null,
        source_table_name: []const u8,
        target_database_name: ?[]const u8 = null,
        target_schema_name: ?[]const u8 = null,
        new_table_name: []const u8,
        enable_case_sensitive_identifier: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .snapshot_identifier = "SnapshotIdentifier",
                .source_database_name = "SourceDatabaseName",
                .source_schema_name = "SourceSchemaName",
                .source_table_name = "SourceTableName",
                .target_database_name = "TargetDatabaseName",
                .target_schema_name = "TargetSchemaName",
                .new_table_name = "NewTableName",
                .enable_case_sensitive_identifier = "EnableCaseSensitiveIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_table_from_cluster_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = restore_table_from_cluster_snapshot };
        }
    },
    Response: type = struct {
        table_restore_status: ?TableRestoreStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_restore_status = "TableRestoreStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        ClusterSnapshotNotFound,
        InProgressTableRestoreQuotaExceeded,
        InvalidClusterSnapshotState,
        InvalidClusterState,
        InvalidTableRestoreArgument,
        UnsupportedOperation,
    },
} = .{};
pub const resume_cluster: struct {
    action_name: []const u8 = "ResumeCluster",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_cluster) } {
            return .{ .service_metadata = service_metadata, .action = resume_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InsufficientClusterCapacity,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const revoke_cluster_security_group_ingress: struct {
    action_name: []const u8 = "RevokeClusterSecurityGroupIngress",
    Request: type = struct {
        cluster_security_group_name: []const u8,
        cidrip: ?[]const u8 = null,
        ec2_security_group_name: ?[]const u8 = null,
        ec2_security_group_owner_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group_name = "ClusterSecurityGroupName",
                .cidrip = "CIDRIP",
                .ec2_security_group_name = "EC2SecurityGroupName",
                .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_cluster_security_group_ingress) } {
            return .{ .service_metadata = service_metadata, .action = revoke_cluster_security_group_ingress };
        }
    },
    Response: type = struct {
        cluster_security_group: ?ClusterSecurityGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_security_group = "ClusterSecurityGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationNotFound,
        ClusterSecurityGroupNotFound,
        InvalidClusterSecurityGroupState,
    },
} = .{};
pub const revoke_endpoint_access: struct {
    action_name: []const u8 = "RevokeEndpointAccess",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        account: ?[]const u8 = null,
        vpc_ids: ?[][]const u8 = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .account = "Account",
                .vpc_ids = "VpcIds",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = revoke_endpoint_access };
        }
    },
    Response: type = struct {
        grantor: ?[]const u8 = null,
        grantee: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        authorize_time: ?i64 = null,
        cluster_status: ?[]const u8 = null,
        status: ?[]const u8 = null,
        allowed_all_vp_cs: ?bool = null,
        allowed_vp_cs: ?[][]const u8 = null,
        endpoint_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grantor = "Grantor",
                .grantee = "Grantee",
                .cluster_identifier = "ClusterIdentifier",
                .authorize_time = "AuthorizeTime",
                .cluster_status = "ClusterStatus",
                .status = "Status",
                .allowed_all_vp_cs = "AllowedAllVPCs",
                .allowed_vp_cs = "AllowedVPCs",
                .endpoint_count = "EndpointCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        EndpointAuthorizationNotFound,
        EndpointNotFound,
        InvalidAuthorizationState,
        InvalidClusterSecurityGroupState,
        InvalidClusterState,
        InvalidEndpointState,
    },
} = .{};
pub const revoke_snapshot_access: struct {
    action_name: []const u8 = "RevokeSnapshotAccess",
    Request: type = struct {
        snapshot_identifier: ?[]const u8 = null,
        snapshot_arn: ?[]const u8 = null,
        snapshot_cluster_identifier: ?[]const u8 = null,
        account_with_restore_access: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_identifier = "SnapshotIdentifier",
                .snapshot_arn = "SnapshotArn",
                .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
                .account_with_restore_access = "AccountWithRestoreAccess",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_snapshot_access) } {
            return .{ .service_metadata = service_metadata, .action = revoke_snapshot_access };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessToSnapshotDenied,
        AuthorizationNotFound,
        ClusterSnapshotNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const rotate_encryption_key: struct {
    action_name: []const u8 = "RotateEncryptionKey",
    Request: type = struct {
        cluster_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rotate_encryption_key) } {
            return .{ .service_metadata = service_metadata, .action = rotate_encryption_key };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        DependentServiceRequestThrottling,
        InvalidClusterState,
        UnsupportedOperation,
    },
} = .{};
pub const update_partner_status: struct {
    action_name: []const u8 = "UpdatePartnerStatus",
    Request: type = struct {
        account_id: []const u8,
        cluster_identifier: []const u8,
        database_name: []const u8,
        partner_name: []const u8,
        status: []const u8,
        status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .cluster_identifier = "ClusterIdentifier",
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
                .status = "Status",
                .status_message = "StatusMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_partner_status) } {
            return .{ .service_metadata = service_metadata, .action = update_partner_status };
        }
    },
    Response: type = struct {
        database_name: ?[]const u8 = null,
        partner_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .partner_name = "PartnerName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        PartnerNotFound,
        UnauthorizedPartnerIntegration,
        UnsupportedOperation,
    },
} = .{};

pub const Cluster = struct {
    cluster_identifier: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    cluster_status: ?[]const u8 = null,
    cluster_availability_status: ?[]const u8 = null,
    modify_status: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    endpoint: ?Endpoint = null,
    cluster_create_time: ?i64 = null,
    automated_snapshot_retention_period: ?i64 = null,
    manual_snapshot_retention_period: ?i64 = null,
    cluster_security_groups: ?[]ClusterSecurityGroupMembership = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    cluster_parameter_groups: ?[]ClusterParameterGroupStatus = null,
    cluster_subnet_group_name: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?PendingModifiedValues = null,
    cluster_version: ?[]const u8 = null,
    allow_version_upgrade: ?bool = null,
    number_of_nodes: ?i64 = null,
    publicly_accessible: ?bool = null,
    encrypted: ?bool = null,
    restore_status: ?RestoreStatus = null,
    data_transfer_progress: ?DataTransferProgress = null,
    hsm_status: ?HsmStatus = null,
    cluster_snapshot_copy_status: ?ClusterSnapshotCopyStatus = null,
    cluster_public_key: ?[]const u8 = null,
    cluster_nodes: ?[]ClusterNode = null,
    elastic_ip_status: ?ElasticIpStatus = null,
    cluster_revision_number: ?[]const u8 = null,
    tags: ?[]Tag = null,
    kms_key_id: ?[]const u8 = null,
    enhanced_vpc_routing: ?bool = null,
    iam_roles: ?[]ClusterIamRole = null,
    pending_actions: ?[][]const u8 = null,
    maintenance_track_name: ?[]const u8 = null,
    elastic_resize_number_of_node_options: ?[]const u8 = null,
    deferred_maintenance_windows: ?[]DeferredMaintenanceWindow = null,
    snapshot_schedule_identifier: ?[]const u8 = null,
    snapshot_schedule_state: ?[]const u8 = null,
    expected_next_snapshot_schedule_time: ?i64 = null,
    expected_next_snapshot_schedule_time_status: ?[]const u8 = null,
    next_maintenance_window_start_time: ?i64 = null,
    resize_info: ?ResizeInfo = null,
    availability_zone_relocation_status: ?[]const u8 = null,
    cluster_namespace_arn: ?[]const u8 = null,
    total_storage_capacity_in_mega_bytes: ?i64 = null,
    aqua_configuration: ?AquaConfiguration = null,
    default_iam_role_arn: ?[]const u8 = null,
    reserved_node_exchange_status: ?ReservedNodeExchangeStatus = null,
    custom_domain_name: ?[]const u8 = null,
    custom_domain_certificate_arn: ?[]const u8 = null,
    custom_domain_certificate_expiry_date: ?i64 = null,
    master_password_secret_arn: ?[]const u8 = null,
    master_password_secret_kms_key_id: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    multi_az: ?[]const u8 = null,
    multi_az_secondary: ?SecondaryClusterInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
            .node_type = "NodeType",
            .cluster_status = "ClusterStatus",
            .cluster_availability_status = "ClusterAvailabilityStatus",
            .modify_status = "ModifyStatus",
            .master_username = "MasterUsername",
            .db_name = "DBName",
            .endpoint = "Endpoint",
            .cluster_create_time = "ClusterCreateTime",
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .cluster_security_groups = "ClusterSecurityGroups",
            .vpc_security_groups = "VpcSecurityGroups",
            .cluster_parameter_groups = "ClusterParameterGroups",
            .cluster_subnet_group_name = "ClusterSubnetGroupName",
            .vpc_id = "VpcId",
            .availability_zone = "AvailabilityZone",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .cluster_version = "ClusterVersion",
            .allow_version_upgrade = "AllowVersionUpgrade",
            .number_of_nodes = "NumberOfNodes",
            .publicly_accessible = "PubliclyAccessible",
            .encrypted = "Encrypted",
            .restore_status = "RestoreStatus",
            .data_transfer_progress = "DataTransferProgress",
            .hsm_status = "HsmStatus",
            .cluster_snapshot_copy_status = "ClusterSnapshotCopyStatus",
            .cluster_public_key = "ClusterPublicKey",
            .cluster_nodes = "ClusterNodes",
            .elastic_ip_status = "ElasticIpStatus",
            .cluster_revision_number = "ClusterRevisionNumber",
            .tags = "Tags",
            .kms_key_id = "KmsKeyId",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .iam_roles = "IamRoles",
            .pending_actions = "PendingActions",
            .maintenance_track_name = "MaintenanceTrackName",
            .elastic_resize_number_of_node_options = "ElasticResizeNumberOfNodeOptions",
            .deferred_maintenance_windows = "DeferredMaintenanceWindows",
            .snapshot_schedule_identifier = "SnapshotScheduleIdentifier",
            .snapshot_schedule_state = "SnapshotScheduleState",
            .expected_next_snapshot_schedule_time = "ExpectedNextSnapshotScheduleTime",
            .expected_next_snapshot_schedule_time_status = "ExpectedNextSnapshotScheduleTimeStatus",
            .next_maintenance_window_start_time = "NextMaintenanceWindowStartTime",
            .resize_info = "ResizeInfo",
            .availability_zone_relocation_status = "AvailabilityZoneRelocationStatus",
            .cluster_namespace_arn = "ClusterNamespaceArn",
            .total_storage_capacity_in_mega_bytes = "TotalStorageCapacityInMegaBytes",
            .aqua_configuration = "AquaConfiguration",
            .default_iam_role_arn = "DefaultIamRoleArn",
            .reserved_node_exchange_status = "ReservedNodeExchangeStatus",
            .custom_domain_name = "CustomDomainName",
            .custom_domain_certificate_arn = "CustomDomainCertificateArn",
            .custom_domain_certificate_expiry_date = "CustomDomainCertificateExpiryDate",
            .master_password_secret_arn = "MasterPasswordSecretArn",
            .master_password_secret_kms_key_id = "MasterPasswordSecretKmsKeyId",
            .ip_address_type = "IpAddressType",
            .multi_az = "MultiAZ",
            .multi_az_secondary = "MultiAZSecondary",
        };
        return @field(mappings, field_name);
    }
};

pub const SecondaryClusterInfo = struct {
    availability_zone: ?[]const u8 = null,
    cluster_nodes: ?[]ClusterNode = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "AvailabilityZone",
            .cluster_nodes = "ClusterNodes",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterNode = struct {
    node_role: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    public_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_role = "NodeRole",
            .private_ip_address = "PrivateIPAddress",
            .public_ip_address = "PublicIPAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedNodeExchangeStatus = struct {
    reserved_node_exchange_request_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    request_time: ?i64 = null,
    source_reserved_node_id: ?[]const u8 = null,
    source_reserved_node_type: ?[]const u8 = null,
    source_reserved_node_count: ?i64 = null,
    target_reserved_node_offering_id: ?[]const u8 = null,
    target_reserved_node_type: ?[]const u8 = null,
    target_reserved_node_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_node_exchange_request_id = "ReservedNodeExchangeRequestId",
            .status = "Status",
            .request_time = "RequestTime",
            .source_reserved_node_id = "SourceReservedNodeId",
            .source_reserved_node_type = "SourceReservedNodeType",
            .source_reserved_node_count = "SourceReservedNodeCount",
            .target_reserved_node_offering_id = "TargetReservedNodeOfferingId",
            .target_reserved_node_type = "TargetReservedNodeType",
            .target_reserved_node_count = "TargetReservedNodeCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AquaConfiguration = struct {
    aqua_status: ?[]const u8 = null,
    aqua_configuration_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aqua_status = "AquaStatus",
            .aqua_configuration_status = "AquaConfigurationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ResizeInfo = struct {
    resize_type: ?[]const u8 = null,
    allow_cancel_resize: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resize_type = "ResizeType",
            .allow_cancel_resize = "AllowCancelResize",
        };
        return @field(mappings, field_name);
    }
};

pub const DeferredMaintenanceWindow = struct {
    defer_maintenance_identifier: ?[]const u8 = null,
    defer_maintenance_start_time: ?i64 = null,
    defer_maintenance_end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .defer_maintenance_identifier = "DeferMaintenanceIdentifier",
            .defer_maintenance_start_time = "DeferMaintenanceStartTime",
            .defer_maintenance_end_time = "DeferMaintenanceEndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterIamRole = struct {
    iam_role_arn: ?[]const u8 = null,
    apply_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .apply_status = "ApplyStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticIpStatus = struct {
    elastic_ip: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elastic_ip = "ElasticIp",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSnapshotCopyStatus = struct {
    destination_region: ?[]const u8 = null,
    retention_period: ?i64 = null,
    manual_snapshot_retention_period: ?i64 = null,
    snapshot_copy_grant_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_region = "DestinationRegion",
            .retention_period = "RetentionPeriod",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .snapshot_copy_grant_name = "SnapshotCopyGrantName",
        };
        return @field(mappings, field_name);
    }
};

pub const HsmStatus = struct {
    hsm_client_certificate_identifier: ?[]const u8 = null,
    hsm_configuration_identifier: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
            .hsm_configuration_identifier = "HsmConfigurationIdentifier",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DataTransferProgress = struct {
    status: ?[]const u8 = null,
    current_rate_in_mega_bytes_per_second: ?f64 = null,
    total_data_in_mega_bytes: ?i64 = null,
    data_transferred_in_mega_bytes: ?i64 = null,
    estimated_time_to_completion_in_seconds: ?i64 = null,
    elapsed_time_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .current_rate_in_mega_bytes_per_second = "CurrentRateInMegaBytesPerSecond",
            .total_data_in_mega_bytes = "TotalDataInMegaBytes",
            .data_transferred_in_mega_bytes = "DataTransferredInMegaBytes",
            .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
            .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreStatus = struct {
    status: ?[]const u8 = null,
    current_restore_rate_in_mega_bytes_per_second: ?f64 = null,
    snapshot_size_in_mega_bytes: ?i64 = null,
    progress_in_mega_bytes: ?i64 = null,
    elapsed_time_in_seconds: ?i64 = null,
    estimated_time_to_completion_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .current_restore_rate_in_mega_bytes_per_second = "CurrentRestoreRateInMegaBytesPerSecond",
            .snapshot_size_in_mega_bytes = "SnapshotSizeInMegaBytes",
            .progress_in_mega_bytes = "ProgressInMegaBytes",
            .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
            .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingModifiedValues = struct {
    master_user_password: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    cluster_type: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    automated_snapshot_retention_period: ?i64 = null,
    cluster_identifier: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    enhanced_vpc_routing: ?bool = null,
    maintenance_track_name: ?[]const u8 = null,
    encryption_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .master_user_password = "MasterUserPassword",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .cluster_type = "ClusterType",
            .cluster_version = "ClusterVersion",
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .cluster_identifier = "ClusterIdentifier",
            .publicly_accessible = "PubliclyAccessible",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .maintenance_track_name = "MaintenanceTrackName",
            .encryption_type = "EncryptionType",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterParameterGroupStatus = struct {
    parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    cluster_parameter_status_list: ?[]ClusterParameterStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_group_name = "ParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
            .cluster_parameter_status_list = "ClusterParameterStatusList",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterParameterStatus = struct {
    parameter_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    parameter_apply_error_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_apply_status = "ParameterApplyStatus",
            .parameter_apply_error_description = "ParameterApplyErrorDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcSecurityGroupMembership = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSecurityGroupMembership = struct {
    cluster_security_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_security_group_name = "ClusterSecurityGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_endpoints: ?[]VpcEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .vpc_endpoints = "VpcEndpoints",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpoint = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    network_interfaces: ?[]NetworkInterface = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_id = "VpcId",
            .network_interfaces = "NetworkInterfaces",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    network_interface_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    ipv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_id = "NetworkInterfaceId",
            .subnet_id = "SubnetId",
            .private_ip_address = "PrivateIpAddress",
            .availability_zone = "AvailabilityZone",
            .ipv6_address = "Ipv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    snapshot_identifier: ?[]const u8 = null,
    cluster_identifier: ?[]const u8 = null,
    snapshot_create_time: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    cluster_create_time: ?i64 = null,
    master_username: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    engine_full_version: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    db_name: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    encrypted_with_hsm: ?bool = null,
    accounts_with_restore_access: ?[]AccountWithRestoreAccess = null,
    owner_account: ?[]const u8 = null,
    total_backup_size_in_mega_bytes: ?f64 = null,
    actual_incremental_backup_size_in_mega_bytes: ?f64 = null,
    backup_progress_in_mega_bytes: ?f64 = null,
    current_backup_rate_in_mega_bytes_per_second: ?f64 = null,
    estimated_seconds_to_completion: ?i64 = null,
    elapsed_time_in_seconds: ?i64 = null,
    source_region: ?[]const u8 = null,
    tags: ?[]Tag = null,
    restorable_node_types: ?[][]const u8 = null,
    enhanced_vpc_routing: ?bool = null,
    maintenance_track_name: ?[]const u8 = null,
    manual_snapshot_retention_period: ?i64 = null,
    manual_snapshot_remaining_days: ?i64 = null,
    snapshot_retention_start_time: ?i64 = null,
    master_password_secret_arn: ?[]const u8 = null,
    master_password_secret_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_identifier = "SnapshotIdentifier",
            .cluster_identifier = "ClusterIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .status = "Status",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
            .cluster_create_time = "ClusterCreateTime",
            .master_username = "MasterUsername",
            .cluster_version = "ClusterVersion",
            .engine_full_version = "EngineFullVersion",
            .snapshot_type = "SnapshotType",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .db_name = "DBName",
            .vpc_id = "VpcId",
            .encrypted = "Encrypted",
            .kms_key_id = "KmsKeyId",
            .encrypted_with_hsm = "EncryptedWithHSM",
            .accounts_with_restore_access = "AccountsWithRestoreAccess",
            .owner_account = "OwnerAccount",
            .total_backup_size_in_mega_bytes = "TotalBackupSizeInMegaBytes",
            .actual_incremental_backup_size_in_mega_bytes = "ActualIncrementalBackupSizeInMegaBytes",
            .backup_progress_in_mega_bytes = "BackupProgressInMegaBytes",
            .current_backup_rate_in_mega_bytes_per_second = "CurrentBackupRateInMegaBytesPerSecond",
            .estimated_seconds_to_completion = "EstimatedSecondsToCompletion",
            .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
            .source_region = "SourceRegion",
            .tags = "Tags",
            .restorable_node_types = "RestorableNodeTypes",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .maintenance_track_name = "MaintenanceTrackName",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .manual_snapshot_remaining_days = "ManualSnapshotRemainingDays",
            .snapshot_retention_start_time = "SnapshotRetentionStartTime",
            .master_password_secret_arn = "MasterPasswordSecretArn",
            .master_password_secret_kms_key_id = "MasterPasswordSecretKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountWithRestoreAccess = struct {
    account_id: ?[]const u8 = null,
    account_alias: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .account_alias = "AccountAlias",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSecurityGroup = struct {
    cluster_security_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    ec2_security_groups: ?[]EC2SecurityGroup = null,
    ip_ranges: ?[]IPRange = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_security_group_name = "ClusterSecurityGroupName",
            .description = "Description",
            .ec2_security_groups = "EC2SecurityGroups",
            .ip_ranges = "IPRanges",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const IPRange = struct {
    status: ?[]const u8 = null,
    cidrip: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .cidrip = "CIDRIP",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2SecurityGroup = struct {
    status: ?[]const u8 = null,
    ec2_security_group_name: ?[]const u8 = null,
    ec2_security_group_owner_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .ec2_security_group_name = "EC2SecurityGroupName",
            .ec2_security_group_owner_id = "EC2SecurityGroupOwnerId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const TableRestoreStatus = struct {
    table_restore_request_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,
    request_time: ?i64 = null,
    progress_in_mega_bytes: ?i64 = null,
    total_data_in_mega_bytes: ?i64 = null,
    cluster_identifier: ?[]const u8 = null,
    snapshot_identifier: ?[]const u8 = null,
    source_database_name: ?[]const u8 = null,
    source_schema_name: ?[]const u8 = null,
    source_table_name: ?[]const u8 = null,
    target_database_name: ?[]const u8 = null,
    target_schema_name: ?[]const u8 = null,
    new_table_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_restore_request_id = "TableRestoreRequestId",
            .status = "Status",
            .message = "Message",
            .request_time = "RequestTime",
            .progress_in_mega_bytes = "ProgressInMegaBytes",
            .total_data_in_mega_bytes = "TotalDataInMegaBytes",
            .cluster_identifier = "ClusterIdentifier",
            .snapshot_identifier = "SnapshotIdentifier",
            .source_database_name = "SourceDatabaseName",
            .source_schema_name = "SourceSchemaName",
            .source_table_name = "SourceTableName",
            .target_database_name = "TargetDatabaseName",
            .target_schema_name = "TargetSchemaName",
            .new_table_name = "NewTableName",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    source: ?[]const u8 = null,
    data_type: ?[]const u8 = null,
    allowed_values: ?[]const u8 = null,
    apply_type: ?[]const u8 = null,
    is_modifiable: ?bool = null,
    minimum_engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
            .description = "Description",
            .source = "Source",
            .data_type = "DataType",
            .allowed_values = "AllowedValues",
            .apply_type = "ApplyType",
            .is_modifiable = "IsModifiable",
            .minimum_engine_version = "MinimumEngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const DataShareAssociation = struct {
    consumer_identifier: ?[]const u8 = null,
    status: ?[]const u8 = null,
    consumer_region: ?[]const u8 = null,
    created_date: ?i64 = null,
    status_change_date: ?i64 = null,
    producer_allowed_writes: ?bool = null,
    consumer_accepted_writes: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .consumer_identifier = "ConsumerIdentifier",
            .status = "Status",
            .consumer_region = "ConsumerRegion",
            .created_date = "CreatedDate",
            .status_change_date = "StatusChangeDate",
            .producer_allowed_writes = "ProducerAllowedWrites",
            .consumer_accepted_writes = "ConsumerAcceptedWrites",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicy = struct {
    resource_arn: ?[]const u8 = null,
    policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .policy = "Policy",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedNode = struct {
    reserved_node_id: ?[]const u8 = null,
    reserved_node_offering_id: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    start_time: ?i64 = null,
    duration: ?i64 = null,
    fixed_price: ?f64 = null,
    usage_price: ?f64 = null,
    currency_code: ?[]const u8 = null,
    node_count: ?i64 = null,
    state: ?[]const u8 = null,
    offering_type: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,
    reserved_node_offering_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_node_id = "ReservedNodeId",
            .reserved_node_offering_id = "ReservedNodeOfferingId",
            .node_type = "NodeType",
            .start_time = "StartTime",
            .duration = "Duration",
            .fixed_price = "FixedPrice",
            .usage_price = "UsagePrice",
            .currency_code = "CurrencyCode",
            .node_count = "NodeCount",
            .state = "State",
            .offering_type = "OfferingType",
            .recurring_charges = "RecurringCharges",
            .reserved_node_offering_type = "ReservedNodeOfferingType",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterAssociatedToSchedule = struct {
    cluster_identifier: ?[]const u8 = null,
    schedule_association_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
            .schedule_association_state = "ScheduleAssociationState",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledActionType = struct {
    resize_cluster: ?ResizeClusterMessage = null,
    pause_cluster: ?PauseClusterMessage = null,
    resume_cluster: ?ResumeClusterMessage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resize_cluster = "ResizeCluster",
            .pause_cluster = "PauseCluster",
            .resume_cluster = "ResumeCluster",
        };
        return @field(mappings, field_name);
    }
};

pub const ResumeClusterMessage = struct {
    cluster_identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const PauseClusterMessage = struct {
    cluster_identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ResizeClusterMessage = struct {
    cluster_identifier: []const u8,
    cluster_type: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    classic: ?bool = null,
    reserved_node_id: ?[]const u8 = null,
    target_reserved_node_offering_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
            .cluster_type = "ClusterType",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .classic = "Classic",
            .reserved_node_id = "ReservedNodeId",
            .target_reserved_node_offering_id = "TargetReservedNodeOfferingId",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftIdcApplication = struct {
    idc_instance_arn: ?[]const u8 = null,
    redshift_idc_application_name: ?[]const u8 = null,
    redshift_idc_application_arn: ?[]const u8 = null,
    identity_namespace: ?[]const u8 = null,
    idc_display_name: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,
    idc_managed_application_arn: ?[]const u8 = null,
    idc_onboard_status: ?[]const u8 = null,
    authorized_token_issuer_list: ?[]AuthorizedTokenIssuer = null,
    service_integrations: ?[]ServiceIntegrationsUnion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idc_instance_arn = "IdcInstanceArn",
            .redshift_idc_application_name = "RedshiftIdcApplicationName",
            .redshift_idc_application_arn = "RedshiftIdcApplicationArn",
            .identity_namespace = "IdentityNamespace",
            .idc_display_name = "IdcDisplayName",
            .iam_role_arn = "IamRoleArn",
            .idc_managed_application_arn = "IdcManagedApplicationArn",
            .idc_onboard_status = "IdcOnboardStatus",
            .authorized_token_issuer_list = "AuthorizedTokenIssuerList",
            .service_integrations = "ServiceIntegrations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceIntegrationsUnion = union {
    lake_formation: ?[]LakeFormationScopeUnion,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lake_formation = "LakeFormation",
        };
        return @field(mappings, field_name);
    }
};

pub const LakeFormationScopeUnion = union {
    lake_formation_query: ?LakeFormationQuery,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lake_formation_query = "LakeFormationQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const LakeFormationQuery = struct {
    authorization: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorization = "Authorization",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizedTokenIssuer = struct {
    trusted_token_issuer_arn: ?[]const u8 = null,
    authorized_audiences_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
            .authorized_audiences_list = "AuthorizedAudiencesList",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSubscription = struct {
    customer_aws_id: ?[]const u8 = null,
    cust_subscription_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?i64 = null,
    source_type: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    event_categories_list: ?[][]const u8 = null,
    severity: ?[]const u8 = null,
    enabled: ?bool = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_aws_id = "CustomerAwsId",
            .cust_subscription_id = "CustSubscriptionId",
            .sns_topic_arn = "SnsTopicArn",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
            .source_type = "SourceType",
            .source_ids_list = "SourceIdsList",
            .event_categories_list = "EventCategoriesList",
            .severity = "Severity",
            .enabled = "Enabled",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterSubnetGroup = struct {
    cluster_subnet_group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    tags: ?[]Tag = null,
    supported_cluster_ip_address_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_subnet_group_name = "ClusterSubnetGroupName",
            .description = "Description",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .tags = "Tags",
            .supported_cluster_ip_address_types = "SupportedClusterIpAddressTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,
    supported_platforms: ?[]SupportedPlatform = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .supported_platforms = "SupportedPlatforms",
        };
        return @field(mappings, field_name);
    }
};

pub const SupportedPlatform = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedNodeOffering = struct {
    reserved_node_offering_id: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    duration: ?i64 = null,
    fixed_price: ?f64 = null,
    usage_price: ?f64 = null,
    currency_code: ?[]const u8 = null,
    offering_type: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,
    reserved_node_offering_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_node_offering_id = "ReservedNodeOfferingId",
            .node_type = "NodeType",
            .duration = "Duration",
            .fixed_price = "FixedPrice",
            .usage_price = "UsagePrice",
            .currency_code = "CurrencyCode",
            .offering_type = "OfferingType",
            .recurring_charges = "RecurringCharges",
            .reserved_node_offering_type = "ReservedNodeOfferingType",
        };
        return @field(mappings, field_name);
    }
};

pub const UsageLimit = struct {
    usage_limit_id: ?[]const u8 = null,
    cluster_identifier: ?[]const u8 = null,
    feature_type: ?[]const u8 = null,
    limit_type: ?[]const u8 = null,
    amount: ?i64 = null,
    period: ?[]const u8 = null,
    breach_action: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .usage_limit_id = "UsageLimitId",
            .cluster_identifier = "ClusterIdentifier",
            .feature_type = "FeatureType",
            .limit_type = "LimitType",
            .amount = "Amount",
            .period = "Period",
            .breach_action = "BreachAction",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotSchedule = struct {
    schedule_definitions: ?[][]const u8 = null,
    schedule_identifier: ?[]const u8 = null,
    schedule_description: ?[]const u8 = null,
    tags: ?[]Tag = null,
    next_invocations: ?[]i64 = null,
    associated_cluster_count: ?i64 = null,
    associated_clusters: ?[]ClusterAssociatedToSchedule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_definitions = "ScheduleDefinitions",
            .schedule_identifier = "ScheduleIdentifier",
            .schedule_description = "ScheduleDescription",
            .tags = "Tags",
            .next_invocations = "NextInvocations",
            .associated_cluster_count = "AssociatedClusterCount",
            .associated_clusters = "AssociatedClusters",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotCopyGrant = struct {
    snapshot_copy_grant_name: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_copy_grant_name = "SnapshotCopyGrantName",
            .kms_key_id = "KmsKeyId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledAction = struct {
    scheduled_action_name: ?[]const u8 = null,
    target_action: ?ScheduledActionType = null,
    schedule: ?[]const u8 = null,
    iam_role: ?[]const u8 = null,
    scheduled_action_description: ?[]const u8 = null,
    state: ?[]const u8 = null,
    next_invocations: ?[]i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_action_name = "ScheduledActionName",
            .target_action = "TargetAction",
            .schedule = "Schedule",
            .iam_role = "IamRole",
            .scheduled_action_description = "ScheduledActionDescription",
            .state = "State",
            .next_invocations = "NextInvocations",
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const HsmConfiguration = struct {
    hsm_configuration_identifier: ?[]const u8 = null,
    description: ?[]const u8 = null,
    hsm_ip_address: ?[]const u8 = null,
    hsm_partition_name: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hsm_configuration_identifier = "HsmConfigurationIdentifier",
            .description = "Description",
            .hsm_ip_address = "HsmIpAddress",
            .hsm_partition_name = "HsmPartitionName",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const HsmClientCertificate = struct {
    hsm_client_certificate_identifier: ?[]const u8 = null,
    hsm_client_certificate_public_key: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
            .hsm_client_certificate_public_key = "HsmClientCertificatePublicKey",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointAuthorization = struct {
    grantor: ?[]const u8 = null,
    grantee: ?[]const u8 = null,
    cluster_identifier: ?[]const u8 = null,
    authorize_time: ?i64 = null,
    cluster_status: ?[]const u8 = null,
    status: ?[]const u8 = null,
    allowed_all_vp_cs: ?bool = null,
    allowed_vp_cs: ?[][]const u8 = null,
    endpoint_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantor = "Grantor",
            .grantee = "Grantee",
            .cluster_identifier = "ClusterIdentifier",
            .authorize_time = "AuthorizeTime",
            .cluster_status = "ClusterStatus",
            .status = "Status",
            .allowed_all_vp_cs = "AllowedAllVPCs",
            .allowed_vp_cs = "AllowedVPCs",
            .endpoint_count = "EndpointCount",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointAccess = struct {
    cluster_identifier: ?[]const u8 = null,
    resource_owner: ?[]const u8 = null,
    subnet_group_name: ?[]const u8 = null,
    endpoint_status: ?[]const u8 = null,
    endpoint_name: ?[]const u8 = null,
    endpoint_create_time: ?i64 = null,
    port: ?i64 = null,
    address: ?[]const u8 = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    vpc_endpoint: ?VpcEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
            .resource_owner = "ResourceOwner",
            .subnet_group_name = "SubnetGroupName",
            .endpoint_status = "EndpointStatus",
            .endpoint_name = "EndpointName",
            .endpoint_create_time = "EndpointCreateTime",
            .port = "Port",
            .address = "Address",
            .vpc_security_groups = "VpcSecurityGroups",
            .vpc_endpoint = "VpcEndpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const DataShare = struct {
    data_share_arn: ?[]const u8 = null,
    producer_arn: ?[]const u8 = null,
    allow_publicly_accessible_consumers: ?bool = null,
    data_share_associations: ?[]DataShareAssociation = null,
    managed_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_share_arn = "DataShareArn",
            .producer_arn = "ProducerArn",
            .allow_publicly_accessible_consumers = "AllowPubliclyAccessibleConsumers",
            .data_share_associations = "DataShareAssociations",
            .managed_by = "ManagedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterParameterGroup = struct {
    parameter_group_name: ?[]const u8 = null,
    parameter_group_family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_group_name = "ParameterGroupName",
            .parameter_group_family = "ParameterGroupFamily",
            .description = "Description",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotErrorMessage = struct {
    snapshot_identifier: ?[]const u8 = null,
    snapshot_cluster_identifier: ?[]const u8 = null,
    failure_code: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_identifier = "SnapshotIdentifier",
            .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
            .failure_code = "FailureCode",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteClusterSnapshotMessage = struct {
    snapshot_identifier: []const u8,
    snapshot_cluster_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_identifier = "SnapshotIdentifier",
            .snapshot_cluster_identifier = "SnapshotClusterIdentifier",
        };
        return @field(mappings, field_name);
    }
};
