const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2006-03-01";
pub const sdk_id: []const u8 = "S3";
pub const arn_namespace: ?[]const u8 = "s3";
pub const endpoint_prefix: []const u8 = "s3";
pub const sigv4_name: []const u8 = "s3";
pub const name: []const u8 = "AmazonS3";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml;

pub const service_metadata: struct {
    version: []const u8 = "2006-03-01",
    sdk_id: []const u8 = "S3",
    arn_namespace: ?[]const u8 = "s3",
    endpoint_prefix: []const u8 = "s3",
    sigv4_name: []const u8 = "s3",
    name: []const u8 = "AmazonS3",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml,
} = .{};
pub const abort_multipart_upload: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}/{Key+}?x-id=AbortMultipartUpload",
        .success_code = 204,
    };

    action_name: []const u8 = "AbortMultipartUpload",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        upload_id: []const u8,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .upload_id = "uploadId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .upload_id = "UploadId",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(abort_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = abort_multipart_upload };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchUpload,
    },
} = .{};
pub const complete_multipart_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{Bucket}/{Key+}?x-id=CompleteMultipartUpload",
        .success_code = 200,
    };

    action_name: []const u8 = "CompleteMultipartUpload",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        multipart_upload: ?struct {
            parts: ?[]struct {
                e_tag: ?[]const u8 = null,
                checksum_crc32: ?[]const u8 = null,
                checksum_crc32c: ?[]const u8 = null,
                checksum_sha1: ?[]const u8 = null,
                checksum_sha256: ?[]const u8 = null,
                part_number: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .e_tag = "ETag",
                        .checksum_crc32 = "ChecksumCRC32",
                        .checksum_crc32c = "ChecksumCRC32C",
                        .checksum_sha1 = "ChecksumSHA1",
                        .checksum_sha256 = "ChecksumSHA256",
                        .part_number = "PartNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parts = "Part",
                };
                return @field(mappings, field_name);
            }
        } = null,
        upload_id: []const u8,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,

        pub const http_query = .{
            .upload_id = "uploadId",
        };

        pub const http_header = .{
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
        };

        pub const http_payload: []const u8 = "multipart_upload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .multipart_upload = "CompleteMultipartUpload",
                .upload_id = "UploadId",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = complete_multipart_upload };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        bucket: ?[]const u8 = null,
        key: ?[]const u8 = null,
        expiration: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .expiration = "x-amz-expiration",
            .server_side_encryption = "x-amz-server-side-encryption",
            .version_id = "x-amz-version-id",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
                .bucket = "Bucket",
                .key = "Key",
                .expiration = "Expiration",
                .e_tag = "ETag",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .server_side_encryption = "ServerSideEncryption",
                .version_id = "VersionId",
                .ssekms_key_id = "SSEKMSKeyId",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const copy_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?x-id=CopyObject",
        .success_code = 200,
    };

    action_name: []const u8 = "CopyObject",
    Request: type = struct {
        acl: ?[]const u8 = null,
        bucket: []const u8,
        cache_control: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        copy_source: []const u8,
        copy_source_if_match: ?[]const u8 = null,
        copy_source_if_modified_since: ?i64 = null,
        copy_source_if_none_match: ?[]const u8 = null,
        copy_source_if_unmodified_since: ?i64 = null,
        expires: ?i64 = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        key: []const u8,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_directive: ?[]const u8 = null,
        tagging_directive: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,
        website_redirect_location: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        copy_source_sse_customer_algorithm: ?[]const u8 = null,
        copy_source_sse_customer_key: ?[]const u8 = null,
        copy_source_sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        tagging: ?[]const u8 = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        expected_source_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .cache_control = "Cache-Control",
            .checksum_algorithm = "x-amz-checksum-algorithm",
            .content_disposition = "Content-Disposition",
            .content_encoding = "Content-Encoding",
            .content_language = "Content-Language",
            .content_type = "Content-Type",
            .copy_source = "x-amz-copy-source",
            .copy_source_if_match = "x-amz-copy-source-if-match",
            .copy_source_if_modified_since = "x-amz-copy-source-if-modified-since",
            .copy_source_if_none_match = "x-amz-copy-source-if-none-match",
            .copy_source_if_unmodified_since = "x-amz-copy-source-if-unmodified-since",
            .expires = "Expires",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write_acp = "x-amz-grant-write-acp",
            .metadata_directive = "x-amz-metadata-directive",
            .tagging_directive = "x-amz-tagging-directive",
            .server_side_encryption = "x-amz-server-side-encryption",
            .storage_class = "x-amz-storage-class",
            .website_redirect_location = "x-amz-website-redirect-location",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .copy_source_sse_customer_algorithm = "x-amz-copy-source-server-side-encryption-customer-algorithm",
            .copy_source_sse_customer_key = "x-amz-copy-source-server-side-encryption-customer-key",
            .copy_source_sse_customer_key_md5 = "x-amz-copy-source-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .tagging = "x-amz-tagging",
            .object_lock_mode = "x-amz-object-lock-mode",
            .object_lock_retain_until_date = "x-amz-object-lock-retain-until-date",
            .object_lock_legal_hold_status = "x-amz-object-lock-legal-hold",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .expected_source_bucket_owner = "x-amz-source-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .bucket = "Bucket",
                .cache_control = "CacheControl",
                .checksum_algorithm = "ChecksumAlgorithm",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_type = "ContentType",
                .copy_source = "CopySource",
                .copy_source_if_match = "CopySourceIfMatch",
                .copy_source_if_modified_since = "CopySourceIfModifiedSince",
                .copy_source_if_none_match = "CopySourceIfNoneMatch",
                .copy_source_if_unmodified_since = "CopySourceIfUnmodifiedSince",
                .expires = "Expires",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write_acp = "GrantWriteACP",
                .key = "Key",
                .metadata = "Metadata",
                .metadata_directive = "MetadataDirective",
                .tagging_directive = "TaggingDirective",
                .server_side_encryption = "ServerSideEncryption",
                .storage_class = "StorageClass",
                .website_redirect_location = "WebsiteRedirectLocation",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .copy_source_sse_customer_algorithm = "CopySourceSSECustomerAlgorithm",
                .copy_source_sse_customer_key = "CopySourceSSECustomerKey",
                .copy_source_sse_customer_key_md5 = "CopySourceSSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .tagging = "Tagging",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .expected_source_bucket_owner = "ExpectedSourceBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_object) } {
            return .{ .service_metadata = service_metadata, .action = copy_object };
        }
    },
    Response: type = struct {
        copy_object_result: ?struct {
            e_tag: ?[]const u8 = null,
            last_modified: ?i64 = null,
            checksum_crc32: ?[]const u8 = null,
            checksum_crc32c: ?[]const u8 = null,
            checksum_sha1: ?[]const u8 = null,
            checksum_sha256: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .e_tag = "ETag",
                    .last_modified = "LastModified",
                    .checksum_crc32 = "ChecksumCRC32",
                    .checksum_crc32c = "ChecksumCRC32C",
                    .checksum_sha1 = "ChecksumSHA1",
                    .checksum_sha256 = "ChecksumSHA256",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expiration: ?[]const u8 = null,
        copy_source_version_id: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .expiration = "x-amz-expiration",
            .copy_source_version_id = "x-amz-copy-source-version-id",
            .version_id = "x-amz-version-id",
            .server_side_encryption = "x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
        };

        pub const http_payload: []const u8 = "copy_object_result";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_object_result = "CopyObjectResult",
                .expiration = "Expiration",
                .copy_source_version_id = "CopySourceVersionId",
                .version_id = "VersionId",
                .server_side_encryption = "ServerSideEncryption",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ObjectNotInActiveTierError,
    },
} = .{};
pub const create_bucket: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBucket",
    Request: type = struct {
        acl: ?[]const u8 = null,
        bucket: []const u8,
        create_bucket_configuration: ?struct {
            location_constraint: ?[]const u8 = null,
            location: ?struct {
                type: ?[]const u8 = null,
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            bucket: ?struct {
                data_redundancy: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data_redundancy = "DataRedundancy",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_constraint = "LocationConstraint",
                    .location = "Location",
                    .bucket = "Bucket",
                };
                return @field(mappings, field_name);
            }
        } = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        object_lock_enabled_for_bucket: ?bool = null,
        object_ownership: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write = "x-amz-grant-write",
            .grant_write_acp = "x-amz-grant-write-acp",
            .object_lock_enabled_for_bucket = "x-amz-bucket-object-lock-enabled",
            .object_ownership = "x-amz-object-ownership",
        };

        pub const http_payload: []const u8 = "create_bucket_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .bucket = "Bucket",
                .create_bucket_configuration = "CreateBucketConfiguration",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write = "GrantWrite",
                .grant_write_acp = "GrantWriteACP",
                .object_lock_enabled_for_bucket = "ObjectLockEnabledForBucket",
                .object_ownership = "ObjectOwnership",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bucket) } {
            return .{ .service_metadata = service_metadata, .action = create_bucket };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BucketAlreadyExists,
        BucketAlreadyOwnedByYou,
    },
} = .{};
pub const create_multipart_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{Bucket}/{Key+}?uploads&x-id=CreateMultipartUpload",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMultipartUpload",
    Request: type = struct {
        acl: ?[]const u8 = null,
        bucket: []const u8,
        cache_control: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        expires: ?i64 = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        key: []const u8,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        server_side_encryption: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,
        website_redirect_location: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_payer: ?[]const u8 = null,
        tagging: ?[]const u8 = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .cache_control = "Cache-Control",
            .content_disposition = "Content-Disposition",
            .content_encoding = "Content-Encoding",
            .content_language = "Content-Language",
            .content_type = "Content-Type",
            .expires = "Expires",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write_acp = "x-amz-grant-write-acp",
            .server_side_encryption = "x-amz-server-side-encryption",
            .storage_class = "x-amz-storage-class",
            .website_redirect_location = "x-amz-website-redirect-location",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_payer = "x-amz-request-payer",
            .tagging = "x-amz-tagging",
            .object_lock_mode = "x-amz-object-lock-mode",
            .object_lock_retain_until_date = "x-amz-object-lock-retain-until-date",
            .object_lock_legal_hold_status = "x-amz-object-lock-legal-hold",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .checksum_algorithm = "x-amz-checksum-algorithm",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .bucket = "Bucket",
                .cache_control = "CacheControl",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_type = "ContentType",
                .expires = "Expires",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write_acp = "GrantWriteACP",
                .key = "Key",
                .metadata = "Metadata",
                .server_side_encryption = "ServerSideEncryption",
                .storage_class = "StorageClass",
                .website_redirect_location = "WebsiteRedirectLocation",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_payer = "RequestPayer",
                .tagging = "Tagging",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_multipart_upload) } {
            return .{ .service_metadata = service_metadata, .action = create_multipart_upload };
        }
    },
    Response: type = struct {
        abort_date: ?i64 = null,
        abort_rule_id: ?[]const u8 = null,
        bucket: ?[]const u8 = null,
        key: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .abort_date = "x-amz-abort-date",
            .abort_rule_id = "x-amz-abort-rule-id",
            .server_side_encryption = "x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
            .checksum_algorithm = "x-amz-checksum-algorithm",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .abort_date = "AbortDate",
                .abort_rule_id = "AbortRuleId",
                .bucket = "Bucket",
                .key = "Key",
                .upload_id = "UploadId",
                .server_side_encryption = "ServerSideEncryption",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?session",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSession",
    Request: type = struct {
        session_mode: ?[]const u8 = null,
        bucket: []const u8,
        pub const http_header = .{
            .session_mode = "x-amz-create-session-mode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_mode = "SessionMode",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_session) } {
            return .{ .service_metadata = service_metadata, .action = create_session };
        }
    },
    Response: type = struct {
        credentials: struct {
            access_key_id: []const u8,
            secret_access_key: []const u8,
            session_token: []const u8,
            expiration: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "AccessKeyId",
                    .secret_access_key = "SecretAccessKey",
                    .session_token = "SessionToken",
                    .expiration = "Expiration",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchBucket,
    },
} = .{};
pub const delete_bucket: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucket",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_analytics_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?analytics",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketAnalyticsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_analytics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_analytics_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_cors: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?cors",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketCors",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_cors) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_cors };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_encryption: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?encryption",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketEncryption",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_encryption) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_encryption };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_intelligent_tiering_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?intelligent-tiering",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketIntelligentTieringConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_intelligent_tiering_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_intelligent_tiering_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_inventory_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?inventory",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketInventoryConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_inventory_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_inventory_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_lifecycle: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?lifecycle",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketLifecycle",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_lifecycle) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_lifecycle };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_metrics_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?metrics",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketMetricsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_metrics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_metrics_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_ownership_controls: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?ownershipControls",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketOwnershipControls",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_ownership_controls) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_ownership_controls };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?policy",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketPolicy",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_replication: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?replication",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketReplication",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_replication };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?tagging",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketTagging",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_website: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?website",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketWebsite",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_website) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_website };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_object: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}/{Key+}?x-id=DeleteObject",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteObject",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        mfa: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        bypass_governance_retention: ?bool = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .mfa = "x-amz-mfa",
            .request_payer = "x-amz-request-payer",
            .bypass_governance_retention = "x-amz-bypass-governance-retention",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .mfa = "MFA",
                .version_id = "VersionId",
                .request_payer = "RequestPayer",
                .bypass_governance_retention = "BypassGovernanceRetention",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_object };
        }
    },
    Response: type = struct {
        delete_marker: ?bool = null,
        version_id: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .delete_marker = "x-amz-delete-marker",
            .version_id = "x-amz-version-id",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delete_marker = "DeleteMarker",
                .version_id = "VersionId",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_objects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{Bucket}?delete&x-id=DeleteObjects",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteObjects",
    Request: type = struct {
        bucket: []const u8,
        delete: struct {
            objects: []struct {
                key: []const u8,
                version_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .version_id = "VersionId",
                    };
                    return @field(mappings, field_name);
                }
            },
            quiet: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .objects = "Object",
                    .quiet = "Quiet",
                };
                return @field(mappings, field_name);
            }
        },
        mfa: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        bypass_governance_retention: ?bool = null,
        expected_bucket_owner: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .mfa = "x-amz-mfa",
            .request_payer = "x-amz-request-payer",
            .bypass_governance_retention = "x-amz-bypass-governance-retention",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
        };

        pub const http_payload: []const u8 = "delete";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .delete = "Delete",
                .mfa = "MFA",
                .request_payer = "RequestPayer",
                .bypass_governance_retention = "BypassGovernanceRetention",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_objects) } {
            return .{ .service_metadata = service_metadata, .action = delete_objects };
        }
    },
    Response: type = struct {
        deleted: ?[]struct {
            key: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            delete_marker: ?bool = null,
            delete_marker_version_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .version_id = "VersionId",
                    .delete_marker = "DeleteMarker",
                    .delete_marker_version_id = "DeleteMarkerVersionId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_charged: ?[]const u8 = null,
        errors: ?[]struct {
            key: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .version_id = "VersionId",
                    .code = "Code",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted = "Deleted",
                .request_charged = "RequestCharged",
                .errors = "Error",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_object_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}/{Key+}?tagging",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteObjectTagging",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_object_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_object_tagging };
        }
    },
    Response: type = struct {
        version_id: ?[]const u8 = null,
        pub const http_header = .{
            .version_id = "x-amz-version-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_public_access_block: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Bucket}?publicAccessBlock",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePublicAccessBlock",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = delete_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const get_bucket_accelerate_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?accelerate",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketAccelerateConfiguration",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .request_payer = "x-amz-request-payer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .request_payer = "RequestPayer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_accelerate_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_accelerate_configuration };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_acl: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?acl",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketAcl",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_acl) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_acl };
        }
    },
    Response: type = struct {
        owner: ?Owner = null,
        grants: ?[]Grant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "Owner",
                .grants = "AccessControlList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_analytics_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?analytics&x-id=GetBucketAnalyticsConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketAnalyticsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_analytics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_analytics_configuration };
        }
    },
    Response: type = struct {
        analytics_configuration: ?AnalyticsConfiguration = null,

        pub const http_payload: []const u8 = "analytics_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analytics_configuration = "AnalyticsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_cors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?cors",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketCors",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_cors) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_cors };
        }
    },
    Response: type = struct {
        cors_rules: ?[]CORSRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cors_rules = "CORSRule",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_encryption: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?encryption",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketEncryption",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_encryption) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_encryption };
        }
    },
    Response: type = struct {
        server_side_encryption_configuration: ?ServerSideEncryptionConfiguration = null,

        pub const http_payload: []const u8 = "server_side_encryption_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_intelligent_tiering_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?intelligent-tiering&x-id=GetBucketIntelligentTieringConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketIntelligentTieringConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_intelligent_tiering_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_intelligent_tiering_configuration };
        }
    },
    Response: type = struct {
        intelligent_tiering_configuration: ?IntelligentTieringConfiguration = null,

        pub const http_payload: []const u8 = "intelligent_tiering_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intelligent_tiering_configuration = "IntelligentTieringConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_inventory_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?inventory&x-id=GetBucketInventoryConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketInventoryConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_inventory_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_inventory_configuration };
        }
    },
    Response: type = struct {
        inventory_configuration: ?InventoryConfiguration = null,

        pub const http_payload: []const u8 = "inventory_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inventory_configuration = "InventoryConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?lifecycle",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketLifecycleConfiguration",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {
        rules: ?[]LifecycleRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rule",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_location: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?location",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketLocation",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_location) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_location };
        }
    },
    Response: type = struct {
        location_constraint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_constraint = "LocationConstraint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_logging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?logging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketLogging",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_logging) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_logging };
        }
    },
    Response: type = struct {
        logging_enabled: ?LoggingEnabled = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_enabled = "LoggingEnabled",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_metrics_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?metrics&x-id=GetBucketMetricsConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketMetricsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_metrics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_metrics_configuration };
        }
    },
    Response: type = struct {
        metrics_configuration: ?MetricsConfiguration = null,

        pub const http_payload: []const u8 = "metrics_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics_configuration = "MetricsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_notification_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?notification",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketNotificationConfiguration",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_notification_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_notification_configuration };
        }
    },
    Response: type = struct {
        topic_configurations: ?[]TopicConfiguration = null,
        queue_configurations: ?[]QueueConfiguration = null,
        lambda_function_configurations: ?[]LambdaFunctionConfiguration = null,
        event_bridge_configuration: ?EventBridgeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_configurations = "TopicConfiguration",
                .queue_configurations = "QueueConfiguration",
                .lambda_function_configurations = "CloudFunctionConfiguration",
                .event_bridge_configuration = "EventBridgeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_ownership_controls: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?ownershipControls",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketOwnershipControls",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_ownership_controls) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_ownership_controls };
        }
    },
    Response: type = struct {
        ownership_controls: ?OwnershipControls = null,

        pub const http_payload: []const u8 = "ownership_controls";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ownership_controls = "OwnershipControls",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketPolicy",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub const http_payload: []const u8 = "policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_policy_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?policyStatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketPolicyStatus",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_policy_status) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_policy_status };
        }
    },
    Response: type = struct {
        policy_status: ?struct {
            is_public: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .is_public = "IsPublic",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "policy_status";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_status = "PolicyStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_replication: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?replication",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketReplication",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_replication };
        }
    },
    Response: type = struct {
        replication_configuration: ?ReplicationConfiguration = null,

        pub const http_payload: []const u8 = "replication_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_configuration = "ReplicationConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_request_payment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?requestPayment",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketRequestPayment",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_request_payment) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_request_payment };
        }
    },
    Response: type = struct {
        payer: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payer = "Payer",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketTagging",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_tagging };
        }
    },
    Response: type = struct {
        tag_set: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_set = "TagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_versioning: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?versioning",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketVersioning",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_versioning) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_versioning };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        mfa_delete: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .mfa_delete = "MfaDelete",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_website: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?website",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketWebsite",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_website) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_website };
        }
    },
    Response: type = struct {
        redirect_all_requests_to: ?RedirectAllRequestsTo = null,
        index_document: ?IndexDocument = null,
        error_document: ?ErrorDocument = null,
        routing_rules: ?[]RoutingRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .redirect_all_requests_to = "RedirectAllRequestsTo",
                .index_document = "IndexDocument",
                .error_document = "ErrorDocument",
                .routing_rules = "RoutingRules",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_object: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?x-id=GetObject",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObject",
    Request: type = struct {
        bucket: []const u8,
        if_match: ?[]const u8 = null,
        if_modified_since: ?i64 = null,
        if_none_match: ?[]const u8 = null,
        if_unmodified_since: ?i64 = null,
        key: []const u8,
        range: ?[]const u8 = null,
        response_cache_control: ?[]const u8 = null,
        response_content_disposition: ?[]const u8 = null,
        response_content_encoding: ?[]const u8 = null,
        response_content_language: ?[]const u8 = null,
        response_content_type: ?[]const u8 = null,
        response_expires: ?i64 = null,
        version_id: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        part_number: ?i64 = null,
        expected_bucket_owner: ?[]const u8 = null,
        checksum_mode: ?[]const u8 = null,

        pub const http_query = .{
            .response_cache_control = "response-cache-control",
            .response_content_disposition = "response-content-disposition",
            .response_content_encoding = "response-content-encoding",
            .response_content_language = "response-content-language",
            .response_content_type = "response-content-type",
            .response_expires = "response-expires",
            .version_id = "versionId",
            .part_number = "partNumber",
        };

        pub const http_header = .{
            .if_match = "If-Match",
            .if_modified_since = "If-Modified-Since",
            .if_none_match = "If-None-Match",
            .if_unmodified_since = "If-Unmodified-Since",
            .range = "Range",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .checksum_mode = "x-amz-checksum-mode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .if_match = "IfMatch",
                .if_modified_since = "IfModifiedSince",
                .if_none_match = "IfNoneMatch",
                .if_unmodified_since = "IfUnmodifiedSince",
                .key = "Key",
                .range = "Range",
                .response_cache_control = "ResponseCacheControl",
                .response_content_disposition = "ResponseContentDisposition",
                .response_content_encoding = "ResponseContentEncoding",
                .response_content_language = "ResponseContentLanguage",
                .response_content_type = "ResponseContentType",
                .response_expires = "ResponseExpires",
                .version_id = "VersionId",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .part_number = "PartNumber",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .checksum_mode = "ChecksumMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object) } {
            return .{ .service_metadata = service_metadata, .action = get_object };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        delete_marker: ?bool = null,
        accept_ranges: ?[]const u8 = null,
        expiration: ?[]const u8 = null,
        restore: ?[]const u8 = null,
        last_modified: ?i64 = null,
        content_length: ?i64 = null,
        e_tag: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        missing_meta: ?i64 = null,
        version_id: ?[]const u8 = null,
        cache_control: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_range: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        expires: ?i64 = null,
        website_redirect_location: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        storage_class: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        replication_status: ?[]const u8 = null,
        parts_count: ?i64 = null,
        tag_count: ?i64 = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        pub const http_header = .{
            .delete_marker = "x-amz-delete-marker",
            .accept_ranges = "accept-ranges",
            .expiration = "x-amz-expiration",
            .restore = "x-amz-restore",
            .last_modified = "Last-Modified",
            .content_length = "Content-Length",
            .e_tag = "ETag",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .missing_meta = "x-amz-missing-meta",
            .version_id = "x-amz-version-id",
            .cache_control = "Cache-Control",
            .content_disposition = "Content-Disposition",
            .content_encoding = "Content-Encoding",
            .content_language = "Content-Language",
            .content_range = "Content-Range",
            .content_type = "Content-Type",
            .expires = "Expires",
            .website_redirect_location = "x-amz-website-redirect-location",
            .server_side_encryption = "x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .storage_class = "x-amz-storage-class",
            .request_charged = "x-amz-request-charged",
            .replication_status = "x-amz-replication-status",
            .parts_count = "x-amz-mp-parts-count",
            .tag_count = "x-amz-tagging-count",
            .object_lock_mode = "x-amz-object-lock-mode",
            .object_lock_retain_until_date = "x-amz-object-lock-retain-until-date",
            .object_lock_legal_hold_status = "x-amz-object-lock-legal-hold",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .delete_marker = "DeleteMarker",
                .accept_ranges = "AcceptRanges",
                .expiration = "Expiration",
                .restore = "Restore",
                .last_modified = "LastModified",
                .content_length = "ContentLength",
                .e_tag = "ETag",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .missing_meta = "MissingMeta",
                .version_id = "VersionId",
                .cache_control = "CacheControl",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_range = "ContentRange",
                .content_type = "ContentType",
                .expires = "Expires",
                .website_redirect_location = "WebsiteRedirectLocation",
                .server_side_encryption = "ServerSideEncryption",
                .metadata = "Metadata",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .bucket_key_enabled = "BucketKeyEnabled",
                .storage_class = "StorageClass",
                .request_charged = "RequestCharged",
                .replication_status = "ReplicationStatus",
                .parts_count = "PartsCount",
                .tag_count = "TagCount",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidObjectState,
        NoSuchKey,
    },
} = .{};
pub const get_object_acl: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?acl",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectAcl",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_acl) } {
            return .{ .service_metadata = service_metadata, .action = get_object_acl };
        }
    },
    Response: type = struct {
        owner: ?Owner = null,
        grants: ?[]Grant = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "Owner",
                .grants = "AccessControlList",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchKey,
    },
} = .{};
pub const get_object_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectAttributes",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        max_parts: ?i64 = null,
        part_number_marker: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        object_attributes: [][]const u8,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .max_parts = "x-amz-max-parts",
            .part_number_marker = "x-amz-part-number-marker",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .object_attributes = "x-amz-object-attributes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .max_parts = "MaxParts",
                .part_number_marker = "PartNumberMarker",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .object_attributes = "ObjectAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_object_attributes };
        }
    },
    Response: type = struct {
        delete_marker: ?bool = null,
        last_modified: ?i64 = null,
        version_id: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        checksum: ?struct {
            checksum_crc32: ?[]const u8 = null,
            checksum_crc32c: ?[]const u8 = null,
            checksum_sha1: ?[]const u8 = null,
            checksum_sha256: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .checksum_crc32 = "ChecksumCRC32",
                    .checksum_crc32c = "ChecksumCRC32C",
                    .checksum_sha1 = "ChecksumSHA1",
                    .checksum_sha256 = "ChecksumSHA256",
                };
                return @field(mappings, field_name);
            }
        } = null,
        object_parts: ?struct {
            total_parts_count: ?i64 = null,
            part_number_marker: ?[]const u8 = null,
            next_part_number_marker: ?[]const u8 = null,
            max_parts: ?i64 = null,
            is_truncated: ?bool = null,
            parts: ?[]struct {
                part_number: ?i64 = null,
                size: ?i64 = null,
                checksum_crc32: ?[]const u8 = null,
                checksum_crc32c: ?[]const u8 = null,
                checksum_sha1: ?[]const u8 = null,
                checksum_sha256: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .part_number = "PartNumber",
                        .size = "Size",
                        .checksum_crc32 = "ChecksumCRC32",
                        .checksum_crc32c = "ChecksumCRC32C",
                        .checksum_sha1 = "ChecksumSHA1",
                        .checksum_sha256 = "ChecksumSHA256",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_parts_count = "PartsCount",
                    .part_number_marker = "PartNumberMarker",
                    .next_part_number_marker = "NextPartNumberMarker",
                    .max_parts = "MaxParts",
                    .is_truncated = "IsTruncated",
                    .parts = "Part",
                };
                return @field(mappings, field_name);
            }
        } = null,
        storage_class: ?[]const u8 = null,
        object_size: ?i64 = null,
        pub const http_header = .{
            .delete_marker = "x-amz-delete-marker",
            .last_modified = "Last-Modified",
            .version_id = "x-amz-version-id",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delete_marker = "DeleteMarker",
                .last_modified = "LastModified",
                .version_id = "VersionId",
                .request_charged = "RequestCharged",
                .e_tag = "ETag",
                .checksum = "Checksum",
                .object_parts = "ObjectParts",
                .storage_class = "StorageClass",
                .object_size = "ObjectSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchKey,
    },
} = .{};
pub const get_object_legal_hold: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?legal-hold",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectLegalHold",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = get_object_legal_hold };
        }
    },
    Response: type = struct {
        legal_hold: ?ObjectLockLegalHold = null,

        pub const http_payload: []const u8 = "legal_hold";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .legal_hold = "LegalHold",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_object_lock_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?object-lock",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectLockConfiguration",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_lock_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_object_lock_configuration };
        }
    },
    Response: type = struct {
        object_lock_configuration: ?ObjectLockConfiguration = null,

        pub const http_payload: []const u8 = "object_lock_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_lock_configuration = "ObjectLockConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_object_retention: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?retention",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectRetention",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_retention) } {
            return .{ .service_metadata = service_metadata, .action = get_object_retention };
        }
    },
    Response: type = struct {
        retention: ?ObjectLockRetention = null,

        pub const http_payload: []const u8 = "retention";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention = "Retention",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_object_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectTagging",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .request_payer = "x-amz-request-payer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .request_payer = "RequestPayer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_object_tagging };
        }
    },
    Response: type = struct {
        version_id: ?[]const u8 = null,
        tag_set: []Tag,
        pub const http_header = .{
            .version_id = "x-amz-version-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_id = "VersionId",
                .tag_set = "TagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_object_torrent: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?torrent",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObjectTorrent",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object_torrent) } {
            return .{ .service_metadata = service_metadata, .action = get_object_torrent };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_public_access_block: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPublicAccessBlock",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = get_public_access_block };
        }
    },
    Response: type = struct {
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const head_bucket: struct {
    pub const http_config = .{
        .method = "HEAD",
        .uri = "/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "HeadBucket",
    Request: type = struct {
        bucket: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(head_bucket) } {
            return .{ .service_metadata = service_metadata, .action = head_bucket };
        }
    },
    Response: type = struct {
        bucket_location_type: ?[]const u8 = null,
        bucket_location_name: ?[]const u8 = null,
        bucket_region: ?[]const u8 = null,
        access_point_alias: ?bool = null,
        pub const http_header = .{
            .bucket_location_type = "x-amz-bucket-location-type",
            .bucket_location_name = "x-amz-bucket-location-name",
            .bucket_region = "x-amz-bucket-region",
            .access_point_alias = "x-amz-access-point-alias",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket_location_type = "BucketLocationType",
                .bucket_location_name = "BucketLocationName",
                .bucket_region = "BucketRegion",
                .access_point_alias = "AccessPointAlias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
    },
} = .{};
pub const head_object: struct {
    pub const http_config = .{
        .method = "HEAD",
        .uri = "/{Bucket}/{Key+}",
        .success_code = 200,
    };

    action_name: []const u8 = "HeadObject",
    Request: type = struct {
        bucket: []const u8,
        if_match: ?[]const u8 = null,
        if_modified_since: ?i64 = null,
        if_none_match: ?[]const u8 = null,
        if_unmodified_since: ?i64 = null,
        key: []const u8,
        range: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        part_number: ?i64 = null,
        expected_bucket_owner: ?[]const u8 = null,
        checksum_mode: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
            .part_number = "partNumber",
        };

        pub const http_header = .{
            .if_match = "If-Match",
            .if_modified_since = "If-Modified-Since",
            .if_none_match = "If-None-Match",
            .if_unmodified_since = "If-Unmodified-Since",
            .range = "Range",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .checksum_mode = "x-amz-checksum-mode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .if_match = "IfMatch",
                .if_modified_since = "IfModifiedSince",
                .if_none_match = "IfNoneMatch",
                .if_unmodified_since = "IfUnmodifiedSince",
                .key = "Key",
                .range = "Range",
                .version_id = "VersionId",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .part_number = "PartNumber",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .checksum_mode = "ChecksumMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(head_object) } {
            return .{ .service_metadata = service_metadata, .action = head_object };
        }
    },
    Response: type = struct {
        delete_marker: ?bool = null,
        accept_ranges: ?[]const u8 = null,
        expiration: ?[]const u8 = null,
        restore: ?[]const u8 = null,
        archive_status: ?[]const u8 = null,
        last_modified: ?i64 = null,
        content_length: ?i64 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        missing_meta: ?i64 = null,
        version_id: ?[]const u8 = null,
        cache_control: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        expires: ?i64 = null,
        website_redirect_location: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        storage_class: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        replication_status: ?[]const u8 = null,
        parts_count: ?i64 = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        pub const http_header = .{
            .delete_marker = "x-amz-delete-marker",
            .accept_ranges = "accept-ranges",
            .expiration = "x-amz-expiration",
            .restore = "x-amz-restore",
            .archive_status = "x-amz-archive-status",
            .last_modified = "Last-Modified",
            .content_length = "Content-Length",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .e_tag = "ETag",
            .missing_meta = "x-amz-missing-meta",
            .version_id = "x-amz-version-id",
            .cache_control = "Cache-Control",
            .content_disposition = "Content-Disposition",
            .content_encoding = "Content-Encoding",
            .content_language = "Content-Language",
            .content_type = "Content-Type",
            .expires = "Expires",
            .website_redirect_location = "x-amz-website-redirect-location",
            .server_side_encryption = "x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .storage_class = "x-amz-storage-class",
            .request_charged = "x-amz-request-charged",
            .replication_status = "x-amz-replication-status",
            .parts_count = "x-amz-mp-parts-count",
            .object_lock_mode = "x-amz-object-lock-mode",
            .object_lock_retain_until_date = "x-amz-object-lock-retain-until-date",
            .object_lock_legal_hold_status = "x-amz-object-lock-legal-hold",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delete_marker = "DeleteMarker",
                .accept_ranges = "AcceptRanges",
                .expiration = "Expiration",
                .restore = "Restore",
                .archive_status = "ArchiveStatus",
                .last_modified = "LastModified",
                .content_length = "ContentLength",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .e_tag = "ETag",
                .missing_meta = "MissingMeta",
                .version_id = "VersionId",
                .cache_control = "CacheControl",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_type = "ContentType",
                .expires = "Expires",
                .website_redirect_location = "WebsiteRedirectLocation",
                .server_side_encryption = "ServerSideEncryption",
                .metadata = "Metadata",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .bucket_key_enabled = "BucketKeyEnabled",
                .storage_class = "StorageClass",
                .request_charged = "RequestCharged",
                .replication_status = "ReplicationStatus",
                .parts_count = "PartsCount",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
    },
} = .{};
pub const list_bucket_analytics_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?analytics&x-id=ListBucketAnalyticsConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBucketAnalyticsConfigurations",
    Request: type = struct {
        bucket: []const u8,
        continuation_token: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .continuation_token = "continuation-token",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .continuation_token = "ContinuationToken",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bucket_analytics_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_bucket_analytics_configurations };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        continuation_token: ?[]const u8 = null,
        next_continuation_token: ?[]const u8 = null,
        analytics_configuration_list: ?[]AnalyticsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .continuation_token = "ContinuationToken",
                .next_continuation_token = "NextContinuationToken",
                .analytics_configuration_list = "AnalyticsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_bucket_intelligent_tiering_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?intelligent-tiering&x-id=ListBucketIntelligentTieringConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBucketIntelligentTieringConfigurations",
    Request: type = struct {
        bucket: []const u8,
        continuation_token: ?[]const u8 = null,

        pub const http_query = .{
            .continuation_token = "continuation-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .continuation_token = "ContinuationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bucket_intelligent_tiering_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_bucket_intelligent_tiering_configurations };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        continuation_token: ?[]const u8 = null,
        next_continuation_token: ?[]const u8 = null,
        intelligent_tiering_configuration_list: ?[]IntelligentTieringConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .continuation_token = "ContinuationToken",
                .next_continuation_token = "NextContinuationToken",
                .intelligent_tiering_configuration_list = "IntelligentTieringConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_bucket_inventory_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?inventory&x-id=ListBucketInventoryConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBucketInventoryConfigurations",
    Request: type = struct {
        bucket: []const u8,
        continuation_token: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .continuation_token = "continuation-token",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .continuation_token = "ContinuationToken",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bucket_inventory_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_bucket_inventory_configurations };
        }
    },
    Response: type = struct {
        continuation_token: ?[]const u8 = null,
        inventory_configuration_list: ?[]InventoryConfiguration = null,
        is_truncated: ?bool = null,
        next_continuation_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continuation_token = "ContinuationToken",
                .inventory_configuration_list = "InventoryConfiguration",
                .is_truncated = "IsTruncated",
                .next_continuation_token = "NextContinuationToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_bucket_metrics_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?metrics&x-id=ListBucketMetricsConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBucketMetricsConfigurations",
    Request: type = struct {
        bucket: []const u8,
        continuation_token: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .continuation_token = "continuation-token",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .continuation_token = "ContinuationToken",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bucket_metrics_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_bucket_metrics_configurations };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        continuation_token: ?[]const u8 = null,
        next_continuation_token: ?[]const u8 = null,
        metrics_configuration_list: ?[]MetricsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .continuation_token = "ContinuationToken",
                .next_continuation_token = "NextContinuationToken",
                .metrics_configuration_list = "MetricsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_buckets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/?x-id=ListBuckets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBuckets",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_buckets) } {
            return .{ .service_metadata = service_metadata, .action = list_buckets };
        }
    },
    Response: type = struct {
        buckets: ?[]Bucket = null,
        owner: ?Owner = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .buckets = "Buckets",
                .owner = "Owner",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_directory_buckets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/?x-id=ListDirectoryBuckets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDirectoryBuckets",
    Request: type = struct {
        continuation_token: ?[]const u8 = null,
        max_directory_buckets: ?i64 = null,

        pub const http_query = .{
            .continuation_token = "continuation-token",
            .max_directory_buckets = "max-directory-buckets",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continuation_token = "ContinuationToken",
                .max_directory_buckets = "MaxDirectoryBuckets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_directory_buckets) } {
            return .{ .service_metadata = service_metadata, .action = list_directory_buckets };
        }
    },
    Response: type = struct {
        buckets: ?[]Bucket = null,
        continuation_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .buckets = "Buckets",
                .continuation_token = "ContinuationToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_multipart_uploads: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?uploads",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMultipartUploads",
    Request: type = struct {
        bucket: []const u8,
        delimiter: ?[]const u8 = null,
        encoding_type: ?[]const u8 = null,
        key_marker: ?[]const u8 = null,
        max_uploads: ?i64 = null,
        prefix: ?[]const u8 = null,
        upload_id_marker: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,

        pub const http_query = .{
            .delimiter = "delimiter",
            .encoding_type = "encoding-type",
            .key_marker = "key-marker",
            .max_uploads = "max-uploads",
            .prefix = "prefix",
            .upload_id_marker = "upload-id-marker",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .request_payer = "x-amz-request-payer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .delimiter = "Delimiter",
                .encoding_type = "EncodingType",
                .key_marker = "KeyMarker",
                .max_uploads = "MaxUploads",
                .prefix = "Prefix",
                .upload_id_marker = "UploadIdMarker",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .request_payer = "RequestPayer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multipart_uploads) } {
            return .{ .service_metadata = service_metadata, .action = list_multipart_uploads };
        }
    },
    Response: type = struct {
        bucket: ?[]const u8 = null,
        key_marker: ?[]const u8 = null,
        upload_id_marker: ?[]const u8 = null,
        next_key_marker: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        delimiter: ?[]const u8 = null,
        next_upload_id_marker: ?[]const u8 = null,
        max_uploads: ?i64 = null,
        is_truncated: ?bool = null,
        uploads: ?[]struct {
            upload_id: ?[]const u8 = null,
            key: ?[]const u8 = null,
            initiated: ?i64 = null,
            storage_class: ?[]const u8 = null,
            owner: ?Owner = null,
            initiator: ?Initiator = null,
            checksum_algorithm: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .upload_id = "UploadId",
                    .key = "Key",
                    .initiated = "Initiated",
                    .storage_class = "StorageClass",
                    .owner = "Owner",
                    .initiator = "Initiator",
                    .checksum_algorithm = "ChecksumAlgorithm",
                };
                return @field(mappings, field_name);
            }
        } = null,
        common_prefixes: ?[]CommonPrefix = null,
        encoding_type: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key_marker = "KeyMarker",
                .upload_id_marker = "UploadIdMarker",
                .next_key_marker = "NextKeyMarker",
                .prefix = "Prefix",
                .delimiter = "Delimiter",
                .next_upload_id_marker = "NextUploadIdMarker",
                .max_uploads = "MaxUploads",
                .is_truncated = "IsTruncated",
                .uploads = "Upload",
                .common_prefixes = "CommonPrefixes",
                .encoding_type = "EncodingType",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_objects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjects",
    Request: type = struct {
        bucket: []const u8,
        delimiter: ?[]const u8 = null,
        encoding_type: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_keys: ?i64 = null,
        prefix: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        optional_object_attributes: ?[][]const u8 = null,

        pub const http_query = .{
            .delimiter = "delimiter",
            .encoding_type = "encoding-type",
            .marker = "marker",
            .max_keys = "max-keys",
            .prefix = "prefix",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .optional_object_attributes = "x-amz-optional-object-attributes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .delimiter = "Delimiter",
                .encoding_type = "EncodingType",
                .marker = "Marker",
                .max_keys = "MaxKeys",
                .prefix = "Prefix",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .optional_object_attributes = "OptionalObjectAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_objects) } {
            return .{ .service_metadata = service_metadata, .action = list_objects };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        marker: ?[]const u8 = null,
        next_marker: ?[]const u8 = null,
        contents: ?[]Object = null,
        name: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        delimiter: ?[]const u8 = null,
        max_keys: ?i64 = null,
        common_prefixes: ?[]CommonPrefix = null,
        encoding_type: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .marker = "Marker",
                .next_marker = "NextMarker",
                .contents = "Contents",
                .name = "Name",
                .prefix = "Prefix",
                .delimiter = "Delimiter",
                .max_keys = "MaxKeys",
                .common_prefixes = "CommonPrefixes",
                .encoding_type = "EncodingType",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchBucket,
    },
} = .{};
pub const list_objects_v2: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?list-type=2",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectsV2",
    Request: type = struct {
        bucket: []const u8,
        delimiter: ?[]const u8 = null,
        encoding_type: ?[]const u8 = null,
        max_keys: ?i64 = null,
        prefix: ?[]const u8 = null,
        continuation_token: ?[]const u8 = null,
        fetch_owner: ?bool = null,
        start_after: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        optional_object_attributes: ?[][]const u8 = null,

        pub const http_query = .{
            .delimiter = "delimiter",
            .encoding_type = "encoding-type",
            .max_keys = "max-keys",
            .prefix = "prefix",
            .continuation_token = "continuation-token",
            .fetch_owner = "fetch-owner",
            .start_after = "start-after",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .optional_object_attributes = "x-amz-optional-object-attributes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .delimiter = "Delimiter",
                .encoding_type = "EncodingType",
                .max_keys = "MaxKeys",
                .prefix = "Prefix",
                .continuation_token = "ContinuationToken",
                .fetch_owner = "FetchOwner",
                .start_after = "StartAfter",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .optional_object_attributes = "OptionalObjectAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_objects_v2) } {
            return .{ .service_metadata = service_metadata, .action = list_objects_v2 };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        contents: ?[]Object = null,
        name: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        delimiter: ?[]const u8 = null,
        max_keys: ?i64 = null,
        common_prefixes: ?[]CommonPrefix = null,
        encoding_type: ?[]const u8 = null,
        key_count: ?i64 = null,
        continuation_token: ?[]const u8 = null,
        next_continuation_token: ?[]const u8 = null,
        start_after: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .contents = "Contents",
                .name = "Name",
                .prefix = "Prefix",
                .delimiter = "Delimiter",
                .max_keys = "MaxKeys",
                .common_prefixes = "CommonPrefixes",
                .encoding_type = "EncodingType",
                .key_count = "KeyCount",
                .continuation_token = "ContinuationToken",
                .next_continuation_token = "NextContinuationToken",
                .start_after = "StartAfter",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchBucket,
    },
} = .{};
pub const list_object_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}?versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListObjectVersions",
    Request: type = struct {
        bucket: []const u8,
        delimiter: ?[]const u8 = null,
        encoding_type: ?[]const u8 = null,
        key_marker: ?[]const u8 = null,
        max_keys: ?i64 = null,
        prefix: ?[]const u8 = null,
        version_id_marker: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        optional_object_attributes: ?[][]const u8 = null,

        pub const http_query = .{
            .delimiter = "delimiter",
            .encoding_type = "encoding-type",
            .key_marker = "key-marker",
            .max_keys = "max-keys",
            .prefix = "prefix",
            .version_id_marker = "version-id-marker",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .request_payer = "x-amz-request-payer",
            .optional_object_attributes = "x-amz-optional-object-attributes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .delimiter = "Delimiter",
                .encoding_type = "EncodingType",
                .key_marker = "KeyMarker",
                .max_keys = "MaxKeys",
                .prefix = "Prefix",
                .version_id_marker = "VersionIdMarker",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .request_payer = "RequestPayer",
                .optional_object_attributes = "OptionalObjectAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_object_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_object_versions };
        }
    },
    Response: type = struct {
        is_truncated: ?bool = null,
        key_marker: ?[]const u8 = null,
        version_id_marker: ?[]const u8 = null,
        next_key_marker: ?[]const u8 = null,
        next_version_id_marker: ?[]const u8 = null,
        versions: ?[]struct {
            e_tag: ?[]const u8 = null,
            checksum_algorithm: ?[][]const u8 = null,
            size: ?i64 = null,
            storage_class: ?[]const u8 = null,
            key: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            is_latest: ?bool = null,
            last_modified: ?i64 = null,
            owner: ?Owner = null,
            restore_status: ?RestoreStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .e_tag = "ETag",
                    .checksum_algorithm = "ChecksumAlgorithm",
                    .size = "Size",
                    .storage_class = "StorageClass",
                    .key = "Key",
                    .version_id = "VersionId",
                    .is_latest = "IsLatest",
                    .last_modified = "LastModified",
                    .owner = "Owner",
                    .restore_status = "RestoreStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        delete_markers: ?[]struct {
            owner: ?Owner = null,
            key: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            is_latest: ?bool = null,
            last_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .owner = "Owner",
                    .key = "Key",
                    .version_id = "VersionId",
                    .is_latest = "IsLatest",
                    .last_modified = "LastModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        delimiter: ?[]const u8 = null,
        max_keys: ?i64 = null,
        common_prefixes: ?[]CommonPrefix = null,
        encoding_type: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_truncated = "IsTruncated",
                .key_marker = "KeyMarker",
                .version_id_marker = "VersionIdMarker",
                .next_key_marker = "NextKeyMarker",
                .next_version_id_marker = "NextVersionIdMarker",
                .versions = "Version",
                .delete_markers = "DeleteMarker",
                .name = "Name",
                .prefix = "Prefix",
                .delimiter = "Delimiter",
                .max_keys = "MaxKeys",
                .common_prefixes = "CommonPrefixes",
                .encoding_type = "EncodingType",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_parts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Bucket}/{Key+}?x-id=ListParts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListParts",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        max_parts: ?i64 = null,
        part_number_marker: ?[]const u8 = null,
        upload_id: []const u8,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,

        pub const http_query = .{
            .max_parts = "max-parts",
            .part_number_marker = "part-number-marker",
            .upload_id = "uploadId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .max_parts = "MaxParts",
                .part_number_marker = "PartNumberMarker",
                .upload_id = "UploadId",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_parts) } {
            return .{ .service_metadata = service_metadata, .action = list_parts };
        }
    },
    Response: type = struct {
        abort_date: ?i64 = null,
        abort_rule_id: ?[]const u8 = null,
        bucket: ?[]const u8 = null,
        key: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        part_number_marker: ?[]const u8 = null,
        next_part_number_marker: ?[]const u8 = null,
        max_parts: ?i64 = null,
        is_truncated: ?bool = null,
        parts: ?[]struct {
            part_number: ?i64 = null,
            last_modified: ?i64 = null,
            e_tag: ?[]const u8 = null,
            size: ?i64 = null,
            checksum_crc32: ?[]const u8 = null,
            checksum_crc32c: ?[]const u8 = null,
            checksum_sha1: ?[]const u8 = null,
            checksum_sha256: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .part_number = "PartNumber",
                    .last_modified = "LastModified",
                    .e_tag = "ETag",
                    .size = "Size",
                    .checksum_crc32 = "ChecksumCRC32",
                    .checksum_crc32c = "ChecksumCRC32C",
                    .checksum_sha1 = "ChecksumSHA1",
                    .checksum_sha256 = "ChecksumSHA256",
                };
                return @field(mappings, field_name);
            }
        } = null,
        initiator: ?Initiator = null,
        owner: ?Owner = null,
        storage_class: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .abort_date = "x-amz-abort-date",
            .abort_rule_id = "x-amz-abort-rule-id",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .abort_date = "AbortDate",
                .abort_rule_id = "AbortRuleId",
                .bucket = "Bucket",
                .key = "Key",
                .upload_id = "UploadId",
                .part_number_marker = "PartNumberMarker",
                .next_part_number_marker = "NextPartNumberMarker",
                .max_parts = "MaxParts",
                .is_truncated = "IsTruncated",
                .parts = "Part",
                .initiator = "Initiator",
                .owner = "Owner",
                .storage_class = "StorageClass",
                .request_charged = "RequestCharged",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_bucket_accelerate_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?accelerate",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketAccelerateConfiguration",
    Request: type = struct {
        bucket: []const u8,
        accelerate_configuration: struct {
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },
        expected_bucket_owner: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
        };

        pub const http_payload: []const u8 = "accelerate_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .accelerate_configuration = "AccelerateConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .checksum_algorithm = "ChecksumAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_accelerate_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_accelerate_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_acl: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?acl",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketAcl",
    Request: type = struct {
        acl: ?[]const u8 = null,
        access_control_policy: ?AccessControlPolicy = null,
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write = "x-amz-grant-write",
            .grant_write_acp = "x-amz-grant-write-acp",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "access_control_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .access_control_policy = "AccessControlPolicy",
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write = "GrantWrite",
                .grant_write_acp = "GrantWriteACP",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_acl) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_acl };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_analytics_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?analytics",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketAnalyticsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        analytics_configuration: AnalyticsConfiguration,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "analytics_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .analytics_configuration = "AnalyticsConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_analytics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_analytics_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_cors: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?cors",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketCors",
    Request: type = struct {
        bucket: []const u8,
        cors_configuration: struct {
            cors_rules: []CORSRule,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cors_rules = "CORSRule",
                };
                return @field(mappings, field_name);
            }
        },
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "cors_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .cors_configuration = "CORSConfiguration",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_cors) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_cors };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_encryption: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?encryption",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketEncryption",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        server_side_encryption_configuration: ServerSideEncryptionConfiguration,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "server_side_encryption_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_encryption) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_encryption };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_intelligent_tiering_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?intelligent-tiering",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketIntelligentTieringConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        intelligent_tiering_configuration: IntelligentTieringConfiguration,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_payload: []const u8 = "intelligent_tiering_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .intelligent_tiering_configuration = "IntelligentTieringConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_intelligent_tiering_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_intelligent_tiering_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_inventory_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?inventory",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketInventoryConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        inventory_configuration: InventoryConfiguration,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "inventory_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .inventory_configuration = "InventoryConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_inventory_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_inventory_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?lifecycle",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketLifecycleConfiguration",
    Request: type = struct {
        bucket: []const u8,
        checksum_algorithm: ?[]const u8 = null,
        lifecycle_configuration: ?struct {
            rules: []LifecycleRule,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rules = "Rule",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "lifecycle_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .checksum_algorithm = "ChecksumAlgorithm",
                .lifecycle_configuration = "LifecycleConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_logging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?logging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketLogging",
    Request: type = struct {
        bucket: []const u8,
        bucket_logging_status: struct {
            logging_enabled: ?LoggingEnabled = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .logging_enabled = "LoggingEnabled",
                };
                return @field(mappings, field_name);
            }
        },
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "bucket_logging_status";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .bucket_logging_status = "BucketLoggingStatus",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_logging) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_logging };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_metrics_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?metrics",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketMetricsConfiguration",
    Request: type = struct {
        bucket: []const u8,
        id: []const u8,
        metrics_configuration: MetricsConfiguration,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .id = "id",
        };

        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "metrics_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .id = "Id",
                .metrics_configuration = "MetricsConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_metrics_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_metrics_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_notification_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?notification",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketNotificationConfiguration",
    Request: type = struct {
        bucket: []const u8,
        notification_configuration: NotificationConfiguration,
        expected_bucket_owner: ?[]const u8 = null,
        skip_destination_validation: ?bool = null,
        pub const http_header = .{
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .skip_destination_validation = "x-amz-skip-destination-validation",
        };

        pub const http_payload: []const u8 = "notification_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .notification_configuration = "NotificationConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .skip_destination_validation = "SkipDestinationValidation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_notification_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_notification_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_ownership_controls: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?ownershipControls",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketOwnershipControls",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        ownership_controls: OwnershipControls,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "ownership_controls";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .ownership_controls = "OwnershipControls",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_ownership_controls) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_ownership_controls };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketPolicy",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        confirm_remove_self_bucket_access: ?bool = null,
        policy: []const u8,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .confirm_remove_self_bucket_access = "x-amz-confirm-remove-self-bucket-access",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .confirm_remove_self_bucket_access = "ConfirmRemoveSelfBucketAccess",
                .policy = "Policy",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_replication: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?replication",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketReplication",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        replication_configuration: ReplicationConfiguration,
        token: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .token = "x-amz-bucket-object-lock-token",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "replication_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .replication_configuration = "ReplicationConfiguration",
                .token = "Token",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_replication };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_request_payment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?requestPayment",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketRequestPayment",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        request_payment_configuration: struct {
            payer: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .payer = "Payer",
                };
                return @field(mappings, field_name);
            }
        },
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "request_payment_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .request_payment_configuration = "RequestPaymentConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_request_payment) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_request_payment };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketTagging",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        tagging: Tagging,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "tagging";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .tagging = "Tagging",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_versioning: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?versioning",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketVersioning",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        mfa: ?[]const u8 = null,
        versioning_configuration: struct {
            mfa_delete: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mfa_delete = "MfaDelete",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .mfa = "x-amz-mfa",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "versioning_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .mfa = "MFA",
                .versioning_configuration = "VersioningConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_versioning) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_versioning };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_website: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?website",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketWebsite",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        website_configuration: struct {
            error_document: ?ErrorDocument = null,
            index_document: ?IndexDocument = null,
            redirect_all_requests_to: ?RedirectAllRequestsTo = null,
            routing_rules: ?[]RoutingRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .error_document = "ErrorDocument",
                    .index_document = "IndexDocument",
                    .redirect_all_requests_to = "RedirectAllRequestsTo",
                    .routing_rules = "RoutingRules",
                };
                return @field(mappings, field_name);
            }
        },
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "website_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .website_configuration = "WebsiteConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_website) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_website };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?x-id=PutObject",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObject",
    Request: type = struct {
        acl: ?[]const u8 = null,
        body: ?[]const u8 = null,
        bucket: []const u8,
        cache_control: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_length: ?i64 = null,
        content_md5: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        expires: ?i64 = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        key: []const u8,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        server_side_encryption: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,
        website_redirect_location: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_payer: ?[]const u8 = null,
        tagging: ?[]const u8 = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .cache_control = "Cache-Control",
            .content_disposition = "Content-Disposition",
            .content_encoding = "Content-Encoding",
            .content_language = "Content-Language",
            .content_length = "Content-Length",
            .content_md5 = "Content-MD5",
            .content_type = "Content-Type",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .expires = "Expires",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write_acp = "x-amz-grant-write-acp",
            .server_side_encryption = "x-amz-server-side-encryption",
            .storage_class = "x-amz-storage-class",
            .website_redirect_location = "x-amz-website-redirect-location",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_payer = "x-amz-request-payer",
            .tagging = "x-amz-tagging",
            .object_lock_mode = "x-amz-object-lock-mode",
            .object_lock_retain_until_date = "x-amz-object-lock-retain-until-date",
            .object_lock_legal_hold_status = "x-amz-object-lock-legal-hold",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .body = "Body",
                .bucket = "Bucket",
                .cache_control = "CacheControl",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_length = "ContentLength",
                .content_md5 = "ContentMD5",
                .content_type = "ContentType",
                .checksum_algorithm = "ChecksumAlgorithm",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .expires = "Expires",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write_acp = "GrantWriteACP",
                .key = "Key",
                .metadata = "Metadata",
                .server_side_encryption = "ServerSideEncryption",
                .storage_class = "StorageClass",
                .website_redirect_location = "WebsiteRedirectLocation",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_payer = "RequestPayer",
                .tagging = "Tagging",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object) } {
            return .{ .service_metadata = service_metadata, .action = put_object };
        }
    },
    Response: type = struct {
        expiration: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        ssekms_encryption_context: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .expiration = "x-amz-expiration",
            .e_tag = "ETag",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .server_side_encryption = "x-amz-server-side-encryption",
            .version_id = "x-amz-version-id",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .ssekms_encryption_context = "x-amz-server-side-encryption-context",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expiration = "Expiration",
                .e_tag = "ETag",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .server_side_encryption = "ServerSideEncryption",
                .version_id = "VersionId",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .ssekms_encryption_context = "SSEKMSEncryptionContext",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_object_acl: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?acl",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObjectAcl",
    Request: type = struct {
        acl: ?[]const u8 = null,
        access_control_policy: ?AccessControlPolicy = null,
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        key: []const u8,
        request_payer: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .acl = "x-amz-acl",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write = "x-amz-grant-write",
            .grant_write_acp = "x-amz-grant-write-acp",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "access_control_policy";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .access_control_policy = "AccessControlPolicy",
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write = "GrantWrite",
                .grant_write_acp = "GrantWriteACP",
                .key = "Key",
                .request_payer = "RequestPayer",
                .version_id = "VersionId",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object_acl) } {
            return .{ .service_metadata = service_metadata, .action = put_object_acl };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchKey,
    },
} = .{};
pub const put_object_legal_hold: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?legal-hold",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObjectLegalHold",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        legal_hold: ?ObjectLockLegalHold = null,
        request_payer: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "legal_hold";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .legal_hold = "LegalHold",
                .request_payer = "RequestPayer",
                .version_id = "VersionId",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = put_object_legal_hold };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_object_lock_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?object-lock",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObjectLockConfiguration",
    Request: type = struct {
        bucket: []const u8,
        object_lock_configuration: ?ObjectLockConfiguration = null,
        request_payer: ?[]const u8 = null,
        token: ?[]const u8 = null,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .token = "x-amz-bucket-object-lock-token",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "object_lock_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .object_lock_configuration = "ObjectLockConfiguration",
                .request_payer = "RequestPayer",
                .token = "Token",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object_lock_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_object_lock_configuration };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_object_retention: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?retention",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObjectRetention",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        retention: ?ObjectLockRetention = null,
        request_payer: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        bypass_governance_retention: ?bool = null,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .bypass_governance_retention = "x-amz-bypass-governance-retention",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "retention";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .retention = "Retention",
                .request_payer = "RequestPayer",
                .version_id = "VersionId",
                .bypass_governance_retention = "BypassGovernanceRetention",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object_retention) } {
            return .{ .service_metadata = service_metadata, .action = put_object_retention };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_object_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObjectTagging",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        tagging: Tagging,
        expected_bucket_owner: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .request_payer = "x-amz-request-payer",
        };

        pub const http_payload: []const u8 = "tagging";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .tagging = "Tagging",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .request_payer = "RequestPayer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_object_tagging };
        }
    },
    Response: type = struct {
        version_id: ?[]const u8 = null,
        pub const http_header = .{
            .version_id = "x-amz-version-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_public_access_block: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}?publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPublicAccessBlock",
    Request: type = struct {
        bucket: []const u8,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        public_access_block_configuration: PublicAccessBlockConfiguration,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = put_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const restore_object: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{Bucket}/{Key+}?restore&x-id=RestoreObject",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreObject",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        version_id: ?[]const u8 = null,
        restore_request: ?struct {
            days: ?i64 = null,
            glacier_job_parameters: ?struct {
                tier: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .tier = "Tier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            type: ?[]const u8 = null,
            tier: ?[]const u8 = null,
            description: ?[]const u8 = null,
            select_parameters: ?struct {
                input_serialization: InputSerialization,
                expression_type: []const u8,
                expression: []const u8,
                output_serialization: OutputSerialization,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_serialization = "InputSerialization",
                        .expression_type = "ExpressionType",
                        .expression = "Expression",
                        .output_serialization = "OutputSerialization",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            output_location: ?struct {
                s3: ?struct {
                    bucket_name: []const u8,
                    prefix: []const u8,
                    encryption: ?struct {
                        encryption_type: []const u8,
                        kms_key_id: ?[]const u8 = null,
                        kms_context: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .encryption_type = "EncryptionType",
                                .kms_key_id = "KMSKeyId",
                                .kms_context = "KMSContext",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    canned_acl: ?[]const u8 = null,
                    access_control_list: ?[]Grant = null,
                    tagging: ?Tagging = null,
                    user_metadata: ?[]struct {
                        name: ?[]const u8 = null,
                        value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .value = "Value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    storage_class: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket_name = "BucketName",
                            .prefix = "Prefix",
                            .encryption = "Encryption",
                            .canned_acl = "CannedACL",
                            .access_control_list = "AccessControlList",
                            .tagging = "Tagging",
                            .user_metadata = "UserMetadata",
                            .storage_class = "StorageClass",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3 = "S3",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .days = "Days",
                    .glacier_job_parameters = "GlacierJobParameters",
                    .type = "Type",
                    .tier = "Tier",
                    .description = "Description",
                    .select_parameters = "SelectParameters",
                    .output_location = "OutputLocation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_payer: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub const http_header = .{
            .request_payer = "x-amz-request-payer",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "restore_request";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .version_id = "VersionId",
                .restore_request = "RestoreRequest",
                .request_payer = "RequestPayer",
                .checksum_algorithm = "ChecksumAlgorithm",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_object) } {
            return .{ .service_metadata = service_metadata, .action = restore_object };
        }
    },
    Response: type = struct {
        request_charged: ?[]const u8 = null,
        restore_output_path: ?[]const u8 = null,
        pub const http_header = .{
            .request_charged = "x-amz-request-charged",
            .restore_output_path = "x-amz-restore-output-path",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_charged = "RequestCharged",
                .restore_output_path = "RestoreOutputPath",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ObjectAlreadyInActiveTierError,
    },
} = .{};
pub const select_object_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/{Bucket}/{Key+}?select&select-type=2&x-id=SelectObjectContent",
        .success_code = 200,
    };

    action_name: []const u8 = "SelectObjectContent",
    Request: type = struct {
        bucket: []const u8,
        key: []const u8,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        expression: []const u8,
        expression_type: []const u8,
        request_progress: ?struct {
            enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enabled = "Enabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        input_serialization: InputSerialization,
        output_serialization: OutputSerialization,
        scan_range: ?struct {
            start: ?i64 = null,
            end: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start = "Start",
                    .end = "End",
                };
                return @field(mappings, field_name);
            }
        } = null,
        expected_bucket_owner: ?[]const u8 = null,
        pub const http_header = .{
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .key = "Key",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .expression = "Expression",
                .expression_type = "ExpressionType",
                .request_progress = "RequestProgress",
                .input_serialization = "InputSerialization",
                .output_serialization = "OutputSerialization",
                .scan_range = "ScanRange",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(select_object_content) } {
            return .{ .service_metadata = service_metadata, .action = select_object_content };
        }
    },
    Response: type = struct {
        payload: ?union {
            records: ?struct {
                payload: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .payload = "Payload",
                    };
                    return @field(mappings, field_name);
                }
            },
            stats: ?struct {
                details: ?struct {
                    bytes_scanned: ?i64 = null,
                    bytes_processed: ?i64 = null,
                    bytes_returned: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bytes_scanned = "BytesScanned",
                            .bytes_processed = "BytesProcessed",
                            .bytes_returned = "BytesReturned",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .details = "Details",
                    };
                    return @field(mappings, field_name);
                }
            },
            progress: ?struct {
                details: ?struct {
                    bytes_scanned: ?i64 = null,
                    bytes_processed: ?i64 = null,
                    bytes_returned: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bytes_scanned = "BytesScanned",
                            .bytes_processed = "BytesProcessed",
                            .bytes_returned = "BytesReturned",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .details = "Details",
                    };
                    return @field(mappings, field_name);
                }
            },
            cont: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            },
            end: ?struct {

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{};
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .records = "Records",
                    .stats = "Stats",
                    .progress = "Progress",
                    .cont = "Cont",
                    .end = "End",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const upload_part: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?x-id=UploadPart",
        .success_code = 200,
    };

    action_name: []const u8 = "UploadPart",
    Request: type = struct {
        body: ?[]const u8 = null,
        bucket: []const u8,
        content_length: ?i64 = null,
        content_md5: ?[]const u8 = null,
        checksum_algorithm: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        key: []const u8,
        part_number: i64,
        upload_id: []const u8,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .part_number = "partNumber",
            .upload_id = "uploadId",
        };

        pub const http_header = .{
            .content_length = "Content-Length",
            .content_md5 = "Content-MD5",
            .checksum_algorithm = "x-amz-sdk-checksum-algorithm",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .bucket = "Bucket",
                .content_length = "ContentLength",
                .content_md5 = "ContentMD5",
                .checksum_algorithm = "ChecksumAlgorithm",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .key = "Key",
                .part_number = "PartNumber",
                .upload_id = "UploadId",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_part) } {
            return .{ .service_metadata = service_metadata, .action = upload_part };
        }
    },
    Response: type = struct {
        server_side_encryption: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .server_side_encryption = "x-amz-server-side-encryption",
            .e_tag = "ETag",
            .checksum_crc32 = "x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-checksum-sha256",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_side_encryption = "ServerSideEncryption",
                .e_tag = "ETag",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const upload_part_copy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Bucket}/{Key+}?x-id=UploadPartCopy",
        .success_code = 200,
    };

    action_name: []const u8 = "UploadPartCopy",
    Request: type = struct {
        bucket: []const u8,
        copy_source: []const u8,
        copy_source_if_match: ?[]const u8 = null,
        copy_source_if_modified_since: ?i64 = null,
        copy_source_if_none_match: ?[]const u8 = null,
        copy_source_if_unmodified_since: ?i64 = null,
        copy_source_range: ?[]const u8 = null,
        key: []const u8,
        part_number: i64,
        upload_id: []const u8,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        copy_source_sse_customer_algorithm: ?[]const u8 = null,
        copy_source_sse_customer_key: ?[]const u8 = null,
        copy_source_sse_customer_key_md5: ?[]const u8 = null,
        request_payer: ?[]const u8 = null,
        expected_bucket_owner: ?[]const u8 = null,
        expected_source_bucket_owner: ?[]const u8 = null,

        pub const http_query = .{
            .part_number = "partNumber",
            .upload_id = "uploadId",
        };

        pub const http_header = .{
            .copy_source = "x-amz-copy-source",
            .copy_source_if_match = "x-amz-copy-source-if-match",
            .copy_source_if_modified_since = "x-amz-copy-source-if-modified-since",
            .copy_source_if_none_match = "x-amz-copy-source-if-none-match",
            .copy_source_if_unmodified_since = "x-amz-copy-source-if-unmodified-since",
            .copy_source_range = "x-amz-copy-source-range",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key = "x-amz-server-side-encryption-customer-key",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .copy_source_sse_customer_algorithm = "x-amz-copy-source-server-side-encryption-customer-algorithm",
            .copy_source_sse_customer_key = "x-amz-copy-source-server-side-encryption-customer-key",
            .copy_source_sse_customer_key_md5 = "x-amz-copy-source-server-side-encryption-customer-key-MD5",
            .request_payer = "x-amz-request-payer",
            .expected_bucket_owner = "x-amz-expected-bucket-owner",
            .expected_source_bucket_owner = "x-amz-source-expected-bucket-owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .copy_source = "CopySource",
                .copy_source_if_match = "CopySourceIfMatch",
                .copy_source_if_modified_since = "CopySourceIfModifiedSince",
                .copy_source_if_none_match = "CopySourceIfNoneMatch",
                .copy_source_if_unmodified_since = "CopySourceIfUnmodifiedSince",
                .copy_source_range = "CopySourceRange",
                .key = "Key",
                .part_number = "PartNumber",
                .upload_id = "UploadId",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key = "SSECustomerKey",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .copy_source_sse_customer_algorithm = "CopySourceSSECustomerAlgorithm",
                .copy_source_sse_customer_key = "CopySourceSSECustomerKey",
                .copy_source_sse_customer_key_md5 = "CopySourceSSECustomerKeyMD5",
                .request_payer = "RequestPayer",
                .expected_bucket_owner = "ExpectedBucketOwner",
                .expected_source_bucket_owner = "ExpectedSourceBucketOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_part_copy) } {
            return .{ .service_metadata = service_metadata, .action = upload_part_copy };
        }
    },
    Response: type = struct {
        copy_source_version_id: ?[]const u8 = null,
        copy_part_result: ?struct {
            e_tag: ?[]const u8 = null,
            last_modified: ?i64 = null,
            checksum_crc32: ?[]const u8 = null,
            checksum_crc32c: ?[]const u8 = null,
            checksum_sha1: ?[]const u8 = null,
            checksum_sha256: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .e_tag = "ETag",
                    .last_modified = "LastModified",
                    .checksum_crc32 = "ChecksumCRC32",
                    .checksum_crc32c = "ChecksumCRC32C",
                    .checksum_sha1 = "ChecksumSHA1",
                    .checksum_sha256 = "ChecksumSHA256",
                };
                return @field(mappings, field_name);
            }
        } = null,
        server_side_encryption: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        request_charged: ?[]const u8 = null,
        pub const http_header = .{
            .copy_source_version_id = "x-amz-copy-source-version-id",
            .server_side_encryption = "x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-server-side-encryption-customer-algorithm",
            .sse_customer_key_md5 = "x-amz-server-side-encryption-customer-key-MD5",
            .ssekms_key_id = "x-amz-server-side-encryption-aws-kms-key-id",
            .bucket_key_enabled = "x-amz-server-side-encryption-bucket-key-enabled",
            .request_charged = "x-amz-request-charged",
        };

        pub const http_payload: []const u8 = "copy_part_result";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_source_version_id = "CopySourceVersionId",
                .copy_part_result = "CopyPartResult",
                .server_side_encryption = "ServerSideEncryption",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .ssekms_key_id = "SSEKMSKeyId",
                .bucket_key_enabled = "BucketKeyEnabled",
                .request_charged = "RequestCharged",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const write_get_object_response: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/WriteGetObjectResponse?x-id=WriteGetObjectResponse",
        .success_code = 200,
    };

    action_name: []const u8 = "WriteGetObjectResponse",
    Request: type = struct {
        request_route: []const u8,
        request_token: []const u8,
        body: ?[]const u8 = null,
        status_code: ?i64 = null,
        error_code: ?[]const u8 = null,
        error_message: ?[]const u8 = null,
        accept_ranges: ?[]const u8 = null,
        cache_control: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        content_language: ?[]const u8 = null,
        content_length: ?i64 = null,
        content_range: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        checksum_crc32: ?[]const u8 = null,
        checksum_crc32c: ?[]const u8 = null,
        checksum_sha1: ?[]const u8 = null,
        checksum_sha256: ?[]const u8 = null,
        delete_marker: ?bool = null,
        e_tag: ?[]const u8 = null,
        expires: ?i64 = null,
        expiration: ?[]const u8 = null,
        last_modified: ?i64 = null,
        missing_meta: ?i64 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        object_lock_mode: ?[]const u8 = null,
        object_lock_legal_hold_status: ?[]const u8 = null,
        object_lock_retain_until_date: ?i64 = null,
        parts_count: ?i64 = null,
        replication_status: ?[]const u8 = null,
        request_charged: ?[]const u8 = null,
        restore: ?[]const u8 = null,
        server_side_encryption: ?[]const u8 = null,
        sse_customer_algorithm: ?[]const u8 = null,
        ssekms_key_id: ?[]const u8 = null,
        sse_customer_key_md5: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,
        tag_count: ?i64 = null,
        version_id: ?[]const u8 = null,
        bucket_key_enabled: ?bool = null,
        pub const http_header = .{
            .request_route = "x-amz-request-route",
            .request_token = "x-amz-request-token",
            .status_code = "x-amz-fwd-status",
            .error_code = "x-amz-fwd-error-code",
            .error_message = "x-amz-fwd-error-message",
            .accept_ranges = "x-amz-fwd-header-accept-ranges",
            .cache_control = "x-amz-fwd-header-Cache-Control",
            .content_disposition = "x-amz-fwd-header-Content-Disposition",
            .content_encoding = "x-amz-fwd-header-Content-Encoding",
            .content_language = "x-amz-fwd-header-Content-Language",
            .content_length = "Content-Length",
            .content_range = "x-amz-fwd-header-Content-Range",
            .content_type = "x-amz-fwd-header-Content-Type",
            .checksum_crc32 = "x-amz-fwd-header-x-amz-checksum-crc32",
            .checksum_crc32c = "x-amz-fwd-header-x-amz-checksum-crc32c",
            .checksum_sha1 = "x-amz-fwd-header-x-amz-checksum-sha1",
            .checksum_sha256 = "x-amz-fwd-header-x-amz-checksum-sha256",
            .delete_marker = "x-amz-fwd-header-x-amz-delete-marker",
            .e_tag = "x-amz-fwd-header-ETag",
            .expires = "x-amz-fwd-header-Expires",
            .expiration = "x-amz-fwd-header-x-amz-expiration",
            .last_modified = "x-amz-fwd-header-Last-Modified",
            .missing_meta = "x-amz-fwd-header-x-amz-missing-meta",
            .object_lock_mode = "x-amz-fwd-header-x-amz-object-lock-mode",
            .object_lock_legal_hold_status = "x-amz-fwd-header-x-amz-object-lock-legal-hold",
            .object_lock_retain_until_date = "x-amz-fwd-header-x-amz-object-lock-retain-until-date",
            .parts_count = "x-amz-fwd-header-x-amz-mp-parts-count",
            .replication_status = "x-amz-fwd-header-x-amz-replication-status",
            .request_charged = "x-amz-fwd-header-x-amz-request-charged",
            .restore = "x-amz-fwd-header-x-amz-restore",
            .server_side_encryption = "x-amz-fwd-header-x-amz-server-side-encryption",
            .sse_customer_algorithm = "x-amz-fwd-header-x-amz-server-side-encryption-customer-algorithm",
            .ssekms_key_id = "x-amz-fwd-header-x-amz-server-side-encryption-aws-kms-key-id",
            .sse_customer_key_md5 = "x-amz-fwd-header-x-amz-server-side-encryption-customer-key-MD5",
            .storage_class = "x-amz-fwd-header-x-amz-storage-class",
            .tag_count = "x-amz-fwd-header-x-amz-tagging-count",
            .version_id = "x-amz-fwd-header-x-amz-version-id",
            .bucket_key_enabled = "x-amz-fwd-header-x-amz-server-side-encryption-bucket-key-enabled",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_route = "RequestRoute",
                .request_token = "RequestToken",
                .body = "Body",
                .status_code = "StatusCode",
                .error_code = "ErrorCode",
                .error_message = "ErrorMessage",
                .accept_ranges = "AcceptRanges",
                .cache_control = "CacheControl",
                .content_disposition = "ContentDisposition",
                .content_encoding = "ContentEncoding",
                .content_language = "ContentLanguage",
                .content_length = "ContentLength",
                .content_range = "ContentRange",
                .content_type = "ContentType",
                .checksum_crc32 = "ChecksumCRC32",
                .checksum_crc32c = "ChecksumCRC32C",
                .checksum_sha1 = "ChecksumSHA1",
                .checksum_sha256 = "ChecksumSHA256",
                .delete_marker = "DeleteMarker",
                .e_tag = "ETag",
                .expires = "Expires",
                .expiration = "Expiration",
                .last_modified = "LastModified",
                .missing_meta = "MissingMeta",
                .metadata = "Metadata",
                .object_lock_mode = "ObjectLockMode",
                .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
                .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
                .parts_count = "PartsCount",
                .replication_status = "ReplicationStatus",
                .request_charged = "RequestCharged",
                .restore = "Restore",
                .server_side_encryption = "ServerSideEncryption",
                .sse_customer_algorithm = "SSECustomerAlgorithm",
                .ssekms_key_id = "SSEKMSKeyId",
                .sse_customer_key_md5 = "SSECustomerKeyMD5",
                .storage_class = "StorageClass",
                .tag_count = "TagCount",
                .version_id = "VersionId",
                .bucket_key_enabled = "BucketKeyEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(write_get_object_response) } {
            return .{ .service_metadata = service_metadata, .action = write_get_object_response };
        }
    },
    Response: type = struct {},
} = .{};

pub const OutputSerialization = struct {
    csv: ?CSVOutput = null,
    json: ?JSONOutput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "CSV",
            .json = "JSON",
        };
        return @field(mappings, field_name);
    }
};

pub const JSONOutput = struct {
    record_delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .record_delimiter = "RecordDelimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const CSVOutput = struct {
    quote_fields: ?[]const u8 = null,
    quote_escape_character: ?[]const u8 = null,
    record_delimiter: ?[]const u8 = null,
    field_delimiter: ?[]const u8 = null,
    quote_character: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quote_fields = "QuoteFields",
            .quote_escape_character = "QuoteEscapeCharacter",
            .record_delimiter = "RecordDelimiter",
            .field_delimiter = "FieldDelimiter",
            .quote_character = "QuoteCharacter",
        };
        return @field(mappings, field_name);
    }
};

pub const InputSerialization = struct {
    csv: ?CSVInput = null,
    compression_type: ?[]const u8 = null,
    json: ?JSONInput = null,
    parquet: ?ParquetInput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv = "CSV",
            .compression_type = "CompressionType",
            .json = "JSON",
            .parquet = "Parquet",
        };
        return @field(mappings, field_name);
    }
};

pub const ParquetInput = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const JSONInput = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const CSVInput = struct {
    file_header_info: ?[]const u8 = null,
    comments: ?[]const u8 = null,
    quote_escape_character: ?[]const u8 = null,
    record_delimiter: ?[]const u8 = null,
    field_delimiter: ?[]const u8 = null,
    quote_character: ?[]const u8 = null,
    allow_quoted_record_delimiter: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_header_info = "FileHeaderInfo",
            .comments = "Comments",
            .quote_escape_character = "QuoteEscapeCharacter",
            .record_delimiter = "RecordDelimiter",
            .field_delimiter = "FieldDelimiter",
            .quote_character = "QuoteCharacter",
            .allow_quoted_record_delimiter = "AllowQuotedRecordDelimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const Tagging = struct {
    tag_set: []Tag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_set = "TagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Grant = struct {
    grantee: ?Grantee = null,
    permission: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee = "Grantee",
            .permission = "Permission",
        };
        return @field(mappings, field_name);
    }
};

pub const Grantee = struct {
    display_name: ?[]const u8 = null,
    email_address: ?[]const u8 = null,
    id: ?[]const u8 = null,
    uri: ?[]const u8 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "DisplayName",
            .email_address = "EmailAddress",
            .id = "ID",
            .uri = "URI",
            .type = "xsi:type",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicAccessBlockConfiguration = struct {
    block_public_acls: ?bool = null,
    ignore_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "BlockPublicAcls",
            .ignore_public_acls = "IgnorePublicAcls",
            .block_public_policy = "BlockPublicPolicy",
            .restrict_public_buckets = "RestrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLockRetention = struct {
    mode: ?[]const u8 = null,
    retain_until_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .retain_until_date = "RetainUntilDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLockConfiguration = struct {
    object_lock_enabled: ?[]const u8 = null,
    rule: ?ObjectLockRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_lock_enabled = "ObjectLockEnabled",
            .rule = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLockRule = struct {
    default_retention: ?DefaultRetention = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_retention = "DefaultRetention",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultRetention = struct {
    mode: ?[]const u8 = null,
    days: ?i64 = null,
    years: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .days = "Days",
            .years = "Years",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLockLegalHold = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlPolicy = struct {
    grants: ?[]Grant = null,
    owner: ?Owner = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grants = "AccessControlList",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const Owner = struct {
    display_name: ?[]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "DisplayName",
            .id = "ID",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingRule = struct {
    condition: ?Condition = null,
    redirect: Redirect,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .redirect = "Redirect",
        };
        return @field(mappings, field_name);
    }
};

pub const Redirect = struct {
    host_name: ?[]const u8 = null,
    http_redirect_code: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    replace_key_prefix_with: ?[]const u8 = null,
    replace_key_with: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_name = "HostName",
            .http_redirect_code = "HttpRedirectCode",
            .protocol = "Protocol",
            .replace_key_prefix_with = "ReplaceKeyPrefixWith",
            .replace_key_with = "ReplaceKeyWith",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    http_error_code_returned_equals: ?[]const u8 = null,
    key_prefix_equals: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_error_code_returned_equals = "HttpErrorCodeReturnedEquals",
            .key_prefix_equals = "KeyPrefixEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const RedirectAllRequestsTo = struct {
    host_name: []const u8,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_name = "HostName",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const IndexDocument = struct {
    suffix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .suffix = "Suffix",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDocument = struct {
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationConfiguration = struct {
    role: []const u8,
    rules: []ReplicationRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role = "Role",
            .rules = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRule = struct {
    id: ?[]const u8 = null,
    priority: ?i64 = null,
    prefix: ?[]const u8 = null,
    filter: ?ReplicationRuleFilter = null,
    status: []const u8,
    source_selection_criteria: ?SourceSelectionCriteria = null,
    existing_object_replication: ?ExistingObjectReplication = null,
    destination: Destination,
    delete_marker_replication: ?DeleteMarkerReplication = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .priority = "Priority",
            .prefix = "Prefix",
            .filter = "Filter",
            .status = "Status",
            .source_selection_criteria = "SourceSelectionCriteria",
            .existing_object_replication = "ExistingObjectReplication",
            .destination = "Destination",
            .delete_marker_replication = "DeleteMarkerReplication",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteMarkerReplication = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    bucket: []const u8,
    account: ?[]const u8 = null,
    storage_class: ?[]const u8 = null,
    access_control_translation: ?AccessControlTranslation = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    replication_time: ?ReplicationTime = null,
    metrics: ?Metrics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .account = "Account",
            .storage_class = "StorageClass",
            .access_control_translation = "AccessControlTranslation",
            .encryption_configuration = "EncryptionConfiguration",
            .replication_time = "ReplicationTime",
            .metrics = "Metrics",
        };
        return @field(mappings, field_name);
    }
};

pub const Metrics = struct {
    status: []const u8,
    event_threshold: ?ReplicationTimeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .event_threshold = "EventThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTimeValue = struct {
    minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minutes = "Minutes",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTime = struct {
    status: []const u8,
    time: ReplicationTimeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .time = "Time",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    replica_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replica_kms_key_id = "ReplicaKmsKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlTranslation = struct {
    owner: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const ExistingObjectReplication = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceSelectionCriteria = struct {
    sse_kms_encrypted_objects: ?SseKmsEncryptedObjects = null,
    replica_modifications: ?ReplicaModifications = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sse_kms_encrypted_objects = "SseKmsEncryptedObjects",
            .replica_modifications = "ReplicaModifications",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaModifications = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SseKmsEncryptedObjects = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRuleFilter = union {
    prefix: ?[]const u8,
    tag: ?Tag,
    @"and": ?ReplicationRuleAndOperator,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRuleAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tag",
        };
        return @field(mappings, field_name);
    }
};

pub const OwnershipControls = struct {
    rules: []OwnershipControlsRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const OwnershipControlsRule = struct {
    object_ownership: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_ownership = "ObjectOwnership",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfiguration = struct {
    topic_configurations: ?[]TopicConfiguration = null,
    queue_configurations: ?[]QueueConfiguration = null,
    lambda_function_configurations: ?[]LambdaFunctionConfiguration = null,
    event_bridge_configuration: ?EventBridgeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_configurations = "TopicConfiguration",
            .queue_configurations = "QueueConfiguration",
            .lambda_function_configurations = "CloudFunctionConfiguration",
            .event_bridge_configuration = "EventBridgeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EventBridgeConfiguration = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionConfiguration = struct {
    id: ?[]const u8 = null,
    lambda_function_arn: []const u8,
    events: [][]const u8,
    filter: ?NotificationConfigurationFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .lambda_function_arn = "CloudFunction",
            .events = "Event",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfigurationFilter = struct {
    key: ?S3KeyFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const S3KeyFilter = struct {
    filter_rules: ?[]FilterRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_rules = "FilterRule",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterRule = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueConfiguration = struct {
    id: ?[]const u8 = null,
    queue_arn: []const u8,
    events: [][]const u8,
    filter: ?NotificationConfigurationFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .queue_arn = "Queue",
            .events = "Event",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicConfiguration = struct {
    id: ?[]const u8 = null,
    topic_arn: []const u8,
    events: [][]const u8,
    filter: ?NotificationConfigurationFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .topic_arn = "Topic",
            .events = "Event",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsConfiguration = struct {
    id: []const u8,
    filter: ?MetricsFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .filter = "Filter",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsFilter = union {
    prefix: ?[]const u8,
    tag: ?Tag,
    access_point_arn: ?[]const u8,
    @"and": ?MetricsAndOperator,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .access_point_arn = "AccessPointArn",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]Tag = null,
    access_point_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tag",
            .access_point_arn = "AccessPointArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingEnabled = struct {
    target_bucket: []const u8,
    target_grants: ?[]TargetGrant = null,
    target_prefix: []const u8,
    target_object_key_format: ?TargetObjectKeyFormat = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_bucket = "TargetBucket",
            .target_grants = "TargetGrants",
            .target_prefix = "TargetPrefix",
            .target_object_key_format = "TargetObjectKeyFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetObjectKeyFormat = struct {
    simple_prefix: ?SimplePrefix = null,
    partitioned_prefix: ?PartitionedPrefix = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_prefix = "SimplePrefix",
            .partitioned_prefix = "PartitionedPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionedPrefix = struct {
    partition_date_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partition_date_source = "PartitionDateSource",
        };
        return @field(mappings, field_name);
    }
};

pub const SimplePrefix = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const TargetGrant = struct {
    grantee: ?Grantee = null,
    permission: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee = "Grantee",
            .permission = "Permission",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRule = struct {
    expiration: ?LifecycleExpiration = null,
    id: ?[]const u8 = null,
    prefix: ?[]const u8 = null,
    filter: ?LifecycleRuleFilter = null,
    status: []const u8,
    transitions: ?[]Transition = null,
    noncurrent_version_transitions: ?[]NoncurrentVersionTransition = null,
    noncurrent_version_expiration: ?NoncurrentVersionExpiration = null,
    abort_incomplete_multipart_upload: ?AbortIncompleteMultipartUpload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration = "Expiration",
            .id = "ID",
            .prefix = "Prefix",
            .filter = "Filter",
            .status = "Status",
            .transitions = "Transition",
            .noncurrent_version_transitions = "NoncurrentVersionTransition",
            .noncurrent_version_expiration = "NoncurrentVersionExpiration",
            .abort_incomplete_multipart_upload = "AbortIncompleteMultipartUpload",
        };
        return @field(mappings, field_name);
    }
};

pub const AbortIncompleteMultipartUpload = struct {
    days_after_initiation: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_after_initiation = "DaysAfterInitiation",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionExpiration = struct {
    noncurrent_days: ?i64 = null,
    newer_noncurrent_versions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
            .newer_noncurrent_versions = "NewerNoncurrentVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionTransition = struct {
    noncurrent_days: ?i64 = null,
    storage_class: ?[]const u8 = null,
    newer_noncurrent_versions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
            .storage_class = "StorageClass",
            .newer_noncurrent_versions = "NewerNoncurrentVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const Transition = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleFilter = union {
    prefix: ?[]const u8,
    tag: ?Tag,
    object_size_greater_than: ?i64,
    object_size_less_than: ?i64,
    @"and": ?LifecycleRuleAndOperator,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .object_size_greater_than = "ObjectSizeGreaterThan",
            .object_size_less_than = "ObjectSizeLessThan",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]Tag = null,
    object_size_greater_than: ?i64 = null,
    object_size_less_than: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tag",
            .object_size_greater_than = "ObjectSizeGreaterThan",
            .object_size_less_than = "ObjectSizeLessThan",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExpiration = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    expired_object_delete_marker: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .expired_object_delete_marker = "ExpiredObjectDeleteMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryConfiguration = struct {
    destination: InventoryDestination,
    is_enabled: bool,
    filter: ?InventoryFilter = null,
    id: []const u8,
    included_object_versions: []const u8,
    optional_fields: ?[][]const u8 = null,
    schedule: InventorySchedule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .is_enabled = "IsEnabled",
            .filter = "Filter",
            .id = "Id",
            .included_object_versions = "IncludedObjectVersions",
            .optional_fields = "OptionalFields",
            .schedule = "Schedule",
        };
        return @field(mappings, field_name);
    }
};

pub const InventorySchedule = struct {
    frequency: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .frequency = "Frequency",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryFilter = struct {
    prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryDestination = struct {
    s3_bucket_destination: InventoryS3BucketDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_destination = "S3BucketDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryS3BucketDestination = struct {
    account_id: ?[]const u8 = null,
    bucket: []const u8,
    format: []const u8,
    prefix: ?[]const u8 = null,
    encryption: ?InventoryEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .bucket = "Bucket",
            .format = "Format",
            .prefix = "Prefix",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryEncryption = struct {
    sses3: ?SSES3 = null,
    ssekms: ?SSEKMS = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sses3 = "SSE-S3",
            .ssekms = "SSE-KMS",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEKMS = struct {
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const SSES3 = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const IntelligentTieringConfiguration = struct {
    id: []const u8,
    filter: ?IntelligentTieringFilter = null,
    status: []const u8,
    tierings: []Tiering,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .filter = "Filter",
            .status = "Status",
            .tierings = "Tiering",
        };
        return @field(mappings, field_name);
    }
};

pub const Tiering = struct {
    days: i64,
    access_tier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days = "Days",
            .access_tier = "AccessTier",
        };
        return @field(mappings, field_name);
    }
};

pub const IntelligentTieringFilter = struct {
    prefix: ?[]const u8 = null,
    tag: ?Tag = null,
    @"and": ?IntelligentTieringAndOperator = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const IntelligentTieringAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tag",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionConfiguration = struct {
    rules: []ServerSideEncryptionRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionRule = struct {
    apply_server_side_encryption_by_default: ?ServerSideEncryptionByDefault = null,
    bucket_key_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_server_side_encryption_by_default = "ApplyServerSideEncryptionByDefault",
            .bucket_key_enabled = "BucketKeyEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryptionByDefault = struct {
    sse_algorithm: []const u8,
    kms_master_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sse_algorithm = "SSEAlgorithm",
            .kms_master_key_id = "KMSMasterKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const CORSRule = struct {
    id: ?[]const u8 = null,
    allowed_headers: ?[][]const u8 = null,
    allowed_methods: [][]const u8,
    allowed_origins: [][]const u8,
    expose_headers: ?[][]const u8 = null,
    max_age_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .allowed_headers = "AllowedHeader",
            .allowed_methods = "AllowedMethod",
            .allowed_origins = "AllowedOrigin",
            .expose_headers = "ExposeHeader",
            .max_age_seconds = "MaxAgeSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsConfiguration = struct {
    id: []const u8,
    filter: ?AnalyticsFilter = null,
    storage_class_analysis: StorageClassAnalysis,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .filter = "Filter",
            .storage_class_analysis = "StorageClassAnalysis",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageClassAnalysis = struct {
    data_export: ?StorageClassAnalysisDataExport = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_export = "DataExport",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageClassAnalysisDataExport = struct {
    output_schema_version: []const u8,
    destination: AnalyticsExportDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_schema_version = "OutputSchemaVersion",
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsExportDestination = struct {
    s3_bucket_destination: AnalyticsS3BucketDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_destination = "S3BucketDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsS3BucketDestination = struct {
    format: []const u8,
    bucket_account_id: ?[]const u8 = null,
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .bucket_account_id = "BucketAccountId",
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsFilter = union {
    prefix: ?[]const u8,
    tag: ?Tag,
    @"and": ?AnalyticsAndOperator,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tag",
        };
        return @field(mappings, field_name);
    }
};

pub const Initiator = struct {
    id: ?[]const u8 = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const CommonPrefix = struct {
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreStatus = struct {
    is_restore_in_progress: ?bool = null,
    restore_expiry_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_restore_in_progress = "IsRestoreInProgress",
            .restore_expiry_date = "RestoreExpiryDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Object = struct {
    key: ?[]const u8 = null,
    last_modified: ?i64 = null,
    e_tag: ?[]const u8 = null,
    checksum_algorithm: ?[][]const u8 = null,
    size: ?i64 = null,
    storage_class: ?[]const u8 = null,
    owner: ?Owner = null,
    restore_status: ?RestoreStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .last_modified = "LastModified",
            .e_tag = "ETag",
            .checksum_algorithm = "ChecksumAlgorithm",
            .size = "Size",
            .storage_class = "StorageClass",
            .owner = "Owner",
            .restore_status = "RestoreStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Bucket = struct {
    name: ?[]const u8 = null,
    creation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }
};
