const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-26";
pub const sdk_id: []const u8 = "SecurityHub";
pub const arn_namespace: ?[]const u8 = "securityhub";
pub const endpoint_prefix: []const u8 = "securityhub";
pub const sigv4_name: []const u8 = "securityhub";
pub const name: []const u8 = "SecurityHubAPIService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-26",
    sdk_id: []const u8 = "SecurityHub",
    arn_namespace: ?[]const u8 = "securityhub",
    endpoint_prefix: []const u8 = "securityhub",
    sigv4_name: []const u8 = "securityhub",
    name: []const u8 = "SecurityHubAPIService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_administrator_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptAdministratorInvitation",
    Request: type = struct {
        administrator_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator_id = "AdministratorId",
                .invitation_id = "InvitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_administrator_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_administrator_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const accept_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/master",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInvitation",
    Request: type = struct {
        master_id: []const u8,
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master_id = "MasterId",
                .invitation_id = "InvitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_delete_automation_rules: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/automationrules/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteAutomationRules",
    Request: type = struct {
        automation_rules_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_rules_arns = "AutomationRulesArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_automation_rules) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_automation_rules };
        }
    },
    Response: type = struct {
        processed_automation_rules: ?[][]const u8 = null,
        unprocessed_automation_rules: ?[]UnprocessedAutomationRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_automation_rules = "ProcessedAutomationRules",
                .unprocessed_automation_rules = "UnprocessedAutomationRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_disable_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/deregister",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisableStandards",
    Request: type = struct {
        standards_subscription_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arns = "StandardsSubscriptionArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disable_standards) } {
            return .{ .service_metadata = service_metadata, .action = batch_disable_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_enable_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/register",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchEnableStandards",
    Request: type = struct {
        standards_subscription_requests: []struct {
            standards_arn: []const u8,
            standards_input: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .standards_input = "StandardsInput",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "standards_input", field_name))
                    return try serializeMap(self.standards_input, self.fieldNameFor("standards_input"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_requests = "StandardsSubscriptionRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_enable_standards) } {
            return .{ .service_metadata = service_metadata, .action = batch_enable_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_get_automation_rules: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/automationrules/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetAutomationRules",
    Request: type = struct {
        automation_rules_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_rules_arns = "AutomationRulesArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_automation_rules) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_automation_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            rule_arn: ?[]const u8 = null,
            rule_status: ?[]const u8 = null,
            rule_order: ?i64 = null,
            rule_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            is_terminal: ?bool = null,
            criteria: ?AutomationRulesFindingFilters = null,
            actions: ?[]AutomationRulesAction = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            created_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_arn = "RuleArn",
                    .rule_status = "RuleStatus",
                    .rule_order = "RuleOrder",
                    .rule_name = "RuleName",
                    .description = "Description",
                    .is_terminal = "IsTerminal",
                    .criteria = "Criteria",
                    .actions = "Actions",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unprocessed_automation_rules: ?[]UnprocessedAutomationRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
                .unprocessed_automation_rules = "UnprocessedAutomationRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_get_configuration_policy_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicyAssociation/batchget",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetConfigurationPolicyAssociations",
    Request: type = struct {
        configuration_policy_association_identifiers: []ConfigurationPolicyAssociation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_association_identifiers = "ConfigurationPolicyAssociationIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_configuration_policy_associations) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_configuration_policy_associations };
        }
    },
    Response: type = struct {
        configuration_policy_associations: ?[]ConfigurationPolicyAssociationSummary = null,
        unprocessed_configuration_policy_associations: ?[]struct {
            configuration_policy_association_identifiers: ?ConfigurationPolicyAssociation = null,
            error_code: ?[]const u8 = null,
            error_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configuration_policy_association_identifiers = "ConfigurationPolicyAssociationIdentifiers",
                    .error_code = "ErrorCode",
                    .error_reason = "ErrorReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_associations = "ConfigurationPolicyAssociations",
                .unprocessed_configuration_policy_associations = "UnprocessedConfigurationPolicyAssociations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_get_security_controls: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/securityControls/batchGet",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetSecurityControls",
    Request: type = struct {
        security_control_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_ids = "SecurityControlIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_security_controls) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_security_controls };
        }
    },
    Response: type = struct {
        security_controls: []struct {
            security_control_id: []const u8,
            security_control_arn: []const u8,
            title: []const u8,
            description: []const u8,
            remediation_url: []const u8,
            severity_rating: []const u8,
            security_control_status: []const u8,
            update_status: ?[]const u8 = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ParameterConfiguration = null,
            } = null,
            last_update_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_control_id = "SecurityControlId",
                    .security_control_arn = "SecurityControlArn",
                    .title = "Title",
                    .description = "Description",
                    .remediation_url = "RemediationUrl",
                    .severity_rating = "SeverityRating",
                    .security_control_status = "SecurityControlStatus",
                    .update_status = "UpdateStatus",
                    .parameters = "Parameters",
                    .last_update_reason = "LastUpdateReason",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                return false;
            }
        },
        unprocessed_ids: ?[]struct {
            security_control_id: []const u8,
            error_code: []const u8,
            error_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_control_id = "SecurityControlId",
                    .error_code = "ErrorCode",
                    .error_reason = "ErrorReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_controls = "SecurityControls",
                .unprocessed_ids = "UnprocessedIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_get_standards_control_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associations/batchGet",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetStandardsControlAssociations",
    Request: type = struct {
        standards_control_association_ids: []StandardsControlAssociationId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_association_ids = "StandardsControlAssociationIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_standards_control_associations) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_standards_control_associations };
        }
    },
    Response: type = struct {
        standards_control_association_details: []struct {
            standards_arn: []const u8,
            security_control_id: []const u8,
            security_control_arn: []const u8,
            association_status: []const u8,
            related_requirements: ?[][]const u8 = null,
            updated_at: ?i64 = null,
            updated_reason: ?[]const u8 = null,
            standards_control_title: ?[]const u8 = null,
            standards_control_description: ?[]const u8 = null,
            standards_control_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .security_control_id = "SecurityControlId",
                    .security_control_arn = "SecurityControlArn",
                    .association_status = "AssociationStatus",
                    .related_requirements = "RelatedRequirements",
                    .updated_at = "UpdatedAt",
                    .updated_reason = "UpdatedReason",
                    .standards_control_title = "StandardsControlTitle",
                    .standards_control_description = "StandardsControlDescription",
                    .standards_control_arns = "StandardsControlArns",
                };
                return @field(mappings, field_name);
            }
        },
        unprocessed_associations: ?[]struct {
            standards_control_association_id: StandardsControlAssociationId,
            error_code: []const u8,
            error_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_control_association_id = "StandardsControlAssociationId",
                    .error_code = "ErrorCode",
                    .error_reason = "ErrorReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_association_details = "StandardsControlAssociationDetails",
                .unprocessed_associations = "UnprocessedAssociations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_import_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/import",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchImportFindings",
    Request: type = struct {
        findings: []AwsSecurityFinding,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "Findings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_import_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_import_findings };
        }
    },
    Response: type = struct {
        failed_count: i64,
        success_count: i64,
        failed_findings: ?[]struct {
            id: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_count = "FailedCount",
                .success_count = "SuccessCount",
                .failed_findings = "FailedFindings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_update_automation_rules: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/automationrules/update",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateAutomationRules",
    Request: type = struct {
        update_automation_rules_request_items: []struct {
            rule_arn: []const u8,
            rule_status: ?[]const u8 = null,
            rule_order: ?i64 = null,
            description: ?[]const u8 = null,
            rule_name: ?[]const u8 = null,
            is_terminal: ?bool = null,
            criteria: ?AutomationRulesFindingFilters = null,
            actions: ?[]AutomationRulesAction = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_arn = "RuleArn",
                    .rule_status = "RuleStatus",
                    .rule_order = "RuleOrder",
                    .description = "Description",
                    .rule_name = "RuleName",
                    .is_terminal = "IsTerminal",
                    .criteria = "Criteria",
                    .actions = "Actions",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_automation_rules_request_items = "UpdateAutomationRulesRequestItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_automation_rules) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_automation_rules };
        }
    },
    Response: type = struct {
        processed_automation_rules: ?[][]const u8 = null,
        unprocessed_automation_rules: ?[]UnprocessedAutomationRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_automation_rules = "ProcessedAutomationRules",
                .unprocessed_automation_rules = "UnprocessedAutomationRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const batch_update_findings: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findings/batchupdate",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateFindings",
    Request: type = struct {
        finding_identifiers: []AwsSecurityFindingIdentifier,
        note: ?NoteUpdate = null,
        severity: ?SeverityUpdate = null,
        verification_state: ?[]const u8 = null,
        confidence: ?i64 = null,
        criticality: ?i64 = null,
        types: ?[][]const u8 = null,
        user_defined_fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        workflow: ?WorkflowUpdate = null,
        related_findings: ?[]RelatedFinding = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_identifiers = "FindingIdentifiers",
                .note = "Note",
                .severity = "Severity",
                .verification_state = "VerificationState",
                .confidence = "Confidence",
                .criticality = "Criticality",
                .types = "Types",
                .user_defined_fields = "UserDefinedFields",
                .workflow = "Workflow",
                .related_findings = "RelatedFindings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "user_defined_fields", field_name))
                return try serializeMap(self.user_defined_fields, self.fieldNameFor("user_defined_fields"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_findings };
        }
    },
    Response: type = struct {
        processed_findings: []AwsSecurityFindingIdentifier,
        unprocessed_findings: []struct {
            finding_identifier: AwsSecurityFindingIdentifier,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_identifier = "FindingIdentifier",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_findings = "ProcessedFindings",
                .unprocessed_findings = "UnprocessedFindings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const batch_update_standards_control_associations: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateStandardsControlAssociations",
    Request: type = struct {
        standards_control_association_updates: []StandardsControlAssociationUpdate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_association_updates = "StandardsControlAssociationUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_standards_control_associations) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_standards_control_associations };
        }
    },
    Response: type = struct {
        unprocessed_association_updates: ?[]struct {
            standards_control_association_update: StandardsControlAssociationUpdate,
            error_code: []const u8,
            error_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_control_association_update = "StandardsControlAssociationUpdate",
                    .error_code = "ErrorCode",
                    .error_reason = "ErrorReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_association_updates = "UnprocessedAssociationUpdates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const create_action_target: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actionTargets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateActionTarget",
    Request: type = struct {
        name: []const u8,
        description: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_action_target) } {
            return .{ .service_metadata = service_metadata, .action = create_action_target };
        }
    },
    Response: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const create_automation_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/automationrules/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAutomationRule",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        rule_status: ?[]const u8 = null,
        rule_order: i64,
        rule_name: []const u8,
        description: []const u8,
        is_terminal: ?bool = null,
        criteria: AutomationRulesFindingFilters,
        actions: []AutomationRulesAction,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .rule_status = "RuleStatus",
                .rule_order = "RuleOrder",
                .rule_name = "RuleName",
                .description = "Description",
                .is_terminal = "IsTerminal",
                .criteria = "Criteria",
                .actions = "Actions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_automation_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_automation_rule };
        }
    },
    Response: type = struct {
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const create_configuration_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicy/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationPolicy",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        configuration_policy: Policy,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .configuration_policy = "ConfigurationPolicy",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        updated_at: ?i64 = null,
        created_at: ?i64 = null,
        configuration_policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .updated_at = "UpdatedAt",
                .created_at = "CreatedAt",
                .configuration_policy = "ConfigurationPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const create_finding_aggregator: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findingAggregator/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFindingAggregator",
    Request: type = struct {
        region_linking_mode: []const u8,
        regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .region_linking_mode = "RegionLinkingMode",
                .regions = "Regions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_finding_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = create_finding_aggregator };
        }
    },
    Response: type = struct {
        finding_aggregator_arn: ?[]const u8 = null,
        finding_aggregation_region: ?[]const u8 = null,
        region_linking_mode: ?[]const u8 = null,
        regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
                .finding_aggregation_region = "FindingAggregationRegion",
                .region_linking_mode = "RegionLinkingMode",
                .regions = "Regions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const create_insight: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInsight",
    Request: type = struct {
        name: []const u8,
        filters: AwsSecurityFindingFilters,
        group_by_attribute: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .filters = "Filters",
                .group_by_attribute = "GroupByAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_insight) } {
            return .{ .service_metadata = service_metadata, .action = create_insight };
        }
    },
    Response: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const create_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMembers",
    Request: type = struct {
        account_details: []struct {
            account_id: []const u8,
            email: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .email = "Email",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_details = "AccountDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_members) } {
            return .{ .service_metadata = service_metadata, .action = create_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const decline_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/decline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeclineInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decline_invitations) } {
            return .{ .service_metadata = service_metadata, .action = decline_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_action_target: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/actionTargets/{ActionTargetArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteActionTarget",
    Request: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_action_target) } {
            return .{ .service_metadata = service_metadata, .action = delete_action_target };
        }
    },
    Response: type = struct {
        action_target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_configuration_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/configurationPolicy/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationPolicy",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const delete_finding_aggregator: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/findingAggregator/delete/{FindingAggregatorArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFindingAggregator",
    Request: type = struct {
        finding_aggregator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_finding_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = delete_finding_aggregator };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const delete_insight: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/insights/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInsight",
    Request: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_insight) } {
            return .{ .service_metadata = service_metadata, .action = delete_insight };
        }
    },
    Response: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const delete_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_invitations) } {
            return .{ .service_metadata = service_metadata, .action = delete_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const delete_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_members) } {
            return .{ .service_metadata = service_metadata, .action = delete_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_action_targets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actionTargets/get",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeActionTargets",
    Request: type = struct {
        action_target_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arns = "ActionTargetArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_action_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_action_targets };
        }
    },
    Response: type = struct {
        action_targets: []struct {
            action_target_arn: []const u8,
            name: []const u8,
            description: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_target_arn = "ActionTargetArn",
                    .name = "Name",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_targets = "ActionTargets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_hub: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHub",
    Request: type = struct {
        hub_arn: ?[]const u8 = null,

        pub const http_query = .{
            .hub_arn = "HubArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hub_arn = "HubArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hub) } {
            return .{ .service_metadata = service_metadata, .action = describe_hub };
        }
    },
    Response: type = struct {
        hub_arn: ?[]const u8 = null,
        subscribed_at: ?[]const u8 = null,
        auto_enable_controls: ?bool = null,
        control_finding_generator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hub_arn = "HubArn",
                .subscribed_at = "SubscribedAt",
                .auto_enable_controls = "AutoEnableControls",
                .control_finding_generator = "ControlFindingGenerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organization/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?bool = null,
        member_account_limit_reached: ?bool = null,
        auto_enable_standards: ?[]const u8 = null,
        organization_configuration: ?OrganizationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "AutoEnable",
                .member_account_limit_reached = "MemberAccountLimitReached",
                .auto_enable_standards = "AutoEnableStandards",
                .organization_configuration = "OrganizationConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const describe_products: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/products",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProducts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        product_arn: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .product_arn = "ProductArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .product_arn = "ProductArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_products) } {
            return .{ .service_metadata = service_metadata, .action = describe_products };
        }
    },
    Response: type = struct {
        products: []struct {
            product_arn: []const u8,
            product_name: ?[]const u8 = null,
            company_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            categories: ?[][]const u8 = null,
            integration_types: ?[][]const u8 = null,
            marketplace_url: ?[]const u8 = null,
            activation_url: ?[]const u8 = null,
            product_subscription_resource_policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .product_arn = "ProductArn",
                    .product_name = "ProductName",
                    .company_name = "CompanyName",
                    .description = "Description",
                    .categories = "Categories",
                    .integration_types = "IntegrationTypes",
                    .marketplace_url = "MarketplaceUrl",
                    .activation_url = "ActivationUrl",
                    .product_subscription_resource_policy = "ProductSubscriptionResourcePolicy",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .products = "Products",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const describe_standards: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/standards",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStandards",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_standards) } {
            return .{ .service_metadata = service_metadata, .action = describe_standards };
        }
    },
    Response: type = struct {
        standards: ?[]struct {
            standards_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            enabled_by_default: ?bool = null,
            standards_managed_by: ?struct {
                company: ?[]const u8 = null,
                product: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .company = "Company",
                        .product = "Product",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .name = "Name",
                    .description = "Description",
                    .enabled_by_default = "EnabledByDefault",
                    .standards_managed_by = "StandardsManagedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards = "Standards",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
    },
} = .{};
pub const describe_standards_controls: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/standards/controls/{StandardsSubscriptionArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeStandardsControls",
    Request: type = struct {
        standards_subscription_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arn = "StandardsSubscriptionArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_standards_controls) } {
            return .{ .service_metadata = service_metadata, .action = describe_standards_controls };
        }
    },
    Response: type = struct {
        controls: ?[]struct {
            standards_control_arn: ?[]const u8 = null,
            control_status: ?[]const u8 = null,
            disabled_reason: ?[]const u8 = null,
            control_status_updated_at: ?i64 = null,
            control_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            description: ?[]const u8 = null,
            remediation_url: ?[]const u8 = null,
            severity_rating: ?[]const u8 = null,
            related_requirements: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_control_arn = "StandardsControlArn",
                    .control_status = "ControlStatus",
                    .disabled_reason = "DisabledReason",
                    .control_status_updated_at = "ControlStatusUpdatedAt",
                    .control_id = "ControlId",
                    .title = "Title",
                    .description = "Description",
                    .remediation_url = "RemediationUrl",
                    .severity_rating = "SeverityRating",
                    .related_requirements = "RelatedRequirements",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .controls = "Controls",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const disable_import_findings_for_product: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/productSubscriptions/{ProductSubscriptionArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableImportFindingsForProduct",
    Request: type = struct {
        product_subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscription_arn = "ProductSubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_import_findings_for_product) } {
            return .{ .service_metadata = service_metadata, .action = disable_import_findings_for_product };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/admin/disable",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "AdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const disable_security_hub: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableSecurityHub",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_security_hub) } {
            return .{ .service_metadata = service_metadata, .action = disable_security_hub };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_from_administrator_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/administrator/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_administrator_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_from_master_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/master/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_master_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_master_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_members) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_members };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const enable_import_findings_for_product: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/productSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableImportFindingsForProduct",
    Request: type = struct {
        product_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_arn = "ProductArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_import_findings_for_product) } {
            return .{ .service_metadata = service_metadata, .action = enable_import_findings_for_product };
        }
    },
    Response: type = struct {
        product_subscription_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscription_arn = "ProductSubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const enable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/admin/enable",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "AdminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const enable_security_hub: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableSecurityHub",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        enable_default_standards: ?bool = null,
        control_finding_generator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .enable_default_standards = "EnableDefaultStandards",
                .control_finding_generator = "ControlFindingGenerator",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_security_hub) } {
            return .{ .service_metadata = service_metadata, .action = enable_security_hub };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        LimitExceeded,
        ResourceConflict,
    },
} = .{};
pub const get_administrator_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = get_administrator_account };
        }
    },
    Response: type = struct {
        administrator: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator = "Administrator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_configuration_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/configurationPolicy/get/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationPolicy",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        updated_at: ?i64 = null,
        created_at: ?i64 = null,
        configuration_policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .updated_at = "UpdatedAt",
                .created_at = "CreatedAt",
                .configuration_policy = "ConfigurationPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_configuration_policy_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicyAssociation/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationPolicyAssociation",
    Request: type = struct {
        target: Target,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_policy_association) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_policy_association };
        }
    },
    Response: type = struct {
        configuration_policy_id: ?[]const u8 = null,
        target_id: ?[]const u8 = null,
        target_type: ?[]const u8 = null,
        association_type: ?[]const u8 = null,
        updated_at: ?i64 = null,
        association_status: ?[]const u8 = null,
        association_status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_id = "ConfigurationPolicyId",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .association_type = "AssociationType",
                .updated_at = "UpdatedAt",
                .association_status = "AssociationStatus",
                .association_status_message = "AssociationStatusMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_enabled_standards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/standards/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnabledStandards",
    Request: type = struct {
        standards_subscription_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscription_arns = "StandardsSubscriptionArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enabled_standards) } {
            return .{ .service_metadata = service_metadata, .action = get_enabled_standards };
        }
    },
    Response: type = struct {
        standards_subscriptions: ?[]StandardsSubscription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_subscriptions = "StandardsSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_finding_aggregator: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findingAggregator/get/{FindingAggregatorArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingAggregator",
    Request: type = struct {
        finding_aggregator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_finding_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = get_finding_aggregator };
        }
    },
    Response: type = struct {
        finding_aggregator_arn: ?[]const u8 = null,
        finding_aggregation_region: ?[]const u8 = null,
        region_linking_mode: ?[]const u8 = null,
        regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
                .finding_aggregation_region = "FindingAggregationRegion",
                .region_linking_mode = "RegionLinkingMode",
                .regions = "Regions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_finding_history: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findingHistory/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingHistory",
    Request: type = struct {
        finding_identifier: AwsSecurityFindingIdentifier,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_identifier = "FindingIdentifier",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_finding_history) } {
            return .{ .service_metadata = service_metadata, .action = get_finding_history };
        }
    },
    Response: type = struct {
        records: ?[]struct {
            finding_identifier: ?AwsSecurityFindingIdentifier = null,
            update_time: ?i64 = null,
            finding_created: ?bool = null,
            update_source: ?struct {
                type: ?[]const u8 = null,
                identity: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .identity = "Identity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            updates: ?[]struct {
                updated_field: ?[]const u8 = null,
                old_value: ?[]const u8 = null,
                new_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .updated_field = "UpdatedField",
                        .old_value = "OldValue",
                        .new_value = "NewValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_identifier = "FindingIdentifier",
                    .update_time = "UpdateTime",
                    .finding_created = "FindingCreated",
                    .update_source = "UpdateSource",
                    .updates = "Updates",
                    .next_token = "NextToken",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindings",
    Request: type = struct {
        filters: ?AwsSecurityFindingFilters = null,
        sort_criteria: ?[]struct {
            field: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .sort_criteria = "SortCriteria",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_findings };
        }
    },
    Response: type = struct {
        findings: []AwsSecurityFinding,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "Findings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_insight_results: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/results/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightResults",
    Request: type = struct {
        insight_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_results) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_results };
        }
    },
    Response: type = struct {
        insight_results: struct {
            insight_arn: []const u8,
            group_by_attribute: []const u8,
            result_values: []struct {
                group_by_attribute_value: []const u8,
                count: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_by_attribute_value = "GroupByAttributeValue",
                        .count = "Count",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_arn = "InsightArn",
                    .group_by_attribute = "GroupByAttribute",
                    .result_values = "ResultValues",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_results = "InsightResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsights",
    Request: type = struct {
        insight_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arns = "InsightArns",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insights) } {
            return .{ .service_metadata = service_metadata, .action = get_insights };
        }
    },
    Response: type = struct {
        insights: []struct {
            insight_arn: []const u8,
            name: []const u8,
            filters: AwsSecurityFindingFilters,
            group_by_attribute: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_arn = "InsightArn",
                    .name = "Name",
                    .filters = "Filters",
                    .group_by_attribute = "GroupByAttribute",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insights = "Insights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_invitations_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations/count",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvitationsCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_invitations_count) } {
            return .{ .service_metadata = service_metadata, .action = get_invitations_count };
        }
    },
    Response: type = struct {
        invitations_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations_count = "InvitationsCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const get_master_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/master",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_master_account) } {
            return .{ .service_metadata = service_metadata, .action = get_master_account };
        }
    },
    Response: type = struct {
        master: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master = "Master",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/get",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_members) } {
            return .{ .service_metadata = service_metadata, .action = get_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const get_security_control_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/securityControl/definition",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSecurityControlDefinition",
    Request: type = struct {
        security_control_id: []const u8,

        pub const http_query = .{
            .security_control_id = "SecurityControlId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_id = "SecurityControlId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_control_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_security_control_definition };
        }
    },
    Response: type = struct {
        security_control_definition: SecurityControlDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_definition = "SecurityControlDefinition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const invite_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/invite",
        .success_code = 200,
    };

    action_name: []const u8 = "InviteMembers",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invite_members) } {
            return .{ .service_metadata = service_metadata, .action = invite_members };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]Result = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "UnprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const list_automation_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/automationrules/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAutomationRules",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_automation_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_automation_rules };
        }
    },
    Response: type = struct {
        automation_rules_metadata: ?[]struct {
            rule_arn: ?[]const u8 = null,
            rule_status: ?[]const u8 = null,
            rule_order: ?i64 = null,
            rule_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            is_terminal: ?bool = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            created_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_arn = "RuleArn",
                    .rule_status = "RuleStatus",
                    .rule_order = "RuleOrder",
                    .rule_name = "RuleName",
                    .description = "Description",
                    .is_terminal = "IsTerminal",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_rules_metadata = "AutomationRulesMetadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_configuration_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/configurationPolicy/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationPolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_policies };
        }
    },
    Response: type = struct {
        configuration_policy_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            updated_at: ?i64 = null,
            service_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .updated_at = "UpdatedAt",
                    .service_enabled = "ServiceEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_summaries = "ConfigurationPolicySummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_configuration_policy_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicyAssociation/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationPolicyAssociations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?struct {
            configuration_policy_id: ?[]const u8 = null,
            association_type: ?[]const u8 = null,
            association_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configuration_policy_id = "ConfigurationPolicyId",
                    .association_type = "AssociationType",
                    .association_status = "AssociationStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_policy_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_policy_associations };
        }
    },
    Response: type = struct {
        configuration_policy_association_summaries: ?[]ConfigurationPolicyAssociationSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_association_summaries = "ConfigurationPolicyAssociationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_enabled_products_for_import: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/productSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnabledProductsForImport",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_enabled_products_for_import) } {
            return .{ .service_metadata = service_metadata, .action = list_enabled_products_for_import };
        }
    },
    Response: type = struct {
        product_subscriptions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_subscriptions = "ProductSubscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        LimitExceeded,
    },
} = .{};
pub const list_finding_aggregators: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findingAggregator/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindingAggregators",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_finding_aggregators) } {
            return .{ .service_metadata = service_metadata, .action = list_finding_aggregators };
        }
    },
    Response: type = struct {
        finding_aggregators: ?[]struct {
            finding_aggregator_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_aggregator_arn = "FindingAggregatorArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregators = "FindingAggregators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]Invitation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "Invitations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        only_associated: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .only_associated = "OnlyAssociated",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .only_associated = "OnlyAssociated",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]Member = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_organization_admin_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organization/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationAdminAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_admin_accounts };
        }
    },
    Response: type = struct {
        admin_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_accounts = "AdminAccounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_security_control_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/securityControls/definitions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityControlDefinitions",
    Request: type = struct {
        standards_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .standards_arn = "StandardsArn",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_arn = "StandardsArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_control_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_security_control_definitions };
        }
    },
    Response: type = struct {
        security_control_definitions: []SecurityControlDefinition,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_definitions = "SecurityControlDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_standards_control_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStandardsControlAssociations",
    Request: type = struct {
        security_control_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .security_control_id = "SecurityControlId",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_id = "SecurityControlId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_standards_control_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_standards_control_associations };
        }
    },
    Response: type = struct {
        standards_control_association_summaries: []struct {
            standards_arn: []const u8,
            security_control_id: []const u8,
            security_control_arn: []const u8,
            association_status: []const u8,
            related_requirements: ?[][]const u8 = null,
            updated_at: ?i64 = null,
            updated_reason: ?[]const u8 = null,
            standards_control_title: ?[]const u8 = null,
            standards_control_description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standards_arn = "StandardsArn",
                    .security_control_id = "SecurityControlId",
                    .security_control_arn = "SecurityControlArn",
                    .association_status = "AssociationStatus",
                    .related_requirements = "RelatedRequirements",
                    .updated_at = "UpdatedAt",
                    .updated_reason = "UpdatedReason",
                    .standards_control_title = "StandardsControlTitle",
                    .standards_control_description = "StandardsControlDescription",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_association_summaries = "StandardsControlAssociationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const start_configuration_policy_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicyAssociation/associate",
        .success_code = 200,
    };

    action_name: []const u8 = "StartConfigurationPolicyAssociation",
    Request: type = struct {
        configuration_policy_identifier: []const u8,
        target: Target,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_identifier = "ConfigurationPolicyIdentifier",
                .target = "Target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_configuration_policy_association) } {
            return .{ .service_metadata = service_metadata, .action = start_configuration_policy_association };
        }
    },
    Response: type = struct {
        configuration_policy_id: ?[]const u8 = null,
        target_id: ?[]const u8 = null,
        target_type: ?[]const u8 = null,
        association_type: ?[]const u8 = null,
        updated_at: ?i64 = null,
        association_status: ?[]const u8 = null,
        association_status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_policy_id = "ConfigurationPolicyId",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .association_type = "AssociationType",
                .updated_at = "UpdatedAt",
                .association_status = "AssociationStatus",
                .association_status_message = "AssociationStatusMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const start_configuration_policy_disassociation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/configurationPolicyAssociation/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "StartConfigurationPolicyDisassociation",
    Request: type = struct {
        target: ?Target = null,
        configuration_policy_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
                .configuration_policy_identifier = "ConfigurationPolicyIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_configuration_policy_disassociation) } {
            return .{ .service_metadata = service_metadata, .action = start_configuration_policy_disassociation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_action_target: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/actionTargets/{ActionTargetArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateActionTarget",
    Request: type = struct {
        action_target_arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_target_arn = "ActionTargetArn",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_action_target) } {
            return .{ .service_metadata = service_metadata, .action = update_action_target };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_configuration_policy: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/configurationPolicy/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfigurationPolicy",
    Request: type = struct {
        identifier: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        updated_reason: ?[]const u8 = null,
        configuration_policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .name = "Name",
                .description = "Description",
                .updated_reason = "UpdatedReason",
                .configuration_policy = "ConfigurationPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        updated_at: ?i64 = null,
        created_at: ?i64 = null,
        configuration_policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .updated_at = "UpdatedAt",
                .created_at = "CreatedAt",
                .configuration_policy = "ConfigurationPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const update_finding_aggregator: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findingAggregator/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindingAggregator",
    Request: type = struct {
        finding_aggregator_arn: []const u8,
        region_linking_mode: []const u8,
        regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
                .region_linking_mode = "RegionLinkingMode",
                .regions = "Regions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_finding_aggregator) } {
            return .{ .service_metadata = service_metadata, .action = update_finding_aggregator };
        }
    },
    Response: type = struct {
        finding_aggregator_arn: ?[]const u8 = null,
        finding_aggregation_region: ?[]const u8 = null,
        region_linking_mode: ?[]const u8 = null,
        regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_aggregator_arn = "FindingAggregatorArn",
                .finding_aggregation_region = "FindingAggregationRegion",
                .region_linking_mode = "RegionLinkingMode",
                .regions = "Regions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_findings: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindings",
    Request: type = struct {
        filters: AwsSecurityFindingFilters,
        note: ?NoteUpdate = null,
        record_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .note = "Note",
                .record_state = "RecordState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_findings) } {
            return .{ .service_metadata = service_metadata, .action = update_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_insight: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/insights/{InsightArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInsight",
    Request: type = struct {
        insight_arn: []const u8,
        name: ?[]const u8 = null,
        filters: ?AwsSecurityFindingFilters = null,
        group_by_attribute: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_arn = "InsightArn",
                .name = "Name",
                .filters = "Filters",
                .group_by_attribute = "GroupByAttribute",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_insight) } {
            return .{ .service_metadata = service_metadata, .action = update_insight };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organization/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        auto_enable: bool,
        auto_enable_standards: ?[]const u8 = null,
        organization_configuration: ?OrganizationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "AutoEnable",
                .auto_enable_standards = "AutoEnableStandards",
                .organization_configuration = "OrganizationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceConflict,
        ResourceNotFound,
    },
} = .{};
pub const update_security_control: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/securityControl/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSecurityControl",
    Request: type = struct {
        security_control_id: []const u8,
        parameters: []struct {
            key: ?[]const u8 = null,
            value: ?ParameterConfiguration = null,
        },
        last_update_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_control_id = "SecurityControlId",
                .parameters = "Parameters",
                .last_update_reason = "LastUpdateReason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_control) } {
            return .{ .service_metadata = service_metadata, .action = update_security_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_security_hub_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSecurityHubConfiguration",
    Request: type = struct {
        auto_enable_controls: ?bool = null,
        control_finding_generator: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable_controls = "AutoEnableControls",
                .control_finding_generator = "ControlFindingGenerator",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_hub_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_security_hub_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_standards_control: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/standards/control/{StandardsControlArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStandardsControl",
    Request: type = struct {
        standards_control_arn: []const u8,
        control_status: ?[]const u8 = null,
        disabled_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .standards_control_arn = "StandardsControlArn",
                .control_status = "ControlStatus",
                .disabled_reason = "DisabledReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_standards_control) } {
            return .{ .service_metadata = service_metadata, .action = update_standards_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidAccess,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};

pub const ParameterConfiguration = struct {
    value_type: []const u8,
    value: ?ParameterValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value_type = "ValueType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterValue = union {
    integer: ?i64,
    integer_list: ?[]i64,
    double: ?f64,
    string: ?[]const u8,
    string_list: ?[][]const u8,
    boolean: ?bool,
    @"enum": ?[]const u8,
    enum_list: ?[][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .integer = "Integer",
            .integer_list = "IntegerList",
            .double = "Double",
            .string = "String",
            .string_list = "StringList",
            .boolean = "Boolean",
            .@"enum" = "Enum",
            .enum_list = "EnumList",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationConfiguration = struct {
    configuration_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_type = "ConfigurationType",
            .status = "Status",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecurityFindingFilters = struct {
    product_arn: ?[]StringFilter = null,
    aws_account_id: ?[]StringFilter = null,
    id: ?[]StringFilter = null,
    generator_id: ?[]StringFilter = null,
    region: ?[]StringFilter = null,
    type: ?[]StringFilter = null,
    first_observed_at: ?[]DateFilter = null,
    last_observed_at: ?[]DateFilter = null,
    created_at: ?[]DateFilter = null,
    updated_at: ?[]DateFilter = null,
    severity_product: ?[]NumberFilter = null,
    severity_normalized: ?[]NumberFilter = null,
    severity_label: ?[]StringFilter = null,
    confidence: ?[]NumberFilter = null,
    criticality: ?[]NumberFilter = null,
    title: ?[]StringFilter = null,
    description: ?[]StringFilter = null,
    recommendation_text: ?[]StringFilter = null,
    source_url: ?[]StringFilter = null,
    product_fields: ?[]MapFilter = null,
    product_name: ?[]StringFilter = null,
    company_name: ?[]StringFilter = null,
    user_defined_fields: ?[]MapFilter = null,
    malware_name: ?[]StringFilter = null,
    malware_type: ?[]StringFilter = null,
    malware_path: ?[]StringFilter = null,
    malware_state: ?[]StringFilter = null,
    network_direction: ?[]StringFilter = null,
    network_protocol: ?[]StringFilter = null,
    network_source_ip_v4: ?[]IpFilter = null,
    network_source_ip_v6: ?[]IpFilter = null,
    network_source_port: ?[]NumberFilter = null,
    network_source_domain: ?[]StringFilter = null,
    network_source_mac: ?[]StringFilter = null,
    network_destination_ip_v4: ?[]IpFilter = null,
    network_destination_ip_v6: ?[]IpFilter = null,
    network_destination_port: ?[]NumberFilter = null,
    network_destination_domain: ?[]StringFilter = null,
    process_name: ?[]StringFilter = null,
    process_path: ?[]StringFilter = null,
    process_pid: ?[]NumberFilter = null,
    process_parent_pid: ?[]NumberFilter = null,
    process_launched_at: ?[]DateFilter = null,
    process_terminated_at: ?[]DateFilter = null,
    threat_intel_indicator_type: ?[]StringFilter = null,
    threat_intel_indicator_value: ?[]StringFilter = null,
    threat_intel_indicator_category: ?[]StringFilter = null,
    threat_intel_indicator_last_observed_at: ?[]DateFilter = null,
    threat_intel_indicator_source: ?[]StringFilter = null,
    threat_intel_indicator_source_url: ?[]StringFilter = null,
    resource_type: ?[]StringFilter = null,
    resource_id: ?[]StringFilter = null,
    resource_partition: ?[]StringFilter = null,
    resource_region: ?[]StringFilter = null,
    resource_tags: ?[]MapFilter = null,
    resource_aws_ec2_instance_type: ?[]StringFilter = null,
    resource_aws_ec2_instance_image_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_ip_v4_addresses: ?[]IpFilter = null,
    resource_aws_ec2_instance_ip_v6_addresses: ?[]IpFilter = null,
    resource_aws_ec2_instance_key_name: ?[]StringFilter = null,
    resource_aws_ec2_instance_iam_instance_profile_arn: ?[]StringFilter = null,
    resource_aws_ec2_instance_vpc_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_subnet_id: ?[]StringFilter = null,
    resource_aws_ec2_instance_launched_at: ?[]DateFilter = null,
    resource_aws_s3_bucket_owner_id: ?[]StringFilter = null,
    resource_aws_s3_bucket_owner_name: ?[]StringFilter = null,
    resource_aws_iam_access_key_user_name: ?[]StringFilter = null,
    resource_aws_iam_access_key_principal_name: ?[]StringFilter = null,
    resource_aws_iam_access_key_status: ?[]StringFilter = null,
    resource_aws_iam_access_key_created_at: ?[]DateFilter = null,
    resource_aws_iam_user_user_name: ?[]StringFilter = null,
    resource_container_name: ?[]StringFilter = null,
    resource_container_image_id: ?[]StringFilter = null,
    resource_container_image_name: ?[]StringFilter = null,
    resource_container_launched_at: ?[]DateFilter = null,
    resource_details_other: ?[]MapFilter = null,
    compliance_status: ?[]StringFilter = null,
    verification_state: ?[]StringFilter = null,
    workflow_state: ?[]StringFilter = null,
    workflow_status: ?[]StringFilter = null,
    record_state: ?[]StringFilter = null,
    related_findings_product_arn: ?[]StringFilter = null,
    related_findings_id: ?[]StringFilter = null,
    note_text: ?[]StringFilter = null,
    note_updated_at: ?[]DateFilter = null,
    note_updated_by: ?[]StringFilter = null,
    keyword: ?[]KeywordFilter = null,
    finding_provider_fields_confidence: ?[]NumberFilter = null,
    finding_provider_fields_criticality: ?[]NumberFilter = null,
    finding_provider_fields_related_findings_id: ?[]StringFilter = null,
    finding_provider_fields_related_findings_product_arn: ?[]StringFilter = null,
    finding_provider_fields_severity_label: ?[]StringFilter = null,
    finding_provider_fields_severity_original: ?[]StringFilter = null,
    finding_provider_fields_types: ?[]StringFilter = null,
    sample: ?[]BooleanFilter = null,
    compliance_security_control_id: ?[]StringFilter = null,
    compliance_associated_standards_id: ?[]StringFilter = null,
    vulnerabilities_exploit_available: ?[]StringFilter = null,
    vulnerabilities_fix_available: ?[]StringFilter = null,
    compliance_security_control_parameters_name: ?[]StringFilter = null,
    compliance_security_control_parameters_value: ?[]StringFilter = null,
    aws_account_name: ?[]StringFilter = null,
    resource_application_name: ?[]StringFilter = null,
    resource_application_arn: ?[]StringFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_arn = "ProductArn",
            .aws_account_id = "AwsAccountId",
            .id = "Id",
            .generator_id = "GeneratorId",
            .region = "Region",
            .type = "Type",
            .first_observed_at = "FirstObservedAt",
            .last_observed_at = "LastObservedAt",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .severity_product = "SeverityProduct",
            .severity_normalized = "SeverityNormalized",
            .severity_label = "SeverityLabel",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .title = "Title",
            .description = "Description",
            .recommendation_text = "RecommendationText",
            .source_url = "SourceUrl",
            .product_fields = "ProductFields",
            .product_name = "ProductName",
            .company_name = "CompanyName",
            .user_defined_fields = "UserDefinedFields",
            .malware_name = "MalwareName",
            .malware_type = "MalwareType",
            .malware_path = "MalwarePath",
            .malware_state = "MalwareState",
            .network_direction = "NetworkDirection",
            .network_protocol = "NetworkProtocol",
            .network_source_ip_v4 = "NetworkSourceIpV4",
            .network_source_ip_v6 = "NetworkSourceIpV6",
            .network_source_port = "NetworkSourcePort",
            .network_source_domain = "NetworkSourceDomain",
            .network_source_mac = "NetworkSourceMac",
            .network_destination_ip_v4 = "NetworkDestinationIpV4",
            .network_destination_ip_v6 = "NetworkDestinationIpV6",
            .network_destination_port = "NetworkDestinationPort",
            .network_destination_domain = "NetworkDestinationDomain",
            .process_name = "ProcessName",
            .process_path = "ProcessPath",
            .process_pid = "ProcessPid",
            .process_parent_pid = "ProcessParentPid",
            .process_launched_at = "ProcessLaunchedAt",
            .process_terminated_at = "ProcessTerminatedAt",
            .threat_intel_indicator_type = "ThreatIntelIndicatorType",
            .threat_intel_indicator_value = "ThreatIntelIndicatorValue",
            .threat_intel_indicator_category = "ThreatIntelIndicatorCategory",
            .threat_intel_indicator_last_observed_at = "ThreatIntelIndicatorLastObservedAt",
            .threat_intel_indicator_source = "ThreatIntelIndicatorSource",
            .threat_intel_indicator_source_url = "ThreatIntelIndicatorSourceUrl",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .resource_partition = "ResourcePartition",
            .resource_region = "ResourceRegion",
            .resource_tags = "ResourceTags",
            .resource_aws_ec2_instance_type = "ResourceAwsEc2InstanceType",
            .resource_aws_ec2_instance_image_id = "ResourceAwsEc2InstanceImageId",
            .resource_aws_ec2_instance_ip_v4_addresses = "ResourceAwsEc2InstanceIpV4Addresses",
            .resource_aws_ec2_instance_ip_v6_addresses = "ResourceAwsEc2InstanceIpV6Addresses",
            .resource_aws_ec2_instance_key_name = "ResourceAwsEc2InstanceKeyName",
            .resource_aws_ec2_instance_iam_instance_profile_arn = "ResourceAwsEc2InstanceIamInstanceProfileArn",
            .resource_aws_ec2_instance_vpc_id = "ResourceAwsEc2InstanceVpcId",
            .resource_aws_ec2_instance_subnet_id = "ResourceAwsEc2InstanceSubnetId",
            .resource_aws_ec2_instance_launched_at = "ResourceAwsEc2InstanceLaunchedAt",
            .resource_aws_s3_bucket_owner_id = "ResourceAwsS3BucketOwnerId",
            .resource_aws_s3_bucket_owner_name = "ResourceAwsS3BucketOwnerName",
            .resource_aws_iam_access_key_user_name = "ResourceAwsIamAccessKeyUserName",
            .resource_aws_iam_access_key_principal_name = "ResourceAwsIamAccessKeyPrincipalName",
            .resource_aws_iam_access_key_status = "ResourceAwsIamAccessKeyStatus",
            .resource_aws_iam_access_key_created_at = "ResourceAwsIamAccessKeyCreatedAt",
            .resource_aws_iam_user_user_name = "ResourceAwsIamUserUserName",
            .resource_container_name = "ResourceContainerName",
            .resource_container_image_id = "ResourceContainerImageId",
            .resource_container_image_name = "ResourceContainerImageName",
            .resource_container_launched_at = "ResourceContainerLaunchedAt",
            .resource_details_other = "ResourceDetailsOther",
            .compliance_status = "ComplianceStatus",
            .verification_state = "VerificationState",
            .workflow_state = "WorkflowState",
            .workflow_status = "WorkflowStatus",
            .record_state = "RecordState",
            .related_findings_product_arn = "RelatedFindingsProductArn",
            .related_findings_id = "RelatedFindingsId",
            .note_text = "NoteText",
            .note_updated_at = "NoteUpdatedAt",
            .note_updated_by = "NoteUpdatedBy",
            .keyword = "Keyword",
            .finding_provider_fields_confidence = "FindingProviderFieldsConfidence",
            .finding_provider_fields_criticality = "FindingProviderFieldsCriticality",
            .finding_provider_fields_related_findings_id = "FindingProviderFieldsRelatedFindingsId",
            .finding_provider_fields_related_findings_product_arn = "FindingProviderFieldsRelatedFindingsProductArn",
            .finding_provider_fields_severity_label = "FindingProviderFieldsSeverityLabel",
            .finding_provider_fields_severity_original = "FindingProviderFieldsSeverityOriginal",
            .finding_provider_fields_types = "FindingProviderFieldsTypes",
            .sample = "Sample",
            .compliance_security_control_id = "ComplianceSecurityControlId",
            .compliance_associated_standards_id = "ComplianceAssociatedStandardsId",
            .vulnerabilities_exploit_available = "VulnerabilitiesExploitAvailable",
            .vulnerabilities_fix_available = "VulnerabilitiesFixAvailable",
            .compliance_security_control_parameters_name = "ComplianceSecurityControlParametersName",
            .compliance_security_control_parameters_value = "ComplianceSecurityControlParametersValue",
            .aws_account_name = "AwsAccountName",
            .resource_application_name = "ResourceApplicationName",
            .resource_application_arn = "ResourceApplicationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StringFilter = struct {
    value: ?[]const u8 = null,
    comparison: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .comparison = "Comparison",
        };
        return @field(mappings, field_name);
    }
};

pub const BooleanFilter = struct {
    value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const NumberFilter = struct {
    gte: ?f64 = null,
    lte: ?f64 = null,
    gt: ?f64 = null,
    lt: ?f64 = null,
    eq: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gte = "Gte",
            .lte = "Lte",
            .gt = "Gt",
            .lt = "Lt",
            .eq = "Eq",
        };
        return @field(mappings, field_name);
    }
};

pub const KeywordFilter = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DateFilter = struct {
    start: ?[]const u8 = null,
    end: ?[]const u8 = null,
    date_range: ?DateRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
            .date_range = "DateRange",
        };
        return @field(mappings, field_name);
    }
};

pub const DateRange = struct {
    value: ?i64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const MapFilter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    comparison: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .comparison = "Comparison",
        };
        return @field(mappings, field_name);
    }
};

pub const IpFilter = struct {
    cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr = "Cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const NoteUpdate = struct {
    text: []const u8,
    updated_by: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .updated_by = "UpdatedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const Policy = union {
    security_hub: ?SecurityHubPolicy,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_hub = "SecurityHub",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityHubPolicy = struct {
    service_enabled: ?bool = null,
    enabled_standard_identifiers: ?[][]const u8 = null,
    security_controls_configuration: ?SecurityControlsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_enabled = "ServiceEnabled",
            .enabled_standard_identifiers = "EnabledStandardIdentifiers",
            .security_controls_configuration = "SecurityControlsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityControlsConfiguration = struct {
    enabled_security_control_identifiers: ?[][]const u8 = null,
    disabled_security_control_identifiers: ?[][]const u8 = null,
    security_control_custom_parameters: ?[]SecurityControlCustomParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled_security_control_identifiers = "EnabledSecurityControlIdentifiers",
            .disabled_security_control_identifiers = "DisabledSecurityControlIdentifiers",
            .security_control_custom_parameters = "SecurityControlCustomParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityControlCustomParameter = struct {
    security_control_id: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ParameterConfiguration = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_control_id = "SecurityControlId",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Target = union {
    account_id: ?[]const u8,
    organizational_unit_id: ?[]const u8,
    root_id: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .organizational_unit_id = "OrganizationalUnitId",
            .root_id = "RootId",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityControlDefinition = struct {
    security_control_id: []const u8,
    title: []const u8,
    description: []const u8,
    remediation_url: []const u8,
    severity_rating: []const u8,
    current_region_availability: []const u8,
    customizable_properties: ?[][]const u8 = null,
    parameter_definitions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ParameterDefinition = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_control_id = "SecurityControlId",
            .title = "Title",
            .description = "Description",
            .remediation_url = "RemediationUrl",
            .severity_rating = "SeverityRating",
            .current_region_availability = "CurrentRegionAvailability",
            .customizable_properties = "CustomizableProperties",
            .parameter_definitions = "ParameterDefinitions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameter_definitions", field_name))
            return try serializeMap(self.parameter_definitions, self.fieldNameFor("parameter_definitions"), options, out_stream);
        return false;
    }
};

pub const ParameterDefinition = struct {
    description: []const u8,
    configuration_options: ConfigurationOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .configuration_options = "ConfigurationOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationOptions = union {
    integer: ?IntegerConfigurationOptions,
    integer_list: ?IntegerListConfigurationOptions,
    double: ?DoubleConfigurationOptions,
    string: ?StringConfigurationOptions,
    string_list: ?StringListConfigurationOptions,
    boolean: ?BooleanConfigurationOptions,
    @"enum": ?EnumConfigurationOptions,
    enum_list: ?EnumListConfigurationOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .integer = "Integer",
            .integer_list = "IntegerList",
            .double = "Double",
            .string = "String",
            .string_list = "StringList",
            .boolean = "Boolean",
            .@"enum" = "Enum",
            .enum_list = "EnumList",
        };
        return @field(mappings, field_name);
    }
};

pub const EnumListConfigurationOptions = struct {
    default_value: ?[][]const u8 = null,
    max_items: ?i64 = null,
    allowed_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .max_items = "MaxItems",
            .allowed_values = "AllowedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const EnumConfigurationOptions = struct {
    default_value: ?[]const u8 = null,
    allowed_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .allowed_values = "AllowedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const BooleanConfigurationOptions = struct {
    default_value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const StringListConfigurationOptions = struct {
    default_value: ?[][]const u8 = null,
    re2_expression: ?[]const u8 = null,
    max_items: ?i64 = null,
    expression_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .re2_expression = "Re2Expression",
            .max_items = "MaxItems",
            .expression_description = "ExpressionDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const StringConfigurationOptions = struct {
    default_value: ?[]const u8 = null,
    re2_expression: ?[]const u8 = null,
    expression_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .re2_expression = "Re2Expression",
            .expression_description = "ExpressionDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const DoubleConfigurationOptions = struct {
    default_value: ?f64 = null,
    min: ?f64 = null,
    max: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerListConfigurationOptions = struct {
    default_value: ?[]i64 = null,
    min: ?i64 = null,
    max: ?i64 = null,
    max_items: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .min = "Min",
            .max = "Max",
            .max_items = "MaxItems",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerConfigurationOptions = struct {
    default_value: ?i64 = null,
    min: ?i64 = null,
    max: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "DefaultValue",
            .min = "Min",
            .max = "Max",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = struct {
    account_id: ?[]const u8 = null,
    email: ?[]const u8 = null,
    master_id: ?[]const u8 = null,
    administrator_id: ?[]const u8 = null,
    member_status: ?[]const u8 = null,
    invited_at: ?i64 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .email = "Email",
            .master_id = "MasterId",
            .administrator_id = "AdministratorId",
            .member_status = "MemberStatus",
            .invited_at = "InvitedAt",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Invitation = struct {
    account_id: ?[]const u8 = null,
    invitation_id: ?[]const u8 = null,
    invited_at: ?i64 = null,
    member_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .invitation_id = "InvitationId",
            .invited_at = "InvitedAt",
            .member_status = "MemberStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationPolicyAssociationSummary = struct {
    configuration_policy_id: ?[]const u8 = null,
    target_id: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    association_type: ?[]const u8 = null,
    updated_at: ?i64 = null,
    association_status: ?[]const u8 = null,
    association_status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_policy_id = "ConfigurationPolicyId",
            .target_id = "TargetId",
            .target_type = "TargetType",
            .association_type = "AssociationType",
            .updated_at = "UpdatedAt",
            .association_status = "AssociationStatus",
            .association_status_message = "AssociationStatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Result = struct {
    account_id: ?[]const u8 = null,
    processing_result: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .processing_result = "ProcessingResult",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecurityFinding = struct {
    schema_version: []const u8,
    id: []const u8,
    product_arn: []const u8,
    product_name: ?[]const u8 = null,
    company_name: ?[]const u8 = null,
    region: ?[]const u8 = null,
    generator_id: []const u8,
    aws_account_id: []const u8,
    types: ?[][]const u8 = null,
    first_observed_at: ?[]const u8 = null,
    last_observed_at: ?[]const u8 = null,
    created_at: []const u8,
    updated_at: []const u8,
    severity: ?Severity = null,
    confidence: ?i64 = null,
    criticality: ?i64 = null,
    title: []const u8,
    description: []const u8,
    remediation: ?Remediation = null,
    source_url: ?[]const u8 = null,
    product_fields: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    user_defined_fields: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    malware: ?[]Malware = null,
    network: ?Network = null,
    network_path: ?[]NetworkPathComponent = null,
    process: ?ProcessDetails = null,
    threats: ?[]Threat = null,
    threat_intel_indicators: ?[]ThreatIntelIndicator = null,
    resources: []Resource,
    compliance: ?Compliance = null,
    verification_state: ?[]const u8 = null,
    workflow_state: ?[]const u8 = null,
    workflow: ?Workflow = null,
    record_state: ?[]const u8 = null,
    related_findings: ?[]RelatedFinding = null,
    note: ?Note = null,
    vulnerabilities: ?[]Vulnerability = null,
    patch_summary: ?PatchSummary = null,
    action: ?Action = null,
    finding_provider_fields: ?FindingProviderFields = null,
    sample: ?bool = null,
    generator_details: ?GeneratorDetails = null,
    processed_at: ?[]const u8 = null,
    aws_account_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_version = "SchemaVersion",
            .id = "Id",
            .product_arn = "ProductArn",
            .product_name = "ProductName",
            .company_name = "CompanyName",
            .region = "Region",
            .generator_id = "GeneratorId",
            .aws_account_id = "AwsAccountId",
            .types = "Types",
            .first_observed_at = "FirstObservedAt",
            .last_observed_at = "LastObservedAt",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .severity = "Severity",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .title = "Title",
            .description = "Description",
            .remediation = "Remediation",
            .source_url = "SourceUrl",
            .product_fields = "ProductFields",
            .user_defined_fields = "UserDefinedFields",
            .malware = "Malware",
            .network = "Network",
            .network_path = "NetworkPath",
            .process = "Process",
            .threats = "Threats",
            .threat_intel_indicators = "ThreatIntelIndicators",
            .resources = "Resources",
            .compliance = "Compliance",
            .verification_state = "VerificationState",
            .workflow_state = "WorkflowState",
            .workflow = "Workflow",
            .record_state = "RecordState",
            .related_findings = "RelatedFindings",
            .note = "Note",
            .vulnerabilities = "Vulnerabilities",
            .patch_summary = "PatchSummary",
            .action = "Action",
            .finding_provider_fields = "FindingProviderFields",
            .sample = "Sample",
            .generator_details = "GeneratorDetails",
            .processed_at = "ProcessedAt",
            .aws_account_name = "AwsAccountName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "product_fields", field_name))
            return try serializeMap(self.product_fields, self.fieldNameFor("product_fields"), options, out_stream);
        if (std.mem.eql(u8, "user_defined_fields", field_name))
            return try serializeMap(self.user_defined_fields, self.fieldNameFor("user_defined_fields"), options, out_stream);
        return false;
    }
};

pub const GeneratorDetails = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    labels: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .labels = "Labels",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingProviderFields = struct {
    confidence: ?i64 = null,
    criticality: ?i64 = null,
    related_findings: ?[]RelatedFinding = null,
    severity: ?FindingProviderSeverity = null,
    types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence = "Confidence",
            .criticality = "Criticality",
            .related_findings = "RelatedFindings",
            .severity = "Severity",
            .types = "Types",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingProviderSeverity = struct {
    label: ?[]const u8 = null,
    original: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label = "Label",
            .original = "Original",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedFinding = struct {
    product_arn: []const u8,
    id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_arn = "ProductArn",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    action_type: ?[]const u8 = null,
    network_connection_action: ?NetworkConnectionAction = null,
    aws_api_call_action: ?AwsApiCallAction = null,
    dns_request_action: ?DnsRequestAction = null,
    port_probe_action: ?PortProbeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type = "ActionType",
            .network_connection_action = "NetworkConnectionAction",
            .aws_api_call_action = "AwsApiCallAction",
            .dns_request_action = "DnsRequestAction",
            .port_probe_action = "PortProbeAction",
        };
        return @field(mappings, field_name);
    }
};

pub const PortProbeAction = struct {
    port_probe_details: ?[]PortProbeDetail = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port_probe_details = "PortProbeDetails",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const PortProbeDetail = struct {
    local_port_details: ?ActionLocalPortDetails = null,
    local_ip_details: ?ActionLocalIpDetails = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_port_details = "LocalPortDetails",
            .local_ip_details = "LocalIpDetails",
            .remote_ip_details = "RemoteIpDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionRemoteIpDetails = struct {
    ip_address_v4: ?[]const u8 = null,
    organization: ?IpOrganizationDetails = null,
    country: ?Country = null,
    city: ?City = null,
    geo_location: ?GeoLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_v4 = "IpAddressV4",
            .organization = "Organization",
            .country = "Country",
            .city = "City",
            .geo_location = "GeoLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocation = struct {
    lon: ?f64 = null,
    lat: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lon = "Lon",
            .lat = "Lat",
        };
        return @field(mappings, field_name);
    }
};

pub const City = struct {
    city_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city_name = "CityName",
        };
        return @field(mappings, field_name);
    }
};

pub const Country = struct {
    country_code: ?[]const u8 = null,
    country_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country_code = "CountryCode",
            .country_name = "CountryName",
        };
        return @field(mappings, field_name);
    }
};

pub const IpOrganizationDetails = struct {
    asn: ?i64 = null,
    asn_org: ?[]const u8 = null,
    isp: ?[]const u8 = null,
    org: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asn = "Asn",
            .asn_org = "AsnOrg",
            .isp = "Isp",
            .org = "Org",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionLocalIpDetails = struct {
    ip_address_v4: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_v4 = "IpAddressV4",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionLocalPortDetails = struct {
    port: ?i64 = null,
    port_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .port_name = "PortName",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsRequestAction = struct {
    domain: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .protocol = "Protocol",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiCallAction = struct {
    api: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    caller_type: ?[]const u8 = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,
    domain_details: ?AwsApiCallActionDomainDetails = null,
    affected_resources: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    first_seen: ?[]const u8 = null,
    last_seen: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api = "Api",
            .service_name = "ServiceName",
            .caller_type = "CallerType",
            .remote_ip_details = "RemoteIpDetails",
            .domain_details = "DomainDetails",
            .affected_resources = "AffectedResources",
            .first_seen = "FirstSeen",
            .last_seen = "LastSeen",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "affected_resources", field_name))
            return try serializeMap(self.affected_resources, self.fieldNameFor("affected_resources"), options, out_stream);
        return false;
    }
};

pub const AwsApiCallActionDomainDetails = struct {
    domain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConnectionAction = struct {
    connection_direction: ?[]const u8 = null,
    remote_ip_details: ?ActionRemoteIpDetails = null,
    remote_port_details: ?ActionRemotePortDetails = null,
    local_port_details: ?ActionLocalPortDetails = null,
    protocol: ?[]const u8 = null,
    blocked: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_direction = "ConnectionDirection",
            .remote_ip_details = "RemoteIpDetails",
            .remote_port_details = "RemotePortDetails",
            .local_port_details = "LocalPortDetails",
            .protocol = "Protocol",
            .blocked = "Blocked",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionRemotePortDetails = struct {
    port: ?i64 = null,
    port_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .port_name = "PortName",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchSummary = struct {
    id: []const u8,
    installed_count: ?i64 = null,
    missing_count: ?i64 = null,
    failed_count: ?i64 = null,
    installed_other_count: ?i64 = null,
    installed_rejected_count: ?i64 = null,
    installed_pending_reboot: ?i64 = null,
    operation_start_time: ?[]const u8 = null,
    operation_end_time: ?[]const u8 = null,
    reboot_option: ?[]const u8 = null,
    operation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .installed_count = "InstalledCount",
            .missing_count = "MissingCount",
            .failed_count = "FailedCount",
            .installed_other_count = "InstalledOtherCount",
            .installed_rejected_count = "InstalledRejectedCount",
            .installed_pending_reboot = "InstalledPendingReboot",
            .operation_start_time = "OperationStartTime",
            .operation_end_time = "OperationEndTime",
            .reboot_option = "RebootOption",
            .operation = "Operation",
        };
        return @field(mappings, field_name);
    }
};

pub const Vulnerability = struct {
    id: []const u8,
    vulnerable_packages: ?[]SoftwarePackage = null,
    cvss: ?[]Cvss = null,
    related_vulnerabilities: ?[][]const u8 = null,
    vendor: ?VulnerabilityVendor = null,
    reference_urls: ?[][]const u8 = null,
    fix_available: ?[]const u8 = null,
    epss_score: ?f64 = null,
    exploit_available: ?[]const u8 = null,
    code_vulnerabilities: ?[]VulnerabilityCodeVulnerabilities = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .vulnerable_packages = "VulnerablePackages",
            .cvss = "Cvss",
            .related_vulnerabilities = "RelatedVulnerabilities",
            .vendor = "Vendor",
            .reference_urls = "ReferenceUrls",
            .fix_available = "FixAvailable",
            .epss_score = "EpssScore",
            .exploit_available = "ExploitAvailable",
            .code_vulnerabilities = "CodeVulnerabilities",
        };
        return @field(mappings, field_name);
    }
};

pub const VulnerabilityCodeVulnerabilities = struct {
    cwes: ?[][]const u8 = null,
    file_path: ?CodeVulnerabilitiesFilePath = null,
    source_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cwes = "Cwes",
            .file_path = "FilePath",
            .source_arn = "SourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeVulnerabilitiesFilePath = struct {
    end_line: ?i64 = null,
    file_name: ?[]const u8 = null,
    file_path: ?[]const u8 = null,
    start_line: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_line = "EndLine",
            .file_name = "FileName",
            .file_path = "FilePath",
            .start_line = "StartLine",
        };
        return @field(mappings, field_name);
    }
};

pub const VulnerabilityVendor = struct {
    name: []const u8,
    url: ?[]const u8 = null,
    vendor_severity: ?[]const u8 = null,
    vendor_created_at: ?[]const u8 = null,
    vendor_updated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .url = "Url",
            .vendor_severity = "VendorSeverity",
            .vendor_created_at = "VendorCreatedAt",
            .vendor_updated_at = "VendorUpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Cvss = struct {
    version: ?[]const u8 = null,
    base_score: ?f64 = null,
    base_vector: ?[]const u8 = null,
    source: ?[]const u8 = null,
    adjustments: ?[]Adjustment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .base_score = "BaseScore",
            .base_vector = "BaseVector",
            .source = "Source",
            .adjustments = "Adjustments",
        };
        return @field(mappings, field_name);
    }
};

pub const Adjustment = struct {
    metric: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric = "Metric",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwarePackage = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,
    epoch: ?[]const u8 = null,
    release: ?[]const u8 = null,
    architecture: ?[]const u8 = null,
    package_manager: ?[]const u8 = null,
    file_path: ?[]const u8 = null,
    fixed_in_version: ?[]const u8 = null,
    remediation: ?[]const u8 = null,
    source_layer_hash: ?[]const u8 = null,
    source_layer_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .version = "Version",
            .epoch = "Epoch",
            .release = "Release",
            .architecture = "Architecture",
            .package_manager = "PackageManager",
            .file_path = "FilePath",
            .fixed_in_version = "FixedInVersion",
            .remediation = "Remediation",
            .source_layer_hash = "SourceLayerHash",
            .source_layer_arn = "SourceLayerArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Note = struct {
    text: []const u8,
    updated_by: []const u8,
    updated_at: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .updated_by = "UpdatedBy",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Workflow = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Compliance = struct {
    status: ?[]const u8 = null,
    related_requirements: ?[][]const u8 = null,
    status_reasons: ?[]StatusReason = null,
    security_control_id: ?[]const u8 = null,
    associated_standards: ?[]AssociatedStandard = null,
    security_control_parameters: ?[]SecurityControlParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .related_requirements = "RelatedRequirements",
            .status_reasons = "StatusReasons",
            .security_control_id = "SecurityControlId",
            .associated_standards = "AssociatedStandards",
            .security_control_parameters = "SecurityControlParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityControlParameter = struct {
    name: ?[]const u8 = null,
    value: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociatedStandard = struct {
    standards_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standards_id = "StandardsId",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusReason = struct {
    reason_code: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason_code = "ReasonCode",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    type: []const u8,
    id: []const u8,
    partition: ?[]const u8 = null,
    region: ?[]const u8 = null,
    resource_role: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    data_classification: ?DataClassificationDetails = null,
    details: ?ResourceDetails = null,
    application_name: ?[]const u8 = null,
    application_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .id = "Id",
            .partition = "Partition",
            .region = "Region",
            .resource_role = "ResourceRole",
            .tags = "Tags",
            .data_classification = "DataClassification",
            .details = "Details",
            .application_name = "ApplicationName",
            .application_arn = "ApplicationArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ResourceDetails = struct {
    aws_auto_scaling_auto_scaling_group: ?AwsAutoScalingAutoScalingGroupDetails = null,
    aws_code_build_project: ?AwsCodeBuildProjectDetails = null,
    aws_cloud_front_distribution: ?AwsCloudFrontDistributionDetails = null,
    aws_ec2_instance: ?AwsEc2InstanceDetails = null,
    aws_ec2_network_interface: ?AwsEc2NetworkInterfaceDetails = null,
    aws_ec2_security_group: ?AwsEc2SecurityGroupDetails = null,
    aws_ec2_volume: ?AwsEc2VolumeDetails = null,
    aws_ec2_vpc: ?AwsEc2VpcDetails = null,
    aws_ec2_eip: ?AwsEc2EipDetails = null,
    aws_ec2_subnet: ?AwsEc2SubnetDetails = null,
    aws_ec2_network_acl: ?AwsEc2NetworkAclDetails = null,
    aws_elbv2_load_balancer: ?AwsElbv2LoadBalancerDetails = null,
    aws_elastic_beanstalk_environment: ?AwsElasticBeanstalkEnvironmentDetails = null,
    aws_elasticsearch_domain: ?AwsElasticsearchDomainDetails = null,
    aws_s3_bucket: ?AwsS3BucketDetails = null,
    aws_s3_account_public_access_block: ?AwsS3AccountPublicAccessBlockDetails = null,
    aws_s3_object: ?AwsS3ObjectDetails = null,
    aws_secrets_manager_secret: ?AwsSecretsManagerSecretDetails = null,
    aws_iam_access_key: ?AwsIamAccessKeyDetails = null,
    aws_iam_user: ?AwsIamUserDetails = null,
    aws_iam_policy: ?AwsIamPolicyDetails = null,
    aws_api_gateway_v2_stage: ?AwsApiGatewayV2StageDetails = null,
    aws_api_gateway_v2_api: ?AwsApiGatewayV2ApiDetails = null,
    aws_dynamo_db_table: ?AwsDynamoDbTableDetails = null,
    aws_api_gateway_stage: ?AwsApiGatewayStageDetails = null,
    aws_api_gateway_rest_api: ?AwsApiGatewayRestApiDetails = null,
    aws_cloud_trail_trail: ?AwsCloudTrailTrailDetails = null,
    aws_ssm_patch_compliance: ?AwsSsmPatchComplianceDetails = null,
    aws_certificate_manager_certificate: ?AwsCertificateManagerCertificateDetails = null,
    aws_redshift_cluster: ?AwsRedshiftClusterDetails = null,
    aws_elb_load_balancer: ?AwsElbLoadBalancerDetails = null,
    aws_iam_group: ?AwsIamGroupDetails = null,
    aws_iam_role: ?AwsIamRoleDetails = null,
    aws_kms_key: ?AwsKmsKeyDetails = null,
    aws_lambda_function: ?AwsLambdaFunctionDetails = null,
    aws_lambda_layer_version: ?AwsLambdaLayerVersionDetails = null,
    aws_rds_db_instance: ?AwsRdsDbInstanceDetails = null,
    aws_sns_topic: ?AwsSnsTopicDetails = null,
    aws_sqs_queue: ?AwsSqsQueueDetails = null,
    aws_waf_web_acl: ?AwsWafWebAclDetails = null,
    aws_rds_db_snapshot: ?AwsRdsDbSnapshotDetails = null,
    aws_rds_db_cluster_snapshot: ?AwsRdsDbClusterSnapshotDetails = null,
    aws_rds_db_cluster: ?AwsRdsDbClusterDetails = null,
    aws_ecs_cluster: ?AwsEcsClusterDetails = null,
    aws_ecs_container: ?AwsEcsContainerDetails = null,
    aws_ecs_task_definition: ?AwsEcsTaskDefinitionDetails = null,
    container: ?ContainerDetails = null,
    other: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    aws_rds_event_subscription: ?AwsRdsEventSubscriptionDetails = null,
    aws_ecs_service: ?AwsEcsServiceDetails = null,
    aws_auto_scaling_launch_configuration: ?AwsAutoScalingLaunchConfigurationDetails = null,
    aws_ec2_vpn_connection: ?AwsEc2VpnConnectionDetails = null,
    aws_ecr_container_image: ?AwsEcrContainerImageDetails = null,
    aws_open_search_service_domain: ?AwsOpenSearchServiceDomainDetails = null,
    aws_ec2_vpc_endpoint_service: ?AwsEc2VpcEndpointServiceDetails = null,
    aws_xray_encryption_config: ?AwsXrayEncryptionConfigDetails = null,
    aws_waf_rate_based_rule: ?AwsWafRateBasedRuleDetails = null,
    aws_waf_regional_rate_based_rule: ?AwsWafRegionalRateBasedRuleDetails = null,
    aws_ecr_repository: ?AwsEcrRepositoryDetails = null,
    aws_eks_cluster: ?AwsEksClusterDetails = null,
    aws_network_firewall_firewall_policy: ?AwsNetworkFirewallFirewallPolicyDetails = null,
    aws_network_firewall_firewall: ?AwsNetworkFirewallFirewallDetails = null,
    aws_network_firewall_rule_group: ?AwsNetworkFirewallRuleGroupDetails = null,
    aws_rds_db_security_group: ?AwsRdsDbSecurityGroupDetails = null,
    aws_kinesis_stream: ?AwsKinesisStreamDetails = null,
    aws_ec2_transit_gateway: ?AwsEc2TransitGatewayDetails = null,
    aws_efs_access_point: ?AwsEfsAccessPointDetails = null,
    aws_cloud_formation_stack: ?AwsCloudFormationStackDetails = null,
    aws_cloud_watch_alarm: ?AwsCloudWatchAlarmDetails = null,
    aws_ec2_vpc_peering_connection: ?AwsEc2VpcPeeringConnectionDetails = null,
    aws_waf_regional_rule_group: ?AwsWafRegionalRuleGroupDetails = null,
    aws_waf_regional_rule: ?AwsWafRegionalRuleDetails = null,
    aws_waf_regional_web_acl: ?AwsWafRegionalWebAclDetails = null,
    aws_waf_rule: ?AwsWafRuleDetails = null,
    aws_waf_rule_group: ?AwsWafRuleGroupDetails = null,
    aws_ecs_task: ?AwsEcsTaskDetails = null,
    aws_backup_backup_vault: ?AwsBackupBackupVaultDetails = null,
    aws_backup_backup_plan: ?AwsBackupBackupPlanDetails = null,
    aws_backup_recovery_point: ?AwsBackupRecoveryPointDetails = null,
    aws_ec2_launch_template: ?AwsEc2LaunchTemplateDetails = null,
    aws_sage_maker_notebook_instance: ?AwsSageMakerNotebookInstanceDetails = null,
    aws_wafv2_web_acl: ?AwsWafv2WebAclDetails = null,
    aws_wafv2_rule_group: ?AwsWafv2RuleGroupDetails = null,
    aws_ec2_route_table: ?AwsEc2RouteTableDetails = null,
    aws_amazon_mq_broker: ?AwsAmazonMqBrokerDetails = null,
    aws_app_sync_graph_ql_api: ?AwsAppSyncGraphQlApiDetails = null,
    aws_event_schemas_registry: ?AwsEventSchemasRegistryDetails = null,
    aws_guard_duty_detector: ?AwsGuardDutyDetectorDetails = null,
    aws_step_function_state_machine: ?AwsStepFunctionStateMachineDetails = null,
    aws_athena_work_group: ?AwsAthenaWorkGroupDetails = null,
    aws_events_eventbus: ?AwsEventsEventbusDetails = null,
    aws_dms_endpoint: ?AwsDmsEndpointDetails = null,
    aws_events_endpoint: ?AwsEventsEndpointDetails = null,
    aws_dms_replication_task: ?AwsDmsReplicationTaskDetails = null,
    aws_dms_replication_instance: ?AwsDmsReplicationInstanceDetails = null,
    aws_route53_hosted_zone: ?AwsRoute53HostedZoneDetails = null,
    aws_msk_cluster: ?AwsMskClusterDetails = null,
    aws_s3_access_point: ?AwsS3AccessPointDetails = null,
    aws_ec2_client_vpn_endpoint: ?AwsEc2ClientVpnEndpointDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_auto_scaling_auto_scaling_group = "AwsAutoScalingAutoScalingGroup",
            .aws_code_build_project = "AwsCodeBuildProject",
            .aws_cloud_front_distribution = "AwsCloudFrontDistribution",
            .aws_ec2_instance = "AwsEc2Instance",
            .aws_ec2_network_interface = "AwsEc2NetworkInterface",
            .aws_ec2_security_group = "AwsEc2SecurityGroup",
            .aws_ec2_volume = "AwsEc2Volume",
            .aws_ec2_vpc = "AwsEc2Vpc",
            .aws_ec2_eip = "AwsEc2Eip",
            .aws_ec2_subnet = "AwsEc2Subnet",
            .aws_ec2_network_acl = "AwsEc2NetworkAcl",
            .aws_elbv2_load_balancer = "AwsElbv2LoadBalancer",
            .aws_elastic_beanstalk_environment = "AwsElasticBeanstalkEnvironment",
            .aws_elasticsearch_domain = "AwsElasticsearchDomain",
            .aws_s3_bucket = "AwsS3Bucket",
            .aws_s3_account_public_access_block = "AwsS3AccountPublicAccessBlock",
            .aws_s3_object = "AwsS3Object",
            .aws_secrets_manager_secret = "AwsSecretsManagerSecret",
            .aws_iam_access_key = "AwsIamAccessKey",
            .aws_iam_user = "AwsIamUser",
            .aws_iam_policy = "AwsIamPolicy",
            .aws_api_gateway_v2_stage = "AwsApiGatewayV2Stage",
            .aws_api_gateway_v2_api = "AwsApiGatewayV2Api",
            .aws_dynamo_db_table = "AwsDynamoDbTable",
            .aws_api_gateway_stage = "AwsApiGatewayStage",
            .aws_api_gateway_rest_api = "AwsApiGatewayRestApi",
            .aws_cloud_trail_trail = "AwsCloudTrailTrail",
            .aws_ssm_patch_compliance = "AwsSsmPatchCompliance",
            .aws_certificate_manager_certificate = "AwsCertificateManagerCertificate",
            .aws_redshift_cluster = "AwsRedshiftCluster",
            .aws_elb_load_balancer = "AwsElbLoadBalancer",
            .aws_iam_group = "AwsIamGroup",
            .aws_iam_role = "AwsIamRole",
            .aws_kms_key = "AwsKmsKey",
            .aws_lambda_function = "AwsLambdaFunction",
            .aws_lambda_layer_version = "AwsLambdaLayerVersion",
            .aws_rds_db_instance = "AwsRdsDbInstance",
            .aws_sns_topic = "AwsSnsTopic",
            .aws_sqs_queue = "AwsSqsQueue",
            .aws_waf_web_acl = "AwsWafWebAcl",
            .aws_rds_db_snapshot = "AwsRdsDbSnapshot",
            .aws_rds_db_cluster_snapshot = "AwsRdsDbClusterSnapshot",
            .aws_rds_db_cluster = "AwsRdsDbCluster",
            .aws_ecs_cluster = "AwsEcsCluster",
            .aws_ecs_container = "AwsEcsContainer",
            .aws_ecs_task_definition = "AwsEcsTaskDefinition",
            .container = "Container",
            .other = "Other",
            .aws_rds_event_subscription = "AwsRdsEventSubscription",
            .aws_ecs_service = "AwsEcsService",
            .aws_auto_scaling_launch_configuration = "AwsAutoScalingLaunchConfiguration",
            .aws_ec2_vpn_connection = "AwsEc2VpnConnection",
            .aws_ecr_container_image = "AwsEcrContainerImage",
            .aws_open_search_service_domain = "AwsOpenSearchServiceDomain",
            .aws_ec2_vpc_endpoint_service = "AwsEc2VpcEndpointService",
            .aws_xray_encryption_config = "AwsXrayEncryptionConfig",
            .aws_waf_rate_based_rule = "AwsWafRateBasedRule",
            .aws_waf_regional_rate_based_rule = "AwsWafRegionalRateBasedRule",
            .aws_ecr_repository = "AwsEcrRepository",
            .aws_eks_cluster = "AwsEksCluster",
            .aws_network_firewall_firewall_policy = "AwsNetworkFirewallFirewallPolicy",
            .aws_network_firewall_firewall = "AwsNetworkFirewallFirewall",
            .aws_network_firewall_rule_group = "AwsNetworkFirewallRuleGroup",
            .aws_rds_db_security_group = "AwsRdsDbSecurityGroup",
            .aws_kinesis_stream = "AwsKinesisStream",
            .aws_ec2_transit_gateway = "AwsEc2TransitGateway",
            .aws_efs_access_point = "AwsEfsAccessPoint",
            .aws_cloud_formation_stack = "AwsCloudFormationStack",
            .aws_cloud_watch_alarm = "AwsCloudWatchAlarm",
            .aws_ec2_vpc_peering_connection = "AwsEc2VpcPeeringConnection",
            .aws_waf_regional_rule_group = "AwsWafRegionalRuleGroup",
            .aws_waf_regional_rule = "AwsWafRegionalRule",
            .aws_waf_regional_web_acl = "AwsWafRegionalWebAcl",
            .aws_waf_rule = "AwsWafRule",
            .aws_waf_rule_group = "AwsWafRuleGroup",
            .aws_ecs_task = "AwsEcsTask",
            .aws_backup_backup_vault = "AwsBackupBackupVault",
            .aws_backup_backup_plan = "AwsBackupBackupPlan",
            .aws_backup_recovery_point = "AwsBackupRecoveryPoint",
            .aws_ec2_launch_template = "AwsEc2LaunchTemplate",
            .aws_sage_maker_notebook_instance = "AwsSageMakerNotebookInstance",
            .aws_wafv2_web_acl = "AwsWafv2WebAcl",
            .aws_wafv2_rule_group = "AwsWafv2RuleGroup",
            .aws_ec2_route_table = "AwsEc2RouteTable",
            .aws_amazon_mq_broker = "AwsAmazonMqBroker",
            .aws_app_sync_graph_ql_api = "AwsAppSyncGraphQlApi",
            .aws_event_schemas_registry = "AwsEventSchemasRegistry",
            .aws_guard_duty_detector = "AwsGuardDutyDetector",
            .aws_step_function_state_machine = "AwsStepFunctionStateMachine",
            .aws_athena_work_group = "AwsAthenaWorkGroup",
            .aws_events_eventbus = "AwsEventsEventbus",
            .aws_dms_endpoint = "AwsDmsEndpoint",
            .aws_events_endpoint = "AwsEventsEndpoint",
            .aws_dms_replication_task = "AwsDmsReplicationTask",
            .aws_dms_replication_instance = "AwsDmsReplicationInstance",
            .aws_route53_hosted_zone = "AwsRoute53HostedZone",
            .aws_msk_cluster = "AwsMskCluster",
            .aws_s3_access_point = "AwsS3AccessPoint",
            .aws_ec2_client_vpn_endpoint = "AwsEc2ClientVpnEndpoint",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "other", field_name))
            return try serializeMap(self.other, self.fieldNameFor("other"), options, out_stream);
        return false;
    }
};

pub const AwsEc2ClientVpnEndpointDetails = struct {
    client_vpn_endpoint_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    client_cidr_block: ?[]const u8 = null,
    dns_server: ?[][]const u8 = null,
    split_tunnel: ?bool = null,
    transport_protocol: ?[]const u8 = null,
    vpn_port: ?i64 = null,
    server_certificate_arn: ?[]const u8 = null,
    authentication_options: ?[]AwsEc2ClientVpnEndpointAuthenticationOptionsDetails = null,
    connection_log_options: ?AwsEc2ClientVpnEndpointConnectionLogOptionsDetails = null,
    security_group_id_set: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,
    self_service_portal_url: ?[]const u8 = null,
    client_connect_options: ?AwsEc2ClientVpnEndpointClientConnectOptionsDetails = null,
    session_timeout_hours: ?i64 = null,
    client_login_banner_options: ?AwsEc2ClientVpnEndpointClientLoginBannerOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_vpn_endpoint_id = "ClientVpnEndpointId",
            .description = "Description",
            .client_cidr_block = "ClientCidrBlock",
            .dns_server = "DnsServer",
            .split_tunnel = "SplitTunnel",
            .transport_protocol = "TransportProtocol",
            .vpn_port = "VpnPort",
            .server_certificate_arn = "ServerCertificateArn",
            .authentication_options = "AuthenticationOptions",
            .connection_log_options = "ConnectionLogOptions",
            .security_group_id_set = "SecurityGroupIdSet",
            .vpc_id = "VpcId",
            .self_service_portal_url = "SelfServicePortalUrl",
            .client_connect_options = "ClientConnectOptions",
            .session_timeout_hours = "SessionTimeoutHours",
            .client_login_banner_options = "ClientLoginBannerOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointClientLoginBannerOptionsDetails = struct {
    enabled: ?bool = null,
    banner_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .banner_text = "BannerText",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointClientConnectOptionsDetails = struct {
    enabled: ?bool = null,
    lambda_function_arn: ?[]const u8 = null,
    status: ?AwsEc2ClientVpnEndpointClientConnectOptionsStatusDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .lambda_function_arn = "LambdaFunctionArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointClientConnectOptionsStatusDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointConnectionLogOptionsDetails = struct {
    enabled: ?bool = null,
    cloudwatch_log_group: ?[]const u8 = null,
    cloudwatch_log_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .cloudwatch_log_group = "CloudwatchLogGroup",
            .cloudwatch_log_stream = "CloudwatchLogStream",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointAuthenticationOptionsDetails = struct {
    type: ?[]const u8 = null,
    active_directory: ?AwsEc2ClientVpnEndpointAuthenticationOptionsActiveDirectoryDetails = null,
    mutual_authentication: ?AwsEc2ClientVpnEndpointAuthenticationOptionsMutualAuthenticationDetails = null,
    federated_authentication: ?AwsEc2ClientVpnEndpointAuthenticationOptionsFederatedAuthenticationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .active_directory = "ActiveDirectory",
            .mutual_authentication = "MutualAuthentication",
            .federated_authentication = "FederatedAuthentication",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointAuthenticationOptionsFederatedAuthenticationDetails = struct {
    saml_provider_arn: ?[]const u8 = null,
    self_service_saml_provider_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .saml_provider_arn = "SamlProviderArn",
            .self_service_saml_provider_arn = "SelfServiceSamlProviderArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointAuthenticationOptionsMutualAuthenticationDetails = struct {
    client_root_certificate_chain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_root_certificate_chain = "ClientRootCertificateChain",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2ClientVpnEndpointAuthenticationOptionsActiveDirectoryDetails = struct {
    directory_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_id = "DirectoryId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3AccessPointDetails = struct {
    access_point_arn: ?[]const u8 = null,
    alias: ?[]const u8 = null,
    bucket: ?[]const u8 = null,
    bucket_account_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    network_origin: ?[]const u8 = null,
    public_access_block_configuration: ?AwsS3AccountPublicAccessBlockDetails = null,
    vpc_configuration: ?AwsS3AccessPointVpcConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_arn = "AccessPointArn",
            .alias = "Alias",
            .bucket = "Bucket",
            .bucket_account_id = "BucketAccountId",
            .name = "Name",
            .network_origin = "NetworkOrigin",
            .public_access_block_configuration = "PublicAccessBlockConfiguration",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3AccessPointVpcConfigurationDetails = struct {
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3AccountPublicAccessBlockDetails = struct {
    block_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    ignore_public_acls: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "BlockPublicAcls",
            .block_public_policy = "BlockPublicPolicy",
            .ignore_public_acls = "IgnorePublicAcls",
            .restrict_public_buckets = "RestrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterDetails = struct {
    cluster_info: ?AwsMskClusterClusterInfoDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_info = "ClusterInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoDetails = struct {
    encryption_info: ?AwsMskClusterClusterInfoEncryptionInfoDetails = null,
    current_version: ?[]const u8 = null,
    number_of_broker_nodes: ?i64 = null,
    cluster_name: ?[]const u8 = null,
    client_authentication: ?AwsMskClusterClusterInfoClientAuthenticationDetails = null,
    enhanced_monitoring: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_info = "EncryptionInfo",
            .current_version = "CurrentVersion",
            .number_of_broker_nodes = "NumberOfBrokerNodes",
            .cluster_name = "ClusterName",
            .client_authentication = "ClientAuthentication",
            .enhanced_monitoring = "EnhancedMonitoring",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationDetails = struct {
    sasl: ?AwsMskClusterClusterInfoClientAuthenticationSaslDetails = null,
    unauthenticated: ?AwsMskClusterClusterInfoClientAuthenticationUnauthenticatedDetails = null,
    tls: ?AwsMskClusterClusterInfoClientAuthenticationTlsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sasl = "Sasl",
            .unauthenticated = "Unauthenticated",
            .tls = "Tls",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationTlsDetails = struct {
    certificate_authority_arn_list: ?[][]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_authority_arn_list = "CertificateAuthorityArnList",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationUnauthenticatedDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationSaslDetails = struct {
    iam: ?AwsMskClusterClusterInfoClientAuthenticationSaslIamDetails = null,
    scram: ?AwsMskClusterClusterInfoClientAuthenticationSaslScramDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam = "Iam",
            .scram = "Scram",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationSaslScramDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoClientAuthenticationSaslIamDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoEncryptionInfoDetails = struct {
    encryption_in_transit: ?AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails = null,
    encryption_at_rest: ?AwsMskClusterClusterInfoEncryptionInfoEncryptionAtRestDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_in_transit = "EncryptionInTransit",
            .encryption_at_rest = "EncryptionAtRest",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoEncryptionInfoEncryptionAtRestDetails = struct {
    data_volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_volume_kms_key_id = "DataVolumeKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMskClusterClusterInfoEncryptionInfoEncryptionInTransitDetails = struct {
    in_cluster: ?bool = null,
    client_broker: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .in_cluster = "InCluster",
            .client_broker = "ClientBroker",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRoute53HostedZoneDetails = struct {
    hosted_zone: ?AwsRoute53HostedZoneObjectDetails = null,
    vpcs: ?[]AwsRoute53HostedZoneVpcDetails = null,
    name_servers: ?[][]const u8 = null,
    query_logging_config: ?AwsRoute53QueryLoggingConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosted_zone = "HostedZone",
            .vpcs = "Vpcs",
            .name_servers = "NameServers",
            .query_logging_config = "QueryLoggingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRoute53QueryLoggingConfigDetails = struct {
    cloud_watch_logs_log_group_arn: ?CloudWatchLogsLogGroupArnConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsLogGroupArnConfigDetails = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    hosted_zone_id: ?[]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .hosted_zone_id = "HostedZoneId",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRoute53HostedZoneVpcDetails = struct {
    id: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRoute53HostedZoneObjectDetails = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    config: ?AwsRoute53HostedZoneConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .config = "Config",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRoute53HostedZoneConfigDetails = struct {
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDmsReplicationInstanceDetails = struct {
    allocated_storage: ?i64 = null,
    auto_minor_version_upgrade: ?bool = null,
    availability_zone: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    multi_az: ?bool = null,
    preferred_maintenance_window: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    replication_instance_class: ?[]const u8 = null,
    replication_instance_identifier: ?[]const u8 = null,
    replication_subnet_group: ?AwsDmsReplicationInstanceReplicationSubnetGroupDetails = null,
    vpc_security_groups: ?[]AwsDmsReplicationInstanceVpcSecurityGroupsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocated_storage = "AllocatedStorage",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .availability_zone = "AvailabilityZone",
            .engine_version = "EngineVersion",
            .kms_key_id = "KmsKeyId",
            .multi_az = "MultiAZ",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .publicly_accessible = "PubliclyAccessible",
            .replication_instance_class = "ReplicationInstanceClass",
            .replication_instance_identifier = "ReplicationInstanceIdentifier",
            .replication_subnet_group = "ReplicationSubnetGroup",
            .vpc_security_groups = "VpcSecurityGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDmsReplicationInstanceVpcSecurityGroupsDetails = struct {
    vpc_security_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDmsReplicationInstanceReplicationSubnetGroupDetails = struct {
    replication_subnet_group_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDmsReplicationTaskDetails = struct {
    cdc_start_position: ?[]const u8 = null,
    cdc_start_time: ?[]const u8 = null,
    cdc_stop_position: ?[]const u8 = null,
    migration_type: ?[]const u8 = null,
    id: ?[]const u8 = null,
    resource_identifier: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    replication_task_identifier: ?[]const u8 = null,
    replication_task_settings: ?[]const u8 = null,
    source_endpoint_arn: ?[]const u8 = null,
    table_mappings: ?[]const u8 = null,
    target_endpoint_arn: ?[]const u8 = null,
    task_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdc_start_position = "CdcStartPosition",
            .cdc_start_time = "CdcStartTime",
            .cdc_stop_position = "CdcStopPosition",
            .migration_type = "MigrationType",
            .id = "Id",
            .resource_identifier = "ResourceIdentifier",
            .replication_instance_arn = "ReplicationInstanceArn",
            .replication_task_identifier = "ReplicationTaskIdentifier",
            .replication_task_settings = "ReplicationTaskSettings",
            .source_endpoint_arn = "SourceEndpointArn",
            .table_mappings = "TableMappings",
            .target_endpoint_arn = "TargetEndpointArn",
            .task_data = "TaskData",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointDetails = struct {
    arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    endpoint_id: ?[]const u8 = null,
    endpoint_url: ?[]const u8 = null,
    event_buses: ?[]AwsEventsEndpointEventBusesDetails = null,
    name: ?[]const u8 = null,
    replication_config: ?AwsEventsEndpointReplicationConfigDetails = null,
    role_arn: ?[]const u8 = null,
    routing_config: ?AwsEventsEndpointRoutingConfigDetails = null,
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .description = "Description",
            .endpoint_id = "EndpointId",
            .endpoint_url = "EndpointUrl",
            .event_buses = "EventBuses",
            .name = "Name",
            .replication_config = "ReplicationConfig",
            .role_arn = "RoleArn",
            .routing_config = "RoutingConfig",
            .state = "State",
            .state_reason = "StateReason",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointRoutingConfigDetails = struct {
    failover_config: ?AwsEventsEndpointRoutingConfigFailoverConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_config = "FailoverConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointRoutingConfigFailoverConfigDetails = struct {
    primary: ?AwsEventsEndpointRoutingConfigFailoverConfigPrimaryDetails = null,
    secondary: ?AwsEventsEndpointRoutingConfigFailoverConfigSecondaryDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary = "Primary",
            .secondary = "Secondary",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointRoutingConfigFailoverConfigSecondaryDetails = struct {
    route: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .route = "Route",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointRoutingConfigFailoverConfigPrimaryDetails = struct {
    health_check: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .health_check = "HealthCheck",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointReplicationConfigDetails = struct {
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEndpointEventBusesDetails = struct {
    event_bus_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_bus_arn = "EventBusArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDmsEndpointDetails = struct {
    certificate_arn: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    endpoint_arn: ?[]const u8 = null,
    endpoint_identifier: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    engine_name: ?[]const u8 = null,
    external_id: ?[]const u8 = null,
    extra_connection_attributes: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
            .database_name = "DatabaseName",
            .endpoint_arn = "EndpointArn",
            .endpoint_identifier = "EndpointIdentifier",
            .endpoint_type = "EndpointType",
            .engine_name = "EngineName",
            .external_id = "ExternalId",
            .extra_connection_attributes = "ExtraConnectionAttributes",
            .kms_key_id = "KmsKeyId",
            .port = "Port",
            .server_name = "ServerName",
            .ssl_mode = "SslMode",
            .username = "Username",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventsEventbusDetails = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
            .policy = "Policy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAthenaWorkGroupDetails = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    state: ?[]const u8 = null,
    configuration: ?AwsAthenaWorkGroupConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .state = "State",
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAthenaWorkGroupConfigurationDetails = struct {
    result_configuration: ?AwsAthenaWorkGroupConfigurationResultConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result_configuration = "ResultConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAthenaWorkGroupConfigurationResultConfigurationDetails = struct {
    encryption_configuration: ?AwsAthenaWorkGroupConfigurationResultConfigurationEncryptionConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAthenaWorkGroupConfigurationResultConfigurationEncryptionConfigurationDetails = struct {
    encryption_option: ?[]const u8 = null,
    kms_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_option = "EncryptionOption",
            .kms_key = "KmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsStepFunctionStateMachineDetails = struct {
    label: ?[]const u8 = null,
    logging_configuration: ?AwsStepFunctionStateMachineLoggingConfigurationDetails = null,
    name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    state_machine_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    tracing_configuration: ?AwsStepFunctionStateMachineTracingConfigurationDetails = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label = "Label",
            .logging_configuration = "LoggingConfiguration",
            .name = "Name",
            .role_arn = "RoleArn",
            .state_machine_arn = "StateMachineArn",
            .status = "Status",
            .tracing_configuration = "TracingConfiguration",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsStepFunctionStateMachineTracingConfigurationDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsStepFunctionStateMachineLoggingConfigurationDetails = struct {
    destinations: ?[]AwsStepFunctionStateMachineLoggingConfigurationDestinationsDetails = null,
    include_execution_data: ?bool = null,
    level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destinations = "Destinations",
            .include_execution_data = "IncludeExecutionData",
            .level = "Level",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsStepFunctionStateMachineLoggingConfigurationDestinationsDetails = struct {
    cloud_watch_logs_log_group: ?AwsStepFunctionStateMachineLoggingConfigurationDestinationsCloudWatchLogsLogGroupDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group = "CloudWatchLogsLogGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsStepFunctionStateMachineLoggingConfigurationDestinationsCloudWatchLogsLogGroupDetails = struct {
    log_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_arn = "LogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDetails = struct {
    data_sources: ?AwsGuardDutyDetectorDataSourcesDetails = null,
    features: ?[]AwsGuardDutyDetectorFeaturesDetails = null,
    finding_publishing_frequency: ?[]const u8 = null,
    service_role: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_sources = "DataSources",
            .features = "Features",
            .finding_publishing_frequency = "FindingPublishingFrequency",
            .service_role = "ServiceRole",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorFeaturesDetails = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesDetails = struct {
    cloud_trail: ?AwsGuardDutyDetectorDataSourcesCloudTrailDetails = null,
    dns_logs: ?AwsGuardDutyDetectorDataSourcesDnsLogsDetails = null,
    flow_logs: ?AwsGuardDutyDetectorDataSourcesFlowLogsDetails = null,
    kubernetes: ?AwsGuardDutyDetectorDataSourcesKubernetesDetails = null,
    malware_protection: ?AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails = null,
    s3_logs: ?AwsGuardDutyDetectorDataSourcesS3LogsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_trail = "CloudTrail",
            .dns_logs = "DnsLogs",
            .flow_logs = "FlowLogs",
            .kubernetes = "Kubernetes",
            .malware_protection = "MalwareProtection",
            .s3_logs = "S3Logs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesS3LogsDetails = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesMalwareProtectionDetails = struct {
    scan_ec2_instance_with_findings: ?AwsGuardDutyDetectorDataSourcesMalwareProtectionScanEc2InstanceWithFindingsDetails = null,
    service_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_ec2_instance_with_findings = "ScanEc2InstanceWithFindings",
            .service_role = "ServiceRole",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesMalwareProtectionScanEc2InstanceWithFindingsDetails = struct {
    ebs_volumes: ?AwsGuardDutyDetectorDataSourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_volumes = "EbsVolumes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesDetails = struct {
    reason: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason = "Reason",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesKubernetesDetails = struct {
    audit_logs: ?AwsGuardDutyDetectorDataSourcesKubernetesAuditLogsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit_logs = "AuditLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesKubernetesAuditLogsDetails = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesFlowLogsDetails = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesDnsLogsDetails = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsGuardDutyDetectorDataSourcesCloudTrailDetails = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEventSchemasRegistryDetails = struct {
    description: ?[]const u8 = null,
    registry_arn: ?[]const u8 = null,
    registry_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .registry_arn = "RegistryArn",
            .registry_name = "RegistryName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiDetails = struct {
    api_id: ?[]const u8 = null,
    id: ?[]const u8 = null,
    open_id_connect_config: ?AwsAppSyncGraphQlApiOpenIdConnectConfigDetails = null,
    name: ?[]const u8 = null,
    lambda_authorizer_config: ?AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails = null,
    xray_enabled: ?bool = null,
    arn: ?[]const u8 = null,
    user_pool_config: ?AwsAppSyncGraphQlApiUserPoolConfigDetails = null,
    authentication_type: ?[]const u8 = null,
    log_config: ?AwsAppSyncGraphQlApiLogConfigDetails = null,
    additional_authentication_providers: ?[]AwsAppSyncGraphQlApiAdditionalAuthenticationProvidersDetails = null,
    waf_web_acl_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_id = "ApiId",
            .id = "Id",
            .open_id_connect_config = "OpenIdConnectConfig",
            .name = "Name",
            .lambda_authorizer_config = "LambdaAuthorizerConfig",
            .xray_enabled = "XrayEnabled",
            .arn = "Arn",
            .user_pool_config = "UserPoolConfig",
            .authentication_type = "AuthenticationType",
            .log_config = "LogConfig",
            .additional_authentication_providers = "AdditionalAuthenticationProviders",
            .waf_web_acl_arn = "WafWebAclArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiAdditionalAuthenticationProvidersDetails = struct {
    authentication_type: ?[]const u8 = null,
    lambda_authorizer_config: ?AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails = null,
    open_id_connect_config: ?AwsAppSyncGraphQlApiOpenIdConnectConfigDetails = null,
    user_pool_config: ?AwsAppSyncGraphQlApiUserPoolConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authentication_type = "AuthenticationType",
            .lambda_authorizer_config = "LambdaAuthorizerConfig",
            .open_id_connect_config = "OpenIdConnectConfig",
            .user_pool_config = "UserPoolConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiUserPoolConfigDetails = struct {
    app_id_client_regex: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    default_action: ?[]const u8 = null,
    user_pool_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_id_client_regex = "AppIdClientRegex",
            .aws_region = "AwsRegion",
            .default_action = "DefaultAction",
            .user_pool_id = "UserPoolId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiOpenIdConnectConfigDetails = struct {
    auth_ttl: ?i64 = null,
    client_id: ?[]const u8 = null,
    iat_ttl: ?i64 = null,
    issuer: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auth_ttl = "AuthTtL",
            .client_id = "ClientId",
            .iat_ttl = "IatTtL",
            .issuer = "Issuer",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiLambdaAuthorizerConfigDetails = struct {
    authorizer_result_ttl_in_seconds: ?i64 = null,
    authorizer_uri: ?[]const u8 = null,
    identity_validation_expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorizer_result_ttl_in_seconds = "AuthorizerResultTtlInSeconds",
            .authorizer_uri = "AuthorizerUri",
            .identity_validation_expression = "IdentityValidationExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAppSyncGraphQlApiLogConfigDetails = struct {
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    exclude_verbose_content: ?bool = null,
    field_log_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .exclude_verbose_content = "ExcludeVerboseContent",
            .field_log_level = "FieldLogLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerDetails = struct {
    authentication_strategy: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    broker_arn: ?[]const u8 = null,
    broker_name: ?[]const u8 = null,
    deployment_mode: ?[]const u8 = null,
    encryption_options: ?AwsAmazonMqBrokerEncryptionOptionsDetails = null,
    engine_type: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    host_instance_type: ?[]const u8 = null,
    broker_id: ?[]const u8 = null,
    ldap_server_metadata: ?AwsAmazonMqBrokerLdapServerMetadataDetails = null,
    logs: ?AwsAmazonMqBrokerLogsDetails = null,
    maintenance_window_start_time: ?AwsAmazonMqBrokerMaintenanceWindowStartTimeDetails = null,
    publicly_accessible: ?bool = null,
    security_groups: ?[][]const u8 = null,
    storage_type: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    users: ?[]AwsAmazonMqBrokerUsersDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authentication_strategy = "AuthenticationStrategy",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .broker_arn = "BrokerArn",
            .broker_name = "BrokerName",
            .deployment_mode = "DeploymentMode",
            .encryption_options = "EncryptionOptions",
            .engine_type = "EngineType",
            .engine_version = "EngineVersion",
            .host_instance_type = "HostInstanceType",
            .broker_id = "BrokerId",
            .ldap_server_metadata = "LdapServerMetadata",
            .logs = "Logs",
            .maintenance_window_start_time = "MaintenanceWindowStartTime",
            .publicly_accessible = "PubliclyAccessible",
            .security_groups = "SecurityGroups",
            .storage_type = "StorageType",
            .subnet_ids = "SubnetIds",
            .users = "Users",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerUsersDetails = struct {
    pending_change: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pending_change = "PendingChange",
            .username = "Username",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerMaintenanceWindowStartTimeDetails = struct {
    day_of_week: ?[]const u8 = null,
    time_of_day: ?[]const u8 = null,
    time_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_week = "DayOfWeek",
            .time_of_day = "TimeOfDay",
            .time_zone = "TimeZone",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerLogsDetails = struct {
    audit: ?bool = null,
    general: ?bool = null,
    audit_log_group: ?[]const u8 = null,
    general_log_group: ?[]const u8 = null,
    pending: ?AwsAmazonMqBrokerLogsPendingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit = "Audit",
            .general = "General",
            .audit_log_group = "AuditLogGroup",
            .general_log_group = "GeneralLogGroup",
            .pending = "Pending",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerLogsPendingDetails = struct {
    audit: ?bool = null,
    general: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit = "Audit",
            .general = "General",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerLdapServerMetadataDetails = struct {
    hosts: ?[][]const u8 = null,
    role_base: ?[]const u8 = null,
    role_name: ?[]const u8 = null,
    role_search_matching: ?[]const u8 = null,
    role_search_subtree: ?bool = null,
    service_account_username: ?[]const u8 = null,
    user_base: ?[]const u8 = null,
    user_role_name: ?[]const u8 = null,
    user_search_matching: ?[]const u8 = null,
    user_search_subtree: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosts = "Hosts",
            .role_base = "RoleBase",
            .role_name = "RoleName",
            .role_search_matching = "RoleSearchMatching",
            .role_search_subtree = "RoleSearchSubtree",
            .service_account_username = "ServiceAccountUsername",
            .user_base = "UserBase",
            .user_role_name = "UserRoleName",
            .user_search_matching = "UserSearchMatching",
            .user_search_subtree = "UserSearchSubtree",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAmazonMqBrokerEncryptionOptionsDetails = struct {
    kms_key_id: ?[]const u8 = null,
    use_aws_owned_key: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
            .use_aws_owned_key = "UseAwsOwnedKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2RouteTableDetails = struct {
    association_set: ?[]AssociationSetDetails = null,
    owner_id: ?[]const u8 = null,
    propagating_vgw_set: ?[]PropagatingVgwSetDetails = null,
    route_table_id: ?[]const u8 = null,
    route_set: ?[]RouteSetDetails = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_set = "AssociationSet",
            .owner_id = "OwnerId",
            .propagating_vgw_set = "PropagatingVgwSet",
            .route_table_id = "RouteTableId",
            .route_set = "RouteSet",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteSetDetails = struct {
    carrier_gateway_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    destination_cidr_block: ?[]const u8 = null,
    destination_ipv6_cidr_block: ?[]const u8 = null,
    destination_prefix_list_id: ?[]const u8 = null,
    egress_only_internet_gateway_id: ?[]const u8 = null,
    gateway_id: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    instance_owner_id: ?[]const u8 = null,
    local_gateway_id: ?[]const u8 = null,
    nat_gateway_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    origin: ?[]const u8 = null,
    state: ?[]const u8 = null,
    transit_gateway_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .carrier_gateway_id = "CarrierGatewayId",
            .core_network_arn = "CoreNetworkArn",
            .destination_cidr_block = "DestinationCidrBlock",
            .destination_ipv6_cidr_block = "DestinationIpv6CidrBlock",
            .destination_prefix_list_id = "DestinationPrefixListId",
            .egress_only_internet_gateway_id = "EgressOnlyInternetGatewayId",
            .gateway_id = "GatewayId",
            .instance_id = "InstanceId",
            .instance_owner_id = "InstanceOwnerId",
            .local_gateway_id = "LocalGatewayId",
            .nat_gateway_id = "NatGatewayId",
            .network_interface_id = "NetworkInterfaceId",
            .origin = "Origin",
            .state = "State",
            .transit_gateway_id = "TransitGatewayId",
            .vpc_peering_connection_id = "VpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const PropagatingVgwSetDetails = struct {
    gateway_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_id = "GatewayId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationSetDetails = struct {
    association_state: ?AssociationStateDetails = null,
    gateway_id: ?[]const u8 = null,
    main: ?bool = null,
    route_table_association_id: ?[]const u8 = null,
    route_table_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_state = "AssociationState",
            .gateway_id = "GatewayId",
            .main = "Main",
            .route_table_association_id = "RouteTableAssociationId",
            .route_table_id = "RouteTableId",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationStateDetails = struct {
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2RuleGroupDetails = struct {
    capacity: ?i64 = null,
    description: ?[]const u8 = null,
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    rules: ?[]AwsWafv2RulesDetails = null,
    scope: ?[]const u8 = null,
    visibility_config: ?AwsWafv2VisibilityConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
            .description = "Description",
            .id = "Id",
            .name = "Name",
            .arn = "Arn",
            .rules = "Rules",
            .scope = "Scope",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2VisibilityConfigDetails = struct {
    cloud_watch_metrics_enabled: ?bool = null,
    metric_name: ?[]const u8 = null,
    sampled_requests_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .metric_name = "MetricName",
            .sampled_requests_enabled = "SampledRequestsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2RulesDetails = struct {
    action: ?AwsWafv2RulesActionDetails = null,
    name: ?[]const u8 = null,
    override_action: ?[]const u8 = null,
    priority: ?i64 = null,
    visibility_config: ?AwsWafv2VisibilityConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .name = "Name",
            .override_action = "OverrideAction",
            .priority = "Priority",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2RulesActionDetails = struct {
    allow: ?AwsWafv2ActionAllowDetails = null,
    block: ?AwsWafv2ActionBlockDetails = null,
    captcha: ?AwsWafv2RulesActionCaptchaDetails = null,
    count: ?AwsWafv2RulesActionCountDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow = "Allow",
            .block = "Block",
            .captcha = "Captcha",
            .count = "Count",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2RulesActionCountDetails = struct {
    custom_request_handling: ?AwsWafv2CustomRequestHandlingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2CustomRequestHandlingDetails = struct {
    insert_headers: ?[]AwsWafv2CustomHttpHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insert_headers = "InsertHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2CustomHttpHeader = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2RulesActionCaptchaDetails = struct {
    custom_request_handling: ?AwsWafv2CustomRequestHandlingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2ActionBlockDetails = struct {
    custom_response: ?AwsWafv2CustomResponseDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_response = "CustomResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2CustomResponseDetails = struct {
    custom_response_body_key: ?[]const u8 = null,
    response_code: ?i64 = null,
    response_headers: ?[]AwsWafv2CustomHttpHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_response_body_key = "CustomResponseBodyKey",
            .response_code = "ResponseCode",
            .response_headers = "ResponseHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2ActionAllowDetails = struct {
    custom_request_handling: ?AwsWafv2CustomRequestHandlingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2WebAclDetails = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    managedby_firewall_manager: ?bool = null,
    id: ?[]const u8 = null,
    capacity: ?i64 = null,
    captcha_config: ?AwsWafv2WebAclCaptchaConfigDetails = null,
    default_action: ?AwsWafv2WebAclActionDetails = null,
    description: ?[]const u8 = null,
    rules: ?[]AwsWafv2RulesDetails = null,
    visibility_config: ?AwsWafv2VisibilityConfigDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .managedby_firewall_manager = "ManagedbyFirewallManager",
            .id = "Id",
            .capacity = "Capacity",
            .captcha_config = "CaptchaConfig",
            .default_action = "DefaultAction",
            .description = "Description",
            .rules = "Rules",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2WebAclActionDetails = struct {
    allow: ?AwsWafv2ActionAllowDetails = null,
    block: ?AwsWafv2ActionBlockDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow = "Allow",
            .block = "Block",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2WebAclCaptchaConfigDetails = struct {
    immunity_time_property: ?AwsWafv2WebAclCaptchaConfigImmunityTimePropertyDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .immunity_time_property = "ImmunityTimeProperty",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafv2WebAclCaptchaConfigImmunityTimePropertyDetails = struct {
    immunity_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .immunity_time = "ImmunityTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSageMakerNotebookInstanceDetails = struct {
    accelerator_types: ?[][]const u8 = null,
    additional_code_repositories: ?[][]const u8 = null,
    default_code_repository: ?[]const u8 = null,
    direct_internet_access: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    instance_metadata_service_configuration: ?AwsSageMakerNotebookInstanceMetadataServiceConfigurationDetails = null,
    instance_type: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    notebook_instance_arn: ?[]const u8 = null,
    notebook_instance_lifecycle_config_name: ?[]const u8 = null,
    notebook_instance_name: ?[]const u8 = null,
    notebook_instance_status: ?[]const u8 = null,
    platform_identifier: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    root_access: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    subnet_id: ?[]const u8 = null,
    url: ?[]const u8 = null,
    volume_size_in_gb: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accelerator_types = "AcceleratorTypes",
            .additional_code_repositories = "AdditionalCodeRepositories",
            .default_code_repository = "DefaultCodeRepository",
            .direct_internet_access = "DirectInternetAccess",
            .failure_reason = "FailureReason",
            .instance_metadata_service_configuration = "InstanceMetadataServiceConfiguration",
            .instance_type = "InstanceType",
            .kms_key_id = "KmsKeyId",
            .network_interface_id = "NetworkInterfaceId",
            .notebook_instance_arn = "NotebookInstanceArn",
            .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
            .notebook_instance_name = "NotebookInstanceName",
            .notebook_instance_status = "NotebookInstanceStatus",
            .platform_identifier = "PlatformIdentifier",
            .role_arn = "RoleArn",
            .root_access = "RootAccess",
            .security_groups = "SecurityGroups",
            .subnet_id = "SubnetId",
            .url = "Url",
            .volume_size_in_gb = "VolumeSizeInGB",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSageMakerNotebookInstanceMetadataServiceConfigurationDetails = struct {
    minimum_instance_metadata_service_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_instance_metadata_service_version = "MinimumInstanceMetadataServiceVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDetails = struct {
    launch_template_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    launch_template_data: ?AwsEc2LaunchTemplateDataDetails = null,
    default_version_number: ?i64 = null,
    latest_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_name = "LaunchTemplateName",
            .id = "Id",
            .launch_template_data = "LaunchTemplateData",
            .default_version_number = "DefaultVersionNumber",
            .latest_version_number = "LatestVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataDetails = struct {
    block_device_mapping_set: ?[]AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails = null,
    capacity_reservation_specification: ?AwsEc2LaunchTemplateDataCapacityReservationSpecificationDetails = null,
    cpu_options: ?AwsEc2LaunchTemplateDataCpuOptionsDetails = null,
    credit_specification: ?AwsEc2LaunchTemplateDataCreditSpecificationDetails = null,
    disable_api_stop: ?bool = null,
    disable_api_termination: ?bool = null,
    ebs_optimized: ?bool = null,
    elastic_gpu_specification_set: ?[]AwsEc2LaunchTemplateDataElasticGpuSpecificationSetDetails = null,
    elastic_inference_accelerator_set: ?[]AwsEc2LaunchTemplateDataElasticInferenceAcceleratorSetDetails = null,
    enclave_options: ?AwsEc2LaunchTemplateDataEnclaveOptionsDetails = null,
    hibernation_options: ?AwsEc2LaunchTemplateDataHibernationOptionsDetails = null,
    iam_instance_profile: ?AwsEc2LaunchTemplateDataIamInstanceProfileDetails = null,
    image_id: ?[]const u8 = null,
    instance_initiated_shutdown_behavior: ?[]const u8 = null,
    instance_market_options: ?AwsEc2LaunchTemplateDataInstanceMarketOptionsDetails = null,
    instance_requirements: ?AwsEc2LaunchTemplateDataInstanceRequirementsDetails = null,
    instance_type: ?[]const u8 = null,
    kernel_id: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    license_set: ?[]AwsEc2LaunchTemplateDataLicenseSetDetails = null,
    maintenance_options: ?AwsEc2LaunchTemplateDataMaintenanceOptionsDetails = null,
    metadata_options: ?AwsEc2LaunchTemplateDataMetadataOptionsDetails = null,
    monitoring: ?AwsEc2LaunchTemplateDataMonitoringDetails = null,
    network_interface_set: ?[]AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails = null,
    placement: ?AwsEc2LaunchTemplateDataPlacementDetails = null,
    private_dns_name_options: ?AwsEc2LaunchTemplateDataPrivateDnsNameOptionsDetails = null,
    ram_disk_id: ?[]const u8 = null,
    security_group_id_set: ?[][]const u8 = null,
    security_group_set: ?[][]const u8 = null,
    user_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_device_mapping_set = "BlockDeviceMappingSet",
            .capacity_reservation_specification = "CapacityReservationSpecification",
            .cpu_options = "CpuOptions",
            .credit_specification = "CreditSpecification",
            .disable_api_stop = "DisableApiStop",
            .disable_api_termination = "DisableApiTermination",
            .ebs_optimized = "EbsOptimized",
            .elastic_gpu_specification_set = "ElasticGpuSpecificationSet",
            .elastic_inference_accelerator_set = "ElasticInferenceAcceleratorSet",
            .enclave_options = "EnclaveOptions",
            .hibernation_options = "HibernationOptions",
            .iam_instance_profile = "IamInstanceProfile",
            .image_id = "ImageId",
            .instance_initiated_shutdown_behavior = "InstanceInitiatedShutdownBehavior",
            .instance_market_options = "InstanceMarketOptions",
            .instance_requirements = "InstanceRequirements",
            .instance_type = "InstanceType",
            .kernel_id = "KernelId",
            .key_name = "KeyName",
            .license_set = "LicenseSet",
            .maintenance_options = "MaintenanceOptions",
            .metadata_options = "MetadataOptions",
            .monitoring = "Monitoring",
            .network_interface_set = "NetworkInterfaceSet",
            .placement = "Placement",
            .private_dns_name_options = "PrivateDnsNameOptions",
            .ram_disk_id = "RamDiskId",
            .security_group_id_set = "SecurityGroupIdSet",
            .security_group_set = "SecurityGroupSet",
            .user_data = "UserData",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataPrivateDnsNameOptionsDetails = struct {
    enable_resource_name_dns_aaaa_record: ?bool = null,
    enable_resource_name_dns_a_record: ?bool = null,
    hostname_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_resource_name_dns_aaaa_record = "EnableResourceNameDnsAAAARecord",
            .enable_resource_name_dns_a_record = "EnableResourceNameDnsARecord",
            .hostname_type = "HostnameType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataPlacementDetails = struct {
    affinity: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    host_id: ?[]const u8 = null,
    host_resource_group_arn: ?[]const u8 = null,
    partition_number: ?i64 = null,
    spread_domain: ?[]const u8 = null,
    tenancy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .affinity = "Affinity",
            .availability_zone = "AvailabilityZone",
            .group_name = "GroupName",
            .host_id = "HostId",
            .host_resource_group_arn = "HostResourceGroupArn",
            .partition_number = "PartitionNumber",
            .spread_domain = "SpreadDomain",
            .tenancy = "Tenancy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataNetworkInterfaceSetDetails = struct {
    associate_carrier_ip_address: ?bool = null,
    associate_public_ip_address: ?bool = null,
    delete_on_termination: ?bool = null,
    description: ?[]const u8 = null,
    device_index: ?i64 = null,
    groups: ?[][]const u8 = null,
    interface_type: ?[]const u8 = null,
    ipv4_prefix_count: ?i64 = null,
    ipv4_prefixes: ?[]AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv4PrefixesDetails = null,
    ipv6_address_count: ?i64 = null,
    ipv6_addresses: ?[]AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6AddressesDetails = null,
    ipv6_prefix_count: ?i64 = null,
    ipv6_prefixes: ?[]AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6PrefixesDetails = null,
    network_card_index: ?i64 = null,
    network_interface_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    private_ip_addresses: ?[]AwsEc2LaunchTemplateDataNetworkInterfaceSetPrivateIpAddressesDetails = null,
    secondary_private_ip_address_count: ?i64 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_carrier_ip_address = "AssociateCarrierIpAddress",
            .associate_public_ip_address = "AssociatePublicIpAddress",
            .delete_on_termination = "DeleteOnTermination",
            .description = "Description",
            .device_index = "DeviceIndex",
            .groups = "Groups",
            .interface_type = "InterfaceType",
            .ipv4_prefix_count = "Ipv4PrefixCount",
            .ipv4_prefixes = "Ipv4Prefixes",
            .ipv6_address_count = "Ipv6AddressCount",
            .ipv6_addresses = "Ipv6Addresses",
            .ipv6_prefix_count = "Ipv6PrefixCount",
            .ipv6_prefixes = "Ipv6Prefixes",
            .network_card_index = "NetworkCardIndex",
            .network_interface_id = "NetworkInterfaceId",
            .private_ip_address = "PrivateIpAddress",
            .private_ip_addresses = "PrivateIpAddresses",
            .secondary_private_ip_address_count = "SecondaryPrivateIpAddressCount",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataNetworkInterfaceSetPrivateIpAddressesDetails = struct {
    primary: ?bool = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary = "Primary",
            .private_ip_address = "PrivateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6PrefixesDetails = struct {
    ipv6_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_prefix = "Ipv6Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv6AddressesDetails = struct {
    ipv6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_address = "Ipv6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataNetworkInterfaceSetIpv4PrefixesDetails = struct {
    ipv4_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv4_prefix = "Ipv4Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataMonitoringDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataMetadataOptionsDetails = struct {
    http_endpoint: ?[]const u8 = null,
    http_protocol_ipv6: ?[]const u8 = null,
    http_tokens: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    instance_metadata_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_endpoint = "HttpEndpoint",
            .http_protocol_ipv6 = "HttpProtocolIpv6",
            .http_tokens = "HttpTokens",
            .http_put_response_hop_limit = "HttpPutResponseHopLimit",
            .instance_metadata_tags = "InstanceMetadataTags",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataMaintenanceOptionsDetails = struct {
    auto_recovery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_recovery = "AutoRecovery",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataLicenseSetDetails = struct {
    license_configuration_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "LicenseConfigurationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsDetails = struct {
    accelerator_count: ?AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorCountDetails = null,
    accelerator_manufacturers: ?[][]const u8 = null,
    accelerator_names: ?[][]const u8 = null,
    accelerator_total_memory_mib: ?AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorTotalMemoryMiBDetails = null,
    accelerator_types: ?[][]const u8 = null,
    bare_metal: ?[]const u8 = null,
    baseline_ebs_bandwidth_mbps: ?AwsEc2LaunchTemplateDataInstanceRequirementsBaselineEbsBandwidthMbpsDetails = null,
    burstable_performance: ?[]const u8 = null,
    cpu_manufacturers: ?[][]const u8 = null,
    excluded_instance_types: ?[][]const u8 = null,
    instance_generations: ?[][]const u8 = null,
    local_storage: ?[]const u8 = null,
    local_storage_types: ?[][]const u8 = null,
    memory_gi_b_per_v_cpu: ?AwsEc2LaunchTemplateDataInstanceRequirementsMemoryGiBPerVCpuDetails = null,
    memory_mib: ?AwsEc2LaunchTemplateDataInstanceRequirementsMemoryMiBDetails = null,
    network_interface_count: ?AwsEc2LaunchTemplateDataInstanceRequirementsNetworkInterfaceCountDetails = null,
    on_demand_max_price_percentage_over_lowest_price: ?i64 = null,
    require_hibernate_support: ?bool = null,
    spot_max_price_percentage_over_lowest_price: ?i64 = null,
    total_local_storage_gb: ?AwsEc2LaunchTemplateDataInstanceRequirementsTotalLocalStorageGBDetails = null,
    v_cpu_count: ?AwsEc2LaunchTemplateDataInstanceRequirementsVCpuCountDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accelerator_count = "AcceleratorCount",
            .accelerator_manufacturers = "AcceleratorManufacturers",
            .accelerator_names = "AcceleratorNames",
            .accelerator_total_memory_mib = "AcceleratorTotalMemoryMiB",
            .accelerator_types = "AcceleratorTypes",
            .bare_metal = "BareMetal",
            .baseline_ebs_bandwidth_mbps = "BaselineEbsBandwidthMbps",
            .burstable_performance = "BurstablePerformance",
            .cpu_manufacturers = "CpuManufacturers",
            .excluded_instance_types = "ExcludedInstanceTypes",
            .instance_generations = "InstanceGenerations",
            .local_storage = "LocalStorage",
            .local_storage_types = "LocalStorageTypes",
            .memory_gi_b_per_v_cpu = "MemoryGiBPerVCpu",
            .memory_mib = "MemoryMiB",
            .network_interface_count = "NetworkInterfaceCount",
            .on_demand_max_price_percentage_over_lowest_price = "OnDemandMaxPricePercentageOverLowestPrice",
            .require_hibernate_support = "RequireHibernateSupport",
            .spot_max_price_percentage_over_lowest_price = "SpotMaxPricePercentageOverLowestPrice",
            .total_local_storage_gb = "TotalLocalStorageGB",
            .v_cpu_count = "VCpuCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsVCpuCountDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsTotalLocalStorageGBDetails = struct {
    max: ?f64 = null,
    min: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsNetworkInterfaceCountDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsMemoryMiBDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsMemoryGiBPerVCpuDetails = struct {
    max: ?f64 = null,
    min: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsBaselineEbsBandwidthMbpsDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorTotalMemoryMiBDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceRequirementsAcceleratorCountDetails = struct {
    max: ?i64 = null,
    min: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max = "Max",
            .min = "Min",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceMarketOptionsDetails = struct {
    market_type: ?[]const u8 = null,
    spot_options: ?AwsEc2LaunchTemplateDataInstanceMarketOptionsSpotOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .market_type = "MarketType",
            .spot_options = "SpotOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataInstanceMarketOptionsSpotOptionsDetails = struct {
    block_duration_minutes: ?i64 = null,
    instance_interruption_behavior: ?[]const u8 = null,
    max_price: ?[]const u8 = null,
    spot_instance_type: ?[]const u8 = null,
    valid_until: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_duration_minutes = "BlockDurationMinutes",
            .instance_interruption_behavior = "InstanceInterruptionBehavior",
            .max_price = "MaxPrice",
            .spot_instance_type = "SpotInstanceType",
            .valid_until = "ValidUntil",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataIamInstanceProfileDetails = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataHibernationOptionsDetails = struct {
    configured: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configured = "Configured",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataEnclaveOptionsDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataElasticInferenceAcceleratorSetDetails = struct {
    count: ?i64 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataElasticGpuSpecificationSetDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataCreditSpecificationDetails = struct {
    cpu_credits: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cpu_credits = "CpuCredits",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataCpuOptionsDetails = struct {
    core_count: ?i64 = null,
    threads_per_core: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_count = "CoreCount",
            .threads_per_core = "ThreadsPerCore",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataCapacityReservationSpecificationDetails = struct {
    capacity_reservation_preference: ?[]const u8 = null,
    capacity_reservation_target: ?AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_preference = "CapacityReservationPreference",
            .capacity_reservation_target = "CapacityReservationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataCapacityReservationSpecificationCapacityReservationTargetDetails = struct {
    capacity_reservation_id: ?[]const u8 = null,
    capacity_reservation_resource_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_reservation_id = "CapacityReservationId",
            .capacity_reservation_resource_group_arn = "CapacityReservationResourceGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataBlockDeviceMappingSetDetails = struct {
    device_name: ?[]const u8 = null,
    ebs: ?AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails = null,
    no_device: ?[]const u8 = null,
    virtual_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .ebs = "Ebs",
            .no_device = "NoDevice",
            .virtual_name = "VirtualName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2LaunchTemplateDataBlockDeviceMappingSetEbsDetails = struct {
    delete_on_termination: ?bool = null,
    encrypted: ?bool = null,
    iops: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    throughput: ?i64 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_on_termination = "DeleteOnTermination",
            .encrypted = "Encrypted",
            .iops = "Iops",
            .kms_key_id = "KmsKeyId",
            .snapshot_id = "SnapshotId",
            .throughput = "Throughput",
            .volume_size = "VolumeSize",
            .volume_type = "VolumeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupRecoveryPointDetails = struct {
    backup_size_in_bytes: ?i64 = null,
    backup_vault_arn: ?[]const u8 = null,
    backup_vault_name: ?[]const u8 = null,
    calculated_lifecycle: ?AwsBackupRecoveryPointCalculatedLifecycleDetails = null,
    completion_date: ?[]const u8 = null,
    created_by: ?AwsBackupRecoveryPointCreatedByDetails = null,
    creation_date: ?[]const u8 = null,
    encryption_key_arn: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,
    is_encrypted: ?bool = null,
    last_restore_time: ?[]const u8 = null,
    lifecycle: ?AwsBackupRecoveryPointLifecycleDetails = null,
    recovery_point_arn: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    source_backup_vault_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_size_in_bytes = "BackupSizeInBytes",
            .backup_vault_arn = "BackupVaultArn",
            .backup_vault_name = "BackupVaultName",
            .calculated_lifecycle = "CalculatedLifecycle",
            .completion_date = "CompletionDate",
            .created_by = "CreatedBy",
            .creation_date = "CreationDate",
            .encryption_key_arn = "EncryptionKeyArn",
            .iam_role_arn = "IamRoleArn",
            .is_encrypted = "IsEncrypted",
            .last_restore_time = "LastRestoreTime",
            .lifecycle = "Lifecycle",
            .recovery_point_arn = "RecoveryPointArn",
            .resource_arn = "ResourceArn",
            .resource_type = "ResourceType",
            .source_backup_vault_arn = "SourceBackupVaultArn",
            .status = "Status",
            .status_message = "StatusMessage",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupRecoveryPointLifecycleDetails = struct {
    delete_after_days: ?i64 = null,
    move_to_cold_storage_after_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_after_days = "DeleteAfterDays",
            .move_to_cold_storage_after_days = "MoveToColdStorageAfterDays",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupRecoveryPointCreatedByDetails = struct {
    backup_plan_arn: ?[]const u8 = null,
    backup_plan_id: ?[]const u8 = null,
    backup_plan_version: ?[]const u8 = null,
    backup_rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_arn = "BackupPlanArn",
            .backup_plan_id = "BackupPlanId",
            .backup_plan_version = "BackupPlanVersion",
            .backup_rule_id = "BackupRuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupRecoveryPointCalculatedLifecycleDetails = struct {
    delete_at: ?[]const u8 = null,
    move_to_cold_storage_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_at = "DeleteAt",
            .move_to_cold_storage_at = "MoveToColdStorageAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanDetails = struct {
    backup_plan: ?AwsBackupBackupPlanBackupPlanDetails = null,
    backup_plan_arn: ?[]const u8 = null,
    backup_plan_id: ?[]const u8 = null,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan = "BackupPlan",
            .backup_plan_arn = "BackupPlanArn",
            .backup_plan_id = "BackupPlanId",
            .version_id = "VersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanBackupPlanDetails = struct {
    backup_plan_name: ?[]const u8 = null,
    advanced_backup_settings: ?[]AwsBackupBackupPlanAdvancedBackupSettingsDetails = null,
    backup_plan_rule: ?[]AwsBackupBackupPlanRuleDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_name = "BackupPlanName",
            .advanced_backup_settings = "AdvancedBackupSettings",
            .backup_plan_rule = "BackupPlanRule",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanRuleDetails = struct {
    target_backup_vault: ?[]const u8 = null,
    start_window_minutes: ?i64 = null,
    schedule_expression: ?[]const u8 = null,
    rule_name: ?[]const u8 = null,
    rule_id: ?[]const u8 = null,
    enable_continuous_backup: ?bool = null,
    completion_window_minutes: ?i64 = null,
    copy_actions: ?[]AwsBackupBackupPlanRuleCopyActionsDetails = null,
    lifecycle: ?AwsBackupBackupPlanLifecycleDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_backup_vault = "TargetBackupVault",
            .start_window_minutes = "StartWindowMinutes",
            .schedule_expression = "ScheduleExpression",
            .rule_name = "RuleName",
            .rule_id = "RuleId",
            .enable_continuous_backup = "EnableContinuousBackup",
            .completion_window_minutes = "CompletionWindowMinutes",
            .copy_actions = "CopyActions",
            .lifecycle = "Lifecycle",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanLifecycleDetails = struct {
    delete_after_days: ?i64 = null,
    move_to_cold_storage_after_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_after_days = "DeleteAfterDays",
            .move_to_cold_storage_after_days = "MoveToColdStorageAfterDays",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanRuleCopyActionsDetails = struct {
    destination_backup_vault_arn: ?[]const u8 = null,
    lifecycle: ?AwsBackupBackupPlanLifecycleDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_backup_vault_arn = "DestinationBackupVaultArn",
            .lifecycle = "Lifecycle",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupPlanAdvancedBackupSettingsDetails = struct {
    backup_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_options = "BackupOptions",
            .resource_type = "ResourceType",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "backup_options", field_name))
            return try serializeMap(self.backup_options, self.fieldNameFor("backup_options"), options, out_stream);
        return false;
    }
};

pub const AwsBackupBackupVaultDetails = struct {
    backup_vault_arn: ?[]const u8 = null,
    backup_vault_name: ?[]const u8 = null,
    encryption_key_arn: ?[]const u8 = null,
    notifications: ?AwsBackupBackupVaultNotificationsDetails = null,
    access_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_vault_arn = "BackupVaultArn",
            .backup_vault_name = "BackupVaultName",
            .encryption_key_arn = "EncryptionKeyArn",
            .notifications = "Notifications",
            .access_policy = "AccessPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsBackupBackupVaultNotificationsDetails = struct {
    backup_vault_events: ?[][]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_vault_events = "BackupVaultEvents",
            .sns_topic_arn = "SnsTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDetails = struct {
    cluster_arn: ?[]const u8 = null,
    task_definition_arn: ?[]const u8 = null,
    version: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    started_at: ?[]const u8 = null,
    started_by: ?[]const u8 = null,
    group: ?[]const u8 = null,
    volumes: ?[]AwsEcsTaskVolumeDetails = null,
    containers: ?[]AwsEcsContainerDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_arn = "ClusterArn",
            .task_definition_arn = "TaskDefinitionArn",
            .version = "Version",
            .created_at = "CreatedAt",
            .started_at = "StartedAt",
            .started_by = "StartedBy",
            .group = "Group",
            .volumes = "Volumes",
            .containers = "Containers",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsContainerDetails = struct {
    name: ?[]const u8 = null,
    image: ?[]const u8 = null,
    mount_points: ?[]AwsMountPoint = null,
    privileged: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .image = "Image",
            .mount_points = "MountPoints",
            .privileged = "Privileged",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsMountPoint = struct {
    source_volume: ?[]const u8 = null,
    container_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_volume = "SourceVolume",
            .container_path = "ContainerPath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskVolumeDetails = struct {
    name: ?[]const u8 = null,
    host: ?AwsEcsTaskVolumeHostDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .host = "Host",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskVolumeHostDetails = struct {
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "SourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRuleGroupDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    rule_group_id: ?[]const u8 = null,
    rules: ?[]AwsWafRuleGroupRulesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .rule_group_id = "RuleGroupId",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRuleGroupRulesDetails = struct {
    action: ?AwsWafRuleGroupRulesActionDetails = null,
    priority: ?i64 = null,
    rule_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .priority = "Priority",
            .rule_id = "RuleId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRuleGroupRulesActionDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRuleDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    predicate_list: ?[]AwsWafRulePredicateListDetails = null,
    rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .predicate_list = "PredicateList",
            .rule_id = "RuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRulePredicateListDetails = struct {
    data_id: ?[]const u8 = null,
    negated: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_id = "DataId",
            .negated = "Negated",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalWebAclDetails = struct {
    default_action: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    rules_list: ?[]AwsWafRegionalWebAclRulesListDetails = null,
    web_acl_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_action = "DefaultAction",
            .metric_name = "MetricName",
            .name = "Name",
            .rules_list = "RulesList",
            .web_acl_id = "WebAclId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalWebAclRulesListDetails = struct {
    action: ?AwsWafRegionalWebAclRulesListActionDetails = null,
    override_action: ?AwsWafRegionalWebAclRulesListOverrideActionDetails = null,
    priority: ?i64 = null,
    rule_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .override_action = "OverrideAction",
            .priority = "Priority",
            .rule_id = "RuleId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalWebAclRulesListOverrideActionDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalWebAclRulesListActionDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRuleDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    predicate_list: ?[]AwsWafRegionalRulePredicateListDetails = null,
    rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .predicate_list = "PredicateList",
            .rule_id = "RuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRulePredicateListDetails = struct {
    data_id: ?[]const u8 = null,
    negated: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_id = "DataId",
            .negated = "Negated",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRuleGroupDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    rule_group_id: ?[]const u8 = null,
    rules: ?[]AwsWafRegionalRuleGroupRulesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .rule_group_id = "RuleGroupId",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRuleGroupRulesDetails = struct {
    action: ?AwsWafRegionalRuleGroupRulesActionDetails = null,
    priority: ?i64 = null,
    rule_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .priority = "Priority",
            .rule_id = "RuleId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRuleGroupRulesActionDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcPeeringConnectionDetails = struct {
    accepter_vpc_info: ?AwsEc2VpcPeeringConnectionVpcInfoDetails = null,
    expiration_time: ?[]const u8 = null,
    requester_vpc_info: ?AwsEc2VpcPeeringConnectionVpcInfoDetails = null,
    status: ?AwsEc2VpcPeeringConnectionStatusDetails = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accepter_vpc_info = "AccepterVpcInfo",
            .expiration_time = "ExpirationTime",
            .requester_vpc_info = "RequesterVpcInfo",
            .status = "Status",
            .vpc_peering_connection_id = "VpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcPeeringConnectionStatusDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcPeeringConnectionVpcInfoDetails = struct {
    cidr_block: ?[]const u8 = null,
    cidr_block_set: ?[]VpcInfoCidrBlockSetDetails = null,
    ipv6_cidr_block_set: ?[]VpcInfoIpv6CidrBlockSetDetails = null,
    owner_id: ?[]const u8 = null,
    peering_options: ?VpcInfoPeeringOptionsDetails = null,
    region: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "CidrBlock",
            .cidr_block_set = "CidrBlockSet",
            .ipv6_cidr_block_set = "Ipv6CidrBlockSet",
            .owner_id = "OwnerId",
            .peering_options = "PeeringOptions",
            .region = "Region",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInfoPeeringOptionsDetails = struct {
    allow_dns_resolution_from_remote_vpc: ?bool = null,
    allow_egress_from_local_classic_link_to_remote_vpc: ?bool = null,
    allow_egress_from_local_vpc_to_remote_classic_link: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_dns_resolution_from_remote_vpc = "AllowDnsResolutionFromRemoteVpc",
            .allow_egress_from_local_classic_link_to_remote_vpc = "AllowEgressFromLocalClassicLinkToRemoteVpc",
            .allow_egress_from_local_vpc_to_remote_classic_link = "AllowEgressFromLocalVpcToRemoteClassicLink",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInfoIpv6CidrBlockSetDetails = struct {
    ipv6_cidr_block: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_cidr_block = "Ipv6CidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInfoCidrBlockSetDetails = struct {
    cidr_block: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "CidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudWatchAlarmDetails = struct {
    actions_enabled: ?bool = null,
    alarm_actions: ?[][]const u8 = null,
    alarm_arn: ?[]const u8 = null,
    alarm_configuration_updated_timestamp: ?[]const u8 = null,
    alarm_description: ?[]const u8 = null,
    alarm_name: ?[]const u8 = null,
    comparison_operator: ?[]const u8 = null,
    datapoints_to_alarm: ?i64 = null,
    dimensions: ?[]AwsCloudWatchAlarmDimensionsDetails = null,
    evaluate_low_sample_count_percentile: ?[]const u8 = null,
    evaluation_periods: ?i64 = null,
    extended_statistic: ?[]const u8 = null,
    insufficient_data_actions: ?[][]const u8 = null,
    metric_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    ok_actions: ?[][]const u8 = null,
    period: ?i64 = null,
    statistic: ?[]const u8 = null,
    threshold: ?f64 = null,
    threshold_metric_id: ?[]const u8 = null,
    treat_missing_data: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions_enabled = "ActionsEnabled",
            .alarm_actions = "AlarmActions",
            .alarm_arn = "AlarmArn",
            .alarm_configuration_updated_timestamp = "AlarmConfigurationUpdatedTimestamp",
            .alarm_description = "AlarmDescription",
            .alarm_name = "AlarmName",
            .comparison_operator = "ComparisonOperator",
            .datapoints_to_alarm = "DatapointsToAlarm",
            .dimensions = "Dimensions",
            .evaluate_low_sample_count_percentile = "EvaluateLowSampleCountPercentile",
            .evaluation_periods = "EvaluationPeriods",
            .extended_statistic = "ExtendedStatistic",
            .insufficient_data_actions = "InsufficientDataActions",
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .ok_actions = "OkActions",
            .period = "Period",
            .statistic = "Statistic",
            .threshold = "Threshold",
            .threshold_metric_id = "ThresholdMetricId",
            .treat_missing_data = "TreatMissingData",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudWatchAlarmDimensionsDetails = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFormationStackDetails = struct {
    capabilities: ?[][]const u8 = null,
    creation_time: ?[]const u8 = null,
    description: ?[]const u8 = null,
    disable_rollback: ?bool = null,
    drift_information: ?AwsCloudFormationStackDriftInformationDetails = null,
    enable_termination_protection: ?bool = null,
    last_updated_time: ?[]const u8 = null,
    notification_arns: ?[][]const u8 = null,
    outputs: ?[]AwsCloudFormationStackOutputsDetails = null,
    role_arn: ?[]const u8 = null,
    stack_id: ?[]const u8 = null,
    stack_name: ?[]const u8 = null,
    stack_status: ?[]const u8 = null,
    stack_status_reason: ?[]const u8 = null,
    timeout_in_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capabilities = "Capabilities",
            .creation_time = "CreationTime",
            .description = "Description",
            .disable_rollback = "DisableRollback",
            .drift_information = "DriftInformation",
            .enable_termination_protection = "EnableTerminationProtection",
            .last_updated_time = "LastUpdatedTime",
            .notification_arns = "NotificationArns",
            .outputs = "Outputs",
            .role_arn = "RoleArn",
            .stack_id = "StackId",
            .stack_name = "StackName",
            .stack_status = "StackStatus",
            .stack_status_reason = "StackStatusReason",
            .timeout_in_minutes = "TimeoutInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFormationStackOutputsDetails = struct {
    description: ?[]const u8 = null,
    output_key: ?[]const u8 = null,
    output_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .output_key = "OutputKey",
            .output_value = "OutputValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFormationStackDriftInformationDetails = struct {
    stack_drift_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_drift_status = "StackDriftStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEfsAccessPointDetails = struct {
    access_point_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    client_token: ?[]const u8 = null,
    file_system_id: ?[]const u8 = null,
    posix_user: ?AwsEfsAccessPointPosixUserDetails = null,
    root_directory: ?AwsEfsAccessPointRootDirectoryDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_id = "AccessPointId",
            .arn = "Arn",
            .client_token = "ClientToken",
            .file_system_id = "FileSystemId",
            .posix_user = "PosixUser",
            .root_directory = "RootDirectory",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEfsAccessPointRootDirectoryDetails = struct {
    creation_info: ?AwsEfsAccessPointRootDirectoryCreationInfoDetails = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_info = "CreationInfo",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEfsAccessPointRootDirectoryCreationInfoDetails = struct {
    owner_gid: ?[]const u8 = null,
    owner_uid: ?[]const u8 = null,
    permissions: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_gid = "OwnerGid",
            .owner_uid = "OwnerUid",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEfsAccessPointPosixUserDetails = struct {
    gid: ?[]const u8 = null,
    secondary_gids: ?[][]const u8 = null,
    uid: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gid = "Gid",
            .secondary_gids = "SecondaryGids",
            .uid = "Uid",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2TransitGatewayDetails = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_route_table_propagation: ?[]const u8 = null,
    auto_accept_shared_attachments: ?[]const u8 = null,
    default_route_table_association: ?[]const u8 = null,
    transit_gateway_cidr_blocks: ?[][]const u8 = null,
    association_default_route_table_id: ?[]const u8 = null,
    propagation_default_route_table_id: ?[]const u8 = null,
    vpn_ecmp_support: ?[]const u8 = null,
    dns_support: ?[]const u8 = null,
    multicast_support: ?[]const u8 = null,
    amazon_side_asn: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .description = "Description",
            .default_route_table_propagation = "DefaultRouteTablePropagation",
            .auto_accept_shared_attachments = "AutoAcceptSharedAttachments",
            .default_route_table_association = "DefaultRouteTableAssociation",
            .transit_gateway_cidr_blocks = "TransitGatewayCidrBlocks",
            .association_default_route_table_id = "AssociationDefaultRouteTableId",
            .propagation_default_route_table_id = "PropagationDefaultRouteTableId",
            .vpn_ecmp_support = "VpnEcmpSupport",
            .dns_support = "DnsSupport",
            .multicast_support = "MulticastSupport",
            .amazon_side_asn = "AmazonSideAsn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsKinesisStreamDetails = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    stream_encryption: ?AwsKinesisStreamStreamEncryptionDetails = null,
    shard_count: ?i64 = null,
    retention_period_hours: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .stream_encryption = "StreamEncryption",
            .shard_count = "ShardCount",
            .retention_period_hours = "RetentionPeriodHours",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsKinesisStreamStreamEncryptionDetails = struct {
    encryption_type: ?[]const u8 = null,
    key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "EncryptionType",
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSecurityGroupDetails = struct {
    db_security_group_arn: ?[]const u8 = null,
    db_security_group_description: ?[]const u8 = null,
    db_security_group_name: ?[]const u8 = null,
    ec2_security_groups: ?[]AwsRdsDbSecurityGroupEc2SecurityGroup = null,
    ip_ranges: ?[]AwsRdsDbSecurityGroupIpRange = null,
    owner_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_security_group_arn = "DbSecurityGroupArn",
            .db_security_group_description = "DbSecurityGroupDescription",
            .db_security_group_name = "DbSecurityGroupName",
            .ec2_security_groups = "Ec2SecurityGroups",
            .ip_ranges = "IpRanges",
            .owner_id = "OwnerId",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSecurityGroupIpRange = struct {
    cidr_ip: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ip = "CidrIp",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSecurityGroupEc2SecurityGroup = struct {
    ec2_security_group_id: ?[]const u8 = null,
    ec2_security_group_name: ?[]const u8 = null,
    ec2_security_group_owner_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ec2_security_group_id = "Ec2SecurityGroupId",
            .ec2_security_group_name = "Ec2SecurityGroupName",
            .ec2_security_group_owner_id = "Ec2SecurityGroupOwnerId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsNetworkFirewallRuleGroupDetails = struct {
    capacity: ?i64 = null,
    description: ?[]const u8 = null,
    rule_group: ?RuleGroupDetails = null,
    rule_group_arn: ?[]const u8 = null,
    rule_group_id: ?[]const u8 = null,
    rule_group_name: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
            .description = "Description",
            .rule_group = "RuleGroup",
            .rule_group_arn = "RuleGroupArn",
            .rule_group_id = "RuleGroupId",
            .rule_group_name = "RuleGroupName",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupDetails = struct {
    rule_variables: ?RuleGroupVariables = null,
    rules_source: ?RuleGroupSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_variables = "RuleVariables",
            .rules_source = "RulesSource",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSource = struct {
    rules_source_list: ?RuleGroupSourceListDetails = null,
    rules_string: ?[]const u8 = null,
    stateful_rules: ?[]RuleGroupSourceStatefulRulesDetails = null,
    stateless_rules_and_custom_actions: ?RuleGroupSourceStatelessRulesAndCustomActionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules_source_list = "RulesSourceList",
            .rules_string = "RulesString",
            .stateful_rules = "StatefulRules",
            .stateless_rules_and_custom_actions = "StatelessRulesAndCustomActions",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRulesAndCustomActionsDetails = struct {
    custom_actions: ?[]RuleGroupSourceCustomActionsDetails = null,
    stateless_rules: ?[]RuleGroupSourceStatelessRulesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_actions = "CustomActions",
            .stateless_rules = "StatelessRules",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRulesDetails = struct {
    priority: ?i64 = null,
    rule_definition: ?RuleGroupSourceStatelessRuleDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .rule_definition = "RuleDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleDefinition = struct {
    actions: ?[][]const u8 = null,
    match_attributes: ?RuleGroupSourceStatelessRuleMatchAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions = "Actions",
            .match_attributes = "MatchAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributes = struct {
    destination_ports: ?[]RuleGroupSourceStatelessRuleMatchAttributesDestinationPorts = null,
    destinations: ?[]RuleGroupSourceStatelessRuleMatchAttributesDestinations = null,
    protocols: ?[]i64 = null,
    source_ports: ?[]RuleGroupSourceStatelessRuleMatchAttributesSourcePorts = null,
    sources: ?[]RuleGroupSourceStatelessRuleMatchAttributesSources = null,
    tcp_flags: ?[]RuleGroupSourceStatelessRuleMatchAttributesTcpFlags = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_ports = "DestinationPorts",
            .destinations = "Destinations",
            .protocols = "Protocols",
            .source_ports = "SourcePorts",
            .sources = "Sources",
            .tcp_flags = "TcpFlags",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributesTcpFlags = struct {
    flags: ?[][]const u8 = null,
    masks: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flags = "Flags",
            .masks = "Masks",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributesSources = struct {
    address_definition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_definition = "AddressDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributesSourcePorts = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributesDestinations = struct {
    address_definition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_definition = "AddressDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatelessRuleMatchAttributesDestinationPorts = struct {
    from_port: ?i64 = null,
    to_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceCustomActionsDetails = struct {
    action_definition: ?StatelessCustomActionDefinition = null,
    action_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_definition = "ActionDefinition",
            .action_name = "ActionName",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessCustomActionDefinition = struct {
    publish_metric_action: ?StatelessCustomPublishMetricAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .publish_metric_action = "PublishMetricAction",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessCustomPublishMetricAction = struct {
    dimensions: ?[]StatelessCustomPublishMetricActionDimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessCustomPublishMetricActionDimension = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatefulRulesDetails = struct {
    action: ?[]const u8 = null,
    header: ?RuleGroupSourceStatefulRulesHeaderDetails = null,
    rule_options: ?[]RuleGroupSourceStatefulRulesOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .header = "Header",
            .rule_options = "RuleOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatefulRulesOptionsDetails = struct {
    keyword: ?[]const u8 = null,
    settings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keyword = "Keyword",
            .settings = "Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceStatefulRulesHeaderDetails = struct {
    destination: ?[]const u8 = null,
    destination_port: ?[]const u8 = null,
    direction: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    source: ?[]const u8 = null,
    source_port: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
            .destination_port = "DestinationPort",
            .direction = "Direction",
            .protocol = "Protocol",
            .source = "Source",
            .source_port = "SourcePort",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSourceListDetails = struct {
    generated_rules_type: ?[]const u8 = null,
    target_types: ?[][]const u8 = null,
    targets: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .generated_rules_type = "GeneratedRulesType",
            .target_types = "TargetTypes",
            .targets = "Targets",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupVariables = struct {
    ip_sets: ?RuleGroupVariablesIpSetsDetails = null,
    port_sets: ?RuleGroupVariablesPortSetsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_sets = "IpSets",
            .port_sets = "PortSets",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupVariablesPortSetsDetails = struct {
    definition: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupVariablesIpSetsDetails = struct {
    definition: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsNetworkFirewallFirewallDetails = struct {
    delete_protection: ?bool = null,
    description: ?[]const u8 = null,
    firewall_arn: ?[]const u8 = null,
    firewall_id: ?[]const u8 = null,
    firewall_name: ?[]const u8 = null,
    firewall_policy_arn: ?[]const u8 = null,
    firewall_policy_change_protection: ?bool = null,
    subnet_change_protection: ?bool = null,
    subnet_mappings: ?[]AwsNetworkFirewallFirewallSubnetMappingsDetails = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_protection = "DeleteProtection",
            .description = "Description",
            .firewall_arn = "FirewallArn",
            .firewall_id = "FirewallId",
            .firewall_name = "FirewallName",
            .firewall_policy_arn = "FirewallPolicyArn",
            .firewall_policy_change_protection = "FirewallPolicyChangeProtection",
            .subnet_change_protection = "SubnetChangeProtection",
            .subnet_mappings = "SubnetMappings",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsNetworkFirewallFirewallSubnetMappingsDetails = struct {
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsNetworkFirewallFirewallPolicyDetails = struct {
    firewall_policy: ?FirewallPolicyDetails = null,
    firewall_policy_arn: ?[]const u8 = null,
    firewall_policy_id: ?[]const u8 = null,
    firewall_policy_name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .firewall_policy = "FirewallPolicy",
            .firewall_policy_arn = "FirewallPolicyArn",
            .firewall_policy_id = "FirewallPolicyId",
            .firewall_policy_name = "FirewallPolicyName",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallPolicyDetails = struct {
    stateful_rule_group_references: ?[]FirewallPolicyStatefulRuleGroupReferencesDetails = null,
    stateless_custom_actions: ?[]FirewallPolicyStatelessCustomActionsDetails = null,
    stateless_default_actions: ?[][]const u8 = null,
    stateless_fragment_default_actions: ?[][]const u8 = null,
    stateless_rule_group_references: ?[]FirewallPolicyStatelessRuleGroupReferencesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stateful_rule_group_references = "StatefulRuleGroupReferences",
            .stateless_custom_actions = "StatelessCustomActions",
            .stateless_default_actions = "StatelessDefaultActions",
            .stateless_fragment_default_actions = "StatelessFragmentDefaultActions",
            .stateless_rule_group_references = "StatelessRuleGroupReferences",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallPolicyStatelessRuleGroupReferencesDetails = struct {
    priority: ?i64 = null,
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallPolicyStatelessCustomActionsDetails = struct {
    action_definition: ?StatelessCustomActionDefinition = null,
    action_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_definition = "ActionDefinition",
            .action_name = "ActionName",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallPolicyStatefulRuleGroupReferencesDetails = struct {
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEksClusterDetails = struct {
    arn: ?[]const u8 = null,
    certificate_authority_data: ?[]const u8 = null,
    cluster_status: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    name: ?[]const u8 = null,
    resources_vpc_config: ?AwsEksClusterResourcesVpcConfigDetails = null,
    role_arn: ?[]const u8 = null,
    version: ?[]const u8 = null,
    logging: ?AwsEksClusterLoggingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .certificate_authority_data = "CertificateAuthorityData",
            .cluster_status = "ClusterStatus",
            .endpoint = "Endpoint",
            .name = "Name",
            .resources_vpc_config = "ResourcesVpcConfig",
            .role_arn = "RoleArn",
            .version = "Version",
            .logging = "Logging",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEksClusterLoggingDetails = struct {
    cluster_logging: ?[]AwsEksClusterLoggingClusterLoggingDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_logging = "ClusterLogging",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEksClusterLoggingClusterLoggingDetails = struct {
    enabled: ?bool = null,
    types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .types = "Types",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEksClusterResourcesVpcConfigDetails = struct {
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    endpoint_public_access: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
            .endpoint_public_access = "EndpointPublicAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcrRepositoryDetails = struct {
    arn: ?[]const u8 = null,
    image_scanning_configuration: ?AwsEcrRepositoryImageScanningConfigurationDetails = null,
    image_tag_mutability: ?[]const u8 = null,
    lifecycle_policy: ?AwsEcrRepositoryLifecyclePolicyDetails = null,
    repository_name: ?[]const u8 = null,
    repository_policy_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .image_scanning_configuration = "ImageScanningConfiguration",
            .image_tag_mutability = "ImageTagMutability",
            .lifecycle_policy = "LifecyclePolicy",
            .repository_name = "RepositoryName",
            .repository_policy_text = "RepositoryPolicyText",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcrRepositoryLifecyclePolicyDetails = struct {
    lifecycle_policy_text: ?[]const u8 = null,
    registry_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lifecycle_policy_text = "LifecyclePolicyText",
            .registry_id = "RegistryId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcrRepositoryImageScanningConfigurationDetails = struct {
    scan_on_push: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_on_push = "ScanOnPush",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRateBasedRuleDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    rate_key: ?[]const u8 = null,
    rate_limit: ?i64 = null,
    rule_id: ?[]const u8 = null,
    match_predicates: ?[]AwsWafRegionalRateBasedRuleMatchPredicate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .rate_key = "RateKey",
            .rate_limit = "RateLimit",
            .rule_id = "RuleId",
            .match_predicates = "MatchPredicates",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRegionalRateBasedRuleMatchPredicate = struct {
    data_id: ?[]const u8 = null,
    negated: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_id = "DataId",
            .negated = "Negated",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRateBasedRuleDetails = struct {
    metric_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    rate_key: ?[]const u8 = null,
    rate_limit: ?i64 = null,
    rule_id: ?[]const u8 = null,
    match_predicates: ?[]AwsWafRateBasedRuleMatchPredicate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .name = "Name",
            .rate_key = "RateKey",
            .rate_limit = "RateLimit",
            .rule_id = "RuleId",
            .match_predicates = "MatchPredicates",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafRateBasedRuleMatchPredicate = struct {
    data_id: ?[]const u8 = null,
    negated: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_id = "DataId",
            .negated = "Negated",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsXrayEncryptionConfigDetails = struct {
    key_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
            .status = "Status",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcEndpointServiceDetails = struct {
    acceptance_required: ?bool = null,
    availability_zones: ?[][]const u8 = null,
    base_endpoint_dns_names: ?[][]const u8 = null,
    manages_vpc_endpoints: ?bool = null,
    gateway_load_balancer_arns: ?[][]const u8 = null,
    network_load_balancer_arns: ?[][]const u8 = null,
    private_dns_name: ?[]const u8 = null,
    service_id: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    service_state: ?[]const u8 = null,
    service_type: ?[]AwsEc2VpcEndpointServiceServiceTypeDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acceptance_required = "AcceptanceRequired",
            .availability_zones = "AvailabilityZones",
            .base_endpoint_dns_names = "BaseEndpointDnsNames",
            .manages_vpc_endpoints = "ManagesVpcEndpoints",
            .gateway_load_balancer_arns = "GatewayLoadBalancerArns",
            .network_load_balancer_arns = "NetworkLoadBalancerArns",
            .private_dns_name = "PrivateDnsName",
            .service_id = "ServiceId",
            .service_name = "ServiceName",
            .service_state = "ServiceState",
            .service_type = "ServiceType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcEndpointServiceServiceTypeDetails = struct {
    service_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_type = "ServiceType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainDetails = struct {
    arn: ?[]const u8 = null,
    access_policies: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    domain_endpoint: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    encryption_at_rest_options: ?AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetails = null,
    node_to_node_encryption_options: ?AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetails = null,
    service_software_options: ?AwsOpenSearchServiceDomainServiceSoftwareOptionsDetails = null,
    cluster_config: ?AwsOpenSearchServiceDomainClusterConfigDetails = null,
    domain_endpoint_options: ?AwsOpenSearchServiceDomainDomainEndpointOptionsDetails = null,
    vpc_options: ?AwsOpenSearchServiceDomainVpcOptionsDetails = null,
    log_publishing_options: ?AwsOpenSearchServiceDomainLogPublishingOptionsDetails = null,
    domain_endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    advanced_security_options: ?AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .access_policies = "AccessPolicies",
            .domain_name = "DomainName",
            .id = "Id",
            .domain_endpoint = "DomainEndpoint",
            .engine_version = "EngineVersion",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .service_software_options = "ServiceSoftwareOptions",
            .cluster_config = "ClusterConfig",
            .domain_endpoint_options = "DomainEndpointOptions",
            .vpc_options = "VpcOptions",
            .log_publishing_options = "LogPublishingOptions",
            .domain_endpoints = "DomainEndpoints",
            .advanced_security_options = "AdvancedSecurityOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "domain_endpoints", field_name))
            return try serializeMap(self.domain_endpoints, self.fieldNameFor("domain_endpoints"), options, out_stream);
        return false;
    }
};

pub const AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetails = struct {
    enabled: ?bool = null,
    internal_user_database_enabled: ?bool = null,
    master_user_options: ?AwsOpenSearchServiceDomainMasterUserOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .internal_user_database_enabled = "InternalUserDatabaseEnabled",
            .master_user_options = "MasterUserOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainMasterUserOptionsDetails = struct {
    master_user_arn: ?[]const u8 = null,
    master_user_name: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .master_user_arn = "MasterUserArn",
            .master_user_name = "MasterUserName",
            .master_user_password = "MasterUserPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainLogPublishingOptionsDetails = struct {
    index_slow_logs: ?AwsOpenSearchServiceDomainLogPublishingOption = null,
    search_slow_logs: ?AwsOpenSearchServiceDomainLogPublishingOption = null,
    audit_logs: ?AwsOpenSearchServiceDomainLogPublishingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_slow_logs = "IndexSlowLogs",
            .search_slow_logs = "SearchSlowLogs",
            .audit_logs = "AuditLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainLogPublishingOption = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainVpcOptionsDetails = struct {
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainDomainEndpointOptionsDetails = struct {
    custom_endpoint_certificate_arn: ?[]const u8 = null,
    custom_endpoint_enabled: ?bool = null,
    enforce_https: ?bool = null,
    custom_endpoint: ?[]const u8 = null,
    tls_security_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_endpoint_certificate_arn = "CustomEndpointCertificateArn",
            .custom_endpoint_enabled = "CustomEndpointEnabled",
            .enforce_https = "EnforceHTTPS",
            .custom_endpoint = "CustomEndpoint",
            .tls_security_policy = "TLSSecurityPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainClusterConfigDetails = struct {
    instance_count: ?i64 = null,
    warm_enabled: ?bool = null,
    warm_count: ?i64 = null,
    dedicated_master_enabled: ?bool = null,
    zone_awareness_config: ?AwsOpenSearchServiceDomainClusterConfigZoneAwarenessConfigDetails = null,
    dedicated_master_count: ?i64 = null,
    instance_type: ?[]const u8 = null,
    warm_type: ?[]const u8 = null,
    zone_awareness_enabled: ?bool = null,
    dedicated_master_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_count = "InstanceCount",
            .warm_enabled = "WarmEnabled",
            .warm_count = "WarmCount",
            .dedicated_master_enabled = "DedicatedMasterEnabled",
            .zone_awareness_config = "ZoneAwarenessConfig",
            .dedicated_master_count = "DedicatedMasterCount",
            .instance_type = "InstanceType",
            .warm_type = "WarmType",
            .zone_awareness_enabled = "ZoneAwarenessEnabled",
            .dedicated_master_type = "DedicatedMasterType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainClusterConfigZoneAwarenessConfigDetails = struct {
    availability_zone_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone_count = "AvailabilityZoneCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainServiceSoftwareOptionsDetails = struct {
    automated_update_date: ?[]const u8 = null,
    cancellable: ?bool = null,
    current_version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    new_version: ?[]const u8 = null,
    update_available: ?bool = null,
    update_status: ?[]const u8 = null,
    optional_deployment: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_update_date = "AutomatedUpdateDate",
            .cancellable = "Cancellable",
            .current_version = "CurrentVersion",
            .description = "Description",
            .new_version = "NewVersion",
            .update_available = "UpdateAvailable",
            .update_status = "UpdateStatus",
            .optional_deployment = "OptionalDeployment",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetails = struct {
    enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcrContainerImageDetails = struct {
    registry_id: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    architecture: ?[]const u8 = null,
    image_digest: ?[]const u8 = null,
    image_tags: ?[][]const u8 = null,
    image_published_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registry_id = "RegistryId",
            .repository_name = "RepositoryName",
            .architecture = "Architecture",
            .image_digest = "ImageDigest",
            .image_tags = "ImageTags",
            .image_published_at = "ImagePublishedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpnConnectionDetails = struct {
    vpn_connection_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    customer_gateway_id: ?[]const u8 = null,
    customer_gateway_configuration: ?[]const u8 = null,
    type: ?[]const u8 = null,
    vpn_gateway_id: ?[]const u8 = null,
    category: ?[]const u8 = null,
    vgw_telemetry: ?[]AwsEc2VpnConnectionVgwTelemetryDetails = null,
    options: ?AwsEc2VpnConnectionOptionsDetails = null,
    routes: ?[]AwsEc2VpnConnectionRoutesDetails = null,
    transit_gateway_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpn_connection_id = "VpnConnectionId",
            .state = "State",
            .customer_gateway_id = "CustomerGatewayId",
            .customer_gateway_configuration = "CustomerGatewayConfiguration",
            .type = "Type",
            .vpn_gateway_id = "VpnGatewayId",
            .category = "Category",
            .vgw_telemetry = "VgwTelemetry",
            .options = "Options",
            .routes = "Routes",
            .transit_gateway_id = "TransitGatewayId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpnConnectionRoutesDetails = struct {
    destination_cidr_block: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_cidr_block = "DestinationCidrBlock",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpnConnectionOptionsDetails = struct {
    static_routes_only: ?bool = null,
    tunnel_options: ?[]AwsEc2VpnConnectionOptionsTunnelOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .static_routes_only = "StaticRoutesOnly",
            .tunnel_options = "TunnelOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpnConnectionOptionsTunnelOptionsDetails = struct {
    dpd_timeout_seconds: ?i64 = null,
    ike_versions: ?[][]const u8 = null,
    outside_ip_address: ?[]const u8 = null,
    phase1_dh_group_numbers: ?[]i64 = null,
    phase1_encryption_algorithms: ?[][]const u8 = null,
    phase1_integrity_algorithms: ?[][]const u8 = null,
    phase1_lifetime_seconds: ?i64 = null,
    phase2_dh_group_numbers: ?[]i64 = null,
    phase2_encryption_algorithms: ?[][]const u8 = null,
    phase2_integrity_algorithms: ?[][]const u8 = null,
    phase2_lifetime_seconds: ?i64 = null,
    pre_shared_key: ?[]const u8 = null,
    rekey_fuzz_percentage: ?i64 = null,
    rekey_margin_time_seconds: ?i64 = null,
    replay_window_size: ?i64 = null,
    tunnel_inside_cidr: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dpd_timeout_seconds = "DpdTimeoutSeconds",
            .ike_versions = "IkeVersions",
            .outside_ip_address = "OutsideIpAddress",
            .phase1_dh_group_numbers = "Phase1DhGroupNumbers",
            .phase1_encryption_algorithms = "Phase1EncryptionAlgorithms",
            .phase1_integrity_algorithms = "Phase1IntegrityAlgorithms",
            .phase1_lifetime_seconds = "Phase1LifetimeSeconds",
            .phase2_dh_group_numbers = "Phase2DhGroupNumbers",
            .phase2_encryption_algorithms = "Phase2EncryptionAlgorithms",
            .phase2_integrity_algorithms = "Phase2IntegrityAlgorithms",
            .phase2_lifetime_seconds = "Phase2LifetimeSeconds",
            .pre_shared_key = "PreSharedKey",
            .rekey_fuzz_percentage = "RekeyFuzzPercentage",
            .rekey_margin_time_seconds = "RekeyMarginTimeSeconds",
            .replay_window_size = "ReplayWindowSize",
            .tunnel_inside_cidr = "TunnelInsideCidr",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpnConnectionVgwTelemetryDetails = struct {
    accepted_route_count: ?i64 = null,
    certificate_arn: ?[]const u8 = null,
    last_status_change: ?[]const u8 = null,
    outside_ip_address: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accepted_route_count = "AcceptedRouteCount",
            .certificate_arn = "CertificateArn",
            .last_status_change = "LastStatusChange",
            .outside_ip_address = "OutsideIpAddress",
            .status = "Status",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingLaunchConfigurationDetails = struct {
    associate_public_ip_address: ?bool = null,
    block_device_mappings: ?[]AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails = null,
    classic_link_vpc_id: ?[]const u8 = null,
    classic_link_vpc_security_groups: ?[][]const u8 = null,
    created_time: ?[]const u8 = null,
    ebs_optimized: ?bool = null,
    iam_instance_profile: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    instance_monitoring: ?AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails = null,
    instance_type: ?[]const u8 = null,
    kernel_id: ?[]const u8 = null,
    key_name: ?[]const u8 = null,
    launch_configuration_name: ?[]const u8 = null,
    placement_tenancy: ?[]const u8 = null,
    ramdisk_id: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    spot_price: ?[]const u8 = null,
    user_data: ?[]const u8 = null,
    metadata_options: ?AwsAutoScalingLaunchConfigurationMetadataOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_public_ip_address = "AssociatePublicIpAddress",
            .block_device_mappings = "BlockDeviceMappings",
            .classic_link_vpc_id = "ClassicLinkVpcId",
            .classic_link_vpc_security_groups = "ClassicLinkVpcSecurityGroups",
            .created_time = "CreatedTime",
            .ebs_optimized = "EbsOptimized",
            .iam_instance_profile = "IamInstanceProfile",
            .image_id = "ImageId",
            .instance_monitoring = "InstanceMonitoring",
            .instance_type = "InstanceType",
            .kernel_id = "KernelId",
            .key_name = "KeyName",
            .launch_configuration_name = "LaunchConfigurationName",
            .placement_tenancy = "PlacementTenancy",
            .ramdisk_id = "RamdiskId",
            .security_groups = "SecurityGroups",
            .spot_price = "SpotPrice",
            .user_data = "UserData",
            .metadata_options = "MetadataOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingLaunchConfigurationMetadataOptions = struct {
    http_endpoint: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    http_tokens: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_endpoint = "HttpEndpoint",
            .http_put_response_hop_limit = "HttpPutResponseHopLimit",
            .http_tokens = "HttpTokens",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetails = struct {
    device_name: ?[]const u8 = null,
    ebs: ?AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails = null,
    no_device: ?bool = null,
    virtual_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .ebs = "Ebs",
            .no_device = "NoDevice",
            .virtual_name = "VirtualName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetails = struct {
    delete_on_termination: ?bool = null,
    encrypted: ?bool = null,
    iops: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delete_on_termination = "DeleteOnTermination",
            .encrypted = "Encrypted",
            .iops = "Iops",
            .snapshot_id = "SnapshotId",
            .volume_size = "VolumeSize",
            .volume_type = "VolumeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceDetails = struct {
    capacity_provider_strategy: ?[]AwsEcsServiceCapacityProviderStrategyDetails = null,
    cluster: ?[]const u8 = null,
    deployment_configuration: ?AwsEcsServiceDeploymentConfigurationDetails = null,
    deployment_controller: ?AwsEcsServiceDeploymentControllerDetails = null,
    desired_count: ?i64 = null,
    enable_ecs_managed_tags: ?bool = null,
    enable_execute_command: ?bool = null,
    health_check_grace_period_seconds: ?i64 = null,
    launch_type: ?[]const u8 = null,
    load_balancers: ?[]AwsEcsServiceLoadBalancersDetails = null,
    name: ?[]const u8 = null,
    network_configuration: ?AwsEcsServiceNetworkConfigurationDetails = null,
    placement_constraints: ?[]AwsEcsServicePlacementConstraintsDetails = null,
    placement_strategies: ?[]AwsEcsServicePlacementStrategiesDetails = null,
    platform_version: ?[]const u8 = null,
    propagate_tags: ?[]const u8 = null,
    role: ?[]const u8 = null,
    scheduling_strategy: ?[]const u8 = null,
    service_arn: ?[]const u8 = null,
    service_name: ?[]const u8 = null,
    service_registries: ?[]AwsEcsServiceServiceRegistriesDetails = null,
    task_definition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_provider_strategy = "CapacityProviderStrategy",
            .cluster = "Cluster",
            .deployment_configuration = "DeploymentConfiguration",
            .deployment_controller = "DeploymentController",
            .desired_count = "DesiredCount",
            .enable_ecs_managed_tags = "EnableEcsManagedTags",
            .enable_execute_command = "EnableExecuteCommand",
            .health_check_grace_period_seconds = "HealthCheckGracePeriodSeconds",
            .launch_type = "LaunchType",
            .load_balancers = "LoadBalancers",
            .name = "Name",
            .network_configuration = "NetworkConfiguration",
            .placement_constraints = "PlacementConstraints",
            .placement_strategies = "PlacementStrategies",
            .platform_version = "PlatformVersion",
            .propagate_tags = "PropagateTags",
            .role = "Role",
            .scheduling_strategy = "SchedulingStrategy",
            .service_arn = "ServiceArn",
            .service_name = "ServiceName",
            .service_registries = "ServiceRegistries",
            .task_definition = "TaskDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceServiceRegistriesDetails = struct {
    container_name: ?[]const u8 = null,
    container_port: ?i64 = null,
    port: ?i64 = null,
    registry_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_name = "ContainerName",
            .container_port = "ContainerPort",
            .port = "Port",
            .registry_arn = "RegistryArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServicePlacementStrategiesDetails = struct {
    field: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field = "Field",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServicePlacementConstraintsDetails = struct {
    expression: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceNetworkConfigurationDetails = struct {
    aws_vpc_configuration: ?AwsEcsServiceNetworkConfigurationAwsVpcConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_vpc_configuration = "AwsVpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceNetworkConfigurationAwsVpcConfigurationDetails = struct {
    assign_public_ip: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    subnets: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assign_public_ip = "AssignPublicIp",
            .security_groups = "SecurityGroups",
            .subnets = "Subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceLoadBalancersDetails = struct {
    container_name: ?[]const u8 = null,
    container_port: ?i64 = null,
    load_balancer_name: ?[]const u8 = null,
    target_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_name = "ContainerName",
            .container_port = "ContainerPort",
            .load_balancer_name = "LoadBalancerName",
            .target_group_arn = "TargetGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceDeploymentControllerDetails = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceDeploymentConfigurationDetails = struct {
    deployment_circuit_breaker: ?AwsEcsServiceDeploymentConfigurationDeploymentCircuitBreakerDetails = null,
    maximum_percent: ?i64 = null,
    minimum_healthy_percent: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_circuit_breaker = "DeploymentCircuitBreaker",
            .maximum_percent = "MaximumPercent",
            .minimum_healthy_percent = "MinimumHealthyPercent",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceDeploymentConfigurationDeploymentCircuitBreakerDetails = struct {
    enable: ?bool = null,
    rollback: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable = "Enable",
            .rollback = "Rollback",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsServiceCapacityProviderStrategyDetails = struct {
    base: ?i64 = null,
    capacity_provider: ?[]const u8 = null,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base = "Base",
            .capacity_provider = "CapacityProvider",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsEventSubscriptionDetails = struct {
    cust_subscription_id: ?[]const u8 = null,
    customer_aws_id: ?[]const u8 = null,
    enabled: ?bool = null,
    event_categories_list: ?[][]const u8 = null,
    event_subscription_arn: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    source_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cust_subscription_id = "CustSubscriptionId",
            .customer_aws_id = "CustomerAwsId",
            .enabled = "Enabled",
            .event_categories_list = "EventCategoriesList",
            .event_subscription_arn = "EventSubscriptionArn",
            .sns_topic_arn = "SnsTopicArn",
            .source_ids_list = "SourceIdsList",
            .source_type = "SourceType",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDetails = struct {
    container_runtime: ?[]const u8 = null,
    name: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    image_name: ?[]const u8 = null,
    launched_at: ?[]const u8 = null,
    volume_mounts: ?[]VolumeMount = null,
    privileged: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_runtime = "ContainerRuntime",
            .name = "Name",
            .image_id = "ImageId",
            .image_name = "ImageName",
            .launched_at = "LaunchedAt",
            .volume_mounts = "VolumeMounts",
            .privileged = "Privileged",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeMount = struct {
    name: ?[]const u8 = null,
    mount_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .mount_path = "MountPath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionDetails = struct {
    container_definitions: ?[]AwsEcsTaskDefinitionContainerDefinitionsDetails = null,
    cpu: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    family: ?[]const u8 = null,
    inference_accelerators: ?[]AwsEcsTaskDefinitionInferenceAcceleratorsDetails = null,
    ipc_mode: ?[]const u8 = null,
    memory: ?[]const u8 = null,
    network_mode: ?[]const u8 = null,
    pid_mode: ?[]const u8 = null,
    placement_constraints: ?[]AwsEcsTaskDefinitionPlacementConstraintsDetails = null,
    proxy_configuration: ?AwsEcsTaskDefinitionProxyConfigurationDetails = null,
    requires_compatibilities: ?[][]const u8 = null,
    task_role_arn: ?[]const u8 = null,
    volumes: ?[]AwsEcsTaskDefinitionVolumesDetails = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_definitions = "ContainerDefinitions",
            .cpu = "Cpu",
            .execution_role_arn = "ExecutionRoleArn",
            .family = "Family",
            .inference_accelerators = "InferenceAccelerators",
            .ipc_mode = "IpcMode",
            .memory = "Memory",
            .network_mode = "NetworkMode",
            .pid_mode = "PidMode",
            .placement_constraints = "PlacementConstraints",
            .proxy_configuration = "ProxyConfiguration",
            .requires_compatibilities = "RequiresCompatibilities",
            .task_role_arn = "TaskRoleArn",
            .volumes = "Volumes",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionVolumesDetails = struct {
    docker_volume_configuration: ?AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails = null,
    efs_volume_configuration: ?AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetails = null,
    host: ?AwsEcsTaskDefinitionVolumesHostDetails = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .docker_volume_configuration = "DockerVolumeConfiguration",
            .efs_volume_configuration = "EfsVolumeConfiguration",
            .host = "Host",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionVolumesHostDetails = struct {
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "SourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetails = struct {
    authorization_config: ?AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationAuthorizationConfigDetails = null,
    filesystem_id: ?[]const u8 = null,
    root_directory: ?[]const u8 = null,
    transit_encryption: ?[]const u8 = null,
    transit_encryption_port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorization_config = "AuthorizationConfig",
            .filesystem_id = "FilesystemId",
            .root_directory = "RootDirectory",
            .transit_encryption = "TransitEncryption",
            .transit_encryption_port = "TransitEncryptionPort",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationAuthorizationConfigDetails = struct {
    access_point_id: ?[]const u8 = null,
    iam: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_id = "AccessPointId",
            .iam = "Iam",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetails = struct {
    autoprovision: ?bool = null,
    driver: ?[]const u8 = null,
    driver_opts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .autoprovision = "Autoprovision",
            .driver = "Driver",
            .driver_opts = "DriverOpts",
            .labels = "Labels",
            .scope = "Scope",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "driver_opts", field_name))
            return try serializeMap(self.driver_opts, self.fieldNameFor("driver_opts"), options, out_stream);
        if (std.mem.eql(u8, "labels", field_name))
            return try serializeMap(self.labels, self.fieldNameFor("labels"), options, out_stream);
        return false;
    }
};

pub const AwsEcsTaskDefinitionProxyConfigurationDetails = struct {
    container_name: ?[]const u8 = null,
    proxy_configuration_properties: ?[]AwsEcsTaskDefinitionProxyConfigurationProxyConfigurationPropertiesDetails = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_name = "ContainerName",
            .proxy_configuration_properties = "ProxyConfigurationProperties",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionProxyConfigurationProxyConfigurationPropertiesDetails = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionPlacementConstraintsDetails = struct {
    expression: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expression = "Expression",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionInferenceAcceleratorsDetails = struct {
    device_name: ?[]const u8 = null,
    device_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .device_type = "DeviceType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsDetails = struct {
    command: ?[][]const u8 = null,
    cpu: ?i64 = null,
    depends_on: ?[]AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails = null,
    disable_networking: ?bool = null,
    dns_search_domains: ?[][]const u8 = null,
    dns_servers: ?[][]const u8 = null,
    docker_labels: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    docker_security_options: ?[][]const u8 = null,
    entry_point: ?[][]const u8 = null,
    environment: ?[]AwsEcsTaskDefinitionContainerDefinitionsEnvironmentDetails = null,
    environment_files: ?[]AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails = null,
    essential: ?bool = null,
    extra_hosts: ?[]AwsEcsTaskDefinitionContainerDefinitionsExtraHostsDetails = null,
    firelens_configuration: ?AwsEcsTaskDefinitionContainerDefinitionsFirelensConfigurationDetails = null,
    health_check: ?AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails = null,
    hostname: ?[]const u8 = null,
    image: ?[]const u8 = null,
    interactive: ?bool = null,
    links: ?[][]const u8 = null,
    linux_parameters: ?AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails = null,
    log_configuration: ?AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationDetails = null,
    memory: ?i64 = null,
    memory_reservation: ?i64 = null,
    mount_points: ?[]AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails = null,
    name: ?[]const u8 = null,
    port_mappings: ?[]AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails = null,
    privileged: ?bool = null,
    pseudo_terminal: ?bool = null,
    readonly_root_filesystem: ?bool = null,
    repository_credentials: ?AwsEcsTaskDefinitionContainerDefinitionsRepositoryCredentialsDetails = null,
    resource_requirements: ?[]AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails = null,
    secrets: ?[]AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails = null,
    start_timeout: ?i64 = null,
    stop_timeout: ?i64 = null,
    system_controls: ?[]AwsEcsTaskDefinitionContainerDefinitionsSystemControlsDetails = null,
    ulimits: ?[]AwsEcsTaskDefinitionContainerDefinitionsUlimitsDetails = null,
    user: ?[]const u8 = null,
    volumes_from: ?[]AwsEcsTaskDefinitionContainerDefinitionsVolumesFromDetails = null,
    working_directory: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command = "Command",
            .cpu = "Cpu",
            .depends_on = "DependsOn",
            .disable_networking = "DisableNetworking",
            .dns_search_domains = "DnsSearchDomains",
            .dns_servers = "DnsServers",
            .docker_labels = "DockerLabels",
            .docker_security_options = "DockerSecurityOptions",
            .entry_point = "EntryPoint",
            .environment = "Environment",
            .environment_files = "EnvironmentFiles",
            .essential = "Essential",
            .extra_hosts = "ExtraHosts",
            .firelens_configuration = "FirelensConfiguration",
            .health_check = "HealthCheck",
            .hostname = "Hostname",
            .image = "Image",
            .interactive = "Interactive",
            .links = "Links",
            .linux_parameters = "LinuxParameters",
            .log_configuration = "LogConfiguration",
            .memory = "Memory",
            .memory_reservation = "MemoryReservation",
            .mount_points = "MountPoints",
            .name = "Name",
            .port_mappings = "PortMappings",
            .privileged = "Privileged",
            .pseudo_terminal = "PseudoTerminal",
            .readonly_root_filesystem = "ReadonlyRootFilesystem",
            .repository_credentials = "RepositoryCredentials",
            .resource_requirements = "ResourceRequirements",
            .secrets = "Secrets",
            .start_timeout = "StartTimeout",
            .stop_timeout = "StopTimeout",
            .system_controls = "SystemControls",
            .ulimits = "Ulimits",
            .user = "User",
            .volumes_from = "VolumesFrom",
            .working_directory = "WorkingDirectory",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "docker_labels", field_name))
            return try serializeMap(self.docker_labels, self.fieldNameFor("docker_labels"), options, out_stream);
        return false;
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsVolumesFromDetails = struct {
    read_only: ?bool = null,
    source_container: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_only = "ReadOnly",
            .source_container = "SourceContainer",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsUlimitsDetails = struct {
    hard_limit: ?i64 = null,
    name: ?[]const u8 = null,
    soft_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hard_limit = "HardLimit",
            .name = "Name",
            .soft_limit = "SoftLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsSystemControlsDetails = struct {
    namespace: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsSecretsDetails = struct {
    name: ?[]const u8 = null,
    value_from: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value_from = "ValueFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetails = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsRepositoryCredentialsDetails = struct {
    credentials_parameter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credentials_parameter = "CredentialsParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetails = struct {
    container_port: ?i64 = null,
    host_port: ?i64 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_port = "ContainerPort",
            .host_port = "HostPort",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetails = struct {
    container_path: ?[]const u8 = null,
    read_only: ?bool = null,
    source_volume: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "ContainerPath",
            .read_only = "ReadOnly",
            .source_volume = "SourceVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationDetails = struct {
    log_driver: ?[]const u8 = null,
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    secret_options: ?[]AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_driver = "LogDriver",
            .options = "Options",
            .secret_options = "SecretOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetails = struct {
    name: ?[]const u8 = null,
    value_from: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value_from = "ValueFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetails = struct {
    capabilities: ?AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails = null,
    devices: ?[]AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails = null,
    init_process_enabled: ?bool = null,
    max_swap: ?i64 = null,
    shared_memory_size: ?i64 = null,
    swappiness: ?i64 = null,
    tmpfs: ?[]AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capabilities = "Capabilities",
            .devices = "Devices",
            .init_process_enabled = "InitProcessEnabled",
            .max_swap = "MaxSwap",
            .shared_memory_size = "SharedMemorySize",
            .swappiness = "Swappiness",
            .tmpfs = "Tmpfs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetails = struct {
    container_path: ?[]const u8 = null,
    mount_options: ?[][]const u8 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "ContainerPath",
            .mount_options = "MountOptions",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetails = struct {
    container_path: ?[]const u8 = null,
    host_path: ?[]const u8 = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "ContainerPath",
            .host_path = "HostPath",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetails = struct {
    add: ?[][]const u8 = null,
    drop: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .add = "Add",
            .drop = "Drop",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetails = struct {
    command: ?[][]const u8 = null,
    interval: ?i64 = null,
    retries: ?i64 = null,
    start_period: ?i64 = null,
    timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command = "Command",
            .interval = "Interval",
            .retries = "Retries",
            .start_period = "StartPeriod",
            .timeout = "Timeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsFirelensConfigurationDetails = struct {
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsExtraHostsDetails = struct {
    hostname: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname = "Hostname",
            .ip_address = "IpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetails = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsEnvironmentDetails = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetails = struct {
    condition: ?[]const u8 = null,
    container_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .container_name = "ContainerName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterDetails = struct {
    cluster_arn: ?[]const u8 = null,
    active_services_count: ?i64 = null,
    capacity_providers: ?[][]const u8 = null,
    cluster_settings: ?[]AwsEcsClusterClusterSettingsDetails = null,
    configuration: ?AwsEcsClusterConfigurationDetails = null,
    default_capacity_provider_strategy: ?[]AwsEcsClusterDefaultCapacityProviderStrategyDetails = null,
    cluster_name: ?[]const u8 = null,
    registered_container_instances_count: ?i64 = null,
    running_tasks_count: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_arn = "ClusterArn",
            .active_services_count = "ActiveServicesCount",
            .capacity_providers = "CapacityProviders",
            .cluster_settings = "ClusterSettings",
            .configuration = "Configuration",
            .default_capacity_provider_strategy = "DefaultCapacityProviderStrategy",
            .cluster_name = "ClusterName",
            .registered_container_instances_count = "RegisteredContainerInstancesCount",
            .running_tasks_count = "RunningTasksCount",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterDefaultCapacityProviderStrategyDetails = struct {
    base: ?i64 = null,
    capacity_provider: ?[]const u8 = null,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base = "Base",
            .capacity_provider = "CapacityProvider",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterConfigurationDetails = struct {
    execute_command_configuration: ?AwsEcsClusterConfigurationExecuteCommandConfigurationDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execute_command_configuration = "ExecuteCommandConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterConfigurationExecuteCommandConfigurationDetails = struct {
    kms_key_id: ?[]const u8 = null,
    log_configuration: ?AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails = null,
    logging: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
            .log_configuration = "LogConfiguration",
            .logging = "Logging",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetails = struct {
    cloud_watch_encryption_enabled: ?bool = null,
    cloud_watch_log_group_name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_encryption_enabled: ?bool = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_encryption_enabled = "CloudWatchEncryptionEnabled",
            .cloud_watch_log_group_name = "CloudWatchLogGroupName",
            .s3_bucket_name = "S3BucketName",
            .s3_encryption_enabled = "S3EncryptionEnabled",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEcsClusterClusterSettingsDetails = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterDetails = struct {
    allocated_storage: ?i64 = null,
    availability_zones: ?[][]const u8 = null,
    backup_retention_period: ?i64 = null,
    database_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    reader_endpoint: ?[]const u8 = null,
    custom_endpoints: ?[][]const u8 = null,
    multi_az: ?bool = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    port: ?i64 = null,
    master_username: ?[]const u8 = null,
    preferred_backup_window: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    read_replica_identifiers: ?[][]const u8 = null,
    vpc_security_groups: ?[]AwsRdsDbInstanceVpcSecurityGroup = null,
    hosted_zone_id: ?[]const u8 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_resource_id: ?[]const u8 = null,
    associated_roles: ?[]AwsRdsDbClusterAssociatedRole = null,
    cluster_create_time: ?[]const u8 = null,
    enabled_cloud_watch_logs_exports: ?[][]const u8 = null,
    engine_mode: ?[]const u8 = null,
    deletion_protection: ?bool = null,
    http_endpoint_enabled: ?bool = null,
    activity_stream_status: ?[]const u8 = null,
    copy_tags_to_snapshot: ?bool = null,
    cross_account_clone: ?bool = null,
    domain_memberships: ?[]AwsRdsDbDomainMembership = null,
    db_cluster_parameter_group: ?[]const u8 = null,
    db_subnet_group: ?[]const u8 = null,
    db_cluster_option_group_memberships: ?[]AwsRdsDbClusterOptionGroupMembership = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_members: ?[]AwsRdsDbClusterMember = null,
    iam_database_authentication_enabled: ?bool = null,
    auto_minor_version_upgrade: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocated_storage = "AllocatedStorage",
            .availability_zones = "AvailabilityZones",
            .backup_retention_period = "BackupRetentionPeriod",
            .database_name = "DatabaseName",
            .status = "Status",
            .endpoint = "Endpoint",
            .reader_endpoint = "ReaderEndpoint",
            .custom_endpoints = "CustomEndpoints",
            .multi_az = "MultiAz",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .port = "Port",
            .master_username = "MasterUsername",
            .preferred_backup_window = "PreferredBackupWindow",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .read_replica_identifiers = "ReadReplicaIdentifiers",
            .vpc_security_groups = "VpcSecurityGroups",
            .hosted_zone_id = "HostedZoneId",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_resource_id = "DbClusterResourceId",
            .associated_roles = "AssociatedRoles",
            .cluster_create_time = "ClusterCreateTime",
            .enabled_cloud_watch_logs_exports = "EnabledCloudWatchLogsExports",
            .engine_mode = "EngineMode",
            .deletion_protection = "DeletionProtection",
            .http_endpoint_enabled = "HttpEndpointEnabled",
            .activity_stream_status = "ActivityStreamStatus",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .cross_account_clone = "CrossAccountClone",
            .domain_memberships = "DomainMemberships",
            .db_cluster_parameter_group = "DbClusterParameterGroup",
            .db_subnet_group = "DbSubnetGroup",
            .db_cluster_option_group_memberships = "DbClusterOptionGroupMemberships",
            .db_cluster_identifier = "DbClusterIdentifier",
            .db_cluster_members = "DbClusterMembers",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterMember = struct {
    is_cluster_writer: ?bool = null,
    promotion_tier: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    db_cluster_parameter_group_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_cluster_writer = "IsClusterWriter",
            .promotion_tier = "PromotionTier",
            .db_instance_identifier = "DbInstanceIdentifier",
            .db_cluster_parameter_group_status = "DbClusterParameterGroupStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterOptionGroupMembership = struct {
    db_cluster_option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_cluster_option_group_name = "DbClusterOptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbDomainMembership = struct {
    domain: ?[]const u8 = null,
    status: ?[]const u8 = null,
    fqdn: ?[]const u8 = null,
    iam_role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .status = "Status",
            .fqdn = "Fqdn",
            .iam_role_name = "IamRoleName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterAssociatedRole = struct {
    role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceVpcSecurityGroup = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterSnapshotDetails = struct {
    availability_zones: ?[][]const u8 = null,
    snapshot_create_time: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    vpc_id: ?[]const u8 = null,
    cluster_create_time: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    storage_encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_cluster_snapshot_identifier: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    db_cluster_snapshot_attributes: ?[]AwsRdsDbClusterSnapshotDbClusterSnapshotAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .vpc_id = "VpcId",
            .cluster_create_time = "ClusterCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .percent_progress = "PercentProgress",
            .storage_encrypted = "StorageEncrypted",
            .kms_key_id = "KmsKeyId",
            .db_cluster_identifier = "DbClusterIdentifier",
            .db_cluster_snapshot_identifier = "DbClusterSnapshotIdentifier",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
            .db_cluster_snapshot_attributes = "DbClusterSnapshotAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbClusterSnapshotDbClusterSnapshotAttribute = struct {
    attribute_name: ?[]const u8 = null,
    attribute_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_values = "AttributeValues",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSnapshotDetails = struct {
    db_snapshot_identifier: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    snapshot_create_time: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    status: ?[]const u8 = null,
    port: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    instance_create_time: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    snapshot_type: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_name: ?[]const u8 = null,
    percent_progress: ?i64 = null,
    source_region: ?[]const u8 = null,
    source_db_snapshot_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    tde_credential_arn: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,
    dbi_resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_snapshot_identifier = "DbSnapshotIdentifier",
            .db_instance_identifier = "DbInstanceIdentifier",
            .snapshot_create_time = "SnapshotCreateTime",
            .engine = "Engine",
            .allocated_storage = "AllocatedStorage",
            .status = "Status",
            .port = "Port",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .instance_create_time = "InstanceCreateTime",
            .master_username = "MasterUsername",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .snapshot_type = "SnapshotType",
            .iops = "Iops",
            .option_group_name = "OptionGroupName",
            .percent_progress = "PercentProgress",
            .source_region = "SourceRegion",
            .source_db_snapshot_identifier = "SourceDbSnapshotIdentifier",
            .storage_type = "StorageType",
            .tde_credential_arn = "TdeCredentialArn",
            .encrypted = "Encrypted",
            .kms_key_id = "KmsKeyId",
            .timezone = "Timezone",
            .iam_database_authentication_enabled = "IamDatabaseAuthenticationEnabled",
            .processor_features = "ProcessorFeatures",
            .dbi_resource_id = "DbiResourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbProcessorFeature = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafWebAclDetails = struct {
    name: ?[]const u8 = null,
    default_action: ?[]const u8 = null,
    rules: ?[]AwsWafWebAclRule = null,
    web_acl_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .default_action = "DefaultAction",
            .rules = "Rules",
            .web_acl_id = "WebAclId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsWafWebAclRule = struct {
    action: ?WafAction = null,
    excluded_rules: ?[]WafExcludedRule = null,
    override_action: ?WafOverrideAction = null,
    priority: ?i64 = null,
    rule_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .excluded_rules = "ExcludedRules",
            .override_action = "OverrideAction",
            .priority = "Priority",
            .rule_id = "RuleId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WafOverrideAction = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WafExcludedRule = struct {
    rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const WafAction = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSqsQueueDetails = struct {
    kms_data_key_reuse_period_seconds: ?i64 = null,
    kms_master_key_id: ?[]const u8 = null,
    queue_name: ?[]const u8 = null,
    dead_letter_target_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_data_key_reuse_period_seconds = "KmsDataKeyReusePeriodSeconds",
            .kms_master_key_id = "KmsMasterKeyId",
            .queue_name = "QueueName",
            .dead_letter_target_arn = "DeadLetterTargetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSnsTopicDetails = struct {
    kms_master_key_id: ?[]const u8 = null,
    subscription: ?[]AwsSnsTopicSubscription = null,
    topic_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    sqs_success_feedback_role_arn: ?[]const u8 = null,
    sqs_failure_feedback_role_arn: ?[]const u8 = null,
    application_success_feedback_role_arn: ?[]const u8 = null,
    firehose_success_feedback_role_arn: ?[]const u8 = null,
    firehose_failure_feedback_role_arn: ?[]const u8 = null,
    http_success_feedback_role_arn: ?[]const u8 = null,
    http_failure_feedback_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_master_key_id = "KmsMasterKeyId",
            .subscription = "Subscription",
            .topic_name = "TopicName",
            .owner = "Owner",
            .sqs_success_feedback_role_arn = "SqsSuccessFeedbackRoleArn",
            .sqs_failure_feedback_role_arn = "SqsFailureFeedbackRoleArn",
            .application_success_feedback_role_arn = "ApplicationSuccessFeedbackRoleArn",
            .firehose_success_feedback_role_arn = "FirehoseSuccessFeedbackRoleArn",
            .firehose_failure_feedback_role_arn = "FirehoseFailureFeedbackRoleArn",
            .http_success_feedback_role_arn = "HttpSuccessFeedbackRoleArn",
            .http_failure_feedback_role_arn = "HttpFailureFeedbackRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSnsTopicSubscription = struct {
    endpoint: ?[]const u8 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "Endpoint",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceDetails = struct {
    associated_roles: ?[]AwsRdsDbInstanceAssociatedRole = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    db_instance_identifier: ?[]const u8 = null,
    db_instance_class: ?[]const u8 = null,
    db_instance_port: ?i64 = null,
    dbi_resource_id: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    deletion_protection: ?bool = null,
    endpoint: ?AwsRdsDbInstanceEndpoint = null,
    engine: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    iam_database_authentication_enabled: ?bool = null,
    instance_create_time: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    storage_encrypted: ?bool = null,
    tde_credential_arn: ?[]const u8 = null,
    vpc_security_groups: ?[]AwsRdsDbInstanceVpcSecurityGroup = null,
    multi_az: ?bool = null,
    enhanced_monitoring_resource_arn: ?[]const u8 = null,
    db_instance_status: ?[]const u8 = null,
    master_username: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    preferred_backup_window: ?[]const u8 = null,
    backup_retention_period: ?i64 = null,
    db_security_groups: ?[][]const u8 = null,
    db_parameter_groups: ?[]AwsRdsDbParameterGroup = null,
    availability_zone: ?[]const u8 = null,
    db_subnet_group: ?AwsRdsDbSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?AwsRdsDbPendingModifiedValues = null,
    latest_restorable_time: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    read_replica_source_db_instance_identifier: ?[]const u8 = null,
    read_replica_db_instance_identifiers: ?[][]const u8 = null,
    read_replica_db_cluster_identifiers: ?[][]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    option_group_memberships: ?[]AwsRdsDbOptionGroupMembership = null,
    character_set_name: ?[]const u8 = null,
    secondary_availability_zone: ?[]const u8 = null,
    status_infos: ?[]AwsRdsDbStatusInfo = null,
    storage_type: ?[]const u8 = null,
    domain_memberships: ?[]AwsRdsDbDomainMembership = null,
    copy_tags_to_snapshot: ?bool = null,
    monitoring_interval: ?i64 = null,
    monitoring_role_arn: ?[]const u8 = null,
    promotion_tier: ?i64 = null,
    timezone: ?[]const u8 = null,
    performance_insights_enabled: ?bool = null,
    performance_insights_kms_key_id: ?[]const u8 = null,
    performance_insights_retention_period: ?i64 = null,
    enabled_cloud_watch_logs_exports: ?[][]const u8 = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,
    listener_endpoint: ?AwsRdsDbInstanceEndpoint = null,
    max_allocated_storage: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associated_roles = "AssociatedRoles",
            .ca_certificate_identifier = "CACertificateIdentifier",
            .db_cluster_identifier = "DBClusterIdentifier",
            .db_instance_identifier = "DBInstanceIdentifier",
            .db_instance_class = "DBInstanceClass",
            .db_instance_port = "DbInstancePort",
            .dbi_resource_id = "DbiResourceId",
            .db_name = "DBName",
            .deletion_protection = "DeletionProtection",
            .endpoint = "Endpoint",
            .engine = "Engine",
            .engine_version = "EngineVersion",
            .iam_database_authentication_enabled = "IAMDatabaseAuthenticationEnabled",
            .instance_create_time = "InstanceCreateTime",
            .kms_key_id = "KmsKeyId",
            .publicly_accessible = "PubliclyAccessible",
            .storage_encrypted = "StorageEncrypted",
            .tde_credential_arn = "TdeCredentialArn",
            .vpc_security_groups = "VpcSecurityGroups",
            .multi_az = "MultiAz",
            .enhanced_monitoring_resource_arn = "EnhancedMonitoringResourceArn",
            .db_instance_status = "DbInstanceStatus",
            .master_username = "MasterUsername",
            .allocated_storage = "AllocatedStorage",
            .preferred_backup_window = "PreferredBackupWindow",
            .backup_retention_period = "BackupRetentionPeriod",
            .db_security_groups = "DbSecurityGroups",
            .db_parameter_groups = "DbParameterGroups",
            .availability_zone = "AvailabilityZone",
            .db_subnet_group = "DbSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .latest_restorable_time = "LatestRestorableTime",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .read_replica_source_db_instance_identifier = "ReadReplicaSourceDBInstanceIdentifier",
            .read_replica_db_instance_identifiers = "ReadReplicaDBInstanceIdentifiers",
            .read_replica_db_cluster_identifiers = "ReadReplicaDBClusterIdentifiers",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .option_group_memberships = "OptionGroupMemberships",
            .character_set_name = "CharacterSetName",
            .secondary_availability_zone = "SecondaryAvailabilityZone",
            .status_infos = "StatusInfos",
            .storage_type = "StorageType",
            .domain_memberships = "DomainMemberships",
            .copy_tags_to_snapshot = "CopyTagsToSnapshot",
            .monitoring_interval = "MonitoringInterval",
            .monitoring_role_arn = "MonitoringRoleArn",
            .promotion_tier = "PromotionTier",
            .timezone = "Timezone",
            .performance_insights_enabled = "PerformanceInsightsEnabled",
            .performance_insights_kms_key_id = "PerformanceInsightsKmsKeyId",
            .performance_insights_retention_period = "PerformanceInsightsRetentionPeriod",
            .enabled_cloud_watch_logs_exports = "EnabledCloudWatchLogsExports",
            .processor_features = "ProcessorFeatures",
            .listener_endpoint = "ListenerEndpoint",
            .max_allocated_storage = "MaxAllocatedStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceEndpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,
    hosted_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
            .hosted_zone_id = "HostedZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbStatusInfo = struct {
    status_type: ?[]const u8 = null,
    normal: ?bool = null,
    status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_type = "StatusType",
            .normal = "Normal",
            .status = "Status",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbOptionGroupMembership = struct {
    option_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .option_group_name = "OptionGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbPendingModifiedValues = struct {
    db_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    master_user_password: ?[]const u8 = null,
    port: ?i64 = null,
    backup_retention_period: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    license_model: ?[]const u8 = null,
    iops: ?i64 = null,
    db_instance_identifier: ?[]const u8 = null,
    storage_type: ?[]const u8 = null,
    ca_certificate_identifier: ?[]const u8 = null,
    db_subnet_group_name: ?[]const u8 = null,
    pending_cloud_watch_logs_exports: ?AwsRdsPendingCloudWatchLogsExports = null,
    processor_features: ?[]AwsRdsDbProcessorFeature = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_class = "DbInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .master_user_password = "MasterUserPassword",
            .port = "Port",
            .backup_retention_period = "BackupRetentionPeriod",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .license_model = "LicenseModel",
            .iops = "Iops",
            .db_instance_identifier = "DbInstanceIdentifier",
            .storage_type = "StorageType",
            .ca_certificate_identifier = "CaCertificateIdentifier",
            .db_subnet_group_name = "DbSubnetGroupName",
            .pending_cloud_watch_logs_exports = "PendingCloudWatchLogsExports",
            .processor_features = "ProcessorFeatures",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsPendingCloudWatchLogsExports = struct {
    log_types_to_enable: ?[][]const u8 = null,
    log_types_to_disable: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_types_to_enable = "LogTypesToEnable",
            .log_types_to_disable = "LogTypesToDisable",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroup = struct {
    db_subnet_group_name: ?[]const u8 = null,
    db_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]AwsRdsDbSubnetGroupSubnet = null,
    db_subnet_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_subnet_group_name = "DbSubnetGroupName",
            .db_subnet_group_description = "DbSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .db_subnet_group_arn = "DbSubnetGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroupSubnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AwsRdsDbSubnetGroupSubnetAvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbSubnetGroupSubnetAvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbParameterGroup = struct {
    db_parameter_group_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_parameter_group_name = "DbParameterGroupName",
            .parameter_apply_status = "ParameterApplyStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRdsDbInstanceAssociatedRole = struct {
    role_arn: ?[]const u8 = null,
    feature_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .feature_name = "FeatureName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaLayerVersionDetails = struct {
    version: ?i64 = null,
    compatible_runtimes: ?[][]const u8 = null,
    created_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .compatible_runtimes = "CompatibleRuntimes",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionDetails = struct {
    code: ?AwsLambdaFunctionCode = null,
    code_sha256: ?[]const u8 = null,
    dead_letter_config: ?AwsLambdaFunctionDeadLetterConfig = null,
    environment: ?AwsLambdaFunctionEnvironment = null,
    function_name: ?[]const u8 = null,
    handler: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,
    last_modified: ?[]const u8 = null,
    layers: ?[]AwsLambdaFunctionLayer = null,
    master_arn: ?[]const u8 = null,
    memory_size: ?i64 = null,
    revision_id: ?[]const u8 = null,
    role: ?[]const u8 = null,
    runtime: ?[]const u8 = null,
    timeout: ?i64 = null,
    tracing_config: ?AwsLambdaFunctionTracingConfig = null,
    vpc_config: ?AwsLambdaFunctionVpcConfig = null,
    version: ?[]const u8 = null,
    architectures: ?[][]const u8 = null,
    package_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .code_sha256 = "CodeSha256",
            .dead_letter_config = "DeadLetterConfig",
            .environment = "Environment",
            .function_name = "FunctionName",
            .handler = "Handler",
            .kms_key_arn = "KmsKeyArn",
            .last_modified = "LastModified",
            .layers = "Layers",
            .master_arn = "MasterArn",
            .memory_size = "MemorySize",
            .revision_id = "RevisionId",
            .role = "Role",
            .runtime = "Runtime",
            .timeout = "Timeout",
            .tracing_config = "TracingConfig",
            .vpc_config = "VpcConfig",
            .version = "Version",
            .architectures = "Architectures",
            .package_type = "PackageType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionVpcConfig = struct {
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionTracingConfig = struct {
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionLayer = struct {
    arn: ?[]const u8 = null,
    code_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .code_size = "CodeSize",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionEnvironment = struct {
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    @"error": ?AwsLambdaFunctionEnvironmentError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variables = "Variables",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const AwsLambdaFunctionEnvironmentError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionDeadLetterConfig = struct {
    target_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "TargetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaFunctionCode = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    s3_object_version: ?[]const u8 = null,
    zip_file: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key = "S3Key",
            .s3_object_version = "S3ObjectVersion",
            .zip_file = "ZipFile",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsKmsKeyDetails = struct {
    aws_account_id: ?[]const u8 = null,
    creation_date: ?f64 = null,
    key_id: ?[]const u8 = null,
    key_manager: ?[]const u8 = null,
    key_state: ?[]const u8 = null,
    origin: ?[]const u8 = null,
    description: ?[]const u8 = null,
    key_rotation_status: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_account_id = "AWSAccountId",
            .creation_date = "CreationDate",
            .key_id = "KeyId",
            .key_manager = "KeyManager",
            .key_state = "KeyState",
            .origin = "Origin",
            .description = "Description",
            .key_rotation_status = "KeyRotationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamRoleDetails = struct {
    assume_role_policy_document: ?[]const u8 = null,
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    instance_profile_list: ?[]AwsIamInstanceProfile = null,
    permissions_boundary: ?AwsIamPermissionsBoundary = null,
    role_id: ?[]const u8 = null,
    role_name: ?[]const u8 = null,
    role_policy_list: ?[]AwsIamRolePolicy = null,
    max_session_duration: ?i64 = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assume_role_policy_document = "AssumeRolePolicyDocument",
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .instance_profile_list = "InstanceProfileList",
            .permissions_boundary = "PermissionsBoundary",
            .role_id = "RoleId",
            .role_name = "RoleName",
            .role_policy_list = "RolePolicyList",
            .max_session_duration = "MaxSessionDuration",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamRolePolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPermissionsBoundary = struct {
    permissions_boundary_arn: ?[]const u8 = null,
    permissions_boundary_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .permissions_boundary_arn = "PermissionsBoundaryArn",
            .permissions_boundary_type = "PermissionsBoundaryType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamInstanceProfile = struct {
    arn: ?[]const u8 = null,
    create_date: ?[]const u8 = null,
    instance_profile_id: ?[]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    roles: ?[]AwsIamInstanceProfileRole = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .create_date = "CreateDate",
            .instance_profile_id = "InstanceProfileId",
            .instance_profile_name = "InstanceProfileName",
            .path = "Path",
            .roles = "Roles",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamInstanceProfileRole = struct {
    arn: ?[]const u8 = null,
    assume_role_policy_document: ?[]const u8 = null,
    create_date: ?[]const u8 = null,
    path: ?[]const u8 = null,
    role_id: ?[]const u8 = null,
    role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .assume_role_policy_document = "AssumeRolePolicyDocument",
            .create_date = "CreateDate",
            .path = "Path",
            .role_id = "RoleId",
            .role_name = "RoleName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAttachedManagedPolicy = struct {
    policy_name: ?[]const u8 = null,
    policy_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
            .policy_arn = "PolicyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamGroupDetails = struct {
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    group_policy_list: ?[]AwsIamGroupPolicy = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .group_id = "GroupId",
            .group_name = "GroupName",
            .group_policy_list = "GroupPolicyList",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamGroupPolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerDetails = struct {
    availability_zones: ?[][]const u8 = null,
    backend_server_descriptions: ?[]AwsElbLoadBalancerBackendServerDescription = null,
    canonical_hosted_zone_name: ?[]const u8 = null,
    canonical_hosted_zone_name_id: ?[]const u8 = null,
    created_time: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    health_check: ?AwsElbLoadBalancerHealthCheck = null,
    instances: ?[]AwsElbLoadBalancerInstance = null,
    listener_descriptions: ?[]AwsElbLoadBalancerListenerDescription = null,
    load_balancer_attributes: ?AwsElbLoadBalancerAttributes = null,
    load_balancer_name: ?[]const u8 = null,
    policies: ?AwsElbLoadBalancerPolicies = null,
    scheme: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    source_security_group: ?AwsElbLoadBalancerSourceSecurityGroup = null,
    subnets: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .backend_server_descriptions = "BackendServerDescriptions",
            .canonical_hosted_zone_name = "CanonicalHostedZoneName",
            .canonical_hosted_zone_name_id = "CanonicalHostedZoneNameID",
            .created_time = "CreatedTime",
            .dns_name = "DnsName",
            .health_check = "HealthCheck",
            .instances = "Instances",
            .listener_descriptions = "ListenerDescriptions",
            .load_balancer_attributes = "LoadBalancerAttributes",
            .load_balancer_name = "LoadBalancerName",
            .policies = "Policies",
            .scheme = "Scheme",
            .security_groups = "SecurityGroups",
            .source_security_group = "SourceSecurityGroup",
            .subnets = "Subnets",
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerSourceSecurityGroup = struct {
    group_name: ?[]const u8 = null,
    owner_alias: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .owner_alias = "OwnerAlias",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerPolicies = struct {
    app_cookie_stickiness_policies: ?[]AwsElbAppCookieStickinessPolicy = null,
    lb_cookie_stickiness_policies: ?[]AwsElbLbCookieStickinessPolicy = null,
    other_policies: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_cookie_stickiness_policies = "AppCookieStickinessPolicies",
            .lb_cookie_stickiness_policies = "LbCookieStickinessPolicies",
            .other_policies = "OtherPolicies",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLbCookieStickinessPolicy = struct {
    cookie_expiration_period: ?i64 = null,
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_expiration_period = "CookieExpirationPeriod",
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbAppCookieStickinessPolicy = struct {
    cookie_name: ?[]const u8 = null,
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cookie_name = "CookieName",
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerAttributes = struct {
    access_log: ?AwsElbLoadBalancerAccessLog = null,
    connection_draining: ?AwsElbLoadBalancerConnectionDraining = null,
    connection_settings: ?AwsElbLoadBalancerConnectionSettings = null,
    cross_zone_load_balancing: ?AwsElbLoadBalancerCrossZoneLoadBalancing = null,
    additional_attributes: ?[]AwsElbLoadBalancerAdditionalAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_log = "AccessLog",
            .connection_draining = "ConnectionDraining",
            .connection_settings = "ConnectionSettings",
            .cross_zone_load_balancing = "CrossZoneLoadBalancing",
            .additional_attributes = "AdditionalAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerAdditionalAttribute = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerCrossZoneLoadBalancing = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerConnectionSettings = struct {
    idle_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .idle_timeout = "IdleTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerConnectionDraining = struct {
    enabled: ?bool = null,
    timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .timeout = "Timeout",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerAccessLog = struct {
    emit_interval: ?i64 = null,
    enabled: ?bool = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_bucket_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .emit_interval = "EmitInterval",
            .enabled = "Enabled",
            .s3_bucket_name = "S3BucketName",
            .s3_bucket_prefix = "S3BucketPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerListenerDescription = struct {
    listener: ?AwsElbLoadBalancerListener = null,
    policy_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .listener = "Listener",
            .policy_names = "PolicyNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerListener = struct {
    instance_port: ?i64 = null,
    instance_protocol: ?[]const u8 = null,
    load_balancer_port: ?i64 = null,
    protocol: ?[]const u8 = null,
    ssl_certificate_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_port = "InstancePort",
            .instance_protocol = "InstanceProtocol",
            .load_balancer_port = "LoadBalancerPort",
            .protocol = "Protocol",
            .ssl_certificate_id = "SslCertificateId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerInstance = struct {
    instance_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerHealthCheck = struct {
    healthy_threshold: ?i64 = null,
    interval: ?i64 = null,
    target: ?[]const u8 = null,
    timeout: ?i64 = null,
    unhealthy_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .healthy_threshold = "HealthyThreshold",
            .interval = "Interval",
            .target = "Target",
            .timeout = "Timeout",
            .unhealthy_threshold = "UnhealthyThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbLoadBalancerBackendServerDescription = struct {
    instance_port: ?i64 = null,
    policy_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_port = "InstancePort",
            .policy_names = "PolicyNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterDetails = struct {
    allow_version_upgrade: ?bool = null,
    automated_snapshot_retention_period: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    cluster_availability_status: ?[]const u8 = null,
    cluster_create_time: ?[]const u8 = null,
    cluster_identifier: ?[]const u8 = null,
    cluster_nodes: ?[]AwsRedshiftClusterClusterNode = null,
    cluster_parameter_groups: ?[]AwsRedshiftClusterClusterParameterGroup = null,
    cluster_public_key: ?[]const u8 = null,
    cluster_revision_number: ?[]const u8 = null,
    cluster_security_groups: ?[]AwsRedshiftClusterClusterSecurityGroup = null,
    cluster_snapshot_copy_status: ?AwsRedshiftClusterClusterSnapshotCopyStatus = null,
    cluster_status: ?[]const u8 = null,
    cluster_subnet_group_name: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    db_name: ?[]const u8 = null,
    deferred_maintenance_windows: ?[]AwsRedshiftClusterDeferredMaintenanceWindow = null,
    elastic_ip_status: ?AwsRedshiftClusterElasticIpStatus = null,
    elastic_resize_number_of_node_options: ?[]const u8 = null,
    encrypted: ?bool = null,
    endpoint: ?AwsRedshiftClusterEndpoint = null,
    enhanced_vpc_routing: ?bool = null,
    expected_next_snapshot_schedule_time: ?[]const u8 = null,
    expected_next_snapshot_schedule_time_status: ?[]const u8 = null,
    hsm_status: ?AwsRedshiftClusterHsmStatus = null,
    iam_roles: ?[]AwsRedshiftClusterIamRole = null,
    kms_key_id: ?[]const u8 = null,
    maintenance_track_name: ?[]const u8 = null,
    manual_snapshot_retention_period: ?i64 = null,
    master_username: ?[]const u8 = null,
    next_maintenance_window_start_time: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    pending_actions: ?[][]const u8 = null,
    pending_modified_values: ?AwsRedshiftClusterPendingModifiedValues = null,
    preferred_maintenance_window: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    resize_info: ?AwsRedshiftClusterResizeInfo = null,
    restore_status: ?AwsRedshiftClusterRestoreStatus = null,
    snapshot_schedule_identifier: ?[]const u8 = null,
    snapshot_schedule_state: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_security_groups: ?[]AwsRedshiftClusterVpcSecurityGroup = null,
    logging_status: ?AwsRedshiftClusterLoggingStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_version_upgrade = "AllowVersionUpgrade",
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .availability_zone = "AvailabilityZone",
            .cluster_availability_status = "ClusterAvailabilityStatus",
            .cluster_create_time = "ClusterCreateTime",
            .cluster_identifier = "ClusterIdentifier",
            .cluster_nodes = "ClusterNodes",
            .cluster_parameter_groups = "ClusterParameterGroups",
            .cluster_public_key = "ClusterPublicKey",
            .cluster_revision_number = "ClusterRevisionNumber",
            .cluster_security_groups = "ClusterSecurityGroups",
            .cluster_snapshot_copy_status = "ClusterSnapshotCopyStatus",
            .cluster_status = "ClusterStatus",
            .cluster_subnet_group_name = "ClusterSubnetGroupName",
            .cluster_version = "ClusterVersion",
            .db_name = "DBName",
            .deferred_maintenance_windows = "DeferredMaintenanceWindows",
            .elastic_ip_status = "ElasticIpStatus",
            .elastic_resize_number_of_node_options = "ElasticResizeNumberOfNodeOptions",
            .encrypted = "Encrypted",
            .endpoint = "Endpoint",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .expected_next_snapshot_schedule_time = "ExpectedNextSnapshotScheduleTime",
            .expected_next_snapshot_schedule_time_status = "ExpectedNextSnapshotScheduleTimeStatus",
            .hsm_status = "HsmStatus",
            .iam_roles = "IamRoles",
            .kms_key_id = "KmsKeyId",
            .maintenance_track_name = "MaintenanceTrackName",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .master_username = "MasterUsername",
            .next_maintenance_window_start_time = "NextMaintenanceWindowStartTime",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .pending_actions = "PendingActions",
            .pending_modified_values = "PendingModifiedValues",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .publicly_accessible = "PubliclyAccessible",
            .resize_info = "ResizeInfo",
            .restore_status = "RestoreStatus",
            .snapshot_schedule_identifier = "SnapshotScheduleIdentifier",
            .snapshot_schedule_state = "SnapshotScheduleState",
            .vpc_id = "VpcId",
            .vpc_security_groups = "VpcSecurityGroups",
            .logging_status = "LoggingStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterLoggingStatus = struct {
    bucket_name: ?[]const u8 = null,
    last_failure_message: ?[]const u8 = null,
    last_failure_time: ?[]const u8 = null,
    last_successful_delivery_time: ?[]const u8 = null,
    logging_enabled: ?bool = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .last_failure_message = "LastFailureMessage",
            .last_failure_time = "LastFailureTime",
            .last_successful_delivery_time = "LastSuccessfulDeliveryTime",
            .logging_enabled = "LoggingEnabled",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterVpcSecurityGroup = struct {
    status: ?[]const u8 = null,
    vpc_security_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .vpc_security_group_id = "VpcSecurityGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterRestoreStatus = struct {
    current_restore_rate_in_mega_bytes_per_second: ?f64 = null,
    elapsed_time_in_seconds: ?i64 = null,
    estimated_time_to_completion_in_seconds: ?i64 = null,
    progress_in_mega_bytes: ?i64 = null,
    snapshot_size_in_mega_bytes: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_restore_rate_in_mega_bytes_per_second = "CurrentRestoreRateInMegaBytesPerSecond",
            .elapsed_time_in_seconds = "ElapsedTimeInSeconds",
            .estimated_time_to_completion_in_seconds = "EstimatedTimeToCompletionInSeconds",
            .progress_in_mega_bytes = "ProgressInMegaBytes",
            .snapshot_size_in_mega_bytes = "SnapshotSizeInMegaBytes",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterResizeInfo = struct {
    allow_cancel_resize: ?bool = null,
    resize_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_cancel_resize = "AllowCancelResize",
            .resize_type = "ResizeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterPendingModifiedValues = struct {
    automated_snapshot_retention_period: ?i64 = null,
    cluster_identifier: ?[]const u8 = null,
    cluster_type: ?[]const u8 = null,
    cluster_version: ?[]const u8 = null,
    encryption_type: ?[]const u8 = null,
    enhanced_vpc_routing: ?bool = null,
    maintenance_track_name: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    number_of_nodes: ?i64 = null,
    publicly_accessible: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_snapshot_retention_period = "AutomatedSnapshotRetentionPeriod",
            .cluster_identifier = "ClusterIdentifier",
            .cluster_type = "ClusterType",
            .cluster_version = "ClusterVersion",
            .encryption_type = "EncryptionType",
            .enhanced_vpc_routing = "EnhancedVpcRouting",
            .maintenance_track_name = "MaintenanceTrackName",
            .master_user_password = "MasterUserPassword",
            .node_type = "NodeType",
            .number_of_nodes = "NumberOfNodes",
            .publicly_accessible = "PubliclyAccessible",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterIamRole = struct {
    apply_status: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_status = "ApplyStatus",
            .iam_role_arn = "IamRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterHsmStatus = struct {
    hsm_client_certificate_identifier: ?[]const u8 = null,
    hsm_configuration_identifier: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hsm_client_certificate_identifier = "HsmClientCertificateIdentifier",
            .hsm_configuration_identifier = "HsmConfigurationIdentifier",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterEndpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterElasticIpStatus = struct {
    elastic_ip: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elastic_ip = "ElasticIp",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterDeferredMaintenanceWindow = struct {
    defer_maintenance_end_time: ?[]const u8 = null,
    defer_maintenance_identifier: ?[]const u8 = null,
    defer_maintenance_start_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .defer_maintenance_end_time = "DeferMaintenanceEndTime",
            .defer_maintenance_identifier = "DeferMaintenanceIdentifier",
            .defer_maintenance_start_time = "DeferMaintenanceStartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterSnapshotCopyStatus = struct {
    destination_region: ?[]const u8 = null,
    manual_snapshot_retention_period: ?i64 = null,
    retention_period: ?i64 = null,
    snapshot_copy_grant_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_region = "DestinationRegion",
            .manual_snapshot_retention_period = "ManualSnapshotRetentionPeriod",
            .retention_period = "RetentionPeriod",
            .snapshot_copy_grant_name = "SnapshotCopyGrantName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterSecurityGroup = struct {
    cluster_security_group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_security_group_name = "ClusterSecurityGroupName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterParameterGroup = struct {
    cluster_parameter_status_list: ?[]AwsRedshiftClusterClusterParameterStatus = null,
    parameter_apply_status: ?[]const u8 = null,
    parameter_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_parameter_status_list = "ClusterParameterStatusList",
            .parameter_apply_status = "ParameterApplyStatus",
            .parameter_group_name = "ParameterGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterParameterStatus = struct {
    parameter_name: ?[]const u8 = null,
    parameter_apply_status: ?[]const u8 = null,
    parameter_apply_error_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_apply_status = "ParameterApplyStatus",
            .parameter_apply_error_description = "ParameterApplyErrorDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsRedshiftClusterClusterNode = struct {
    node_role: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    public_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .node_role = "NodeRole",
            .private_ip_address = "PrivateIpAddress",
            .public_ip_address = "PublicIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateDetails = struct {
    certificate_authority_arn: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    domain_validation_options: ?[]AwsCertificateManagerCertificateDomainValidationOption = null,
    extended_key_usages: ?[]AwsCertificateManagerCertificateExtendedKeyUsage = null,
    failure_reason: ?[]const u8 = null,
    imported_at: ?[]const u8 = null,
    in_use_by: ?[][]const u8 = null,
    issued_at: ?[]const u8 = null,
    issuer: ?[]const u8 = null,
    key_algorithm: ?[]const u8 = null,
    key_usages: ?[]AwsCertificateManagerCertificateKeyUsage = null,
    not_after: ?[]const u8 = null,
    not_before: ?[]const u8 = null,
    options: ?AwsCertificateManagerCertificateOptions = null,
    renewal_eligibility: ?[]const u8 = null,
    renewal_summary: ?AwsCertificateManagerCertificateRenewalSummary = null,
    serial: ?[]const u8 = null,
    signature_algorithm: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    subject_alternative_names: ?[][]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_authority_arn = "CertificateAuthorityArn",
            .created_at = "CreatedAt",
            .domain_name = "DomainName",
            .domain_validation_options = "DomainValidationOptions",
            .extended_key_usages = "ExtendedKeyUsages",
            .failure_reason = "FailureReason",
            .imported_at = "ImportedAt",
            .in_use_by = "InUseBy",
            .issued_at = "IssuedAt",
            .issuer = "Issuer",
            .key_algorithm = "KeyAlgorithm",
            .key_usages = "KeyUsages",
            .not_after = "NotAfter",
            .not_before = "NotBefore",
            .options = "Options",
            .renewal_eligibility = "RenewalEligibility",
            .renewal_summary = "RenewalSummary",
            .serial = "Serial",
            .signature_algorithm = "SignatureAlgorithm",
            .status = "Status",
            .subject = "Subject",
            .subject_alternative_names = "SubjectAlternativeNames",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateRenewalSummary = struct {
    domain_validation_options: ?[]AwsCertificateManagerCertificateDomainValidationOption = null,
    renewal_status: ?[]const u8 = null,
    renewal_status_reason: ?[]const u8 = null,
    updated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_validation_options = "DomainValidationOptions",
            .renewal_status = "RenewalStatus",
            .renewal_status_reason = "RenewalStatusReason",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateDomainValidationOption = struct {
    domain_name: ?[]const u8 = null,
    resource_record: ?AwsCertificateManagerCertificateResourceRecord = null,
    validation_domain: ?[]const u8 = null,
    validation_emails: ?[][]const u8 = null,
    validation_method: ?[]const u8 = null,
    validation_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .resource_record = "ResourceRecord",
            .validation_domain = "ValidationDomain",
            .validation_emails = "ValidationEmails",
            .validation_method = "ValidationMethod",
            .validation_status = "ValidationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateResourceRecord = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateOptions = struct {
    certificate_transparency_logging_preference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_transparency_logging_preference = "CertificateTransparencyLoggingPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateKeyUsage = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCertificateManagerCertificateExtendedKeyUsage = struct {
    name: ?[]const u8 = null,
    o_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .o_id = "OId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmPatchComplianceDetails = struct {
    patch: ?AwsSsmPatch = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .patch = "Patch",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmPatch = struct {
    compliance_summary: ?AwsSsmComplianceSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_summary = "ComplianceSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSsmComplianceSummary = struct {
    status: ?[]const u8 = null,
    compliant_critical_count: ?i64 = null,
    compliant_high_count: ?i64 = null,
    compliant_medium_count: ?i64 = null,
    execution_type: ?[]const u8 = null,
    non_compliant_critical_count: ?i64 = null,
    compliant_informational_count: ?i64 = null,
    non_compliant_informational_count: ?i64 = null,
    compliant_unspecified_count: ?i64 = null,
    non_compliant_low_count: ?i64 = null,
    non_compliant_high_count: ?i64 = null,
    compliant_low_count: ?i64 = null,
    compliance_type: ?[]const u8 = null,
    patch_baseline_id: ?[]const u8 = null,
    overall_severity: ?[]const u8 = null,
    non_compliant_medium_count: ?i64 = null,
    non_compliant_unspecified_count: ?i64 = null,
    patch_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .compliant_critical_count = "CompliantCriticalCount",
            .compliant_high_count = "CompliantHighCount",
            .compliant_medium_count = "CompliantMediumCount",
            .execution_type = "ExecutionType",
            .non_compliant_critical_count = "NonCompliantCriticalCount",
            .compliant_informational_count = "CompliantInformationalCount",
            .non_compliant_informational_count = "NonCompliantInformationalCount",
            .compliant_unspecified_count = "CompliantUnspecifiedCount",
            .non_compliant_low_count = "NonCompliantLowCount",
            .non_compliant_high_count = "NonCompliantHighCount",
            .compliant_low_count = "CompliantLowCount",
            .compliance_type = "ComplianceType",
            .patch_baseline_id = "PatchBaselineId",
            .overall_severity = "OverallSeverity",
            .non_compliant_medium_count = "NonCompliantMediumCount",
            .non_compliant_unspecified_count = "NonCompliantUnspecifiedCount",
            .patch_group = "PatchGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudTrailTrailDetails = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    has_custom_event_selectors: ?bool = null,
    home_region: ?[]const u8 = null,
    include_global_service_events: ?bool = null,
    is_multi_region_trail: ?bool = null,
    is_organization_trail: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    log_file_validation_enabled: ?bool = null,
    name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    sns_topic_name: ?[]const u8 = null,
    trail_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .has_custom_event_selectors = "HasCustomEventSelectors",
            .home_region = "HomeRegion",
            .include_global_service_events = "IncludeGlobalServiceEvents",
            .is_multi_region_trail = "IsMultiRegionTrail",
            .is_organization_trail = "IsOrganizationTrail",
            .kms_key_id = "KmsKeyId",
            .log_file_validation_enabled = "LogFileValidationEnabled",
            .name = "Name",
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .sns_topic_arn = "SnsTopicArn",
            .sns_topic_name = "SnsTopicName",
            .trail_arn = "TrailArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayRestApiDetails = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    version: ?[]const u8 = null,
    binary_media_types: ?[][]const u8 = null,
    minimum_compression_size: ?i64 = null,
    api_key_source: ?[]const u8 = null,
    endpoint_configuration: ?AwsApiGatewayEndpointConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .created_date = "CreatedDate",
            .version = "Version",
            .binary_media_types = "BinaryMediaTypes",
            .minimum_compression_size = "MinimumCompressionSize",
            .api_key_source = "ApiKeySource",
            .endpoint_configuration = "EndpointConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayEndpointConfiguration = struct {
    types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .types = "Types",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayStageDetails = struct {
    deployment_id: ?[]const u8 = null,
    client_certificate_id: ?[]const u8 = null,
    stage_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    cache_cluster_enabled: ?bool = null,
    cache_cluster_size: ?[]const u8 = null,
    cache_cluster_status: ?[]const u8 = null,
    method_settings: ?[]AwsApiGatewayMethodSettings = null,
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    documentation_version: ?[]const u8 = null,
    access_log_settings: ?AwsApiGatewayAccessLogSettings = null,
    canary_settings: ?AwsApiGatewayCanarySettings = null,
    tracing_enabled: ?bool = null,
    created_date: ?[]const u8 = null,
    last_updated_date: ?[]const u8 = null,
    web_acl_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_id = "DeploymentId",
            .client_certificate_id = "ClientCertificateId",
            .stage_name = "StageName",
            .description = "Description",
            .cache_cluster_enabled = "CacheClusterEnabled",
            .cache_cluster_size = "CacheClusterSize",
            .cache_cluster_status = "CacheClusterStatus",
            .method_settings = "MethodSettings",
            .variables = "Variables",
            .documentation_version = "DocumentationVersion",
            .access_log_settings = "AccessLogSettings",
            .canary_settings = "CanarySettings",
            .tracing_enabled = "TracingEnabled",
            .created_date = "CreatedDate",
            .last_updated_date = "LastUpdatedDate",
            .web_acl_arn = "WebAclArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayCanarySettings = struct {
    percent_traffic: ?f64 = null,
    deployment_id: ?[]const u8 = null,
    stage_variable_overrides: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    use_stage_cache: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percent_traffic = "PercentTraffic",
            .deployment_id = "DeploymentId",
            .stage_variable_overrides = "StageVariableOverrides",
            .use_stage_cache = "UseStageCache",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "stage_variable_overrides", field_name))
            return try serializeMap(self.stage_variable_overrides, self.fieldNameFor("stage_variable_overrides"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayAccessLogSettings = struct {
    format: ?[]const u8 = null,
    destination_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .destination_arn = "DestinationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayMethodSettings = struct {
    metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    data_trace_enabled: ?bool = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,
    caching_enabled: ?bool = null,
    cache_ttl_in_seconds: ?i64 = null,
    cache_data_encrypted: ?bool = null,
    require_authorization_for_cache_control: ?bool = null,
    unauthorized_cache_control_header_strategy: ?[]const u8 = null,
    http_method: ?[]const u8 = null,
    resource_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metrics_enabled = "MetricsEnabled",
            .logging_level = "LoggingLevel",
            .data_trace_enabled = "DataTraceEnabled",
            .throttling_burst_limit = "ThrottlingBurstLimit",
            .throttling_rate_limit = "ThrottlingRateLimit",
            .caching_enabled = "CachingEnabled",
            .cache_ttl_in_seconds = "CacheTtlInSeconds",
            .cache_data_encrypted = "CacheDataEncrypted",
            .require_authorization_for_cache_control = "RequireAuthorizationForCacheControl",
            .unauthorized_cache_control_header_strategy = "UnauthorizedCacheControlHeaderStrategy",
            .http_method = "HttpMethod",
            .resource_path = "ResourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableDetails = struct {
    attribute_definitions: ?[]AwsDynamoDbTableAttributeDefinition = null,
    billing_mode_summary: ?AwsDynamoDbTableBillingModeSummary = null,
    creation_date_time: ?[]const u8 = null,
    global_secondary_indexes: ?[]AwsDynamoDbTableGlobalSecondaryIndex = null,
    global_table_version: ?[]const u8 = null,
    item_count: ?i64 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    latest_stream_arn: ?[]const u8 = null,
    latest_stream_label: ?[]const u8 = null,
    local_secondary_indexes: ?[]AwsDynamoDbTableLocalSecondaryIndex = null,
    provisioned_throughput: ?AwsDynamoDbTableProvisionedThroughput = null,
    replicas: ?[]AwsDynamoDbTableReplica = null,
    restore_summary: ?AwsDynamoDbTableRestoreSummary = null,
    sse_description: ?AwsDynamoDbTableSseDescription = null,
    stream_specification: ?AwsDynamoDbTableStreamSpecification = null,
    table_id: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    table_size_bytes: ?i64 = null,
    table_status: ?[]const u8 = null,
    deletion_protection_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_definitions = "AttributeDefinitions",
            .billing_mode_summary = "BillingModeSummary",
            .creation_date_time = "CreationDateTime",
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .global_table_version = "GlobalTableVersion",
            .item_count = "ItemCount",
            .key_schema = "KeySchema",
            .latest_stream_arn = "LatestStreamArn",
            .latest_stream_label = "LatestStreamLabel",
            .local_secondary_indexes = "LocalSecondaryIndexes",
            .provisioned_throughput = "ProvisionedThroughput",
            .replicas = "Replicas",
            .restore_summary = "RestoreSummary",
            .sse_description = "SseDescription",
            .stream_specification = "StreamSpecification",
            .table_id = "TableId",
            .table_name = "TableName",
            .table_size_bytes = "TableSizeBytes",
            .table_status = "TableStatus",
            .deletion_protection_enabled = "DeletionProtectionEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableStreamSpecification = struct {
    stream_enabled: ?bool = null,
    stream_view_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_enabled = "StreamEnabled",
            .stream_view_type = "StreamViewType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableSseDescription = struct {
    inaccessible_encryption_date_time: ?[]const u8 = null,
    status: ?[]const u8 = null,
    sse_type: ?[]const u8 = null,
    kms_master_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inaccessible_encryption_date_time = "InaccessibleEncryptionDateTime",
            .status = "Status",
            .sse_type = "SseType",
            .kms_master_key_arn = "KmsMasterKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableRestoreSummary = struct {
    source_backup_arn: ?[]const u8 = null,
    source_table_arn: ?[]const u8 = null,
    restore_date_time: ?[]const u8 = null,
    restore_in_progress: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_backup_arn = "SourceBackupArn",
            .source_table_arn = "SourceTableArn",
            .restore_date_time = "RestoreDateTime",
            .restore_in_progress = "RestoreInProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableReplica = struct {
    global_secondary_indexes: ?[]AwsDynamoDbTableReplicaGlobalSecondaryIndex = null,
    kms_master_key_id: ?[]const u8 = null,
    provisioned_throughput_override: ?AwsDynamoDbTableProvisionedThroughputOverride = null,
    region_name: ?[]const u8 = null,
    replica_status: ?[]const u8 = null,
    replica_status_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_secondary_indexes = "GlobalSecondaryIndexes",
            .kms_master_key_id = "KmsMasterKeyId",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
            .region_name = "RegionName",
            .replica_status = "ReplicaStatus",
            .replica_status_description = "ReplicaStatusDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProvisionedThroughputOverride = struct {
    read_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_capacity_units = "ReadCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableReplicaGlobalSecondaryIndex = struct {
    index_name: ?[]const u8 = null,
    provisioned_throughput_override: ?AwsDynamoDbTableProvisionedThroughputOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_name = "IndexName",
            .provisioned_throughput_override = "ProvisionedThroughputOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProvisionedThroughput = struct {
    last_decrease_date_time: ?[]const u8 = null,
    last_increase_date_time: ?[]const u8 = null,
    number_of_decreases_today: ?i64 = null,
    read_capacity_units: ?i64 = null,
    write_capacity_units: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_decrease_date_time = "LastDecreaseDateTime",
            .last_increase_date_time = "LastIncreaseDateTime",
            .number_of_decreases_today = "NumberOfDecreasesToday",
            .read_capacity_units = "ReadCapacityUnits",
            .write_capacity_units = "WriteCapacityUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableLocalSecondaryIndex = struct {
    index_arn: ?[]const u8 = null,
    index_name: ?[]const u8 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    projection: ?AwsDynamoDbTableProjection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_arn = "IndexArn",
            .index_name = "IndexName",
            .key_schema = "KeySchema",
            .projection = "Projection",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableProjection = struct {
    non_key_attributes: ?[][]const u8 = null,
    projection_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .non_key_attributes = "NonKeyAttributes",
            .projection_type = "ProjectionType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableKeySchema = struct {
    attribute_name: ?[]const u8 = null,
    key_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .key_type = "KeyType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableGlobalSecondaryIndex = struct {
    backfilling: ?bool = null,
    index_arn: ?[]const u8 = null,
    index_name: ?[]const u8 = null,
    index_size_bytes: ?i64 = null,
    index_status: ?[]const u8 = null,
    item_count: ?i64 = null,
    key_schema: ?[]AwsDynamoDbTableKeySchema = null,
    projection: ?AwsDynamoDbTableProjection = null,
    provisioned_throughput: ?AwsDynamoDbTableProvisionedThroughput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backfilling = "Backfilling",
            .index_arn = "IndexArn",
            .index_name = "IndexName",
            .index_size_bytes = "IndexSizeBytes",
            .index_status = "IndexStatus",
            .item_count = "ItemCount",
            .key_schema = "KeySchema",
            .projection = "Projection",
            .provisioned_throughput = "ProvisionedThroughput",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableBillingModeSummary = struct {
    billing_mode: ?[]const u8 = null,
    last_update_to_pay_per_request_date_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .billing_mode = "BillingMode",
            .last_update_to_pay_per_request_date_time = "LastUpdateToPayPerRequestDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsDynamoDbTableAttributeDefinition = struct {
    attribute_name: ?[]const u8 = null,
    attribute_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_type = "AttributeType",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayV2ApiDetails = struct {
    api_endpoint: ?[]const u8 = null,
    api_id: ?[]const u8 = null,
    api_key_selection_expression: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    description: ?[]const u8 = null,
    version: ?[]const u8 = null,
    name: ?[]const u8 = null,
    protocol_type: ?[]const u8 = null,
    route_selection_expression: ?[]const u8 = null,
    cors_configuration: ?AwsCorsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_endpoint = "ApiEndpoint",
            .api_id = "ApiId",
            .api_key_selection_expression = "ApiKeySelectionExpression",
            .created_date = "CreatedDate",
            .description = "Description",
            .version = "Version",
            .name = "Name",
            .protocol_type = "ProtocolType",
            .route_selection_expression = "RouteSelectionExpression",
            .cors_configuration = "CorsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCorsConfiguration = struct {
    allow_origins: ?[][]const u8 = null,
    allow_credentials: ?bool = null,
    expose_headers: ?[][]const u8 = null,
    max_age: ?i64 = null,
    allow_methods: ?[][]const u8 = null,
    allow_headers: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_origins = "AllowOrigins",
            .allow_credentials = "AllowCredentials",
            .expose_headers = "ExposeHeaders",
            .max_age = "MaxAge",
            .allow_methods = "AllowMethods",
            .allow_headers = "AllowHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsApiGatewayV2StageDetails = struct {
    client_certificate_id: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_route_settings: ?AwsApiGatewayV2RouteSettings = null,
    deployment_id: ?[]const u8 = null,
    last_updated_date: ?[]const u8 = null,
    route_settings: ?AwsApiGatewayV2RouteSettings = null,
    stage_name: ?[]const u8 = null,
    stage_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    access_log_settings: ?AwsApiGatewayAccessLogSettings = null,
    auto_deploy: ?bool = null,
    last_deployment_status_message: ?[]const u8 = null,
    api_gateway_managed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_certificate_id = "ClientCertificateId",
            .created_date = "CreatedDate",
            .description = "Description",
            .default_route_settings = "DefaultRouteSettings",
            .deployment_id = "DeploymentId",
            .last_updated_date = "LastUpdatedDate",
            .route_settings = "RouteSettings",
            .stage_name = "StageName",
            .stage_variables = "StageVariables",
            .access_log_settings = "AccessLogSettings",
            .auto_deploy = "AutoDeploy",
            .last_deployment_status_message = "LastDeploymentStatusMessage",
            .api_gateway_managed = "ApiGatewayManaged",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "stage_variables", field_name))
            return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
        return false;
    }
};

pub const AwsApiGatewayV2RouteSettings = struct {
    detailed_metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    data_trace_enabled: ?bool = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detailed_metrics_enabled = "DetailedMetricsEnabled",
            .logging_level = "LoggingLevel",
            .data_trace_enabled = "DataTraceEnabled",
            .throttling_burst_limit = "ThrottlingBurstLimit",
            .throttling_rate_limit = "ThrottlingRateLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPolicyDetails = struct {
    attachment_count: ?i64 = null,
    create_date: ?[]const u8 = null,
    default_version_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    is_attachable: ?bool = null,
    path: ?[]const u8 = null,
    permissions_boundary_usage_count: ?i64 = null,
    policy_id: ?[]const u8 = null,
    policy_name: ?[]const u8 = null,
    policy_version_list: ?[]AwsIamPolicyVersion = null,
    update_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_count = "AttachmentCount",
            .create_date = "CreateDate",
            .default_version_id = "DefaultVersionId",
            .description = "Description",
            .is_attachable = "IsAttachable",
            .path = "Path",
            .permissions_boundary_usage_count = "PermissionsBoundaryUsageCount",
            .policy_id = "PolicyId",
            .policy_name = "PolicyName",
            .policy_version_list = "PolicyVersionList",
            .update_date = "UpdateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamPolicyVersion = struct {
    version_id: ?[]const u8 = null,
    is_default_version: ?bool = null,
    create_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version_id = "VersionId",
            .is_default_version = "IsDefaultVersion",
            .create_date = "CreateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamUserDetails = struct {
    attached_managed_policies: ?[]AwsIamAttachedManagedPolicy = null,
    create_date: ?[]const u8 = null,
    group_list: ?[][]const u8 = null,
    path: ?[]const u8 = null,
    permissions_boundary: ?AwsIamPermissionsBoundary = null,
    user_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    user_policy_list: ?[]AwsIamUserPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attached_managed_policies = "AttachedManagedPolicies",
            .create_date = "CreateDate",
            .group_list = "GroupList",
            .path = "Path",
            .permissions_boundary = "PermissionsBoundary",
            .user_id = "UserId",
            .user_name = "UserName",
            .user_policy_list = "UserPolicyList",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamUserPolicy = struct {
    policy_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeyDetails = struct {
    user_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    principal_type: ?[]const u8 = null,
    principal_name: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    access_key_id: ?[]const u8 = null,
    session_context: ?AwsIamAccessKeySessionContext = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name = "UserName",
            .status = "Status",
            .created_at = "CreatedAt",
            .principal_id = "PrincipalId",
            .principal_type = "PrincipalType",
            .principal_name = "PrincipalName",
            .account_id = "AccountId",
            .access_key_id = "AccessKeyId",
            .session_context = "SessionContext",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContext = struct {
    attributes: ?AwsIamAccessKeySessionContextAttributes = null,
    session_issuer: ?AwsIamAccessKeySessionContextSessionIssuer = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
            .session_issuer = "SessionIssuer",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContextSessionIssuer = struct {
    type: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .principal_id = "PrincipalId",
            .arn = "Arn",
            .account_id = "AccountId",
            .user_name = "UserName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamAccessKeySessionContextAttributes = struct {
    mfa_authenticated: ?bool = null,
    creation_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mfa_authenticated = "MfaAuthenticated",
            .creation_date = "CreationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecretsManagerSecretDetails = struct {
    rotation_rules: ?AwsSecretsManagerSecretRotationRules = null,
    rotation_occurred_within_frequency: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    rotation_enabled: ?bool = null,
    rotation_lambda_arn: ?[]const u8 = null,
    deleted: ?bool = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rotation_rules = "RotationRules",
            .rotation_occurred_within_frequency = "RotationOccurredWithinFrequency",
            .kms_key_id = "KmsKeyId",
            .rotation_enabled = "RotationEnabled",
            .rotation_lambda_arn = "RotationLambdaArn",
            .deleted = "Deleted",
            .name = "Name",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecretsManagerSecretRotationRules = struct {
    automatically_after_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatically_after_days = "AutomaticallyAfterDays",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3ObjectDetails = struct {
    last_modified: ?[]const u8 = null,
    e_tag: ?[]const u8 = null,
    version_id: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    server_side_encryption: ?[]const u8 = null,
    ssekms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_modified = "LastModified",
            .e_tag = "ETag",
            .version_id = "VersionId",
            .content_type = "ContentType",
            .server_side_encryption = "ServerSideEncryption",
            .ssekms_key_id = "SSEKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketDetails = struct {
    owner_id: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    created_at: ?[]const u8 = null,
    server_side_encryption_configuration: ?AwsS3BucketServerSideEncryptionConfiguration = null,
    bucket_lifecycle_configuration: ?AwsS3BucketBucketLifecycleConfigurationDetails = null,
    public_access_block_configuration: ?AwsS3AccountPublicAccessBlockDetails = null,
    access_control_list: ?[]const u8 = null,
    bucket_logging_configuration: ?AwsS3BucketLoggingConfiguration = null,
    bucket_website_configuration: ?AwsS3BucketWebsiteConfiguration = null,
    bucket_notification_configuration: ?AwsS3BucketNotificationConfiguration = null,
    bucket_versioning_configuration: ?AwsS3BucketBucketVersioningConfiguration = null,
    object_lock_configuration: ?AwsS3BucketObjectLockConfiguration = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .owner_name = "OwnerName",
            .owner_account_id = "OwnerAccountId",
            .created_at = "CreatedAt",
            .server_side_encryption_configuration = "ServerSideEncryptionConfiguration",
            .bucket_lifecycle_configuration = "BucketLifecycleConfiguration",
            .public_access_block_configuration = "PublicAccessBlockConfiguration",
            .access_control_list = "AccessControlList",
            .bucket_logging_configuration = "BucketLoggingConfiguration",
            .bucket_website_configuration = "BucketWebsiteConfiguration",
            .bucket_notification_configuration = "BucketNotificationConfiguration",
            .bucket_versioning_configuration = "BucketVersioningConfiguration",
            .object_lock_configuration = "ObjectLockConfiguration",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketObjectLockConfiguration = struct {
    object_lock_enabled: ?[]const u8 = null,
    rule: ?AwsS3BucketObjectLockConfigurationRuleDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_lock_enabled = "ObjectLockEnabled",
            .rule = "Rule",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketObjectLockConfigurationRuleDetails = struct {
    default_retention: ?AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_retention = "DefaultRetention",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketObjectLockConfigurationRuleDefaultRetentionDetails = struct {
    days: ?i64 = null,
    mode: ?[]const u8 = null,
    years: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days = "Days",
            .mode = "Mode",
            .years = "Years",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketVersioningConfiguration = struct {
    is_mfa_delete_enabled: ?bool = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_mfa_delete_enabled = "IsMfaDeleteEnabled",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketNotificationConfiguration = struct {
    configurations: ?[]AwsS3BucketNotificationConfigurationDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configurations = "Configurations",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketNotificationConfigurationDetail = struct {
    events: ?[][]const u8 = null,
    filter: ?AwsS3BucketNotificationConfigurationFilter = null,
    destination: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .events = "Events",
            .filter = "Filter",
            .destination = "Destination",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketNotificationConfigurationFilter = struct {
    s3_key_filter: ?AwsS3BucketNotificationConfigurationS3KeyFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_key_filter = "S3KeyFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketNotificationConfigurationS3KeyFilter = struct {
    filter_rules: ?[]AwsS3BucketNotificationConfigurationS3KeyFilterRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_rules = "FilterRules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketNotificationConfigurationS3KeyFilterRule = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketWebsiteConfiguration = struct {
    error_document: ?[]const u8 = null,
    index_document_suffix: ?[]const u8 = null,
    redirect_all_requests_to: ?AwsS3BucketWebsiteConfigurationRedirectTo = null,
    routing_rules: ?[]AwsS3BucketWebsiteConfigurationRoutingRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_document = "ErrorDocument",
            .index_document_suffix = "IndexDocumentSuffix",
            .redirect_all_requests_to = "RedirectAllRequestsTo",
            .routing_rules = "RoutingRules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketWebsiteConfigurationRoutingRule = struct {
    condition: ?AwsS3BucketWebsiteConfigurationRoutingRuleCondition = null,
    redirect: ?AwsS3BucketWebsiteConfigurationRoutingRuleRedirect = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "Condition",
            .redirect = "Redirect",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketWebsiteConfigurationRoutingRuleRedirect = struct {
    hostname: ?[]const u8 = null,
    http_redirect_code: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    replace_key_prefix_with: ?[]const u8 = null,
    replace_key_with: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname = "Hostname",
            .http_redirect_code = "HttpRedirectCode",
            .protocol = "Protocol",
            .replace_key_prefix_with = "ReplaceKeyPrefixWith",
            .replace_key_with = "ReplaceKeyWith",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketWebsiteConfigurationRoutingRuleCondition = struct {
    http_error_code_returned_equals: ?[]const u8 = null,
    key_prefix_equals: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_error_code_returned_equals = "HttpErrorCodeReturnedEquals",
            .key_prefix_equals = "KeyPrefixEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketWebsiteConfigurationRedirectTo = struct {
    hostname: ?[]const u8 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hostname = "Hostname",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketLoggingConfiguration = struct {
    destination_bucket_name: ?[]const u8 = null,
    log_file_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_bucket_name = "DestinationBucketName",
            .log_file_prefix = "LogFilePrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationDetails = struct {
    rules: ?[]AwsS3BucketBucketLifecycleConfigurationRulesDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesDetails = struct {
    abort_incomplete_multipart_upload: ?AwsS3BucketBucketLifecycleConfigurationRulesAbortIncompleteMultipartUploadDetails = null,
    expiration_date: ?[]const u8 = null,
    expiration_in_days: ?i64 = null,
    expired_object_delete_marker: ?bool = null,
    filter: ?AwsS3BucketBucketLifecycleConfigurationRulesFilterDetails = null,
    id: ?[]const u8 = null,
    noncurrent_version_expiration_in_days: ?i64 = null,
    noncurrent_version_transitions: ?[]AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetails = null,
    prefix: ?[]const u8 = null,
    status: ?[]const u8 = null,
    transitions: ?[]AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .abort_incomplete_multipart_upload = "AbortIncompleteMultipartUpload",
            .expiration_date = "ExpirationDate",
            .expiration_in_days = "ExpirationInDays",
            .expired_object_delete_marker = "ExpiredObjectDeleteMarker",
            .filter = "Filter",
            .id = "ID",
            .noncurrent_version_expiration_in_days = "NoncurrentVersionExpirationInDays",
            .noncurrent_version_transitions = "NoncurrentVersionTransitions",
            .prefix = "Prefix",
            .status = "Status",
            .transitions = "Transitions",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetails = struct {
    date: ?[]const u8 = null,
    days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetails = struct {
    days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days = "Days",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesFilterDetails = struct {
    predicate: ?AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .predicate = "Predicate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateDetails = struct {
    operands: ?[]AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsDetails = null,
    prefix: ?[]const u8 = null,
    tag: ?AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateTagDetails = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .operands = "Operands",
            .prefix = "Prefix",
            .tag = "Tag",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateTagDetails = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsDetails = struct {
    prefix: ?[]const u8 = null,
    tag: ?AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsTagDetails = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsTagDetails = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketBucketLifecycleConfigurationRulesAbortIncompleteMultipartUploadDetails = struct {
    days_after_initiation: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_after_initiation = "DaysAfterInitiation",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionConfiguration = struct {
    rules: ?[]AwsS3BucketServerSideEncryptionRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionRule = struct {
    apply_server_side_encryption_by_default: ?AwsS3BucketServerSideEncryptionByDefault = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_server_side_encryption_by_default = "ApplyServerSideEncryptionByDefault",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsS3BucketServerSideEncryptionByDefault = struct {
    sse_algorithm: ?[]const u8 = null,
    kms_master_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sse_algorithm = "SSEAlgorithm",
            .kms_master_key_id = "KMSMasterKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainDetails = struct {
    access_policies: ?[]const u8 = null,
    domain_endpoint_options: ?AwsElasticsearchDomainDomainEndpointOptions = null,
    domain_id: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    elasticsearch_version: ?[]const u8 = null,
    elasticsearch_cluster_config: ?AwsElasticsearchDomainElasticsearchClusterConfigDetails = null,
    encryption_at_rest_options: ?AwsElasticsearchDomainEncryptionAtRestOptions = null,
    log_publishing_options: ?AwsElasticsearchDomainLogPublishingOptions = null,
    node_to_node_encryption_options: ?AwsElasticsearchDomainNodeToNodeEncryptionOptions = null,
    service_software_options: ?AwsElasticsearchDomainServiceSoftwareOptions = null,
    vpc_options: ?AwsElasticsearchDomainVPCOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_policies = "AccessPolicies",
            .domain_endpoint_options = "DomainEndpointOptions",
            .domain_id = "DomainId",
            .domain_name = "DomainName",
            .endpoint = "Endpoint",
            .endpoints = "Endpoints",
            .elasticsearch_version = "ElasticsearchVersion",
            .elasticsearch_cluster_config = "ElasticsearchClusterConfig",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .log_publishing_options = "LogPublishingOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .service_software_options = "ServiceSoftwareOptions",
            .vpc_options = "VPCOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoints", field_name))
            return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
        return false;
    }
};

pub const AwsElasticsearchDomainVPCOptions = struct {
    availability_zones: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .security_group_ids = "SecurityGroupIds",
            .subnet_ids = "SubnetIds",
            .vpc_id = "VPCId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainServiceSoftwareOptions = struct {
    automated_update_date: ?[]const u8 = null,
    cancellable: ?bool = null,
    current_version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    new_version: ?[]const u8 = null,
    update_available: ?bool = null,
    update_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_update_date = "AutomatedUpdateDate",
            .cancellable = "Cancellable",
            .current_version = "CurrentVersion",
            .description = "Description",
            .new_version = "NewVersion",
            .update_available = "UpdateAvailable",
            .update_status = "UpdateStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainNodeToNodeEncryptionOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainLogPublishingOptions = struct {
    index_slow_logs: ?AwsElasticsearchDomainLogPublishingOptionsLogConfig = null,
    search_slow_logs: ?AwsElasticsearchDomainLogPublishingOptionsLogConfig = null,
    audit_logs: ?AwsElasticsearchDomainLogPublishingOptionsLogConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_slow_logs = "IndexSlowLogs",
            .search_slow_logs = "SearchSlowLogs",
            .audit_logs = "AuditLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainLogPublishingOptionsLogConfig = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainEncryptionAtRestOptions = struct {
    enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainElasticsearchClusterConfigDetails = struct {
    dedicated_master_count: ?i64 = null,
    dedicated_master_enabled: ?bool = null,
    dedicated_master_type: ?[]const u8 = null,
    instance_count: ?i64 = null,
    instance_type: ?[]const u8 = null,
    zone_awareness_config: ?AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails = null,
    zone_awareness_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dedicated_master_count = "DedicatedMasterCount",
            .dedicated_master_enabled = "DedicatedMasterEnabled",
            .dedicated_master_type = "DedicatedMasterType",
            .instance_count = "InstanceCount",
            .instance_type = "InstanceType",
            .zone_awareness_config = "ZoneAwarenessConfig",
            .zone_awareness_enabled = "ZoneAwarenessEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails = struct {
    availability_zone_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone_count = "AvailabilityZoneCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticsearchDomainDomainEndpointOptions = struct {
    enforce_https: ?bool = null,
    tls_security_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enforce_https = "EnforceHTTPS",
            .tls_security_policy = "TLSSecurityPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentDetails = struct {
    application_name: ?[]const u8 = null,
    cname: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    description: ?[]const u8 = null,
    endpoint_url: ?[]const u8 = null,
    environment_arn: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    environment_links: ?[]AwsElasticBeanstalkEnvironmentEnvironmentLink = null,
    environment_name: ?[]const u8 = null,
    option_settings: ?[]AwsElasticBeanstalkEnvironmentOptionSetting = null,
    platform_arn: ?[]const u8 = null,
    solution_stack_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    tier: ?AwsElasticBeanstalkEnvironmentTier = null,
    version_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_name = "ApplicationName",
            .cname = "Cname",
            .date_created = "DateCreated",
            .date_updated = "DateUpdated",
            .description = "Description",
            .endpoint_url = "EndpointUrl",
            .environment_arn = "EnvironmentArn",
            .environment_id = "EnvironmentId",
            .environment_links = "EnvironmentLinks",
            .environment_name = "EnvironmentName",
            .option_settings = "OptionSettings",
            .platform_arn = "PlatformArn",
            .solution_stack_name = "SolutionStackName",
            .status = "Status",
            .tier = "Tier",
            .version_label = "VersionLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentTier = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentOptionSetting = struct {
    namespace: ?[]const u8 = null,
    option_name: ?[]const u8 = null,
    resource_name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .option_name = "OptionName",
            .resource_name = "ResourceName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElasticBeanstalkEnvironmentEnvironmentLink = struct {
    environment_name: ?[]const u8 = null,
    link_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .environment_name = "EnvironmentName",
            .link_name = "LinkName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbv2LoadBalancerDetails = struct {
    availability_zones: ?[]AvailabilityZone = null,
    canonical_hosted_zone_id: ?[]const u8 = null,
    created_time: ?[]const u8 = null,
    dns_name: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    scheme: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    state: ?LoadBalancerState = null,
    type: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    load_balancer_attributes: ?[]AwsElbv2LoadBalancerAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zones = "AvailabilityZones",
            .canonical_hosted_zone_id = "CanonicalHostedZoneId",
            .created_time = "CreatedTime",
            .dns_name = "DNSName",
            .ip_address_type = "IpAddressType",
            .scheme = "Scheme",
            .security_groups = "SecurityGroups",
            .state = "State",
            .type = "Type",
            .vpc_id = "VpcId",
            .load_balancer_attributes = "LoadBalancerAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsElbv2LoadBalancerAttribute = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoadBalancerState = struct {
    code: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    zone_name: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .zone_name = "ZoneName",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclDetails = struct {
    is_default: ?bool = null,
    network_acl_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    associations: ?[]AwsEc2NetworkAclAssociation = null,
    entries: ?[]AwsEc2NetworkAclEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_default = "IsDefault",
            .network_acl_id = "NetworkAclId",
            .owner_id = "OwnerId",
            .vpc_id = "VpcId",
            .associations = "Associations",
            .entries = "Entries",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclEntry = struct {
    cidr_block: ?[]const u8 = null,
    egress: ?bool = null,
    icmp_type_code: ?IcmpTypeCode = null,
    ipv6_cidr_block: ?[]const u8 = null,
    port_range: ?PortRangeFromTo = null,
    protocol: ?[]const u8 = null,
    rule_action: ?[]const u8 = null,
    rule_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "CidrBlock",
            .egress = "Egress",
            .icmp_type_code = "IcmpTypeCode",
            .ipv6_cidr_block = "Ipv6CidrBlock",
            .port_range = "PortRange",
            .protocol = "Protocol",
            .rule_action = "RuleAction",
            .rule_number = "RuleNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRangeFromTo = struct {
    from: ?i64 = null,
    to: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from = "From",
            .to = "To",
        };
        return @field(mappings, field_name);
    }
};

pub const IcmpTypeCode = struct {
    code: ?i64 = null,
    type: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkAclAssociation = struct {
    network_acl_association_id: ?[]const u8 = null,
    network_acl_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_acl_association_id = "NetworkAclAssociationId",
            .network_acl_id = "NetworkAclId",
            .subnet_id = "SubnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SubnetDetails = struct {
    assign_ipv6_address_on_creation: ?bool = null,
    availability_zone: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    available_ip_address_count: ?i64 = null,
    cidr_block: ?[]const u8 = null,
    default_for_az: ?bool = null,
    map_public_ip_on_launch: ?bool = null,
    owner_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    subnet_arn: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ipv6_cidr_block_association_set: ?[]Ipv6CidrBlockAssociation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assign_ipv6_address_on_creation = "AssignIpv6AddressOnCreation",
            .availability_zone = "AvailabilityZone",
            .availability_zone_id = "AvailabilityZoneId",
            .available_ip_address_count = "AvailableIpAddressCount",
            .cidr_block = "CidrBlock",
            .default_for_az = "DefaultForAz",
            .map_public_ip_on_launch = "MapPublicIpOnLaunch",
            .owner_id = "OwnerId",
            .state = "State",
            .subnet_arn = "SubnetArn",
            .subnet_id = "SubnetId",
            .vpc_id = "VpcId",
            .ipv6_cidr_block_association_set = "Ipv6CidrBlockAssociationSet",
        };
        return @field(mappings, field_name);
    }
};

pub const Ipv6CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    ipv6_cidr_block: ?[]const u8 = null,
    cidr_block_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .ipv6_cidr_block = "Ipv6CidrBlock",
            .cidr_block_state = "CidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2EipDetails = struct {
    instance_id: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,
    allocation_id: ?[]const u8 = null,
    association_id: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    public_ipv4_pool: ?[]const u8 = null,
    network_border_group: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    network_interface_owner_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .public_ip = "PublicIp",
            .allocation_id = "AllocationId",
            .association_id = "AssociationId",
            .domain = "Domain",
            .public_ipv4_pool = "PublicIpv4Pool",
            .network_border_group = "NetworkBorderGroup",
            .network_interface_id = "NetworkInterfaceId",
            .network_interface_owner_id = "NetworkInterfaceOwnerId",
            .private_ip_address = "PrivateIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VpcDetails = struct {
    cidr_block_association_set: ?[]CidrBlockAssociation = null,
    ipv6_cidr_block_association_set: ?[]Ipv6CidrBlockAssociation = null,
    dhcp_options_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block_association_set = "CidrBlockAssociationSet",
            .ipv6_cidr_block_association_set = "Ipv6CidrBlockAssociationSet",
            .dhcp_options_id = "DhcpOptionsId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const CidrBlockAssociation = struct {
    association_id: ?[]const u8 = null,
    cidr_block: ?[]const u8 = null,
    cidr_block_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .cidr_block = "CidrBlock",
            .cidr_block_state = "CidrBlockState",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VolumeDetails = struct {
    create_time: ?[]const u8 = null,
    device_name: ?[]const u8 = null,
    encrypted: ?bool = null,
    size: ?i64 = null,
    snapshot_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    attachments: ?[]AwsEc2VolumeAttachment = null,
    volume_id: ?[]const u8 = null,
    volume_type: ?[]const u8 = null,
    volume_scan_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .create_time = "CreateTime",
            .device_name = "DeviceName",
            .encrypted = "Encrypted",
            .size = "Size",
            .snapshot_id = "SnapshotId",
            .status = "Status",
            .kms_key_id = "KmsKeyId",
            .attachments = "Attachments",
            .volume_id = "VolumeId",
            .volume_type = "VolumeType",
            .volume_scan_status = "VolumeScanStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2VolumeAttachment = struct {
    attach_time: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    instance_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "AttachTime",
            .delete_on_termination = "DeleteOnTermination",
            .instance_id = "InstanceId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupDetails = struct {
    group_name: ?[]const u8 = null,
    group_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ip_permissions: ?[]AwsEc2SecurityGroupIpPermission = null,
    ip_permissions_egress: ?[]AwsEc2SecurityGroupIpPermission = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .group_id = "GroupId",
            .owner_id = "OwnerId",
            .vpc_id = "VpcId",
            .ip_permissions = "IpPermissions",
            .ip_permissions_egress = "IpPermissionsEgress",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpPermission = struct {
    ip_protocol: ?[]const u8 = null,
    from_port: ?i64 = null,
    to_port: ?i64 = null,
    user_id_group_pairs: ?[]AwsEc2SecurityGroupUserIdGroupPair = null,
    ip_ranges: ?[]AwsEc2SecurityGroupIpRange = null,
    ipv6_ranges: ?[]AwsEc2SecurityGroupIpv6Range = null,
    prefix_list_ids: ?[]AwsEc2SecurityGroupPrefixListId = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_protocol = "IpProtocol",
            .from_port = "FromPort",
            .to_port = "ToPort",
            .user_id_group_pairs = "UserIdGroupPairs",
            .ip_ranges = "IpRanges",
            .ipv6_ranges = "Ipv6Ranges",
            .prefix_list_ids = "PrefixListIds",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupPrefixListId = struct {
    prefix_list_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix_list_id = "PrefixListId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpv6Range = struct {
    cidr_ipv6: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ipv6 = "CidrIpv6",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupIpRange = struct {
    cidr_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_ip = "CidrIp",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2SecurityGroupUserIdGroupPair = struct {
    group_id: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    peering_status: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_peering_connection_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_id = "GroupId",
            .group_name = "GroupName",
            .peering_status = "PeeringStatus",
            .user_id = "UserId",
            .vpc_id = "VpcId",
            .vpc_peering_connection_id = "VpcPeeringConnectionId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceDetails = struct {
    attachment: ?AwsEc2NetworkInterfaceAttachment = null,
    network_interface_id: ?[]const u8 = null,
    security_groups: ?[]AwsEc2NetworkInterfaceSecurityGroup = null,
    source_dest_check: ?bool = null,
    ip_v6_addresses: ?[]AwsEc2NetworkInterfaceIpV6AddressDetail = null,
    private_ip_addresses: ?[]AwsEc2NetworkInterfacePrivateIpAddressDetail = null,
    public_dns_name: ?[]const u8 = null,
    public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .network_interface_id = "NetworkInterfaceId",
            .security_groups = "SecurityGroups",
            .source_dest_check = "SourceDestCheck",
            .ip_v6_addresses = "IpV6Addresses",
            .private_ip_addresses = "PrivateIpAddresses",
            .public_dns_name = "PublicDnsName",
            .public_ip = "PublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfacePrivateIpAddressDetail = struct {
    private_ip_address: ?[]const u8 = null,
    private_dns_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .private_ip_address = "PrivateIpAddress",
            .private_dns_name = "PrivateDnsName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceIpV6AddressDetail = struct {
    ip_v6_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_v6_address = "IpV6Address",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceSecurityGroup = struct {
    group_name: ?[]const u8 = null,
    group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .group_id = "GroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2NetworkInterfaceAttachment = struct {
    attach_time: ?[]const u8 = null,
    attachment_id: ?[]const u8 = null,
    delete_on_termination: ?bool = null,
    device_index: ?i64 = null,
    instance_id: ?[]const u8 = null,
    instance_owner_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attach_time = "AttachTime",
            .attachment_id = "AttachmentId",
            .delete_on_termination = "DeleteOnTermination",
            .device_index = "DeviceIndex",
            .instance_id = "InstanceId",
            .instance_owner_id = "InstanceOwnerId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2InstanceDetails = struct {
    type: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    ip_v4_addresses: ?[][]const u8 = null,
    ip_v6_addresses: ?[][]const u8 = null,
    key_name: ?[]const u8 = null,
    iam_instance_profile_arn: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    launched_at: ?[]const u8 = null,
    network_interfaces: ?[]AwsEc2InstanceNetworkInterfacesDetails = null,
    virtualization_type: ?[]const u8 = null,
    metadata_options: ?AwsEc2InstanceMetadataOptions = null,
    monitoring: ?AwsEc2InstanceMonitoringDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .image_id = "ImageId",
            .ip_v4_addresses = "IpV4Addresses",
            .ip_v6_addresses = "IpV6Addresses",
            .key_name = "KeyName",
            .iam_instance_profile_arn = "IamInstanceProfileArn",
            .vpc_id = "VpcId",
            .subnet_id = "SubnetId",
            .launched_at = "LaunchedAt",
            .network_interfaces = "NetworkInterfaces",
            .virtualization_type = "VirtualizationType",
            .metadata_options = "MetadataOptions",
            .monitoring = "Monitoring",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2InstanceMonitoringDetails = struct {
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2InstanceMetadataOptions = struct {
    http_endpoint: ?[]const u8 = null,
    http_protocol_ipv6: ?[]const u8 = null,
    http_put_response_hop_limit: ?i64 = null,
    http_tokens: ?[]const u8 = null,
    instance_metadata_tags: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_endpoint = "HttpEndpoint",
            .http_protocol_ipv6 = "HttpProtocolIpv6",
            .http_put_response_hop_limit = "HttpPutResponseHopLimit",
            .http_tokens = "HttpTokens",
            .instance_metadata_tags = "InstanceMetadataTags",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsEc2InstanceNetworkInterfacesDetails = struct {
    network_interface_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_id = "NetworkInterfaceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionDetails = struct {
    cache_behaviors: ?AwsCloudFrontDistributionCacheBehaviors = null,
    default_cache_behavior: ?AwsCloudFrontDistributionDefaultCacheBehavior = null,
    default_root_object: ?[]const u8 = null,
    domain_name: ?[]const u8 = null,
    e_tag: ?[]const u8 = null,
    last_modified_time: ?[]const u8 = null,
    logging: ?AwsCloudFrontDistributionLogging = null,
    origins: ?AwsCloudFrontDistributionOrigins = null,
    origin_groups: ?AwsCloudFrontDistributionOriginGroups = null,
    viewer_certificate: ?AwsCloudFrontDistributionViewerCertificate = null,
    status: ?[]const u8 = null,
    web_acl_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_behaviors = "CacheBehaviors",
            .default_cache_behavior = "DefaultCacheBehavior",
            .default_root_object = "DefaultRootObject",
            .domain_name = "DomainName",
            .e_tag = "ETag",
            .last_modified_time = "LastModifiedTime",
            .logging = "Logging",
            .origins = "Origins",
            .origin_groups = "OriginGroups",
            .viewer_certificate = "ViewerCertificate",
            .status = "Status",
            .web_acl_id = "WebAclId",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionViewerCertificate = struct {
    acm_certificate_arn: ?[]const u8 = null,
    certificate: ?[]const u8 = null,
    certificate_source: ?[]const u8 = null,
    cloud_front_default_certificate: ?bool = null,
    iam_certificate_id: ?[]const u8 = null,
    minimum_protocol_version: ?[]const u8 = null,
    ssl_support_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acm_certificate_arn = "AcmCertificateArn",
            .certificate = "Certificate",
            .certificate_source = "CertificateSource",
            .cloud_front_default_certificate = "CloudFrontDefaultCertificate",
            .iam_certificate_id = "IamCertificateId",
            .minimum_protocol_version = "MinimumProtocolVersion",
            .ssl_support_method = "SslSupportMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroups = struct {
    items: ?[]AwsCloudFrontDistributionOriginGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroup = struct {
    failover_criteria: ?AwsCloudFrontDistributionOriginGroupFailover = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_criteria = "FailoverCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroupFailover = struct {
    status_codes: ?AwsCloudFrontDistributionOriginGroupFailoverStatusCodes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_codes = "StatusCodes",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginGroupFailoverStatusCodes = struct {
    items: ?[]i64 = null,
    quantity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
            .quantity = "Quantity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOrigins = struct {
    items: ?[]AwsCloudFrontDistributionOriginItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginItem = struct {
    domain_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    origin_path: ?[]const u8 = null,
    s3_origin_config: ?AwsCloudFrontDistributionOriginS3OriginConfig = null,
    custom_origin_config: ?AwsCloudFrontDistributionOriginCustomOriginConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .id = "Id",
            .origin_path = "OriginPath",
            .s3_origin_config = "S3OriginConfig",
            .custom_origin_config = "CustomOriginConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginCustomOriginConfig = struct {
    http_port: ?i64 = null,
    https_port: ?i64 = null,
    origin_keepalive_timeout: ?i64 = null,
    origin_protocol_policy: ?[]const u8 = null,
    origin_read_timeout: ?i64 = null,
    origin_ssl_protocols: ?AwsCloudFrontDistributionOriginSslProtocols = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_port = "HttpPort",
            .https_port = "HttpsPort",
            .origin_keepalive_timeout = "OriginKeepaliveTimeout",
            .origin_protocol_policy = "OriginProtocolPolicy",
            .origin_read_timeout = "OriginReadTimeout",
            .origin_ssl_protocols = "OriginSslProtocols",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginSslProtocols = struct {
    items: ?[][]const u8 = null,
    quantity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
            .quantity = "Quantity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionOriginS3OriginConfig = struct {
    origin_access_identity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .origin_access_identity = "OriginAccessIdentity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionLogging = struct {
    bucket: ?[]const u8 = null,
    enabled: ?bool = null,
    include_cookies: ?bool = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .enabled = "Enabled",
            .include_cookies = "IncludeCookies",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionDefaultCacheBehavior = struct {
    viewer_protocol_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .viewer_protocol_policy = "ViewerProtocolPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionCacheBehaviors = struct {
    items: ?[]AwsCloudFrontDistributionCacheBehavior = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .items = "Items",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCloudFrontDistributionCacheBehavior = struct {
    viewer_protocol_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .viewer_protocol_policy = "ViewerProtocolPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectDetails = struct {
    encryption_key: ?[]const u8 = null,
    artifacts: ?[]AwsCodeBuildProjectArtifactsDetails = null,
    environment: ?AwsCodeBuildProjectEnvironment = null,
    name: ?[]const u8 = null,
    source: ?AwsCodeBuildProjectSource = null,
    service_role: ?[]const u8 = null,
    logs_config: ?AwsCodeBuildProjectLogsConfigDetails = null,
    vpc_config: ?AwsCodeBuildProjectVpcConfig = null,
    secondary_artifacts: ?[]AwsCodeBuildProjectArtifactsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_key = "EncryptionKey",
            .artifacts = "Artifacts",
            .environment = "Environment",
            .name = "Name",
            .source = "Source",
            .service_role = "ServiceRole",
            .logs_config = "LogsConfig",
            .vpc_config = "VpcConfig",
            .secondary_artifacts = "SecondaryArtifacts",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectArtifactsDetails = struct {
    artifact_identifier: ?[]const u8 = null,
    encryption_disabled: ?bool = null,
    location: ?[]const u8 = null,
    name: ?[]const u8 = null,
    namespace_type: ?[]const u8 = null,
    override_artifact_name: ?bool = null,
    packaging: ?[]const u8 = null,
    path: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .artifact_identifier = "ArtifactIdentifier",
            .encryption_disabled = "EncryptionDisabled",
            .location = "Location",
            .name = "Name",
            .namespace_type = "NamespaceType",
            .override_artifact_name = "OverrideArtifactName",
            .packaging = "Packaging",
            .path = "Path",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectVpcConfig = struct {
    vpc_id: ?[]const u8 = null,
    subnets: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnets = "Subnets",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectLogsConfigDetails = struct {
    cloud_watch_logs: ?AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails = null,
    s3_logs: ?AwsCodeBuildProjectLogsConfigS3LogsDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs = "CloudWatchLogs",
            .s3_logs = "S3Logs",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectLogsConfigS3LogsDetails = struct {
    encryption_disabled: ?bool = null,
    location: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_disabled = "EncryptionDisabled",
            .location = "Location",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectLogsConfigCloudWatchLogsDetails = struct {
    group_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    stream_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .status = "Status",
            .stream_name = "StreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectSource = struct {
    type: ?[]const u8 = null,
    location: ?[]const u8 = null,
    git_clone_depth: ?i64 = null,
    insecure_ssl: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .location = "Location",
            .git_clone_depth = "GitCloneDepth",
            .insecure_ssl = "InsecureSsl",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectEnvironment = struct {
    certificate: ?[]const u8 = null,
    environment_variables: ?[]AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails = null,
    privileged_mode: ?bool = null,
    image_pull_credentials_type: ?[]const u8 = null,
    registry_credential: ?AwsCodeBuildProjectEnvironmentRegistryCredential = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate = "Certificate",
            .environment_variables = "EnvironmentVariables",
            .privileged_mode = "PrivilegedMode",
            .image_pull_credentials_type = "ImagePullCredentialsType",
            .registry_credential = "RegistryCredential",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectEnvironmentRegistryCredential = struct {
    credential: ?[]const u8 = null,
    credential_provider: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credential = "Credential",
            .credential_provider = "CredentialProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetails = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupDetails = struct {
    launch_configuration_name: ?[]const u8 = null,
    load_balancer_names: ?[][]const u8 = null,
    health_check_type: ?[]const u8 = null,
    health_check_grace_period: ?i64 = null,
    created_time: ?[]const u8 = null,
    mixed_instances_policy: ?AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails = null,
    availability_zones: ?[]AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails = null,
    launch_template: ?AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification = null,
    capacity_rebalance: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_configuration_name = "LaunchConfigurationName",
            .load_balancer_names = "LoadBalancerNames",
            .health_check_type = "HealthCheckType",
            .health_check_grace_period = "HealthCheckGracePeriod",
            .created_time = "CreatedTime",
            .mixed_instances_policy = "MixedInstancesPolicy",
            .availability_zones = "AvailabilityZones",
            .launch_template = "LaunchTemplate",
            .capacity_rebalance = "CapacityRebalance",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "LaunchTemplateId",
            .launch_template_name = "LaunchTemplateName",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetails = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetails = struct {
    instances_distribution: ?AwsAutoScalingAutoScalingGroupMixedInstancesPolicyInstancesDistributionDetails = null,
    launch_template: ?AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instances_distribution = "InstancesDistribution",
            .launch_template = "LaunchTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateDetails = struct {
    launch_template_specification: ?AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification = null,
    overrides: ?[]AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_specification = "LaunchTemplateSpecification",
            .overrides = "Overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetails = struct {
    instance_type: ?[]const u8 = null,
    weighted_capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .weighted_capacity = "WeightedCapacity",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "LaunchTemplateId",
            .launch_template_name = "LaunchTemplateName",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsAutoScalingAutoScalingGroupMixedInstancesPolicyInstancesDistributionDetails = struct {
    on_demand_allocation_strategy: ?[]const u8 = null,
    on_demand_base_capacity: ?i64 = null,
    on_demand_percentage_above_base_capacity: ?i64 = null,
    spot_allocation_strategy: ?[]const u8 = null,
    spot_instance_pools: ?i64 = null,
    spot_max_price: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_demand_allocation_strategy = "OnDemandAllocationStrategy",
            .on_demand_base_capacity = "OnDemandBaseCapacity",
            .on_demand_percentage_above_base_capacity = "OnDemandPercentageAboveBaseCapacity",
            .spot_allocation_strategy = "SpotAllocationStrategy",
            .spot_instance_pools = "SpotInstancePools",
            .spot_max_price = "SpotMaxPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const DataClassificationDetails = struct {
    detailed_results_location: ?[]const u8 = null,
    result: ?ClassificationResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detailed_results_location = "DetailedResultsLocation",
            .result = "Result",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationResult = struct {
    mime_type: ?[]const u8 = null,
    size_classified: ?i64 = null,
    additional_occurrences: ?bool = null,
    status: ?ClassificationStatus = null,
    sensitive_data: ?[]SensitiveDataResult = null,
    custom_data_identifiers: ?CustomDataIdentifiersResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mime_type = "MimeType",
            .size_classified = "SizeClassified",
            .additional_occurrences = "AdditionalOccurrences",
            .status = "Status",
            .sensitive_data = "SensitiveData",
            .custom_data_identifiers = "CustomDataIdentifiers",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDataIdentifiersResult = struct {
    detections: ?[]CustomDataIdentifiersDetections = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detections = "Detections",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomDataIdentifiersDetections = struct {
    count: ?i64 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    occurrences: ?Occurrences = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .arn = "Arn",
            .name = "Name",
            .occurrences = "Occurrences",
        };
        return @field(mappings, field_name);
    }
};

pub const Occurrences = struct {
    line_ranges: ?[]Range = null,
    offset_ranges: ?[]Range = null,
    pages: ?[]Page = null,
    records: ?[]Record = null,
    cells: ?[]Cell = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_ranges = "LineRanges",
            .offset_ranges = "OffsetRanges",
            .pages = "Pages",
            .records = "Records",
            .cells = "Cells",
        };
        return @field(mappings, field_name);
    }
};

pub const Cell = struct {
    column: ?i64 = null,
    row: ?i64 = null,
    column_name: ?[]const u8 = null,
    cell_reference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .row = "Row",
            .column_name = "ColumnName",
            .cell_reference = "CellReference",
        };
        return @field(mappings, field_name);
    }
};

pub const Record = struct {
    json_path: ?[]const u8 = null,
    record_index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_path = "JsonPath",
            .record_index = "RecordIndex",
        };
        return @field(mappings, field_name);
    }
};

pub const Page = struct {
    page_number: ?i64 = null,
    line_range: ?Range = null,
    offset_range: ?Range = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_number = "PageNumber",
            .line_range = "LineRange",
            .offset_range = "OffsetRange",
        };
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    start: ?i64 = null,
    end: ?i64 = null,
    start_column: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start = "Start",
            .end = "End",
            .start_column = "StartColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitiveDataResult = struct {
    category: ?[]const u8 = null,
    detections: ?[]SensitiveDataDetections = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .detections = "Detections",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitiveDataDetections = struct {
    count: ?i64 = null,
    type: ?[]const u8 = null,
    occurrences: ?Occurrences = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .type = "Type",
            .occurrences = "Occurrences",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationStatus = struct {
    code: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ThreatIntelIndicator = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    category: ?[]const u8 = null,
    last_observed_at: ?[]const u8 = null,
    source: ?[]const u8 = null,
    source_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
            .category = "Category",
            .last_observed_at = "LastObservedAt",
            .source = "Source",
            .source_url = "SourceUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Threat = struct {
    name: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    item_count: ?i64 = null,
    file_paths: ?[]FilePaths = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .severity = "Severity",
            .item_count = "ItemCount",
            .file_paths = "FilePaths",
        };
        return @field(mappings, field_name);
    }
};

pub const FilePaths = struct {
    file_path: ?[]const u8 = null,
    file_name: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    hash: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_path = "FilePath",
            .file_name = "FileName",
            .resource_id = "ResourceId",
            .hash = "Hash",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessDetails = struct {
    name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    pid: ?i64 = null,
    parent_pid: ?i64 = null,
    launched_at: ?[]const u8 = null,
    terminated_at: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .path = "Path",
            .pid = "Pid",
            .parent_pid = "ParentPid",
            .launched_at = "LaunchedAt",
            .terminated_at = "TerminatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkPathComponent = struct {
    component_id: ?[]const u8 = null,
    component_type: ?[]const u8 = null,
    egress: ?NetworkHeader = null,
    ingress: ?NetworkHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_id = "ComponentId",
            .component_type = "ComponentType",
            .egress = "Egress",
            .ingress = "Ingress",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkHeader = struct {
    protocol: ?[]const u8 = null,
    destination: ?NetworkPathComponentDetails = null,
    source: ?NetworkPathComponentDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .destination = "Destination",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkPathComponentDetails = struct {
    address: ?[][]const u8 = null,
    port_ranges: ?[]PortRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port_ranges = "PortRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    begin: ?i64 = null,
    end: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin = "Begin",
            .end = "End",
        };
        return @field(mappings, field_name);
    }
};

pub const Network = struct {
    direction: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    open_port_range: ?PortRange = null,
    source_ip_v4: ?[]const u8 = null,
    source_ip_v6: ?[]const u8 = null,
    source_port: ?i64 = null,
    source_domain: ?[]const u8 = null,
    source_mac: ?[]const u8 = null,
    destination_ip_v4: ?[]const u8 = null,
    destination_ip_v6: ?[]const u8 = null,
    destination_port: ?i64 = null,
    destination_domain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .direction = "Direction",
            .protocol = "Protocol",
            .open_port_range = "OpenPortRange",
            .source_ip_v4 = "SourceIpV4",
            .source_ip_v6 = "SourceIpV6",
            .source_port = "SourcePort",
            .source_domain = "SourceDomain",
            .source_mac = "SourceMac",
            .destination_ip_v4 = "DestinationIpV4",
            .destination_ip_v6 = "DestinationIpV6",
            .destination_port = "DestinationPort",
            .destination_domain = "DestinationDomain",
        };
        return @field(mappings, field_name);
    }
};

pub const Malware = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    path: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .path = "Path",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const Remediation = struct {
    recommendation: ?Recommendation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recommendation = "Recommendation",
        };
        return @field(mappings, field_name);
    }
};

pub const Recommendation = struct {
    text: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const Severity = struct {
    product: ?f64 = null,
    label: ?[]const u8 = null,
    normalized: ?i64 = null,
    original: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product = "Product",
            .label = "Label",
            .normalized = "Normalized",
            .original = "Original",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsSecurityFindingIdentifier = struct {
    id: []const u8,
    product_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .product_arn = "ProductArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StandardsSubscription = struct {
    standards_subscription_arn: []const u8,
    standards_arn: []const u8,
    standards_input: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    standards_status: []const u8,
    standards_status_reason: ?StandardsStatusReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standards_subscription_arn = "StandardsSubscriptionArn",
            .standards_arn = "StandardsArn",
            .standards_input = "StandardsInput",
            .standards_status = "StandardsStatus",
            .standards_status_reason = "StandardsStatusReason",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "standards_input", field_name))
            return try serializeMap(self.standards_input, self.fieldNameFor("standards_input"), options, out_stream);
        return false;
    }
};

pub const StandardsStatusReason = struct {
    status_reason_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_reason_code = "StatusReasonCode",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomationRulesAction = struct {
    type: ?[]const u8 = null,
    finding_fields_update: ?AutomationRulesFindingFieldsUpdate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .finding_fields_update = "FindingFieldsUpdate",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomationRulesFindingFieldsUpdate = struct {
    note: ?NoteUpdate = null,
    severity: ?SeverityUpdate = null,
    verification_state: ?[]const u8 = null,
    confidence: ?i64 = null,
    criticality: ?i64 = null,
    types: ?[][]const u8 = null,
    user_defined_fields: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    workflow: ?WorkflowUpdate = null,
    related_findings: ?[]RelatedFinding = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .note = "Note",
            .severity = "Severity",
            .verification_state = "VerificationState",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .types = "Types",
            .user_defined_fields = "UserDefinedFields",
            .workflow = "Workflow",
            .related_findings = "RelatedFindings",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_defined_fields", field_name))
            return try serializeMap(self.user_defined_fields, self.fieldNameFor("user_defined_fields"), options, out_stream);
        return false;
    }
};

pub const WorkflowUpdate = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SeverityUpdate = struct {
    normalized: ?i64 = null,
    product: ?f64 = null,
    label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .normalized = "Normalized",
            .product = "Product",
            .label = "Label",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomationRulesFindingFilters = struct {
    product_arn: ?[]StringFilter = null,
    aws_account_id: ?[]StringFilter = null,
    id: ?[]StringFilter = null,
    generator_id: ?[]StringFilter = null,
    type: ?[]StringFilter = null,
    first_observed_at: ?[]DateFilter = null,
    last_observed_at: ?[]DateFilter = null,
    created_at: ?[]DateFilter = null,
    updated_at: ?[]DateFilter = null,
    confidence: ?[]NumberFilter = null,
    criticality: ?[]NumberFilter = null,
    title: ?[]StringFilter = null,
    description: ?[]StringFilter = null,
    source_url: ?[]StringFilter = null,
    product_name: ?[]StringFilter = null,
    company_name: ?[]StringFilter = null,
    severity_label: ?[]StringFilter = null,
    resource_type: ?[]StringFilter = null,
    resource_id: ?[]StringFilter = null,
    resource_partition: ?[]StringFilter = null,
    resource_region: ?[]StringFilter = null,
    resource_tags: ?[]MapFilter = null,
    resource_details_other: ?[]MapFilter = null,
    compliance_status: ?[]StringFilter = null,
    compliance_security_control_id: ?[]StringFilter = null,
    compliance_associated_standards_id: ?[]StringFilter = null,
    verification_state: ?[]StringFilter = null,
    workflow_status: ?[]StringFilter = null,
    record_state: ?[]StringFilter = null,
    related_findings_product_arn: ?[]StringFilter = null,
    related_findings_id: ?[]StringFilter = null,
    note_text: ?[]StringFilter = null,
    note_updated_at: ?[]DateFilter = null,
    note_updated_by: ?[]StringFilter = null,
    user_defined_fields: ?[]MapFilter = null,
    resource_application_arn: ?[]StringFilter = null,
    resource_application_name: ?[]StringFilter = null,
    aws_account_name: ?[]StringFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_arn = "ProductArn",
            .aws_account_id = "AwsAccountId",
            .id = "Id",
            .generator_id = "GeneratorId",
            .type = "Type",
            .first_observed_at = "FirstObservedAt",
            .last_observed_at = "LastObservedAt",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .confidence = "Confidence",
            .criticality = "Criticality",
            .title = "Title",
            .description = "Description",
            .source_url = "SourceUrl",
            .product_name = "ProductName",
            .company_name = "CompanyName",
            .severity_label = "SeverityLabel",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .resource_partition = "ResourcePartition",
            .resource_region = "ResourceRegion",
            .resource_tags = "ResourceTags",
            .resource_details_other = "ResourceDetailsOther",
            .compliance_status = "ComplianceStatus",
            .compliance_security_control_id = "ComplianceSecurityControlId",
            .compliance_associated_standards_id = "ComplianceAssociatedStandardsId",
            .verification_state = "VerificationState",
            .workflow_status = "WorkflowStatus",
            .record_state = "RecordState",
            .related_findings_product_arn = "RelatedFindingsProductArn",
            .related_findings_id = "RelatedFindingsId",
            .note_text = "NoteText",
            .note_updated_at = "NoteUpdatedAt",
            .note_updated_by = "NoteUpdatedBy",
            .user_defined_fields = "UserDefinedFields",
            .resource_application_arn = "ResourceApplicationArn",
            .resource_application_name = "ResourceApplicationName",
            .aws_account_name = "AwsAccountName",
        };
        return @field(mappings, field_name);
    }
};

pub const StandardsControlAssociationUpdate = struct {
    standards_arn: []const u8,
    security_control_id: []const u8,
    association_status: []const u8,
    updated_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standards_arn = "StandardsArn",
            .security_control_id = "SecurityControlId",
            .association_status = "AssociationStatus",
            .updated_reason = "UpdatedReason",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedAutomationRule = struct {
    rule_arn: ?[]const u8 = null,
    error_code: ?i64 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_arn = "RuleArn",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const StandardsControlAssociationId = struct {
    security_control_id: []const u8,
    standards_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_control_id = "SecurityControlId",
            .standards_arn = "StandardsArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationPolicyAssociation = struct {
    target: ?Target = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target = "Target",
        };
        return @field(mappings, field_name);
    }
};
