const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-11-06";
pub const sdk_id: []const u8 = "SSM";
pub const arn_namespace: ?[]const u8 = "ssm";
pub const endpoint_prefix: []const u8 = "ssm";
pub const sigv4_name: []const u8 = "ssm";
pub const name: []const u8 = "AmazonSSM";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-11-06",
    sdk_id: []const u8 = "SSM",
    arn_namespace: ?[]const u8 = "ssm",
    endpoint_prefix: []const u8 = "ssm",
    sigv4_name: []const u8 = "ssm",
    name: []const u8 = "AmazonSSM",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidResourceId,
        InvalidResourceType,
        TooManyTagsError,
        TooManyUpdates,
    },
} = .{};
pub const associate_ops_item_related_item: struct {
    action_name: []const u8 = "AssociateOpsItemRelatedItem",
    Request: type = struct {
        ops_item_id: []const u8,
        association_type: []const u8,
        resource_type: []const u8,
        resource_uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
                .association_type = "AssociationType",
                .resource_type = "ResourceType",
                .resource_uri = "ResourceUri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_ops_item_related_item) } {
            return .{ .service_metadata = service_metadata, .action = associate_ops_item_related_item };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemConflict,
        OpsItemInvalidParameter,
        OpsItemLimitExceeded,
        OpsItemNotFound,
        OpsItemRelatedItemAlreadyExists,
    },
} = .{};
pub const cancel_command: struct {
    action_name: []const u8 = "CancelCommand",
    Request: type = struct {
        command_id: []const u8,
        instance_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_id = "CommandId",
                .instance_ids = "InstanceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_command) } {
            return .{ .service_metadata = service_metadata, .action = cancel_command };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateInstanceId,
        InternalServerError,
        InvalidCommandId,
        InvalidInstanceId,
    },
} = .{};
pub const cancel_maintenance_window_execution: struct {
    action_name: []const u8 = "CancelMaintenanceWindowExecution",
    Request: type = struct {
        window_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_maintenance_window_execution) } {
            return .{ .service_metadata = service_metadata, .action = cancel_maintenance_window_execution };
        }
    },
    Response: type = struct {
        window_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const create_activation: struct {
    action_name: []const u8 = "CreateActivation",
    Request: type = struct {
        description: ?[]const u8 = null,
        default_instance_name: ?[]const u8 = null,
        iam_role: []const u8,
        registration_limit: ?i64 = null,
        expiration_date: ?i64 = null,
        tags: ?[]Tag = null,
        registration_metadata: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .default_instance_name = "DefaultInstanceName",
                .iam_role = "IamRole",
                .registration_limit = "RegistrationLimit",
                .expiration_date = "ExpirationDate",
                .tags = "Tags",
                .registration_metadata = "RegistrationMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_activation) } {
            return .{ .service_metadata = service_metadata, .action = create_activation };
        }
    },
    Response: type = struct {
        activation_id: ?[]const u8 = null,
        activation_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_id = "ActivationId",
                .activation_code = "ActivationCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidParameters,
    },
} = .{};
pub const create_association: struct {
    action_name: []const u8 = "CreateAssociation",
    Request: type = struct {
        name: []const u8,
        document_version: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        targets: ?[]Target = null,
        schedule_expression: ?[]const u8 = null,
        output_location: ?InstanceAssociationOutputLocation = null,
        association_name: ?[]const u8 = null,
        automation_target_parameter_name: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        max_concurrency: ?[]const u8 = null,
        compliance_severity: ?[]const u8 = null,
        sync_compliance: ?[]const u8 = null,
        apply_only_at_cron_interval: ?bool = null,
        calendar_names: ?[][]const u8 = null,
        target_locations: ?[]TargetLocation = null,
        schedule_offset: ?i64 = null,
        duration: ?i64 = null,
        target_maps: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        tags: ?[]Tag = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .instance_id = "InstanceId",
                .parameters = "Parameters",
                .targets = "Targets",
                .schedule_expression = "ScheduleExpression",
                .output_location = "OutputLocation",
                .association_name = "AssociationName",
                .automation_target_parameter_name = "AutomationTargetParameterName",
                .max_errors = "MaxErrors",
                .max_concurrency = "MaxConcurrency",
                .compliance_severity = "ComplianceSeverity",
                .sync_compliance = "SyncCompliance",
                .apply_only_at_cron_interval = "ApplyOnlyAtCronInterval",
                .calendar_names = "CalendarNames",
                .target_locations = "TargetLocations",
                .schedule_offset = "ScheduleOffset",
                .duration = "Duration",
                .target_maps = "TargetMaps",
                .tags = "Tags",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "target_maps", field_name))
                return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_association) } {
            return .{ .service_metadata = service_metadata, .action = create_association };
        }
    },
    Response: type = struct {
        association_description: ?AssociationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_description = "AssociationDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationAlreadyExists,
        AssociationLimitExceeded,
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
        InvalidInstanceId,
        InvalidOutputLocation,
        InvalidParameters,
        InvalidSchedule,
        InvalidTag,
        InvalidTarget,
        InvalidTargetMaps,
        UnsupportedPlatformType,
    },
} = .{};
pub const create_association_batch: struct {
    action_name: []const u8 = "CreateAssociationBatch",
    Request: type = struct {
        entries: []CreateAssociationBatchRequestEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_association_batch) } {
            return .{ .service_metadata = service_metadata, .action = create_association_batch };
        }
    },
    Response: type = struct {
        successful: ?[]AssociationDescription = null,
        failed: ?[]struct {
            entry: ?CreateAssociationBatchRequestEntry = null,
            message: ?[]const u8 = null,
            fault: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry = "Entry",
                    .message = "Message",
                    .fault = "Fault",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "Successful",
                .failed = "Failed",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationLimitExceeded,
        DuplicateInstanceId,
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
        InvalidInstanceId,
        InvalidOutputLocation,
        InvalidParameters,
        InvalidSchedule,
        InvalidTarget,
        InvalidTargetMaps,
        UnsupportedPlatformType,
    },
} = .{};
pub const create_document: struct {
    action_name: []const u8 = "CreateDocument",
    Request: type = struct {
        content: []const u8,
        requires: ?[]DocumentRequires = null,
        attachments: ?[]AttachmentsSource = null,
        name: []const u8,
        display_name: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        document_type: ?[]const u8 = null,
        document_format: ?[]const u8 = null,
        target_type: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .requires = "Requires",
                .attachments = "Attachments",
                .name = "Name",
                .display_name = "DisplayName",
                .version_name = "VersionName",
                .document_type = "DocumentType",
                .document_format = "DocumentFormat",
                .target_type = "TargetType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_document) } {
            return .{ .service_metadata = service_metadata, .action = create_document };
        }
    },
    Response: type = struct {
        document_description: ?DocumentDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_description = "DocumentDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DocumentAlreadyExists,
        DocumentLimitExceeded,
        InternalServerError,
        InvalidDocumentContent,
        InvalidDocumentSchemaVersion,
        MaxDocumentSizeExceeded,
    },
} = .{};
pub const create_maintenance_window: struct {
    action_name: []const u8 = "CreateMaintenanceWindow",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        schedule: []const u8,
        schedule_timezone: ?[]const u8 = null,
        schedule_offset: ?i64 = null,
        duration: i64,
        cutoff: i64,
        allow_unassociated_targets: bool,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .schedule = "Schedule",
                .schedule_timezone = "ScheduleTimezone",
                .schedule_offset = "ScheduleOffset",
                .duration = "Duration",
                .cutoff = "Cutoff",
                .allow_unassociated_targets = "AllowUnassociatedTargets",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = create_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServerError,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_ops_item: struct {
    action_name: []const u8 = "CreateOpsItem",
    Request: type = struct {
        description: []const u8,
        ops_item_type: ?[]const u8 = null,
        operational_data: ?[]struct {
            key: ?[]const u8 = null,
            value: ?OpsItemDataValue = null,
        } = null,
        notifications: ?[]OpsItemNotification = null,
        priority: ?i64 = null,
        related_ops_items: ?[]RelatedOpsItem = null,
        source: []const u8,
        title: []const u8,
        tags: ?[]Tag = null,
        category: ?[]const u8 = null,
        severity: ?[]const u8 = null,
        actual_start_time: ?i64 = null,
        actual_end_time: ?i64 = null,
        planned_start_time: ?i64 = null,
        planned_end_time: ?i64 = null,
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .ops_item_type = "OpsItemType",
                .operational_data = "OperationalData",
                .notifications = "Notifications",
                .priority = "Priority",
                .related_ops_items = "RelatedOpsItems",
                .source = "Source",
                .title = "Title",
                .tags = "Tags",
                .category = "Category",
                .severity = "Severity",
                .actual_start_time = "ActualStartTime",
                .actual_end_time = "ActualEndTime",
                .planned_start_time = "PlannedStartTime",
                .planned_end_time = "PlannedEndTime",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "operational_data", field_name))
                return try serializeMap(self.operational_data, self.fieldNameFor("operational_data"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ops_item) } {
            return .{ .service_metadata = service_metadata, .action = create_ops_item };
        }
    },
    Response: type = struct {
        ops_item_id: ?[]const u8 = null,
        ops_item_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
                .ops_item_arn = "OpsItemArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemAccessDenied,
        OpsItemAlreadyExists,
        OpsItemInvalidParameter,
        OpsItemLimitExceeded,
    },
} = .{};
pub const create_ops_metadata: struct {
    action_name: []const u8 = "CreateOpsMetadata",
    Request: type = struct {
        resource_id: []const u8,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MetadataValue = null,
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .metadata = "Metadata",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ops_metadata) } {
            return .{ .service_metadata = service_metadata, .action = create_ops_metadata };
        }
    },
    Response: type = struct {
        ops_metadata_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_arn = "OpsMetadataArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsMetadataAlreadyExists,
        OpsMetadataInvalidArgument,
        OpsMetadataLimitExceeded,
        OpsMetadataTooManyUpdates,
    },
} = .{};
pub const create_patch_baseline: struct {
    action_name: []const u8 = "CreatePatchBaseline",
    Request: type = struct {
        operating_system: ?[]const u8 = null,
        name: []const u8,
        global_filters: ?PatchFilterGroup = null,
        approval_rules: ?PatchRuleGroup = null,
        approved_patches: ?[][]const u8 = null,
        approved_patches_compliance_level: ?[]const u8 = null,
        approved_patches_enable_non_security: ?bool = null,
        rejected_patches: ?[][]const u8 = null,
        rejected_patches_action: ?[]const u8 = null,
        description: ?[]const u8 = null,
        sources: ?[]PatchSource = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operating_system = "OperatingSystem",
                .name = "Name",
                .global_filters = "GlobalFilters",
                .approval_rules = "ApprovalRules",
                .approved_patches = "ApprovedPatches",
                .approved_patches_compliance_level = "ApprovedPatchesComplianceLevel",
                .approved_patches_enable_non_security = "ApprovedPatchesEnableNonSecurity",
                .rejected_patches = "RejectedPatches",
                .rejected_patches_action = "RejectedPatchesAction",
                .description = "Description",
                .sources = "Sources",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = create_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServerError,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_resource_data_sync: struct {
    action_name: []const u8 = "CreateResourceDataSync",
    Request: type = struct {
        sync_name: []const u8,
        s3_destination: ?ResourceDataSyncS3Destination = null,
        sync_type: ?[]const u8 = null,
        sync_source: ?ResourceDataSyncSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_name = "SyncName",
                .s3_destination = "S3Destination",
                .sync_type = "SyncType",
                .sync_source = "SyncSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_data_sync) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_data_sync };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceDataSyncAlreadyExists,
        ResourceDataSyncCountExceeded,
        ResourceDataSyncInvalidConfiguration,
    },
} = .{};
pub const delete_activation: struct {
    action_name: []const u8 = "DeleteActivation",
    Request: type = struct {
        activation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_id = "ActivationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_activation) } {
            return .{ .service_metadata = service_metadata, .action = delete_activation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidActivation,
        InvalidActivationId,
        TooManyUpdates,
    },
} = .{};
pub const delete_association: struct {
    action_name: []const u8 = "DeleteAssociation",
    Request: type = struct {
        name: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_association };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InternalServerError,
        InvalidDocument,
        InvalidInstanceId,
        TooManyUpdates,
    },
} = .{};
pub const delete_document: struct {
    action_name: []const u8 = "DeleteDocument",
    Request: type = struct {
        name: []const u8,
        document_version: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .version_name = "VersionName",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_document) } {
            return .{ .service_metadata = service_metadata, .action = delete_document };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociatedInstances,
        InternalServerError,
        InvalidDocument,
        InvalidDocumentOperation,
    },
} = .{};
pub const delete_inventory: struct {
    action_name: []const u8 = "DeleteInventory",
    Request: type = struct {
        type_name: []const u8,
        schema_delete_option: ?[]const u8 = null,
        dry_run: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .schema_delete_option = "SchemaDeleteOption",
                .dry_run = "DryRun",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inventory) } {
            return .{ .service_metadata = service_metadata, .action = delete_inventory };
        }
    },
    Response: type = struct {
        deletion_id: ?[]const u8 = null,
        type_name: ?[]const u8 = null,
        deletion_summary: ?InventoryDeletionSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deletion_id = "DeletionId",
                .type_name = "TypeName",
                .deletion_summary = "DeletionSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDeleteInventoryParameters,
        InvalidInventoryRequest,
        InvalidOption,
        InvalidTypeName,
    },
} = .{};
pub const delete_maintenance_window: struct {
    action_name: []const u8 = "DeleteMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = delete_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const delete_ops_item: struct {
    action_name: []const u8 = "DeleteOpsItem",
    Request: type = struct {
        ops_item_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ops_item) } {
            return .{ .service_metadata = service_metadata, .action = delete_ops_item };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemInvalidParameter,
    },
} = .{};
pub const delete_ops_metadata: struct {
    action_name: []const u8 = "DeleteOpsMetadata",
    Request: type = struct {
        ops_metadata_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_arn = "OpsMetadataArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ops_metadata) } {
            return .{ .service_metadata = service_metadata, .action = delete_ops_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsMetadataInvalidArgument,
        OpsMetadataNotFound,
    },
} = .{};
pub const delete_parameter: struct {
    action_name: []const u8 = "DeleteParameter",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_parameter) } {
            return .{ .service_metadata = service_metadata, .action = delete_parameter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ParameterNotFound,
    },
} = .{};
pub const delete_parameters: struct {
    action_name: []const u8 = "DeleteParameters",
    Request: type = struct {
        names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_parameters) } {
            return .{ .service_metadata = service_metadata, .action = delete_parameters };
        }
    },
    Response: type = struct {
        deleted_parameters: ?[][]const u8 = null,
        invalid_parameters: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_parameters = "DeletedParameters",
                .invalid_parameters = "InvalidParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const delete_patch_baseline: struct {
    action_name: []const u8 = "DeletePatchBaseline",
    Request: type = struct {
        baseline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = delete_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceInUse,
    },
} = .{};
pub const delete_resource_data_sync: struct {
    action_name: []const u8 = "DeleteResourceDataSync",
    Request: type = struct {
        sync_name: []const u8,
        sync_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_name = "SyncName",
                .sync_type = "SyncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_data_sync) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_data_sync };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceDataSyncInvalidConfiguration,
        ResourceDataSyncNotFound,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy_id: []const u8,
        policy_hash: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy_id = "PolicyId",
                .policy_hash = "PolicyHash",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        MalformedResourcePolicyDocument,
        ResourceNotFound,
        ResourcePolicyConflict,
        ResourcePolicyInvalidParameter,
        ResourcePolicyNotFound,
    },
} = .{};
pub const deregister_managed_instance: struct {
    action_name: []const u8 = "DeregisterManagedInstance",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_managed_instance) } {
            return .{ .service_metadata = service_metadata, .action = deregister_managed_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidInstanceId,
    },
} = .{};
pub const deregister_patch_baseline_for_patch_group: struct {
    action_name: []const u8 = "DeregisterPatchBaselineForPatchGroup",
    Request: type = struct {
        baseline_id: []const u8,
        patch_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .patch_group = "PatchGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_patch_baseline_for_patch_group) } {
            return .{ .service_metadata = service_metadata, .action = deregister_patch_baseline_for_patch_group };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        patch_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .patch_group = "PatchGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidResourceId,
    },
} = .{};
pub const deregister_target_from_maintenance_window: struct {
    action_name: []const u8 = "DeregisterTargetFromMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,
        window_target_id: []const u8,
        safe: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_target_id = "WindowTargetId",
                .safe = "Safe",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_target_from_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = deregister_target_from_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        window_target_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_target_id = "WindowTargetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
        TargetInUse,
    },
} = .{};
pub const deregister_task_from_maintenance_window: struct {
    action_name: []const u8 = "DeregisterTaskFromMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,
        window_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_task_from_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = deregister_task_from_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        window_task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_activations: struct {
    action_name: []const u8 = "DescribeActivations",
    Request: type = struct {
        filters: ?[]struct {
            filter_key: ?[]const u8 = null,
            filter_values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filter_key = "FilterKey",
                    .filter_values = "FilterValues",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_activations) } {
            return .{ .service_metadata = service_metadata, .action = describe_activations };
        }
    },
    Response: type = struct {
        activation_list: ?[]struct {
            activation_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            default_instance_name: ?[]const u8 = null,
            iam_role: ?[]const u8 = null,
            registration_limit: ?i64 = null,
            registrations_count: ?i64 = null,
            expiration_date: ?i64 = null,
            expired: ?bool = null,
            created_date: ?i64 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activation_id = "ActivationId",
                    .description = "Description",
                    .default_instance_name = "DefaultInstanceName",
                    .iam_role = "IamRole",
                    .registration_limit = "RegistrationLimit",
                    .registrations_count = "RegistrationsCount",
                    .expiration_date = "ExpirationDate",
                    .expired = "Expired",
                    .created_date = "CreatedDate",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_list = "ActivationList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidNextToken,
    },
} = .{};
pub const describe_association: struct {
    action_name: []const u8 = "DescribeAssociation",
    Request: type = struct {
        name: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        association_id: ?[]const u8 = null,
        association_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .association_version = "AssociationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_association) } {
            return .{ .service_metadata = service_metadata, .action = describe_association };
        }
    },
    Response: type = struct {
        association_description: ?AssociationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_description = "AssociationDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InternalServerError,
        InvalidAssociationVersion,
        InvalidDocument,
        InvalidInstanceId,
    },
} = .{};
pub const describe_association_executions: struct {
    action_name: []const u8 = "DescribeAssociationExecutions",
    Request: type = struct {
        association_id: []const u8,
        filters: ?[]struct {
            key: []const u8,
            value: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_association_executions) } {
            return .{ .service_metadata = service_metadata, .action = describe_association_executions };
        }
    },
    Response: type = struct {
        association_executions: ?[]struct {
            association_id: ?[]const u8 = null,
            association_version: ?[]const u8 = null,
            execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            detailed_status: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_execution_date: ?i64 = null,
            resource_count_by_status: ?[]const u8 = null,
            alarm_configuration: ?AlarmConfiguration = null,
            triggered_alarms: ?[]AlarmStateInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .association_version = "AssociationVersion",
                    .execution_id = "ExecutionId",
                    .status = "Status",
                    .detailed_status = "DetailedStatus",
                    .created_time = "CreatedTime",
                    .last_execution_date = "LastExecutionDate",
                    .resource_count_by_status = "ResourceCountByStatus",
                    .alarm_configuration = "AlarmConfiguration",
                    .triggered_alarms = "TriggeredAlarms",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_executions = "AssociationExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const describe_association_execution_targets: struct {
    action_name: []const u8 = "DescribeAssociationExecutionTargets",
    Request: type = struct {
        association_id: []const u8,
        execution_id: []const u8,
        filters: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .execution_id = "ExecutionId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_association_execution_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_association_execution_targets };
        }
    },
    Response: type = struct {
        association_execution_targets: ?[]struct {
            association_id: ?[]const u8 = null,
            association_version: ?[]const u8 = null,
            execution_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            detailed_status: ?[]const u8 = null,
            last_execution_date: ?i64 = null,
            output_source: ?struct {
                output_source_id: ?[]const u8 = null,
                output_source_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output_source_id = "OutputSourceId",
                        .output_source_type = "OutputSourceType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .association_version = "AssociationVersion",
                    .execution_id = "ExecutionId",
                    .resource_id = "ResourceId",
                    .resource_type = "ResourceType",
                    .status = "Status",
                    .detailed_status = "DetailedStatus",
                    .last_execution_date = "LastExecutionDate",
                    .output_source = "OutputSource",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_execution_targets = "AssociationExecutionTargets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        AssociationExecutionDoesNotExist,
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const describe_automation_executions: struct {
    action_name: []const u8 = "DescribeAutomationExecutions",
    Request: type = struct {
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_automation_executions) } {
            return .{ .service_metadata = service_metadata, .action = describe_automation_executions };
        }
    },
    Response: type = struct {
        automation_execution_metadata_list: ?[]struct {
            automation_execution_id: ?[]const u8 = null,
            document_name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            automation_execution_status: ?[]const u8 = null,
            execution_start_time: ?i64 = null,
            execution_end_time: ?i64 = null,
            executed_by: ?[]const u8 = null,
            log_file: ?[]const u8 = null,
            outputs: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            mode: ?[]const u8 = null,
            parent_automation_execution_id: ?[]const u8 = null,
            current_step_name: ?[]const u8 = null,
            current_action: ?[]const u8 = null,
            failure_message: ?[]const u8 = null,
            target_parameter_name: ?[]const u8 = null,
            targets: ?[]Target = null,
            target_maps: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            resolved_targets: ?ResolvedTargets = null,
            max_concurrency: ?[]const u8 = null,
            max_errors: ?[]const u8 = null,
            target: ?[]const u8 = null,
            automation_type: ?[]const u8 = null,
            alarm_configuration: ?AlarmConfiguration = null,
            triggered_alarms: ?[]AlarmStateInformation = null,
            automation_subtype: ?[]const u8 = null,
            scheduled_time: ?i64 = null,
            runbooks: ?[]Runbook = null,
            ops_item_id: ?[]const u8 = null,
            association_id: ?[]const u8 = null,
            change_request_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automation_execution_id = "AutomationExecutionId",
                    .document_name = "DocumentName",
                    .document_version = "DocumentVersion",
                    .automation_execution_status = "AutomationExecutionStatus",
                    .execution_start_time = "ExecutionStartTime",
                    .execution_end_time = "ExecutionEndTime",
                    .executed_by = "ExecutedBy",
                    .log_file = "LogFile",
                    .outputs = "Outputs",
                    .mode = "Mode",
                    .parent_automation_execution_id = "ParentAutomationExecutionId",
                    .current_step_name = "CurrentStepName",
                    .current_action = "CurrentAction",
                    .failure_message = "FailureMessage",
                    .target_parameter_name = "TargetParameterName",
                    .targets = "Targets",
                    .target_maps = "TargetMaps",
                    .resolved_targets = "ResolvedTargets",
                    .max_concurrency = "MaxConcurrency",
                    .max_errors = "MaxErrors",
                    .target = "Target",
                    .automation_type = "AutomationType",
                    .alarm_configuration = "AlarmConfiguration",
                    .triggered_alarms = "TriggeredAlarms",
                    .automation_subtype = "AutomationSubtype",
                    .scheduled_time = "ScheduledTime",
                    .runbooks = "Runbooks",
                    .ops_item_id = "OpsItemId",
                    .association_id = "AssociationId",
                    .change_request_name = "ChangeRequestName",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "outputs", field_name))
                    return try serializeMap(self.outputs, self.fieldNameFor("outputs"), options, out_stream);
                if (std.mem.eql(u8, "target_maps", field_name))
                    return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_metadata_list = "AutomationExecutionMetadataList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidFilterValue,
        InvalidNextToken,
    },
} = .{};
pub const describe_automation_step_executions: struct {
    action_name: []const u8 = "DescribeAutomationStepExecutions",
    Request: type = struct {
        automation_execution_id: []const u8,
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .reverse_order = "ReverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_automation_step_executions) } {
            return .{ .service_metadata = service_metadata, .action = describe_automation_step_executions };
        }
    },
    Response: type = struct {
        step_executions: ?[]StepExecution = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .step_executions = "StepExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationExecutionNotFound,
        InternalServerError,
        InvalidFilterKey,
        InvalidFilterValue,
        InvalidNextToken,
    },
} = .{};
pub const describe_available_patches: struct {
    action_name: []const u8 = "DescribeAvailablePatches",
    Request: type = struct {
        filters: ?[]PatchOrchestratorFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_available_patches) } {
            return .{ .service_metadata = service_metadata, .action = describe_available_patches };
        }
    },
    Response: type = struct {
        patches: ?[]Patch = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patches = "Patches",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_document: struct {
    action_name: []const u8 = "DescribeDocument",
    Request: type = struct {
        name: []const u8,
        document_version: ?[]const u8 = null,
        version_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .version_name = "VersionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_document) } {
            return .{ .service_metadata = service_metadata, .action = describe_document };
        }
    },
    Response: type = struct {
        document: ?DocumentDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
    },
} = .{};
pub const describe_document_permission: struct {
    action_name: []const u8 = "DescribeDocumentPermission",
    Request: type = struct {
        name: []const u8,
        permission_type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .permission_type = "PermissionType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_document_permission) } {
            return .{ .service_metadata = service_metadata, .action = describe_document_permission };
        }
    },
    Response: type = struct {
        account_ids: ?[][]const u8 = null,
        account_sharing_info_list: ?[]struct {
            account_id: ?[]const u8 = null,
            shared_document_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .shared_document_version = "SharedDocumentVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .account_sharing_info_list = "AccountSharingInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentOperation,
        InvalidNextToken,
        InvalidPermissionType,
    },
} = .{};
pub const describe_effective_instance_associations: struct {
    action_name: []const u8 = "DescribeEffectiveInstanceAssociations",
    Request: type = struct {
        instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_effective_instance_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_effective_instance_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            association_id: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            content: ?[]const u8 = null,
            association_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .instance_id = "InstanceId",
                    .content = "Content",
                    .association_version = "AssociationVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidInstanceId,
        InvalidNextToken,
    },
} = .{};
pub const describe_effective_patches_for_patch_baseline: struct {
    action_name: []const u8 = "DescribeEffectivePatchesForPatchBaseline",
    Request: type = struct {
        baseline_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_effective_patches_for_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = describe_effective_patches_for_patch_baseline };
        }
    },
    Response: type = struct {
        effective_patches: ?[]struct {
            patch: ?Patch = null,
            patch_status: ?struct {
                deployment_status: ?[]const u8 = null,
                compliance_level: ?[]const u8 = null,
                approval_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .deployment_status = "DeploymentStatus",
                        .compliance_level = "ComplianceLevel",
                        .approval_date = "ApprovalDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .patch = "Patch",
                    .patch_status = "PatchStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_patches = "EffectivePatches",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
        InvalidResourceId,
        UnsupportedOperatingSystem,
    },
} = .{};
pub const describe_instance_associations_status: struct {
    action_name: []const u8 = "DescribeInstanceAssociationsStatus",
    Request: type = struct {
        instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_associations_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_associations_status };
        }
    },
    Response: type = struct {
        instance_association_status_infos: ?[]struct {
            association_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            association_version: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            execution_date: ?i64 = null,
            status: ?[]const u8 = null,
            detailed_status: ?[]const u8 = null,
            execution_summary: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            output_url: ?struct {
                s3_output_url: ?struct {
                    output_url: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .output_url = "OutputUrl",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_output_url = "S3OutputUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            association_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .name = "Name",
                    .document_version = "DocumentVersion",
                    .association_version = "AssociationVersion",
                    .instance_id = "InstanceId",
                    .execution_date = "ExecutionDate",
                    .status = "Status",
                    .detailed_status = "DetailedStatus",
                    .execution_summary = "ExecutionSummary",
                    .error_code = "ErrorCode",
                    .output_url = "OutputUrl",
                    .association_name = "AssociationName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_association_status_infos = "InstanceAssociationStatusInfos",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidInstanceId,
        InvalidNextToken,
    },
} = .{};
pub const describe_instance_information: struct {
    action_name: []const u8 = "DescribeInstanceInformation",
    Request: type = struct {
        instance_information_filter_list: ?[]struct {
            key: []const u8,
            value_set: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value_set = "valueSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_information_filter_list = "InstanceInformationFilterList",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_information) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_information };
        }
    },
    Response: type = struct {
        instance_information_list: ?[]struct {
            instance_id: ?[]const u8 = null,
            ping_status: ?[]const u8 = null,
            last_ping_date_time: ?i64 = null,
            agent_version: ?[]const u8 = null,
            is_latest_version: ?bool = null,
            platform_type: ?[]const u8 = null,
            platform_name: ?[]const u8 = null,
            platform_version: ?[]const u8 = null,
            activation_id: ?[]const u8 = null,
            iam_role: ?[]const u8 = null,
            registration_date: ?i64 = null,
            resource_type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            computer_name: ?[]const u8 = null,
            association_status: ?[]const u8 = null,
            last_association_execution_date: ?i64 = null,
            last_successful_association_execution_date: ?i64 = null,
            association_overview: ?struct {
                detailed_status: ?[]const u8 = null,
                instance_association_status_aggregated_count: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .detailed_status = "DetailedStatus",
                        .instance_association_status_aggregated_count = "InstanceAssociationStatusAggregatedCount",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "instance_association_status_aggregated_count", field_name))
                        return try serializeMap(self.instance_association_status_aggregated_count, self.fieldNameFor("instance_association_status_aggregated_count"), options, out_stream);
                    return false;
                }
            } = null,
            source_id: ?[]const u8 = null,
            source_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .ping_status = "PingStatus",
                    .last_ping_date_time = "LastPingDateTime",
                    .agent_version = "AgentVersion",
                    .is_latest_version = "IsLatestVersion",
                    .platform_type = "PlatformType",
                    .platform_name = "PlatformName",
                    .platform_version = "PlatformVersion",
                    .activation_id = "ActivationId",
                    .iam_role = "IamRole",
                    .registration_date = "RegistrationDate",
                    .resource_type = "ResourceType",
                    .name = "Name",
                    .ip_address = "IPAddress",
                    .computer_name = "ComputerName",
                    .association_status = "AssociationStatus",
                    .last_association_execution_date = "LastAssociationExecutionDate",
                    .last_successful_association_execution_date = "LastSuccessfulAssociationExecutionDate",
                    .association_overview = "AssociationOverview",
                    .source_id = "SourceId",
                    .source_type = "SourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_information_list = "InstanceInformationList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidInstanceId,
        InvalidInstanceInformationFilterValue,
        InvalidNextToken,
    },
} = .{};
pub const describe_instance_patches: struct {
    action_name: []const u8 = "DescribeInstancePatches",
    Request: type = struct {
        instance_id: []const u8,
        filters: ?[]PatchOrchestratorFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_patches) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_patches };
        }
    },
    Response: type = struct {
        patches: ?[]struct {
            title: []const u8,
            kb_id: []const u8,
            classification: []const u8,
            severity: []const u8,
            state: []const u8,
            installed_time: i64,
            cve_ids: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .title = "Title",
                    .kb_id = "KBId",
                    .classification = "Classification",
                    .severity = "Severity",
                    .state = "State",
                    .installed_time = "InstalledTime",
                    .cve_ids = "CVEIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patches = "Patches",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidInstanceId,
        InvalidNextToken,
    },
} = .{};
pub const describe_instance_patch_states: struct {
    action_name: []const u8 = "DescribeInstancePatchStates",
    Request: type = struct {
        instance_ids: [][]const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceIds",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_patch_states) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_patch_states };
        }
    },
    Response: type = struct {
        instance_patch_states: ?[]InstancePatchState = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_patch_states = "InstancePatchStates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const describe_instance_patch_states_for_patch_group: struct {
    action_name: []const u8 = "DescribeInstancePatchStatesForPatchGroup",
    Request: type = struct {
        patch_group: []const u8,
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patch_group = "PatchGroup",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_patch_states_for_patch_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_patch_states_for_patch_group };
        }
    },
    Response: type = struct {
        instance_patch_states: ?[]InstancePatchState = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_patch_states = "InstancePatchStates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidNextToken,
    },
} = .{};
pub const describe_inventory_deletions: struct {
    action_name: []const u8 = "DescribeInventoryDeletions",
    Request: type = struct {
        deletion_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deletion_id = "DeletionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inventory_deletions) } {
            return .{ .service_metadata = service_metadata, .action = describe_inventory_deletions };
        }
    },
    Response: type = struct {
        inventory_deletions: ?[]struct {
            deletion_id: ?[]const u8 = null,
            type_name: ?[]const u8 = null,
            deletion_start_time: ?i64 = null,
            last_status: ?[]const u8 = null,
            last_status_message: ?[]const u8 = null,
            deletion_summary: ?InventoryDeletionSummary = null,
            last_status_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deletion_id = "DeletionId",
                    .type_name = "TypeName",
                    .deletion_start_time = "DeletionStartTime",
                    .last_status = "LastStatus",
                    .last_status_message = "LastStatusMessage",
                    .deletion_summary = "DeletionSummary",
                    .last_status_update_time = "LastStatusUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inventory_deletions = "InventoryDeletions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDeletionId,
        InvalidNextToken,
    },
} = .{};
pub const describe_maintenance_window_executions: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowExecutions",
    Request: type = struct {
        window_id: []const u8,
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_executions) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_executions };
        }
    },
    Response: type = struct {
        window_executions: ?[]struct {
            window_id: ?[]const u8 = null,
            window_execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_details: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .window_execution_id = "WindowExecutionId",
                    .status = "Status",
                    .status_details = "StatusDetails",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_executions = "WindowExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_window_execution_task_invocations: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowExecutionTaskInvocations",
    Request: type = struct {
        window_execution_id: []const u8,
        task_id: []const u8,
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_id = "TaskId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_execution_task_invocations) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_execution_task_invocations };
        }
    },
    Response: type = struct {
        window_execution_task_invocation_identities: ?[]struct {
            window_execution_id: ?[]const u8 = null,
            task_execution_id: ?[]const u8 = null,
            invocation_id: ?[]const u8 = null,
            execution_id: ?[]const u8 = null,
            task_type: ?[]const u8 = null,
            parameters: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_details: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            owner_information: ?[]const u8 = null,
            window_target_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_execution_id = "WindowExecutionId",
                    .task_execution_id = "TaskExecutionId",
                    .invocation_id = "InvocationId",
                    .execution_id = "ExecutionId",
                    .task_type = "TaskType",
                    .parameters = "Parameters",
                    .status = "Status",
                    .status_details = "StatusDetails",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .owner_information = "OwnerInformation",
                    .window_target_id = "WindowTargetId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_task_invocation_identities = "WindowExecutionTaskInvocationIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_window_execution_tasks: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowExecutionTasks",
    Request: type = struct {
        window_execution_id: []const u8,
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_execution_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_execution_tasks };
        }
    },
    Response: type = struct {
        window_execution_task_identities: ?[]struct {
            window_execution_id: ?[]const u8 = null,
            task_execution_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_details: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            task_arn: ?[]const u8 = null,
            task_type: ?[]const u8 = null,
            alarm_configuration: ?AlarmConfiguration = null,
            triggered_alarms: ?[]AlarmStateInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_execution_id = "WindowExecutionId",
                    .task_execution_id = "TaskExecutionId",
                    .status = "Status",
                    .status_details = "StatusDetails",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .task_arn = "TaskArn",
                    .task_type = "TaskType",
                    .alarm_configuration = "AlarmConfiguration",
                    .triggered_alarms = "TriggeredAlarms",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_task_identities = "WindowExecutionTaskIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_windows: struct {
    action_name: []const u8 = "DescribeMaintenanceWindows",
    Request: type = struct {
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_windows) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_windows };
        }
    },
    Response: type = struct {
        window_identities: ?[]struct {
            window_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            enabled: ?bool = null,
            duration: ?i64 = null,
            cutoff: ?i64 = null,
            schedule: ?[]const u8 = null,
            schedule_timezone: ?[]const u8 = null,
            schedule_offset: ?i64 = null,
            end_date: ?[]const u8 = null,
            start_date: ?[]const u8 = null,
            next_execution_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .name = "Name",
                    .description = "Description",
                    .enabled = "Enabled",
                    .duration = "Duration",
                    .cutoff = "Cutoff",
                    .schedule = "Schedule",
                    .schedule_timezone = "ScheduleTimezone",
                    .schedule_offset = "ScheduleOffset",
                    .end_date = "EndDate",
                    .start_date = "StartDate",
                    .next_execution_time = "NextExecutionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_identities = "WindowIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_window_schedule: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowSchedule",
    Request: type = struct {
        window_id: ?[]const u8 = null,
        targets: ?[]Target = null,
        resource_type: ?[]const u8 = null,
        filters: ?[]PatchOrchestratorFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .targets = "Targets",
                .resource_type = "ResourceType",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_schedule };
        }
    },
    Response: type = struct {
        scheduled_window_executions: ?[]struct {
            window_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            execution_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .name = "Name",
                    .execution_time = "ExecutionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_window_executions = "ScheduledWindowExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_windows_for_target: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowsForTarget",
    Request: type = struct {
        targets: []Target,
        resource_type: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .resource_type = "ResourceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_windows_for_target) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_windows_for_target };
        }
    },
    Response: type = struct {
        window_identities: ?[]struct {
            window_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_identities = "WindowIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_window_targets: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowTargets",
    Request: type = struct {
        window_id: []const u8,
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_targets) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_targets };
        }
    },
    Response: type = struct {
        targets: ?[]struct {
            window_id: ?[]const u8 = null,
            window_target_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            targets: ?[]Target = null,
            owner_information: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .window_target_id = "WindowTargetId",
                    .resource_type = "ResourceType",
                    .targets = "Targets",
                    .owner_information = "OwnerInformation",
                    .name = "Name",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_maintenance_window_tasks: struct {
    action_name: []const u8 = "DescribeMaintenanceWindowTasks",
    Request: type = struct {
        window_id: []const u8,
        filters: ?[]MaintenanceWindowFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_window_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_window_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]struct {
            window_id: ?[]const u8 = null,
            window_task_id: ?[]const u8 = null,
            task_arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            targets: ?[]Target = null,
            task_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MaintenanceWindowTaskParameterValueExpression = null,
            } = null,
            priority: ?i64 = null,
            logging_info: ?LoggingInfo = null,
            service_role_arn: ?[]const u8 = null,
            max_concurrency: ?[]const u8 = null,
            max_errors: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            cutoff_behavior: ?[]const u8 = null,
            alarm_configuration: ?AlarmConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .window_id = "WindowId",
                    .window_task_id = "WindowTaskId",
                    .task_arn = "TaskArn",
                    .type = "Type",
                    .targets = "Targets",
                    .task_parameters = "TaskParameters",
                    .priority = "Priority",
                    .logging_info = "LoggingInfo",
                    .service_role_arn = "ServiceRoleArn",
                    .max_concurrency = "MaxConcurrency",
                    .max_errors = "MaxErrors",
                    .name = "Name",
                    .description = "Description",
                    .cutoff_behavior = "CutoffBehavior",
                    .alarm_configuration = "AlarmConfiguration",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "task_parameters", field_name))
                    return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "Tasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const describe_ops_items: struct {
    action_name: []const u8 = "DescribeOpsItems",
    Request: type = struct {
        ops_item_filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_filters = "OpsItemFilters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ops_items) } {
            return .{ .service_metadata = service_metadata, .action = describe_ops_items };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        ops_item_summaries: ?[]struct {
            created_by: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_modified_by: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            priority: ?i64 = null,
            source: ?[]const u8 = null,
            status: ?[]const u8 = null,
            ops_item_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            operational_data: ?[]struct {
                key: ?[]const u8 = null,
                value: ?OpsItemDataValue = null,
            } = null,
            category: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            ops_item_type: ?[]const u8 = null,
            actual_start_time: ?i64 = null,
            actual_end_time: ?i64 = null,
            planned_start_time: ?i64 = null,
            planned_end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_by = "CreatedBy",
                    .created_time = "CreatedTime",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_time = "LastModifiedTime",
                    .priority = "Priority",
                    .source = "Source",
                    .status = "Status",
                    .ops_item_id = "OpsItemId",
                    .title = "Title",
                    .operational_data = "OperationalData",
                    .category = "Category",
                    .severity = "Severity",
                    .ops_item_type = "OpsItemType",
                    .actual_start_time = "ActualStartTime",
                    .actual_end_time = "ActualEndTime",
                    .planned_start_time = "PlannedStartTime",
                    .planned_end_time = "PlannedEndTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "operational_data", field_name))
                    return try serializeMap(self.operational_data, self.fieldNameFor("operational_data"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .ops_item_summaries = "OpsItemSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_parameters: struct {
    action_name: []const u8 = "DescribeParameters",
    Request: type = struct {
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        parameter_filters: ?[]ParameterStringFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        shared: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .parameter_filters = "ParameterFilters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .shared = "Shared",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            key_id: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            last_modified_user: ?[]const u8 = null,
            description: ?[]const u8 = null,
            allowed_pattern: ?[]const u8 = null,
            version: ?i64 = null,
            tier: ?[]const u8 = null,
            policies: ?[]ParameterInlinePolicy = null,
            data_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "ARN",
                    .type = "Type",
                    .key_id = "KeyId",
                    .last_modified_date = "LastModifiedDate",
                    .last_modified_user = "LastModifiedUser",
                    .description = "Description",
                    .allowed_pattern = "AllowedPattern",
                    .version = "Version",
                    .tier = "Tier",
                    .policies = "Policies",
                    .data_type = "DataType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidFilterOption,
        InvalidFilterValue,
        InvalidNextToken,
    },
} = .{};
pub const describe_patch_baselines: struct {
    action_name: []const u8 = "DescribePatchBaselines",
    Request: type = struct {
        filters: ?[]PatchOrchestratorFilter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_patch_baselines) } {
            return .{ .service_metadata = service_metadata, .action = describe_patch_baselines };
        }
    },
    Response: type = struct {
        baseline_identities: ?[]PatchBaselineIdentity = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_identities = "BaselineIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_patch_groups: struct {
    action_name: []const u8 = "DescribePatchGroups",
    Request: type = struct {
        max_results: ?i64 = null,
        filters: ?[]PatchOrchestratorFilter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_patch_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_patch_groups };
        }
    },
    Response: type = struct {
        mappings: ?[]struct {
            patch_group: ?[]const u8 = null,
            baseline_identity: ?PatchBaselineIdentity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .patch_group = "PatchGroup",
                    .baseline_identity = "BaselineIdentity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mappings = "Mappings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_patch_group_state: struct {
    action_name: []const u8 = "DescribePatchGroupState",
    Request: type = struct {
        patch_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patch_group = "PatchGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_patch_group_state) } {
            return .{ .service_metadata = service_metadata, .action = describe_patch_group_state };
        }
    },
    Response: type = struct {
        instances: ?i64 = null,
        instances_with_installed_patches: ?i64 = null,
        instances_with_installed_other_patches: ?i64 = null,
        instances_with_installed_pending_reboot_patches: ?i64 = null,
        instances_with_installed_rejected_patches: ?i64 = null,
        instances_with_missing_patches: ?i64 = null,
        instances_with_failed_patches: ?i64 = null,
        instances_with_not_applicable_patches: ?i64 = null,
        instances_with_unreported_not_applicable_patches: ?i64 = null,
        instances_with_critical_non_compliant_patches: ?i64 = null,
        instances_with_security_non_compliant_patches: ?i64 = null,
        instances_with_other_non_compliant_patches: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .instances_with_installed_patches = "InstancesWithInstalledPatches",
                .instances_with_installed_other_patches = "InstancesWithInstalledOtherPatches",
                .instances_with_installed_pending_reboot_patches = "InstancesWithInstalledPendingRebootPatches",
                .instances_with_installed_rejected_patches = "InstancesWithInstalledRejectedPatches",
                .instances_with_missing_patches = "InstancesWithMissingPatches",
                .instances_with_failed_patches = "InstancesWithFailedPatches",
                .instances_with_not_applicable_patches = "InstancesWithNotApplicablePatches",
                .instances_with_unreported_not_applicable_patches = "InstancesWithUnreportedNotApplicablePatches",
                .instances_with_critical_non_compliant_patches = "InstancesWithCriticalNonCompliantPatches",
                .instances_with_security_non_compliant_patches = "InstancesWithSecurityNonCompliantPatches",
                .instances_with_other_non_compliant_patches = "InstancesWithOtherNonCompliantPatches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const describe_patch_properties: struct {
    action_name: []const u8 = "DescribePatchProperties",
    Request: type = struct {
        operating_system: []const u8,
        property: []const u8,
        patch_set: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operating_system = "OperatingSystem",
                .property = "Property",
                .patch_set = "PatchSet",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_patch_properties) } {
            return .{ .service_metadata = service_metadata, .action = describe_patch_properties };
        }
    },
    Response: type = struct {
        properties: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .properties = "Properties",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_sessions: struct {
    action_name: []const u8 = "DescribeSessions",
    Request: type = struct {
        state: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_sessions) } {
            return .{ .service_metadata = service_metadata, .action = describe_sessions };
        }
    },
    Response: type = struct {
        sessions: ?[]struct {
            session_id: ?[]const u8 = null,
            target: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_date: ?i64 = null,
            end_date: ?i64 = null,
            document_name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            details: ?[]const u8 = null,
            output_url: ?struct {
                s3_output_url: ?[]const u8 = null,
                cloud_watch_output_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_output_url = "S3OutputUrl",
                        .cloud_watch_output_url = "CloudWatchOutputUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            max_session_duration: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_id = "SessionId",
                    .target = "Target",
                    .status = "Status",
                    .start_date = "StartDate",
                    .end_date = "EndDate",
                    .document_name = "DocumentName",
                    .owner = "Owner",
                    .reason = "Reason",
                    .details = "Details",
                    .output_url = "OutputUrl",
                    .max_session_duration = "MaxSessionDuration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sessions = "Sessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidNextToken,
    },
} = .{};
pub const disassociate_ops_item_related_item: struct {
    action_name: []const u8 = "DisassociateOpsItemRelatedItem",
    Request: type = struct {
        ops_item_id: []const u8,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_ops_item_related_item) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_ops_item_related_item };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemConflict,
        OpsItemInvalidParameter,
        OpsItemNotFound,
        OpsItemRelatedItemAssociationNotFound,
    },
} = .{};
pub const get_automation_execution: struct {
    action_name: []const u8 = "GetAutomationExecution",
    Request: type = struct {
        automation_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_automation_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_automation_execution };
        }
    },
    Response: type = struct {
        automation_execution: ?struct {
            automation_execution_id: ?[]const u8 = null,
            document_name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            execution_start_time: ?i64 = null,
            execution_end_time: ?i64 = null,
            automation_execution_status: ?[]const u8 = null,
            step_executions: ?[]StepExecution = null,
            step_executions_truncated: ?bool = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            outputs: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            failure_message: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            parent_automation_execution_id: ?[]const u8 = null,
            executed_by: ?[]const u8 = null,
            current_step_name: ?[]const u8 = null,
            current_action: ?[]const u8 = null,
            target_parameter_name: ?[]const u8 = null,
            targets: ?[]Target = null,
            target_maps: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            resolved_targets: ?ResolvedTargets = null,
            max_concurrency: ?[]const u8 = null,
            max_errors: ?[]const u8 = null,
            target: ?[]const u8 = null,
            target_locations: ?[]TargetLocation = null,
            progress_counters: ?struct {
                total_steps: ?i64 = null,
                success_steps: ?i64 = null,
                failed_steps: ?i64 = null,
                cancelled_steps: ?i64 = null,
                timed_out_steps: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_steps = "TotalSteps",
                        .success_steps = "SuccessSteps",
                        .failed_steps = "FailedSteps",
                        .cancelled_steps = "CancelledSteps",
                        .timed_out_steps = "TimedOutSteps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            alarm_configuration: ?AlarmConfiguration = null,
            triggered_alarms: ?[]AlarmStateInformation = null,
            automation_subtype: ?[]const u8 = null,
            scheduled_time: ?i64 = null,
            runbooks: ?[]Runbook = null,
            ops_item_id: ?[]const u8 = null,
            association_id: ?[]const u8 = null,
            change_request_name: ?[]const u8 = null,
            variables: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automation_execution_id = "AutomationExecutionId",
                    .document_name = "DocumentName",
                    .document_version = "DocumentVersion",
                    .execution_start_time = "ExecutionStartTime",
                    .execution_end_time = "ExecutionEndTime",
                    .automation_execution_status = "AutomationExecutionStatus",
                    .step_executions = "StepExecutions",
                    .step_executions_truncated = "StepExecutionsTruncated",
                    .parameters = "Parameters",
                    .outputs = "Outputs",
                    .failure_message = "FailureMessage",
                    .mode = "Mode",
                    .parent_automation_execution_id = "ParentAutomationExecutionId",
                    .executed_by = "ExecutedBy",
                    .current_step_name = "CurrentStepName",
                    .current_action = "CurrentAction",
                    .target_parameter_name = "TargetParameterName",
                    .targets = "Targets",
                    .target_maps = "TargetMaps",
                    .resolved_targets = "ResolvedTargets",
                    .max_concurrency = "MaxConcurrency",
                    .max_errors = "MaxErrors",
                    .target = "Target",
                    .target_locations = "TargetLocations",
                    .progress_counters = "ProgressCounters",
                    .alarm_configuration = "AlarmConfiguration",
                    .triggered_alarms = "TriggeredAlarms",
                    .automation_subtype = "AutomationSubtype",
                    .scheduled_time = "ScheduledTime",
                    .runbooks = "Runbooks",
                    .ops_item_id = "OpsItemId",
                    .association_id = "AssociationId",
                    .change_request_name = "ChangeRequestName",
                    .variables = "Variables",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "outputs", field_name))
                    return try serializeMap(self.outputs, self.fieldNameFor("outputs"), options, out_stream);
                if (std.mem.eql(u8, "target_maps", field_name))
                    return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
                if (std.mem.eql(u8, "variables", field_name))
                    return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution = "AutomationExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationExecutionNotFound,
        InternalServerError,
    },
} = .{};
pub const get_calendar_state: struct {
    action_name: []const u8 = "GetCalendarState",
    Request: type = struct {
        calendar_names: [][]const u8,
        at_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calendar_names = "CalendarNames",
                .at_time = "AtTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_calendar_state) } {
            return .{ .service_metadata = service_metadata, .action = get_calendar_state };
        }
    },
    Response: type = struct {
        state: ?[]const u8 = null,
        at_time: ?[]const u8 = null,
        next_transition_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state = "State",
                .at_time = "AtTime",
                .next_transition_time = "NextTransitionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentType,
        UnsupportedCalendar,
    },
} = .{};
pub const get_command_invocation: struct {
    action_name: []const u8 = "GetCommandInvocation",
    Request: type = struct {
        command_id: []const u8,
        instance_id: []const u8,
        plugin_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_id = "CommandId",
                .instance_id = "InstanceId",
                .plugin_name = "PluginName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_command_invocation) } {
            return .{ .service_metadata = service_metadata, .action = get_command_invocation };
        }
    },
    Response: type = struct {
        command_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        comment: ?[]const u8 = null,
        document_name: ?[]const u8 = null,
        document_version: ?[]const u8 = null,
        plugin_name: ?[]const u8 = null,
        response_code: ?i64 = null,
        execution_start_date_time: ?[]const u8 = null,
        execution_elapsed_time: ?[]const u8 = null,
        execution_end_date_time: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_details: ?[]const u8 = null,
        standard_output_content: ?[]const u8 = null,
        standard_output_url: ?[]const u8 = null,
        standard_error_content: ?[]const u8 = null,
        standard_error_url: ?[]const u8 = null,
        cloud_watch_output_config: ?CloudWatchOutputConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_id = "CommandId",
                .instance_id = "InstanceId",
                .comment = "Comment",
                .document_name = "DocumentName",
                .document_version = "DocumentVersion",
                .plugin_name = "PluginName",
                .response_code = "ResponseCode",
                .execution_start_date_time = "ExecutionStartDateTime",
                .execution_elapsed_time = "ExecutionElapsedTime",
                .execution_end_date_time = "ExecutionEndDateTime",
                .status = "Status",
                .status_details = "StatusDetails",
                .standard_output_content = "StandardOutputContent",
                .standard_output_url = "StandardOutputUrl",
                .standard_error_content = "StandardErrorContent",
                .standard_error_url = "StandardErrorUrl",
                .cloud_watch_output_config = "CloudWatchOutputConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidCommandId,
        InvalidInstanceId,
        InvalidPluginName,
        InvocationDoesNotExist,
    },
} = .{};
pub const get_connection_status: struct {
    action_name: []const u8 = "GetConnectionStatus",
    Request: type = struct {
        target: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection_status) } {
            return .{ .service_metadata = service_metadata, .action = get_connection_status };
        }
    },
    Response: type = struct {
        target: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const get_default_patch_baseline: struct {
    action_name: []const u8 = "GetDefaultPatchBaseline",
    Request: type = struct {
        operating_system: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operating_system = "OperatingSystem",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_default_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = get_default_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        operating_system: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .operating_system = "OperatingSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const get_deployable_patch_snapshot_for_instance: struct {
    action_name: []const u8 = "GetDeployablePatchSnapshotForInstance",
    Request: type = struct {
        instance_id: []const u8,
        snapshot_id: []const u8,
        baseline_override: ?struct {
            operating_system: ?[]const u8 = null,
            global_filters: ?PatchFilterGroup = null,
            approval_rules: ?PatchRuleGroup = null,
            approved_patches: ?[][]const u8 = null,
            approved_patches_compliance_level: ?[]const u8 = null,
            rejected_patches: ?[][]const u8 = null,
            rejected_patches_action: ?[]const u8 = null,
            approved_patches_enable_non_security: ?bool = null,
            sources: ?[]PatchSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operating_system = "OperatingSystem",
                    .global_filters = "GlobalFilters",
                    .approval_rules = "ApprovalRules",
                    .approved_patches = "ApprovedPatches",
                    .approved_patches_compliance_level = "ApprovedPatchesComplianceLevel",
                    .rejected_patches = "RejectedPatches",
                    .rejected_patches_action = "RejectedPatchesAction",
                    .approved_patches_enable_non_security = "ApprovedPatchesEnableNonSecurity",
                    .sources = "Sources",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .snapshot_id = "SnapshotId",
                .baseline_override = "BaselineOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployable_patch_snapshot_for_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_deployable_patch_snapshot_for_instance };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,
        snapshot_download_url: ?[]const u8 = null,
        product: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .snapshot_id = "SnapshotId",
                .snapshot_download_url = "SnapshotDownloadUrl",
                .product = "Product",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        UnsupportedFeatureRequired,
        UnsupportedOperatingSystem,
    },
} = .{};
pub const get_document: struct {
    action_name: []const u8 = "GetDocument",
    Request: type = struct {
        name: []const u8,
        version_name: ?[]const u8 = null,
        document_version: ?[]const u8 = null,
        document_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .version_name = "VersionName",
                .document_version = "DocumentVersion",
                .document_format = "DocumentFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document) } {
            return .{ .service_metadata = service_metadata, .action = get_document };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        created_date: ?i64 = null,
        display_name: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        document_version: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_information: ?[]const u8 = null,
        content: ?[]const u8 = null,
        document_type: ?[]const u8 = null,
        document_format: ?[]const u8 = null,
        requires: ?[]DocumentRequires = null,
        attachments_content: ?[]struct {
            name: ?[]const u8 = null,
            size: ?i64 = null,
            hash: ?[]const u8 = null,
            hash_type: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .size = "Size",
                    .hash = "Hash",
                    .hash_type = "HashType",
                    .url = "Url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        review_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .created_date = "CreatedDate",
                .display_name = "DisplayName",
                .version_name = "VersionName",
                .document_version = "DocumentVersion",
                .status = "Status",
                .status_information = "StatusInformation",
                .content = "Content",
                .document_type = "DocumentType",
                .document_format = "DocumentFormat",
                .requires = "Requires",
                .attachments_content = "AttachmentsContent",
                .review_status = "ReviewStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
    },
} = .{};
pub const get_inventory: struct {
    action_name: []const u8 = "GetInventory",
    Request: type = struct {
        filters: ?[]InventoryFilter = null,
        aggregators: ?[]struct {
            expression: ?[]const u8 = null,
            aggregators: ?[]struct {
                expression: ?[]const u8 = null,
                aggregators: ?[]struct {
                    expression: ?[]const u8 = null,
                    aggregators: ?[]const u8 = null,
                    groups: ?[]struct {
                        name: []const u8,
                        filters: []InventoryFilter,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .filters = "Filters",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .expression = "Expression",
                            .aggregators = "Aggregators",
                            .groups = "Groups",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                groups: ?[]struct {
                    name: []const u8,
                    filters: []InventoryFilter,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .filters = "Filters",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .expression = "Expression",
                        .aggregators = "Aggregators",
                        .groups = "Groups",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            groups: ?[]struct {
                name: []const u8,
                filters: []InventoryFilter,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .filters = "Filters",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .expression = "Expression",
                    .aggregators = "Aggregators",
                    .groups = "Groups",
                };
                return @field(mappings, field_name);
            }
        } = null,
        result_attributes: ?[]struct {
            type_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type_name = "TypeName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .aggregators = "Aggregators",
                .result_attributes = "ResultAttributes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_inventory) } {
            return .{ .service_metadata = service_metadata, .action = get_inventory };
        }
    },
    Response: type = struct {
        entities: ?[]struct {
            id: ?[]const u8 = null,
            data: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    type_name: []const u8,
                    schema_version: []const u8,
                    capture_time: ?[]const u8 = null,
                    content_hash: ?[]const u8 = null,
                    content: [][]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type_name = "TypeName",
                            .schema_version = "SchemaVersion",
                            .capture_time = "CaptureTime",
                            .content_hash = "ContentHash",
                            .content = "Content",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "content", field_name))
                            return try serializeMap(self.content, self.fieldNameFor("content"), options, out_stream);
                        return false;
                    }
                } = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .data = "Data",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "data", field_name))
                    return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entities = "Entities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidAggregator,
        InvalidFilter,
        InvalidInventoryGroup,
        InvalidNextToken,
        InvalidResultAttribute,
        InvalidTypeName,
    },
} = .{};
pub const get_inventory_schema: struct {
    action_name: []const u8 = "GetInventorySchema",
    Request: type = struct {
        type_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        aggregator: ?bool = null,
        sub_type: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .aggregator = "Aggregator",
                .sub_type = "SubType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_inventory_schema) } {
            return .{ .service_metadata = service_metadata, .action = get_inventory_schema };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            type_name: []const u8,
            version: ?[]const u8 = null,
            attributes: []struct {
                name: []const u8,
                data_type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .data_type = "DataType",
                    };
                    return @field(mappings, field_name);
                }
            },
            display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type_name = "TypeName",
                    .version = "Version",
                    .attributes = "Attributes",
                    .display_name = "DisplayName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidNextToken,
        InvalidTypeName,
    },
} = .{};
pub const get_maintenance_window: struct {
    action_name: []const u8 = "GetMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = get_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        schedule_timezone: ?[]const u8 = null,
        schedule_offset: ?i64 = null,
        next_execution_time: ?[]const u8 = null,
        duration: ?i64 = null,
        cutoff: ?i64 = null,
        allow_unassociated_targets: ?bool = null,
        enabled: ?bool = null,
        created_date: ?i64 = null,
        modified_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .name = "Name",
                .description = "Description",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .schedule = "Schedule",
                .schedule_timezone = "ScheduleTimezone",
                .schedule_offset = "ScheduleOffset",
                .next_execution_time = "NextExecutionTime",
                .duration = "Duration",
                .cutoff = "Cutoff",
                .allow_unassociated_targets = "AllowUnassociatedTargets",
                .enabled = "Enabled",
                .created_date = "CreatedDate",
                .modified_date = "ModifiedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const get_maintenance_window_execution: struct {
    action_name: []const u8 = "GetMaintenanceWindowExecution",
    Request: type = struct {
        window_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_maintenance_window_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_maintenance_window_execution };
        }
    },
    Response: type = struct {
        window_execution_id: ?[]const u8 = null,
        task_ids: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_details: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_ids = "TaskIds",
                .status = "Status",
                .status_details = "StatusDetails",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const get_maintenance_window_execution_task: struct {
    action_name: []const u8 = "GetMaintenanceWindowExecutionTask",
    Request: type = struct {
        window_execution_id: []const u8,
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_maintenance_window_execution_task) } {
            return .{ .service_metadata = service_metadata, .action = get_maintenance_window_execution_task };
        }
    },
    Response: type = struct {
        window_execution_id: ?[]const u8 = null,
        task_execution_id: ?[]const u8 = null,
        task_arn: ?[]const u8 = null,
        service_role: ?[]const u8 = null,
        type: ?[]const u8 = null,
        task_parameters: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?MaintenanceWindowTaskParameterValueExpression = null,
        } = null,
        priority: ?i64 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_details: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        alarm_configuration: ?AlarmConfiguration = null,
        triggered_alarms: ?[]AlarmStateInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_execution_id = "TaskExecutionId",
                .task_arn = "TaskArn",
                .service_role = "ServiceRole",
                .type = "Type",
                .task_parameters = "TaskParameters",
                .priority = "Priority",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .status = "Status",
                .status_details = "StatusDetails",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .alarm_configuration = "AlarmConfiguration",
                .triggered_alarms = "TriggeredAlarms",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_parameters", field_name))
                return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const get_maintenance_window_execution_task_invocation: struct {
    action_name: []const u8 = "GetMaintenanceWindowExecutionTaskInvocation",
    Request: type = struct {
        window_execution_id: []const u8,
        task_id: []const u8,
        invocation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_id = "TaskId",
                .invocation_id = "InvocationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_maintenance_window_execution_task_invocation) } {
            return .{ .service_metadata = service_metadata, .action = get_maintenance_window_execution_task_invocation };
        }
    },
    Response: type = struct {
        window_execution_id: ?[]const u8 = null,
        task_execution_id: ?[]const u8 = null,
        invocation_id: ?[]const u8 = null,
        execution_id: ?[]const u8 = null,
        task_type: ?[]const u8 = null,
        parameters: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_details: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        owner_information: ?[]const u8 = null,
        window_target_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_execution_id = "WindowExecutionId",
                .task_execution_id = "TaskExecutionId",
                .invocation_id = "InvocationId",
                .execution_id = "ExecutionId",
                .task_type = "TaskType",
                .parameters = "Parameters",
                .status = "Status",
                .status_details = "StatusDetails",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .owner_information = "OwnerInformation",
                .window_target_id = "WindowTargetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const get_maintenance_window_task: struct {
    action_name: []const u8 = "GetMaintenanceWindowTask",
    Request: type = struct {
        window_id: []const u8,
        window_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_maintenance_window_task) } {
            return .{ .service_metadata = service_metadata, .action = get_maintenance_window_task };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        window_task_id: ?[]const u8 = null,
        targets: ?[]Target = null,
        task_arn: ?[]const u8 = null,
        service_role_arn: ?[]const u8 = null,
        task_type: ?[]const u8 = null,
        task_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MaintenanceWindowTaskParameterValueExpression = null,
        } = null,
        task_invocation_parameters: ?MaintenanceWindowTaskInvocationParameters = null,
        priority: ?i64 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        logging_info: ?LoggingInfo = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cutoff_behavior: ?[]const u8 = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
                .targets = "Targets",
                .task_arn = "TaskArn",
                .service_role_arn = "ServiceRoleArn",
                .task_type = "TaskType",
                .task_parameters = "TaskParameters",
                .task_invocation_parameters = "TaskInvocationParameters",
                .priority = "Priority",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .logging_info = "LoggingInfo",
                .name = "Name",
                .description = "Description",
                .cutoff_behavior = "CutoffBehavior",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_parameters", field_name))
                return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const get_ops_item: struct {
    action_name: []const u8 = "GetOpsItem",
    Request: type = struct {
        ops_item_id: []const u8,
        ops_item_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
                .ops_item_arn = "OpsItemArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ops_item) } {
            return .{ .service_metadata = service_metadata, .action = get_ops_item };
        }
    },
    Response: type = struct {
        ops_item: ?struct {
            created_by: ?[]const u8 = null,
            ops_item_type: ?[]const u8 = null,
            created_time: ?i64 = null,
            description: ?[]const u8 = null,
            last_modified_by: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            notifications: ?[]OpsItemNotification = null,
            priority: ?i64 = null,
            related_ops_items: ?[]RelatedOpsItem = null,
            status: ?[]const u8 = null,
            ops_item_id: ?[]const u8 = null,
            version: ?[]const u8 = null,
            title: ?[]const u8 = null,
            source: ?[]const u8 = null,
            operational_data: ?[]struct {
                key: ?[]const u8 = null,
                value: ?OpsItemDataValue = null,
            } = null,
            category: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            actual_start_time: ?i64 = null,
            actual_end_time: ?i64 = null,
            planned_start_time: ?i64 = null,
            planned_end_time: ?i64 = null,
            ops_item_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_by = "CreatedBy",
                    .ops_item_type = "OpsItemType",
                    .created_time = "CreatedTime",
                    .description = "Description",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_time = "LastModifiedTime",
                    .notifications = "Notifications",
                    .priority = "Priority",
                    .related_ops_items = "RelatedOpsItems",
                    .status = "Status",
                    .ops_item_id = "OpsItemId",
                    .version = "Version",
                    .title = "Title",
                    .source = "Source",
                    .operational_data = "OperationalData",
                    .category = "Category",
                    .severity = "Severity",
                    .actual_start_time = "ActualStartTime",
                    .actual_end_time = "ActualEndTime",
                    .planned_start_time = "PlannedStartTime",
                    .planned_end_time = "PlannedEndTime",
                    .ops_item_arn = "OpsItemArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "operational_data", field_name))
                    return try serializeMap(self.operational_data, self.fieldNameFor("operational_data"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item = "OpsItem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemAccessDenied,
        OpsItemNotFound,
    },
} = .{};
pub const get_ops_metadata: struct {
    action_name: []const u8 = "GetOpsMetadata",
    Request: type = struct {
        ops_metadata_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_arn = "OpsMetadataArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ops_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_ops_metadata };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MetadataValue = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .metadata = "Metadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsMetadataInvalidArgument,
        OpsMetadataNotFound,
    },
} = .{};
pub const get_ops_summary: struct {
    action_name: []const u8 = "GetOpsSummary",
    Request: type = struct {
        sync_name: ?[]const u8 = null,
        filters: ?[]OpsFilter = null,
        aggregators: ?[]struct {
            aggregator_type: ?[]const u8 = null,
            type_name: ?[]const u8 = null,
            attribute_name: ?[]const u8 = null,
            values: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            filters: ?[]OpsFilter = null,
            aggregators: ?[]struct {
                aggregator_type: ?[]const u8 = null,
                type_name: ?[]const u8 = null,
                attribute_name: ?[]const u8 = null,
                values: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                filters: ?[]OpsFilter = null,
                aggregators: ?[]struct {
                    aggregator_type: ?[]const u8 = null,
                    type_name: ?[]const u8 = null,
                    attribute_name: ?[]const u8 = null,
                    values: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,
                    filters: ?[]OpsFilter = null,
                    aggregators: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .aggregator_type = "AggregatorType",
                            .type_name = "TypeName",
                            .attribute_name = "AttributeName",
                            .values = "Values",
                            .filters = "Filters",
                            .aggregators = "Aggregators",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "values", field_name))
                            return try serializeMap(self.values, self.fieldNameFor("values"), options, out_stream);
                        return false;
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .aggregator_type = "AggregatorType",
                        .type_name = "TypeName",
                        .attribute_name = "AttributeName",
                        .values = "Values",
                        .filters = "Filters",
                        .aggregators = "Aggregators",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "values", field_name))
                        return try serializeMap(self.values, self.fieldNameFor("values"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aggregator_type = "AggregatorType",
                    .type_name = "TypeName",
                    .attribute_name = "AttributeName",
                    .values = "Values",
                    .filters = "Filters",
                    .aggregators = "Aggregators",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "values", field_name))
                    return try serializeMap(self.values, self.fieldNameFor("values"), options, out_stream);
                return false;
            }
        } = null,
        result_attributes: ?[]struct {
            type_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type_name = "TypeName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_name = "SyncName",
                .filters = "Filters",
                .aggregators = "Aggregators",
                .result_attributes = "ResultAttributes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ops_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_ops_summary };
        }
    },
    Response: type = struct {
        entities: ?[]struct {
            id: ?[]const u8 = null,
            data: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    capture_time: ?[]const u8 = null,
                    content: ?[][]struct {
                        key: ?[]const u8 = null,
                        value: ?[]const u8 = null,
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .capture_time = "CaptureTime",
                            .content = "Content",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "content", field_name))
                            return try serializeMap(self.content, self.fieldNameFor("content"), options, out_stream);
                        return false;
                    }
                } = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .data = "Data",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "data", field_name))
                    return try serializeMap(self.data, self.fieldNameFor("data"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entities = "Entities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidAggregator,
        InvalidFilter,
        InvalidNextToken,
        InvalidTypeName,
        ResourceDataSyncNotFound,
    },
} = .{};
pub const get_parameter: struct {
    action_name: []const u8 = "GetParameter",
    Request: type = struct {
        name: []const u8,
        with_decryption: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .with_decryption = "WithDecryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameter) } {
            return .{ .service_metadata = service_metadata, .action = get_parameter };
        }
    },
    Response: type = struct {
        parameter: ?Parameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter = "Parameter",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidKeyId,
        ParameterNotFound,
        ParameterVersionNotFound,
    },
} = .{};
pub const get_parameter_history: struct {
    action_name: []const u8 = "GetParameterHistory",
    Request: type = struct {
        name: []const u8,
        with_decryption: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .with_decryption = "WithDecryption",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameter_history) } {
            return .{ .service_metadata = service_metadata, .action = get_parameter_history };
        }
    },
    Response: type = struct {
        parameters: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            key_id: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            last_modified_user: ?[]const u8 = null,
            description: ?[]const u8 = null,
            value: ?[]const u8 = null,
            allowed_pattern: ?[]const u8 = null,
            version: ?i64 = null,
            labels: ?[][]const u8 = null,
            tier: ?[]const u8 = null,
            policies: ?[]ParameterInlinePolicy = null,
            data_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .key_id = "KeyId",
                    .last_modified_date = "LastModifiedDate",
                    .last_modified_user = "LastModifiedUser",
                    .description = "Description",
                    .value = "Value",
                    .allowed_pattern = "AllowedPattern",
                    .version = "Version",
                    .labels = "Labels",
                    .tier = "Tier",
                    .policies = "Policies",
                    .data_type = "DataType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidKeyId,
        InvalidNextToken,
        ParameterNotFound,
    },
} = .{};
pub const get_parameters: struct {
    action_name: []const u8 = "GetParameters",
    Request: type = struct {
        names: [][]const u8,
        with_decryption: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .with_decryption = "WithDecryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameters) } {
            return .{ .service_metadata = service_metadata, .action = get_parameters };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        invalid_parameters: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .invalid_parameters = "InvalidParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidKeyId,
    },
} = .{};
pub const get_parameters_by_path: struct {
    action_name: []const u8 = "GetParametersByPath",
    Request: type = struct {
        path: []const u8,
        recursive: ?bool = null,
        parameter_filters: ?[]ParameterStringFilter = null,
        with_decryption: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
                .recursive = "Recursive",
                .parameter_filters = "ParameterFilters",
                .with_decryption = "WithDecryption",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameters_by_path) } {
            return .{ .service_metadata = service_metadata, .action = get_parameters_by_path };
        }
    },
    Response: type = struct {
        parameters: ?[]Parameter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameters = "Parameters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidFilterOption,
        InvalidFilterValue,
        InvalidKeyId,
        InvalidNextToken,
    },
} = .{};
pub const get_patch_baseline: struct {
    action_name: []const u8 = "GetPatchBaseline",
    Request: type = struct {
        baseline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = get_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        operating_system: ?[]const u8 = null,
        global_filters: ?PatchFilterGroup = null,
        approval_rules: ?PatchRuleGroup = null,
        approved_patches: ?[][]const u8 = null,
        approved_patches_compliance_level: ?[]const u8 = null,
        approved_patches_enable_non_security: ?bool = null,
        rejected_patches: ?[][]const u8 = null,
        rejected_patches_action: ?[]const u8 = null,
        patch_groups: ?[][]const u8 = null,
        created_date: ?i64 = null,
        modified_date: ?i64 = null,
        description: ?[]const u8 = null,
        sources: ?[]PatchSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .name = "Name",
                .operating_system = "OperatingSystem",
                .global_filters = "GlobalFilters",
                .approval_rules = "ApprovalRules",
                .approved_patches = "ApprovedPatches",
                .approved_patches_compliance_level = "ApprovedPatchesComplianceLevel",
                .approved_patches_enable_non_security = "ApprovedPatchesEnableNonSecurity",
                .rejected_patches = "RejectedPatches",
                .rejected_patches_action = "RejectedPatchesAction",
                .patch_groups = "PatchGroups",
                .created_date = "CreatedDate",
                .modified_date = "ModifiedDate",
                .description = "Description",
                .sources = "Sources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
        InvalidResourceId,
    },
} = .{};
pub const get_patch_baseline_for_patch_group: struct {
    action_name: []const u8 = "GetPatchBaselineForPatchGroup",
    Request: type = struct {
        patch_group: []const u8,
        operating_system: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patch_group = "PatchGroup",
                .operating_system = "OperatingSystem",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_patch_baseline_for_patch_group) } {
            return .{ .service_metadata = service_metadata, .action = get_patch_baseline_for_patch_group };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        patch_group: ?[]const u8 = null,
        operating_system: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .patch_group = "PatchGroup",
                .operating_system = "OperatingSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const get_resource_policies: struct {
    action_name: []const u8 = "GetResourcePolicies",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policies };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        policies: ?[]struct {
            policy_id: ?[]const u8 = null,
            policy_hash: ?[]const u8 = null,
            policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_id = "PolicyId",
                    .policy_hash = "PolicyHash",
                    .policy = "Policy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .policies = "Policies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceNotFound,
        ResourcePolicyInvalidParameter,
    },
} = .{};
pub const get_service_setting: struct {
    action_name: []const u8 = "GetServiceSetting",
    Request: type = struct {
        setting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting_id = "SettingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_setting) } {
            return .{ .service_metadata = service_metadata, .action = get_service_setting };
        }
    },
    Response: type = struct {
        service_setting: ?ServiceSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_setting = "ServiceSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ServiceSettingNotFound,
    },
} = .{};
pub const label_parameter_version: struct {
    action_name: []const u8 = "LabelParameterVersion",
    Request: type = struct {
        name: []const u8,
        parameter_version: ?i64 = null,
        labels: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .parameter_version = "ParameterVersion",
                .labels = "Labels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(label_parameter_version) } {
            return .{ .service_metadata = service_metadata, .action = label_parameter_version };
        }
    },
    Response: type = struct {
        invalid_labels: ?[][]const u8 = null,
        parameter_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invalid_labels = "InvalidLabels",
                .parameter_version = "ParameterVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ParameterNotFound,
        ParameterVersionLabelLimitExceeded,
        ParameterVersionNotFound,
        TooManyUpdates,
    },
} = .{};
pub const list_associations: struct {
    action_name: []const u8 = "ListAssociations",
    Request: type = struct {
        association_filter_list: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_filter_list = "AssociationFilterList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            name: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            association_id: ?[]const u8 = null,
            association_version: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            targets: ?[]Target = null,
            last_execution_date: ?i64 = null,
            overview: ?AssociationOverview = null,
            schedule_expression: ?[]const u8 = null,
            association_name: ?[]const u8 = null,
            schedule_offset: ?i64 = null,
            duration: ?i64 = null,
            target_maps: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .instance_id = "InstanceId",
                    .association_id = "AssociationId",
                    .association_version = "AssociationVersion",
                    .document_version = "DocumentVersion",
                    .targets = "Targets",
                    .last_execution_date = "LastExecutionDate",
                    .overview = "Overview",
                    .schedule_expression = "ScheduleExpression",
                    .association_name = "AssociationName",
                    .schedule_offset = "ScheduleOffset",
                    .duration = "Duration",
                    .target_maps = "TargetMaps",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "target_maps", field_name))
                    return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const list_association_versions: struct {
    action_name: []const u8 = "ListAssociationVersions",
    Request: type = struct {
        association_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_association_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_association_versions };
        }
    },
    Response: type = struct {
        association_versions: ?[]struct {
            association_id: ?[]const u8 = null,
            association_version: ?[]const u8 = null,
            created_date: ?i64 = null,
            name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            targets: ?[]Target = null,
            schedule_expression: ?[]const u8 = null,
            output_location: ?InstanceAssociationOutputLocation = null,
            association_name: ?[]const u8 = null,
            max_errors: ?[]const u8 = null,
            max_concurrency: ?[]const u8 = null,
            compliance_severity: ?[]const u8 = null,
            sync_compliance: ?[]const u8 = null,
            apply_only_at_cron_interval: ?bool = null,
            calendar_names: ?[][]const u8 = null,
            target_locations: ?[]TargetLocation = null,
            schedule_offset: ?i64 = null,
            duration: ?i64 = null,
            target_maps: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .association_version = "AssociationVersion",
                    .created_date = "CreatedDate",
                    .name = "Name",
                    .document_version = "DocumentVersion",
                    .parameters = "Parameters",
                    .targets = "Targets",
                    .schedule_expression = "ScheduleExpression",
                    .output_location = "OutputLocation",
                    .association_name = "AssociationName",
                    .max_errors = "MaxErrors",
                    .max_concurrency = "MaxConcurrency",
                    .compliance_severity = "ComplianceSeverity",
                    .sync_compliance = "SyncCompliance",
                    .apply_only_at_cron_interval = "ApplyOnlyAtCronInterval",
                    .calendar_names = "CalendarNames",
                    .target_locations = "TargetLocations",
                    .schedule_offset = "ScheduleOffset",
                    .duration = "Duration",
                    .target_maps = "TargetMaps",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "target_maps", field_name))
                    return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_versions = "AssociationVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InternalServerError,
        InvalidNextToken,
    },
} = .{};
pub const list_command_invocations: struct {
    action_name: []const u8 = "ListCommandInvocations",
    Request: type = struct {
        command_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]CommandFilter = null,
        details: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_id = "CommandId",
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
                .details = "Details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_command_invocations) } {
            return .{ .service_metadata = service_metadata, .action = list_command_invocations };
        }
    },
    Response: type = struct {
        command_invocations: ?[]struct {
            command_id: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            instance_name: ?[]const u8 = null,
            comment: ?[]const u8 = null,
            document_name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            requested_date_time: ?i64 = null,
            status: ?[]const u8 = null,
            status_details: ?[]const u8 = null,
            trace_output: ?[]const u8 = null,
            standard_output_url: ?[]const u8 = null,
            standard_error_url: ?[]const u8 = null,
            command_plugins: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                status_details: ?[]const u8 = null,
                response_code: ?i64 = null,
                response_start_date_time: ?i64 = null,
                response_finish_date_time: ?i64 = null,
                output: ?[]const u8 = null,
                standard_output_url: ?[]const u8 = null,
                standard_error_url: ?[]const u8 = null,
                output_s3_region: ?[]const u8 = null,
                output_s3_bucket_name: ?[]const u8 = null,
                output_s3_key_prefix: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .status = "Status",
                        .status_details = "StatusDetails",
                        .response_code = "ResponseCode",
                        .response_start_date_time = "ResponseStartDateTime",
                        .response_finish_date_time = "ResponseFinishDateTime",
                        .output = "Output",
                        .standard_output_url = "StandardOutputUrl",
                        .standard_error_url = "StandardErrorUrl",
                        .output_s3_region = "OutputS3Region",
                        .output_s3_bucket_name = "OutputS3BucketName",
                        .output_s3_key_prefix = "OutputS3KeyPrefix",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            service_role: ?[]const u8 = null,
            notification_config: ?NotificationConfig = null,
            cloud_watch_output_config: ?CloudWatchOutputConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .command_id = "CommandId",
                    .instance_id = "InstanceId",
                    .instance_name = "InstanceName",
                    .comment = "Comment",
                    .document_name = "DocumentName",
                    .document_version = "DocumentVersion",
                    .requested_date_time = "RequestedDateTime",
                    .status = "Status",
                    .status_details = "StatusDetails",
                    .trace_output = "TraceOutput",
                    .standard_output_url = "StandardOutputUrl",
                    .standard_error_url = "StandardErrorUrl",
                    .command_plugins = "CommandPlugins",
                    .service_role = "ServiceRole",
                    .notification_config = "NotificationConfig",
                    .cloud_watch_output_config = "CloudWatchOutputConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_invocations = "CommandInvocations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidCommandId,
        InvalidFilterKey,
        InvalidInstanceId,
        InvalidNextToken,
    },
} = .{};
pub const list_commands: struct {
    action_name: []const u8 = "ListCommands",
    Request: type = struct {
        command_id: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]CommandFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command_id = "CommandId",
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_commands) } {
            return .{ .service_metadata = service_metadata, .action = list_commands };
        }
    },
    Response: type = struct {
        commands: ?[]Command = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .commands = "Commands",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidCommandId,
        InvalidFilterKey,
        InvalidInstanceId,
        InvalidNextToken,
    },
} = .{};
pub const list_compliance_items: struct {
    action_name: []const u8 = "ListComplianceItems",
    Request: type = struct {
        filters: ?[]ComplianceStringFilter = null,
        resource_ids: ?[][]const u8 = null,
        resource_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .resource_ids = "ResourceIds",
                .resource_types = "ResourceTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compliance_items) } {
            return .{ .service_metadata = service_metadata, .action = list_compliance_items };
        }
    },
    Response: type = struct {
        compliance_items: ?[]struct {
            compliance_type: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            status: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            execution_summary: ?ComplianceExecutionSummary = null,
            details: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_type = "ComplianceType",
                    .resource_type = "ResourceType",
                    .resource_id = "ResourceId",
                    .id = "Id",
                    .title = "Title",
                    .status = "Status",
                    .severity = "Severity",
                    .execution_summary = "ExecutionSummary",
                    .details = "Details",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "details", field_name))
                    return try serializeMap(self.details, self.fieldNameFor("details"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_items = "ComplianceItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidNextToken,
        InvalidResourceId,
        InvalidResourceType,
    },
} = .{};
pub const list_compliance_summaries: struct {
    action_name: []const u8 = "ListComplianceSummaries",
    Request: type = struct {
        filters: ?[]ComplianceStringFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compliance_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_compliance_summaries };
        }
    },
    Response: type = struct {
        compliance_summary_items: ?[]struct {
            compliance_type: ?[]const u8 = null,
            compliant_summary: ?CompliantSummary = null,
            non_compliant_summary: ?NonCompliantSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_type = "ComplianceType",
                    .compliant_summary = "CompliantSummary",
                    .non_compliant_summary = "NonCompliantSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_summary_items = "ComplianceSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidNextToken,
    },
} = .{};
pub const list_document_metadata_history: struct {
    action_name: []const u8 = "ListDocumentMetadataHistory",
    Request: type = struct {
        name: []const u8,
        document_version: ?[]const u8 = null,
        metadata: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .metadata = "Metadata",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_document_metadata_history) } {
            return .{ .service_metadata = service_metadata, .action = list_document_metadata_history };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        document_version: ?[]const u8 = null,
        author: ?[]const u8 = null,
        metadata: ?struct {
            reviewer_response: ?[]struct {
                create_time: ?i64 = null,
                updated_time: ?i64 = null,
                review_status: ?[]const u8 = null,
                comment: ?[]DocumentReviewCommentSource = null,
                reviewer: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .create_time = "CreateTime",
                        .updated_time = "UpdatedTime",
                        .review_status = "ReviewStatus",
                        .comment = "Comment",
                        .reviewer = "Reviewer",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reviewer_response = "ReviewerResponse",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .author = "Author",
                .metadata = "Metadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
        InvalidNextToken,
    },
} = .{};
pub const list_documents: struct {
    action_name: []const u8 = "ListDocuments",
    Request: type = struct {
        document_filter_list: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_filter_list = "DocumentFilterList",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_documents) } {
            return .{ .service_metadata = service_metadata, .action = list_documents };
        }
    },
    Response: type = struct {
        document_identifiers: ?[]struct {
            name: ?[]const u8 = null,
            created_date: ?i64 = null,
            display_name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            version_name: ?[]const u8 = null,
            platform_types: ?[][]const u8 = null,
            document_version: ?[]const u8 = null,
            document_type: ?[]const u8 = null,
            schema_version: ?[]const u8 = null,
            document_format: ?[]const u8 = null,
            target_type: ?[]const u8 = null,
            tags: ?[]Tag = null,
            requires: ?[]DocumentRequires = null,
            review_status: ?[]const u8 = null,
            author: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .created_date = "CreatedDate",
                    .display_name = "DisplayName",
                    .owner = "Owner",
                    .version_name = "VersionName",
                    .platform_types = "PlatformTypes",
                    .document_version = "DocumentVersion",
                    .document_type = "DocumentType",
                    .schema_version = "SchemaVersion",
                    .document_format = "DocumentFormat",
                    .target_type = "TargetType",
                    .tags = "Tags",
                    .requires = "Requires",
                    .review_status = "ReviewStatus",
                    .author = "Author",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_identifiers = "DocumentIdentifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilterKey,
        InvalidNextToken,
    },
} = .{};
pub const list_document_versions: struct {
    action_name: []const u8 = "ListDocumentVersions",
    Request: type = struct {
        name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_document_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_document_versions };
        }
    },
    Response: type = struct {
        document_versions: ?[]struct {
            name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            document_version: ?[]const u8 = null,
            version_name: ?[]const u8 = null,
            created_date: ?i64 = null,
            is_default_version: ?bool = null,
            document_format: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_information: ?[]const u8 = null,
            review_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .display_name = "DisplayName",
                    .document_version = "DocumentVersion",
                    .version_name = "VersionName",
                    .created_date = "CreatedDate",
                    .is_default_version = "IsDefaultVersion",
                    .document_format = "DocumentFormat",
                    .status = "Status",
                    .status_information = "StatusInformation",
                    .review_status = "ReviewStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_versions = "DocumentVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidNextToken,
    },
} = .{};
pub const list_inventory_entries: struct {
    action_name: []const u8 = "ListInventoryEntries",
    Request: type = struct {
        instance_id: []const u8,
        type_name: []const u8,
        filters: ?[]InventoryFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .type_name = "TypeName",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inventory_entries) } {
            return .{ .service_metadata = service_metadata, .action = list_inventory_entries };
        }
    },
    Response: type = struct {
        type_name: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        schema_version: ?[]const u8 = null,
        capture_time: ?[]const u8 = null,
        entries: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_name = "TypeName",
                .instance_id = "InstanceId",
                .schema_version = "SchemaVersion",
                .capture_time = "CaptureTime",
                .entries = "Entries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "entries", field_name))
                return try serializeMap(self.entries, self.fieldNameFor("entries"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidInstanceId,
        InvalidNextToken,
        InvalidTypeName,
    },
} = .{};
pub const list_ops_item_events: struct {
    action_name: []const u8 = "ListOpsItemEvents",
    Request: type = struct {
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ops_item_events) } {
            return .{ .service_metadata = service_metadata, .action = list_ops_item_events };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        summaries: ?[]struct {
            ops_item_id: ?[]const u8 = null,
            event_id: ?[]const u8 = null,
            source: ?[]const u8 = null,
            detail_type: ?[]const u8 = null,
            detail: ?[]const u8 = null,
            created_by: ?OpsItemIdentity = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_item_id = "OpsItemId",
                    .event_id = "EventId",
                    .source = "Source",
                    .detail_type = "DetailType",
                    .detail = "Detail",
                    .created_by = "CreatedBy",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .summaries = "Summaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemInvalidParameter,
        OpsItemLimitExceeded,
        OpsItemNotFound,
    },
} = .{};
pub const list_ops_item_related_items: struct {
    action_name: []const u8 = "ListOpsItemRelatedItems",
    Request: type = struct {
        ops_item_id: ?[]const u8 = null,
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_item_id = "OpsItemId",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ops_item_related_items) } {
            return .{ .service_metadata = service_metadata, .action = list_ops_item_related_items };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        summaries: ?[]struct {
            ops_item_id: ?[]const u8 = null,
            association_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            association_type: ?[]const u8 = null,
            resource_uri: ?[]const u8 = null,
            created_by: ?OpsItemIdentity = null,
            created_time: ?i64 = null,
            last_modified_by: ?OpsItemIdentity = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_item_id = "OpsItemId",
                    .association_id = "AssociationId",
                    .resource_type = "ResourceType",
                    .association_type = "AssociationType",
                    .resource_uri = "ResourceUri",
                    .created_by = "CreatedBy",
                    .created_time = "CreatedTime",
                    .last_modified_by = "LastModifiedBy",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .summaries = "Summaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemInvalidParameter,
    },
} = .{};
pub const list_ops_metadata: struct {
    action_name: []const u8 = "ListOpsMetadata",
    Request: type = struct {
        filters: ?[]struct {
            key: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ops_metadata) } {
            return .{ .service_metadata = service_metadata, .action = list_ops_metadata };
        }
    },
    Response: type = struct {
        ops_metadata_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            ops_metadata_arn: ?[]const u8 = null,
            last_modified_date: ?i64 = null,
            last_modified_user: ?[]const u8 = null,
            creation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .ops_metadata_arn = "OpsMetadataArn",
                    .last_modified_date = "LastModifiedDate",
                    .last_modified_user = "LastModifiedUser",
                    .creation_date = "CreationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_list = "OpsMetadataList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsMetadataInvalidArgument,
    },
} = .{};
pub const list_resource_compliance_summaries: struct {
    action_name: []const u8 = "ListResourceComplianceSummaries",
    Request: type = struct {
        filters: ?[]ComplianceStringFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_compliance_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_compliance_summaries };
        }
    },
    Response: type = struct {
        resource_compliance_summary_items: ?[]struct {
            compliance_type: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            overall_severity: ?[]const u8 = null,
            execution_summary: ?ComplianceExecutionSummary = null,
            compliant_summary: ?CompliantSummary = null,
            non_compliant_summary: ?NonCompliantSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compliance_type = "ComplianceType",
                    .resource_type = "ResourceType",
                    .resource_id = "ResourceId",
                    .status = "Status",
                    .overall_severity = "OverallSeverity",
                    .execution_summary = "ExecutionSummary",
                    .compliant_summary = "CompliantSummary",
                    .non_compliant_summary = "NonCompliantSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_compliance_summary_items = "ResourceComplianceSummaryItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidFilter,
        InvalidNextToken,
    },
} = .{};
pub const list_resource_data_sync: struct {
    action_name: []const u8 = "ListResourceDataSync",
    Request: type = struct {
        sync_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_type = "SyncType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_data_sync) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_data_sync };
        }
    },
    Response: type = struct {
        resource_data_sync_items: ?[]struct {
            sync_name: ?[]const u8 = null,
            sync_type: ?[]const u8 = null,
            sync_source: ?struct {
                source_type: ?[]const u8 = null,
                aws_organizations_source: ?ResourceDataSyncAwsOrganizationsSource = null,
                source_regions: ?[][]const u8 = null,
                include_future_regions: ?bool = null,
                state: ?[]const u8 = null,
                enable_all_ops_data_sources: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .source_type = "SourceType",
                        .aws_organizations_source = "AwsOrganizationsSource",
                        .source_regions = "SourceRegions",
                        .include_future_regions = "IncludeFutureRegions",
                        .state = "State",
                        .enable_all_ops_data_sources = "EnableAllOpsDataSources",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            s3_destination: ?ResourceDataSyncS3Destination = null,
            last_sync_time: ?i64 = null,
            last_successful_sync_time: ?i64 = null,
            sync_last_modified_time: ?i64 = null,
            last_status: ?[]const u8 = null,
            sync_created_time: ?i64 = null,
            last_sync_status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sync_name = "SyncName",
                    .sync_type = "SyncType",
                    .sync_source = "SyncSource",
                    .s3_destination = "S3Destination",
                    .last_sync_time = "LastSyncTime",
                    .last_successful_sync_time = "LastSuccessfulSyncTime",
                    .sync_last_modified_time = "SyncLastModifiedTime",
                    .last_status = "LastStatus",
                    .sync_created_time = "SyncCreatedTime",
                    .last_sync_status_message = "LastSyncStatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_data_sync_items = "ResourceDataSyncItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidNextToken,
        ResourceDataSyncInvalidConfiguration,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidResourceId,
        InvalidResourceType,
    },
} = .{};
pub const modify_document_permission: struct {
    action_name: []const u8 = "ModifyDocumentPermission",
    Request: type = struct {
        name: []const u8,
        permission_type: []const u8,
        account_ids_to_add: ?[][]const u8 = null,
        account_ids_to_remove: ?[][]const u8 = null,
        shared_document_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .permission_type = "PermissionType",
                .account_ids_to_add = "AccountIdsToAdd",
                .account_ids_to_remove = "AccountIdsToRemove",
                .shared_document_version = "SharedDocumentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_document_permission) } {
            return .{ .service_metadata = service_metadata, .action = modify_document_permission };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DocumentLimitExceeded,
        DocumentPermissionLimit,
        InternalServerError,
        InvalidDocument,
        InvalidPermissionType,
    },
} = .{};
pub const put_compliance_items: struct {
    action_name: []const u8 = "PutComplianceItems",
    Request: type = struct {
        resource_id: []const u8,
        resource_type: []const u8,
        compliance_type: []const u8,
        execution_summary: ComplianceExecutionSummary,
        items: []struct {
            id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            severity: []const u8,
            status: []const u8,
            details: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .title = "Title",
                    .severity = "Severity",
                    .status = "Status",
                    .details = "Details",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "details", field_name))
                    return try serializeMap(self.details, self.fieldNameFor("details"), options, out_stream);
                return false;
            }
        },
        item_content_hash: ?[]const u8 = null,
        upload_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
                .compliance_type = "ComplianceType",
                .execution_summary = "ExecutionSummary",
                .items = "Items",
                .item_content_hash = "ItemContentHash",
                .upload_type = "UploadType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_compliance_items) } {
            return .{ .service_metadata = service_metadata, .action = put_compliance_items };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ComplianceTypeCountLimitExceeded,
        InternalServerError,
        InvalidItemContent,
        InvalidResourceId,
        InvalidResourceType,
        ItemSizeLimitExceeded,
        TotalSizeLimitExceeded,
    },
} = .{};
pub const put_inventory: struct {
    action_name: []const u8 = "PutInventory",
    Request: type = struct {
        instance_id: []const u8,
        items: []struct {
            type_name: []const u8,
            schema_version: []const u8,
            capture_time: []const u8,
            content_hash: ?[]const u8 = null,
            content: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            context: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type_name = "TypeName",
                    .schema_version = "SchemaVersion",
                    .capture_time = "CaptureTime",
                    .content_hash = "ContentHash",
                    .content = "Content",
                    .context = "Context",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "content", field_name))
                    return try serializeMap(self.content, self.fieldNameFor("content"), options, out_stream);
                if (std.mem.eql(u8, "context", field_name))
                    return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .items = "Items",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_inventory) } {
            return .{ .service_metadata = service_metadata, .action = put_inventory };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomSchemaCountLimitExceeded,
        InternalServerError,
        InvalidInstanceId,
        InvalidInventoryItemContext,
        InvalidItemContent,
        InvalidTypeName,
        ItemContentMismatch,
        ItemSizeLimitExceeded,
        SubTypeCountLimitExceeded,
        TotalSizeLimitExceeded,
        UnsupportedInventoryItemContext,
        UnsupportedInventorySchemaVersion,
    },
} = .{};
pub const put_parameter: struct {
    action_name: []const u8 = "PutParameter",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        value: []const u8,
        type: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        overwrite: ?bool = null,
        allowed_pattern: ?[]const u8 = null,
        tags: ?[]Tag = null,
        tier: ?[]const u8 = null,
        policies: ?[]const u8 = null,
        data_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .value = "Value",
                .type = "Type",
                .key_id = "KeyId",
                .overwrite = "Overwrite",
                .allowed_pattern = "AllowedPattern",
                .tags = "Tags",
                .tier = "Tier",
                .policies = "Policies",
                .data_type = "DataType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_parameter) } {
            return .{ .service_metadata = service_metadata, .action = put_parameter };
        }
    },
    Response: type = struct {
        version: ?i64 = null,
        tier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "Version",
                .tier = "Tier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HierarchyLevelLimitExceeded,
        HierarchyTypeMismatch,
        IncompatiblePolicy,
        InternalServerError,
        InvalidAllowedPattern,
        InvalidKeyId,
        InvalidPolicyAttribute,
        InvalidPolicyType,
        ParameterAlreadyExists,
        ParameterLimitExceeded,
        ParameterMaxVersionLimitExceeded,
        ParameterPatternMismatch,
        PoliciesLimitExceeded,
        TooManyUpdates,
        UnsupportedParameterType,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,
        policy_id: ?[]const u8 = null,
        policy_hash: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
                .policy_id = "PolicyId",
                .policy_hash = "PolicyHash",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        policy_id: ?[]const u8 = null,
        policy_hash: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .policy_hash = "PolicyHash",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        MalformedResourcePolicyDocument,
        ResourceNotFound,
        ResourcePolicyConflict,
        ResourcePolicyInvalidParameter,
        ResourcePolicyLimitExceeded,
        ResourcePolicyNotFound,
    },
} = .{};
pub const register_default_patch_baseline: struct {
    action_name: []const u8 = "RegisterDefaultPatchBaseline",
    Request: type = struct {
        baseline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_default_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = register_default_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
        InvalidResourceId,
    },
} = .{};
pub const register_patch_baseline_for_patch_group: struct {
    action_name: []const u8 = "RegisterPatchBaselineForPatchGroup",
    Request: type = struct {
        baseline_id: []const u8,
        patch_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .patch_group = "PatchGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_patch_baseline_for_patch_group) } {
            return .{ .service_metadata = service_metadata, .action = register_patch_baseline_for_patch_group };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        patch_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .patch_group = "PatchGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        DoesNotExist,
        InternalServerError,
        InvalidResourceId,
        ResourceLimitExceeded,
    },
} = .{};
pub const register_target_with_maintenance_window: struct {
    action_name: []const u8 = "RegisterTargetWithMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,
        resource_type: []const u8,
        targets: []Target,
        owner_information: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .resource_type = "ResourceType",
                .targets = "Targets",
                .owner_information = "OwnerInformation",
                .name = "Name",
                .description = "Description",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_target_with_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = register_target_with_maintenance_window };
        }
    },
    Response: type = struct {
        window_target_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_target_id = "WindowTargetId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        IdempotentParameterMismatch,
        InternalServerError,
        ResourceLimitExceeded,
    },
} = .{};
pub const register_task_with_maintenance_window: struct {
    action_name: []const u8 = "RegisterTaskWithMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,
        targets: ?[]Target = null,
        task_arn: []const u8,
        service_role_arn: ?[]const u8 = null,
        task_type: []const u8,
        task_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MaintenanceWindowTaskParameterValueExpression = null,
        } = null,
        task_invocation_parameters: ?MaintenanceWindowTaskInvocationParameters = null,
        priority: ?i64 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        logging_info: ?LoggingInfo = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        cutoff_behavior: ?[]const u8 = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .targets = "Targets",
                .task_arn = "TaskArn",
                .service_role_arn = "ServiceRoleArn",
                .task_type = "TaskType",
                .task_parameters = "TaskParameters",
                .task_invocation_parameters = "TaskInvocationParameters",
                .priority = "Priority",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .logging_info = "LoggingInfo",
                .name = "Name",
                .description = "Description",
                .client_token = "ClientToken",
                .cutoff_behavior = "CutoffBehavior",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_parameters", field_name))
                return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_task_with_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = register_task_with_maintenance_window };
        }
    },
    Response: type = struct {
        window_task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_task_id = "WindowTaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        FeatureNotAvailable,
        IdempotentParameterMismatch,
        InternalServerError,
        ResourceLimitExceeded,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidResourceId,
        InvalidResourceType,
        TooManyUpdates,
    },
} = .{};
pub const reset_service_setting: struct {
    action_name: []const u8 = "ResetServiceSetting",
    Request: type = struct {
        setting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting_id = "SettingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_service_setting) } {
            return .{ .service_metadata = service_metadata, .action = reset_service_setting };
        }
    },
    Response: type = struct {
        service_setting: ?ServiceSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_setting = "ServiceSetting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ServiceSettingNotFound,
        TooManyUpdates,
    },
} = .{};
pub const resume_session: struct {
    action_name: []const u8 = "ResumeSession",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_session) } {
            return .{ .service_metadata = service_metadata, .action = resume_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        token_value: ?[]const u8 = null,
        stream_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .token_value = "TokenValue",
                .stream_url = "StreamUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const send_automation_signal: struct {
    action_name: []const u8 = "SendAutomationSignal",
    Request: type = struct {
        automation_execution_id: []const u8,
        signal_type: []const u8,
        payload: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
                .signal_type = "SignalType",
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "payload", field_name))
                return try serializeMap(self.payload, self.fieldNameFor("payload"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_automation_signal) } {
            return .{ .service_metadata = service_metadata, .action = send_automation_signal };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationExecutionNotFound,
        AutomationStepNotFound,
        InternalServerError,
        InvalidAutomationSignal,
    },
} = .{};
pub const send_command: struct {
    action_name: []const u8 = "SendCommand",
    Request: type = struct {
        instance_ids: ?[][]const u8 = null,
        targets: ?[]Target = null,
        document_name: []const u8,
        document_version: ?[]const u8 = null,
        document_hash: ?[]const u8 = null,
        document_hash_type: ?[]const u8 = null,
        timeout_seconds: ?i64 = null,
        comment: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        output_s3_region: ?[]const u8 = null,
        output_s3_bucket_name: ?[]const u8 = null,
        output_s3_key_prefix: ?[]const u8 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        service_role_arn: ?[]const u8 = null,
        notification_config: ?NotificationConfig = null,
        cloud_watch_output_config: ?CloudWatchOutputConfig = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_ids = "InstanceIds",
                .targets = "Targets",
                .document_name = "DocumentName",
                .document_version = "DocumentVersion",
                .document_hash = "DocumentHash",
                .document_hash_type = "DocumentHashType",
                .timeout_seconds = "TimeoutSeconds",
                .comment = "Comment",
                .parameters = "Parameters",
                .output_s3_region = "OutputS3Region",
                .output_s3_bucket_name = "OutputS3BucketName",
                .output_s3_key_prefix = "OutputS3KeyPrefix",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .service_role_arn = "ServiceRoleArn",
                .notification_config = "NotificationConfig",
                .cloud_watch_output_config = "CloudWatchOutputConfig",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_command) } {
            return .{ .service_metadata = service_metadata, .action = send_command };
        }
    },
    Response: type = struct {
        command: ?Command = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .command = "Command",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateInstanceId,
        InternalServerError,
        InvalidDocument,
        InvalidDocumentVersion,
        InvalidInstanceId,
        InvalidNotificationConfig,
        InvalidOutputFolder,
        InvalidParameters,
        InvalidRole,
        MaxDocumentSizeExceeded,
        UnsupportedPlatformType,
    },
} = .{};
pub const start_associations_once: struct {
    action_name: []const u8 = "StartAssociationsOnce",
    Request: type = struct {
        association_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_ids = "AssociationIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_associations_once) } {
            return .{ .service_metadata = service_metadata, .action = start_associations_once };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InvalidAssociation,
    },
} = .{};
pub const start_automation_execution: struct {
    action_name: []const u8 = "StartAutomationExecution",
    Request: type = struct {
        document_name: []const u8,
        document_version: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,
        mode: ?[]const u8 = null,
        target_parameter_name: ?[]const u8 = null,
        targets: ?[]Target = null,
        target_maps: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        target_locations: ?[]TargetLocation = null,
        tags: ?[]Tag = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_name = "DocumentName",
                .document_version = "DocumentVersion",
                .parameters = "Parameters",
                .client_token = "ClientToken",
                .mode = "Mode",
                .target_parameter_name = "TargetParameterName",
                .targets = "Targets",
                .target_maps = "TargetMaps",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .target_locations = "TargetLocations",
                .tags = "Tags",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "target_maps", field_name))
                return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_automation_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_automation_execution };
        }
    },
    Response: type = struct {
        automation_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationDefinitionNotFound,
        AutomationDefinitionVersionNotFound,
        AutomationExecutionLimitExceeded,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidAutomationExecutionParameters,
        InvalidTarget,
    },
} = .{};
pub const start_change_request_execution: struct {
    action_name: []const u8 = "StartChangeRequestExecution",
    Request: type = struct {
        scheduled_time: ?i64 = null,
        document_name: []const u8,
        document_version: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        change_request_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        auto_approve: ?bool = null,
        runbooks: []Runbook,
        tags: ?[]Tag = null,
        scheduled_end_time: ?i64 = null,
        change_details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_time = "ScheduledTime",
                .document_name = "DocumentName",
                .document_version = "DocumentVersion",
                .parameters = "Parameters",
                .change_request_name = "ChangeRequestName",
                .client_token = "ClientToken",
                .auto_approve = "AutoApprove",
                .runbooks = "Runbooks",
                .tags = "Tags",
                .scheduled_end_time = "ScheduledEndTime",
                .change_details = "ChangeDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_change_request_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_change_request_execution };
        }
    },
    Response: type = struct {
        automation_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationDefinitionNotApproved,
        AutomationDefinitionNotFound,
        AutomationDefinitionVersionNotFound,
        AutomationExecutionLimitExceeded,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidAutomationExecutionParameters,
    },
} = .{};
pub const start_session: struct {
    action_name: []const u8 = "StartSession",
    Request: type = struct {
        target: []const u8,
        document_name: ?[]const u8 = null,
        reason: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
                .document_name = "DocumentName",
                .reason = "Reason",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_session) } {
            return .{ .service_metadata = service_metadata, .action = start_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        token_value: ?[]const u8 = null,
        stream_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .token_value = "TokenValue",
                .stream_url = "StreamUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        TargetNotConnected,
    },
} = .{};
pub const stop_automation_execution: struct {
    action_name: []const u8 = "StopAutomationExecution",
    Request: type = struct {
        automation_execution_id: []const u8,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automation_execution_id = "AutomationExecutionId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_automation_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_automation_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AutomationExecutionNotFound,
        InternalServerError,
        InvalidAutomationStatusUpdate,
    },
} = .{};
pub const terminate_session: struct {
    action_name: []const u8 = "TerminateSession",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_session) } {
            return .{ .service_metadata = service_metadata, .action = terminate_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const unlabel_parameter_version: struct {
    action_name: []const u8 = "UnlabelParameterVersion",
    Request: type = struct {
        name: []const u8,
        parameter_version: i64,
        labels: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .parameter_version = "ParameterVersion",
                .labels = "Labels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unlabel_parameter_version) } {
            return .{ .service_metadata = service_metadata, .action = unlabel_parameter_version };
        }
    },
    Response: type = struct {
        removed_labels: ?[][]const u8 = null,
        invalid_labels: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .removed_labels = "RemovedLabels",
                .invalid_labels = "InvalidLabels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ParameterNotFound,
        ParameterVersionNotFound,
        TooManyUpdates,
    },
} = .{};
pub const update_association: struct {
    action_name: []const u8 = "UpdateAssociation",
    Request: type = struct {
        association_id: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        document_version: ?[]const u8 = null,
        schedule_expression: ?[]const u8 = null,
        output_location: ?InstanceAssociationOutputLocation = null,
        name: ?[]const u8 = null,
        targets: ?[]Target = null,
        association_name: ?[]const u8 = null,
        association_version: ?[]const u8 = null,
        automation_target_parameter_name: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        max_concurrency: ?[]const u8 = null,
        compliance_severity: ?[]const u8 = null,
        sync_compliance: ?[]const u8 = null,
        apply_only_at_cron_interval: ?bool = null,
        calendar_names: ?[][]const u8 = null,
        target_locations: ?[]TargetLocation = null,
        schedule_offset: ?i64 = null,
        duration: ?i64 = null,
        target_maps: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
                .parameters = "Parameters",
                .document_version = "DocumentVersion",
                .schedule_expression = "ScheduleExpression",
                .output_location = "OutputLocation",
                .name = "Name",
                .targets = "Targets",
                .association_name = "AssociationName",
                .association_version = "AssociationVersion",
                .automation_target_parameter_name = "AutomationTargetParameterName",
                .max_errors = "MaxErrors",
                .max_concurrency = "MaxConcurrency",
                .compliance_severity = "ComplianceSeverity",
                .sync_compliance = "SyncCompliance",
                .apply_only_at_cron_interval = "ApplyOnlyAtCronInterval",
                .calendar_names = "CalendarNames",
                .target_locations = "TargetLocations",
                .schedule_offset = "ScheduleOffset",
                .duration = "Duration",
                .target_maps = "TargetMaps",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "target_maps", field_name))
                return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_association) } {
            return .{ .service_metadata = service_metadata, .action = update_association };
        }
    },
    Response: type = struct {
        association_description: ?AssociationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_description = "AssociationDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        AssociationVersionLimitExceeded,
        InternalServerError,
        InvalidAssociationVersion,
        InvalidDocument,
        InvalidDocumentVersion,
        InvalidOutputLocation,
        InvalidParameters,
        InvalidSchedule,
        InvalidTarget,
        InvalidTargetMaps,
        InvalidUpdate,
        TooManyUpdates,
    },
} = .{};
pub const update_association_status: struct {
    action_name: []const u8 = "UpdateAssociationStatus",
    Request: type = struct {
        name: []const u8,
        instance_id: []const u8,
        association_status: AssociationStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .instance_id = "InstanceId",
                .association_status = "AssociationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_association_status) } {
            return .{ .service_metadata = service_metadata, .action = update_association_status };
        }
    },
    Response: type = struct {
        association_description: ?AssociationDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_description = "AssociationDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AssociationDoesNotExist,
        InternalServerError,
        InvalidDocument,
        InvalidInstanceId,
        StatusUnchanged,
        TooManyUpdates,
    },
} = .{};
pub const update_document: struct {
    action_name: []const u8 = "UpdateDocument",
    Request: type = struct {
        content: []const u8,
        attachments: ?[]AttachmentsSource = null,
        name: []const u8,
        display_name: ?[]const u8 = null,
        version_name: ?[]const u8 = null,
        document_version: ?[]const u8 = null,
        document_format: ?[]const u8 = null,
        target_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .attachments = "Attachments",
                .name = "Name",
                .display_name = "DisplayName",
                .version_name = "VersionName",
                .document_version = "DocumentVersion",
                .document_format = "DocumentFormat",
                .target_type = "TargetType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_document) } {
            return .{ .service_metadata = service_metadata, .action = update_document };
        }
    },
    Response: type = struct {
        document_description: ?DocumentDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_description = "DocumentDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DocumentVersionLimitExceeded,
        DuplicateDocumentContent,
        DuplicateDocumentVersionName,
        InternalServerError,
        InvalidDocument,
        InvalidDocumentContent,
        InvalidDocumentOperation,
        InvalidDocumentSchemaVersion,
        InvalidDocumentVersion,
        MaxDocumentSizeExceeded,
    },
} = .{};
pub const update_document_default_version: struct {
    action_name: []const u8 = "UpdateDocumentDefaultVersion",
    Request: type = struct {
        name: []const u8,
        document_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_document_default_version) } {
            return .{ .service_metadata = service_metadata, .action = update_document_default_version };
        }
    },
    Response: type = struct {
        description: ?struct {
            name: ?[]const u8 = null,
            default_version: ?[]const u8 = null,
            default_version_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .default_version = "DefaultVersion",
                    .default_version_name = "DefaultVersionName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentSchemaVersion,
        InvalidDocumentVersion,
    },
} = .{};
pub const update_document_metadata: struct {
    action_name: []const u8 = "UpdateDocumentMetadata",
    Request: type = struct {
        name: []const u8,
        document_version: ?[]const u8 = null,
        document_reviews: struct {
            action: []const u8,
            comment: ?[]DocumentReviewCommentSource = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .comment = "Comment",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document_version = "DocumentVersion",
                .document_reviews = "DocumentReviews",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_document_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_document_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidDocument,
        InvalidDocumentOperation,
        InvalidDocumentVersion,
    },
} = .{};
pub const update_maintenance_window: struct {
    action_name: []const u8 = "UpdateMaintenanceWindow",
    Request: type = struct {
        window_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        schedule_timezone: ?[]const u8 = null,
        schedule_offset: ?i64 = null,
        duration: ?i64 = null,
        cutoff: ?i64 = null,
        allow_unassociated_targets: ?bool = null,
        enabled: ?bool = null,
        replace: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .name = "Name",
                .description = "Description",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .schedule = "Schedule",
                .schedule_timezone = "ScheduleTimezone",
                .schedule_offset = "ScheduleOffset",
                .duration = "Duration",
                .cutoff = "Cutoff",
                .allow_unassociated_targets = "AllowUnassociatedTargets",
                .enabled = "Enabled",
                .replace = "Replace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_maintenance_window) } {
            return .{ .service_metadata = service_metadata, .action = update_maintenance_window };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        schedule: ?[]const u8 = null,
        schedule_timezone: ?[]const u8 = null,
        schedule_offset: ?i64 = null,
        duration: ?i64 = null,
        cutoff: ?i64 = null,
        allow_unassociated_targets: ?bool = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .name = "Name",
                .description = "Description",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .schedule = "Schedule",
                .schedule_timezone = "ScheduleTimezone",
                .schedule_offset = "ScheduleOffset",
                .duration = "Duration",
                .cutoff = "Cutoff",
                .allow_unassociated_targets = "AllowUnassociatedTargets",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const update_maintenance_window_target: struct {
    action_name: []const u8 = "UpdateMaintenanceWindowTarget",
    Request: type = struct {
        window_id: []const u8,
        window_target_id: []const u8,
        targets: ?[]Target = null,
        owner_information: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        replace: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_target_id = "WindowTargetId",
                .targets = "Targets",
                .owner_information = "OwnerInformation",
                .name = "Name",
                .description = "Description",
                .replace = "Replace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_maintenance_window_target) } {
            return .{ .service_metadata = service_metadata, .action = update_maintenance_window_target };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        window_target_id: ?[]const u8 = null,
        targets: ?[]Target = null,
        owner_information: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_target_id = "WindowTargetId",
                .targets = "Targets",
                .owner_information = "OwnerInformation",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const update_maintenance_window_task: struct {
    action_name: []const u8 = "UpdateMaintenanceWindowTask",
    Request: type = struct {
        window_id: []const u8,
        window_task_id: []const u8,
        targets: ?[]Target = null,
        task_arn: ?[]const u8 = null,
        service_role_arn: ?[]const u8 = null,
        task_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MaintenanceWindowTaskParameterValueExpression = null,
        } = null,
        task_invocation_parameters: ?MaintenanceWindowTaskInvocationParameters = null,
        priority: ?i64 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        logging_info: ?LoggingInfo = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        replace: ?bool = null,
        cutoff_behavior: ?[]const u8 = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
                .targets = "Targets",
                .task_arn = "TaskArn",
                .service_role_arn = "ServiceRoleArn",
                .task_parameters = "TaskParameters",
                .task_invocation_parameters = "TaskInvocationParameters",
                .priority = "Priority",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .logging_info = "LoggingInfo",
                .name = "Name",
                .description = "Description",
                .replace = "Replace",
                .cutoff_behavior = "CutoffBehavior",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_parameters", field_name))
                return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_maintenance_window_task) } {
            return .{ .service_metadata = service_metadata, .action = update_maintenance_window_task };
        }
    },
    Response: type = struct {
        window_id: ?[]const u8 = null,
        window_task_id: ?[]const u8 = null,
        targets: ?[]Target = null,
        task_arn: ?[]const u8 = null,
        service_role_arn: ?[]const u8 = null,
        task_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MaintenanceWindowTaskParameterValueExpression = null,
        } = null,
        task_invocation_parameters: ?MaintenanceWindowTaskInvocationParameters = null,
        priority: ?i64 = null,
        max_concurrency: ?[]const u8 = null,
        max_errors: ?[]const u8 = null,
        logging_info: ?LoggingInfo = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cutoff_behavior: ?[]const u8 = null,
        alarm_configuration: ?AlarmConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .window_id = "WindowId",
                .window_task_id = "WindowTaskId",
                .targets = "Targets",
                .task_arn = "TaskArn",
                .service_role_arn = "ServiceRoleArn",
                .task_parameters = "TaskParameters",
                .task_invocation_parameters = "TaskInvocationParameters",
                .priority = "Priority",
                .max_concurrency = "MaxConcurrency",
                .max_errors = "MaxErrors",
                .logging_info = "LoggingInfo",
                .name = "Name",
                .description = "Description",
                .cutoff_behavior = "CutoffBehavior",
                .alarm_configuration = "AlarmConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "task_parameters", field_name))
                return try serializeMap(self.task_parameters, self.fieldNameFor("task_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const update_managed_instance_role: struct {
    action_name: []const u8 = "UpdateManagedInstanceRole",
    Request: type = struct {
        instance_id: []const u8,
        iam_role: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .iam_role = "IamRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_managed_instance_role) } {
            return .{ .service_metadata = service_metadata, .action = update_managed_instance_role };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidInstanceId,
    },
} = .{};
pub const update_ops_item: struct {
    action_name: []const u8 = "UpdateOpsItem",
    Request: type = struct {
        description: ?[]const u8 = null,
        operational_data: ?[]struct {
            key: ?[]const u8 = null,
            value: ?OpsItemDataValue = null,
        } = null,
        operational_data_to_delete: ?[][]const u8 = null,
        notifications: ?[]OpsItemNotification = null,
        priority: ?i64 = null,
        related_ops_items: ?[]RelatedOpsItem = null,
        status: ?[]const u8 = null,
        ops_item_id: []const u8,
        title: ?[]const u8 = null,
        category: ?[]const u8 = null,
        severity: ?[]const u8 = null,
        actual_start_time: ?i64 = null,
        actual_end_time: ?i64 = null,
        planned_start_time: ?i64 = null,
        planned_end_time: ?i64 = null,
        ops_item_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .operational_data = "OperationalData",
                .operational_data_to_delete = "OperationalDataToDelete",
                .notifications = "Notifications",
                .priority = "Priority",
                .related_ops_items = "RelatedOpsItems",
                .status = "Status",
                .ops_item_id = "OpsItemId",
                .title = "Title",
                .category = "Category",
                .severity = "Severity",
                .actual_start_time = "ActualStartTime",
                .actual_end_time = "ActualEndTime",
                .planned_start_time = "PlannedStartTime",
                .planned_end_time = "PlannedEndTime",
                .ops_item_arn = "OpsItemArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "operational_data", field_name))
                return try serializeMap(self.operational_data, self.fieldNameFor("operational_data"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ops_item) } {
            return .{ .service_metadata = service_metadata, .action = update_ops_item };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsItemAccessDenied,
        OpsItemAlreadyExists,
        OpsItemConflict,
        OpsItemInvalidParameter,
        OpsItemLimitExceeded,
        OpsItemNotFound,
    },
} = .{};
pub const update_ops_metadata: struct {
    action_name: []const u8 = "UpdateOpsMetadata",
    Request: type = struct {
        ops_metadata_arn: []const u8,
        metadata_to_update: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MetadataValue = null,
        } = null,
        keys_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_arn = "OpsMetadataArn",
                .metadata_to_update = "MetadataToUpdate",
                .keys_to_delete = "KeysToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata_to_update", field_name))
                return try serializeMap(self.metadata_to_update, self.fieldNameFor("metadata_to_update"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ops_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_ops_metadata };
        }
    },
    Response: type = struct {
        ops_metadata_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ops_metadata_arn = "OpsMetadataArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        OpsMetadataInvalidArgument,
        OpsMetadataKeyLimitExceeded,
        OpsMetadataNotFound,
        OpsMetadataTooManyUpdates,
    },
} = .{};
pub const update_patch_baseline: struct {
    action_name: []const u8 = "UpdatePatchBaseline",
    Request: type = struct {
        baseline_id: []const u8,
        name: ?[]const u8 = null,
        global_filters: ?PatchFilterGroup = null,
        approval_rules: ?PatchRuleGroup = null,
        approved_patches: ?[][]const u8 = null,
        approved_patches_compliance_level: ?[]const u8 = null,
        approved_patches_enable_non_security: ?bool = null,
        rejected_patches: ?[][]const u8 = null,
        rejected_patches_action: ?[]const u8 = null,
        description: ?[]const u8 = null,
        sources: ?[]PatchSource = null,
        replace: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .name = "Name",
                .global_filters = "GlobalFilters",
                .approval_rules = "ApprovalRules",
                .approved_patches = "ApprovedPatches",
                .approved_patches_compliance_level = "ApprovedPatchesComplianceLevel",
                .approved_patches_enable_non_security = "ApprovedPatchesEnableNonSecurity",
                .rejected_patches = "RejectedPatches",
                .rejected_patches_action = "RejectedPatchesAction",
                .description = "Description",
                .sources = "Sources",
                .replace = "Replace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_patch_baseline) } {
            return .{ .service_metadata = service_metadata, .action = update_patch_baseline };
        }
    },
    Response: type = struct {
        baseline_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        operating_system: ?[]const u8 = null,
        global_filters: ?PatchFilterGroup = null,
        approval_rules: ?PatchRuleGroup = null,
        approved_patches: ?[][]const u8 = null,
        approved_patches_compliance_level: ?[]const u8 = null,
        approved_patches_enable_non_security: ?bool = null,
        rejected_patches: ?[][]const u8 = null,
        rejected_patches_action: ?[]const u8 = null,
        created_date: ?i64 = null,
        modified_date: ?i64 = null,
        description: ?[]const u8 = null,
        sources: ?[]PatchSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .baseline_id = "BaselineId",
                .name = "Name",
                .operating_system = "OperatingSystem",
                .global_filters = "GlobalFilters",
                .approval_rules = "ApprovalRules",
                .approved_patches = "ApprovedPatches",
                .approved_patches_compliance_level = "ApprovedPatchesComplianceLevel",
                .approved_patches_enable_non_security = "ApprovedPatchesEnableNonSecurity",
                .rejected_patches = "RejectedPatches",
                .rejected_patches_action = "RejectedPatchesAction",
                .created_date = "CreatedDate",
                .modified_date = "ModifiedDate",
                .description = "Description",
                .sources = "Sources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DoesNotExist,
        InternalServerError,
    },
} = .{};
pub const update_resource_data_sync: struct {
    action_name: []const u8 = "UpdateResourceDataSync",
    Request: type = struct {
        sync_name: []const u8,
        sync_type: []const u8,
        sync_source: ResourceDataSyncSource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sync_name = "SyncName",
                .sync_type = "SyncType",
                .sync_source = "SyncSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_data_sync) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_data_sync };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ResourceDataSyncConflict,
        ResourceDataSyncInvalidConfiguration,
        ResourceDataSyncNotFound,
    },
} = .{};
pub const update_service_setting: struct {
    action_name: []const u8 = "UpdateServiceSetting",
    Request: type = struct {
        setting_id: []const u8,
        setting_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .setting_id = "SettingId",
                .setting_value = "SettingValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_setting) } {
            return .{ .service_metadata = service_metadata, .action = update_service_setting };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        ServiceSettingNotFound,
        TooManyUpdates,
    },
} = .{};

pub const ResourceDataSyncSource = struct {
    source_type: []const u8,
    aws_organizations_source: ?ResourceDataSyncAwsOrganizationsSource = null,
    source_regions: [][]const u8,
    include_future_regions: ?bool = null,
    enable_all_ops_data_sources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_type = "SourceType",
            .aws_organizations_source = "AwsOrganizationsSource",
            .source_regions = "SourceRegions",
            .include_future_regions = "IncludeFutureRegions",
            .enable_all_ops_data_sources = "EnableAllOpsDataSources",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDataSyncAwsOrganizationsSource = struct {
    organization_source_type: []const u8,
    organizational_units: ?[]ResourceDataSyncOrganizationalUnit = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .organization_source_type = "OrganizationSourceType",
            .organizational_units = "OrganizationalUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDataSyncOrganizationalUnit = struct {
    organizational_unit_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .organizational_unit_id = "OrganizationalUnitId",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchSource = struct {
    name: []const u8,
    products: [][]const u8,
    configuration: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .products = "Products",
            .configuration = "Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchRuleGroup = struct {
    patch_rules: []PatchRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .patch_rules = "PatchRules",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchRule = struct {
    patch_filter_group: PatchFilterGroup,
    compliance_level: ?[]const u8 = null,
    approve_after_days: ?i64 = null,
    approve_until_date: ?[]const u8 = null,
    enable_non_security: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .patch_filter_group = "PatchFilterGroup",
            .compliance_level = "ComplianceLevel",
            .approve_after_days = "ApproveAfterDays",
            .approve_until_date = "ApproveUntilDate",
            .enable_non_security = "EnableNonSecurity",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchFilterGroup = struct {
    patch_filters: []PatchFilter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .patch_filters = "PatchFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchFilter = struct {
    key: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataValue = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedOpsItem = struct {
    ops_item_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ops_item_id = "OpsItemId",
        };
        return @field(mappings, field_name);
    }
};

pub const OpsItemNotification = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const OpsItemDataValue = struct {
    value: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmConfiguration = struct {
    ignore_poll_alarm_failure: ?bool = null,
    alarms: []Alarm,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ignore_poll_alarm_failure = "IgnorePollAlarmFailure",
            .alarms = "Alarms",
        };
        return @field(mappings, field_name);
    }
};

pub const Alarm = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingInfo = struct {
    s3_bucket_name: []const u8,
    s3_key_prefix: ?[]const u8 = null,
    s3_region: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .s3_region = "S3Region",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowTaskInvocationParameters = struct {
    run_command: ?MaintenanceWindowRunCommandParameters = null,
    automation: ?MaintenanceWindowAutomationParameters = null,
    step_functions: ?MaintenanceWindowStepFunctionsParameters = null,
    lambda: ?MaintenanceWindowLambdaParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .run_command = "RunCommand",
            .automation = "Automation",
            .step_functions = "StepFunctions",
            .lambda = "Lambda",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowLambdaParameters = struct {
    client_context: ?[]const u8 = null,
    qualifier: ?[]const u8 = null,
    payload: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_context = "ClientContext",
            .qualifier = "Qualifier",
            .payload = "Payload",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowStepFunctionsParameters = struct {
    input: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input = "Input",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowAutomationParameters = struct {
    document_version: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_version = "DocumentVersion",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const MaintenanceWindowRunCommandParameters = struct {
    comment: ?[]const u8 = null,
    cloud_watch_output_config: ?CloudWatchOutputConfig = null,
    document_hash: ?[]const u8 = null,
    document_hash_type: ?[]const u8 = null,
    document_version: ?[]const u8 = null,
    notification_config: ?NotificationConfig = null,
    output_s3_bucket_name: ?[]const u8 = null,
    output_s3_key_prefix: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    service_role_arn: ?[]const u8 = null,
    timeout_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .cloud_watch_output_config = "CloudWatchOutputConfig",
            .document_hash = "DocumentHash",
            .document_hash_type = "DocumentHashType",
            .document_version = "DocumentVersion",
            .notification_config = "NotificationConfig",
            .output_s3_bucket_name = "OutputS3BucketName",
            .output_s3_key_prefix = "OutputS3KeyPrefix",
            .parameters = "Parameters",
            .service_role_arn = "ServiceRoleArn",
            .timeout_seconds = "TimeoutSeconds",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const NotificationConfig = struct {
    notification_arn: ?[]const u8 = null,
    notification_events: ?[][]const u8 = null,
    notification_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_arn = "NotificationArn",
            .notification_events = "NotificationEvents",
            .notification_type = "NotificationType",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchOutputConfig = struct {
    cloud_watch_log_group_name: ?[]const u8 = null,
    cloud_watch_output_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_group_name = "CloudWatchLogGroupName",
            .cloud_watch_output_enabled = "CloudWatchOutputEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowTaskParameterValueExpression = struct {
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const Target = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentReviewCommentSource = struct {
    type: ?[]const u8 = null,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentDescription = struct {
    sha1: ?[]const u8 = null,
    hash: ?[]const u8 = null,
    hash_type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    version_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    created_date: ?i64 = null,
    status: ?[]const u8 = null,
    status_information: ?[]const u8 = null,
    document_version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    parameters: ?[]DocumentParameter = null,
    platform_types: ?[][]const u8 = null,
    document_type: ?[]const u8 = null,
    schema_version: ?[]const u8 = null,
    latest_version: ?[]const u8 = null,
    default_version: ?[]const u8 = null,
    document_format: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    tags: ?[]Tag = null,
    attachments_information: ?[]AttachmentInformation = null,
    requires: ?[]DocumentRequires = null,
    author: ?[]const u8 = null,
    review_information: ?[]ReviewInformation = null,
    approved_version: ?[]const u8 = null,
    pending_review_version: ?[]const u8 = null,
    review_status: ?[]const u8 = null,
    category: ?[][]const u8 = null,
    category_enum: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sha1 = "Sha1",
            .hash = "Hash",
            .hash_type = "HashType",
            .name = "Name",
            .display_name = "DisplayName",
            .version_name = "VersionName",
            .owner = "Owner",
            .created_date = "CreatedDate",
            .status = "Status",
            .status_information = "StatusInformation",
            .document_version = "DocumentVersion",
            .description = "Description",
            .parameters = "Parameters",
            .platform_types = "PlatformTypes",
            .document_type = "DocumentType",
            .schema_version = "SchemaVersion",
            .latest_version = "LatestVersion",
            .default_version = "DefaultVersion",
            .document_format = "DocumentFormat",
            .target_type = "TargetType",
            .tags = "Tags",
            .attachments_information = "AttachmentsInformation",
            .requires = "Requires",
            .author = "Author",
            .review_information = "ReviewInformation",
            .approved_version = "ApprovedVersion",
            .pending_review_version = "PendingReviewVersion",
            .review_status = "ReviewStatus",
            .category = "Category",
            .category_enum = "CategoryEnum",
        };
        return @field(mappings, field_name);
    }
};

pub const ReviewInformation = struct {
    reviewed_time: ?i64 = null,
    status: ?[]const u8 = null,
    reviewer: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reviewed_time = "ReviewedTime",
            .status = "Status",
            .reviewer = "Reviewer",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentRequires = struct {
    name: []const u8,
    version: ?[]const u8 = null,
    require_type: ?[]const u8 = null,
    version_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .version = "Version",
            .require_type = "RequireType",
            .version_name = "VersionName",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentInformation = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentParameter = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .description = "Description",
            .default_value = "DefaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentsSource = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationDescription = struct {
    name: ?[]const u8 = null,
    instance_id: ?[]const u8 = null,
    association_version: ?[]const u8 = null,
    date: ?i64 = null,
    last_update_association_date: ?i64 = null,
    status: ?AssociationStatus = null,
    overview: ?AssociationOverview = null,
    document_version: ?[]const u8 = null,
    automation_target_parameter_name: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    association_id: ?[]const u8 = null,
    targets: ?[]Target = null,
    schedule_expression: ?[]const u8 = null,
    output_location: ?InstanceAssociationOutputLocation = null,
    last_execution_date: ?i64 = null,
    last_successful_execution_date: ?i64 = null,
    association_name: ?[]const u8 = null,
    max_errors: ?[]const u8 = null,
    max_concurrency: ?[]const u8 = null,
    compliance_severity: ?[]const u8 = null,
    sync_compliance: ?[]const u8 = null,
    apply_only_at_cron_interval: ?bool = null,
    calendar_names: ?[][]const u8 = null,
    target_locations: ?[]TargetLocation = null,
    schedule_offset: ?i64 = null,
    duration: ?i64 = null,
    target_maps: ?[][]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    alarm_configuration: ?AlarmConfiguration = null,
    triggered_alarms: ?[]AlarmStateInformation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .instance_id = "InstanceId",
            .association_version = "AssociationVersion",
            .date = "Date",
            .last_update_association_date = "LastUpdateAssociationDate",
            .status = "Status",
            .overview = "Overview",
            .document_version = "DocumentVersion",
            .automation_target_parameter_name = "AutomationTargetParameterName",
            .parameters = "Parameters",
            .association_id = "AssociationId",
            .targets = "Targets",
            .schedule_expression = "ScheduleExpression",
            .output_location = "OutputLocation",
            .last_execution_date = "LastExecutionDate",
            .last_successful_execution_date = "LastSuccessfulExecutionDate",
            .association_name = "AssociationName",
            .max_errors = "MaxErrors",
            .max_concurrency = "MaxConcurrency",
            .compliance_severity = "ComplianceSeverity",
            .sync_compliance = "SyncCompliance",
            .apply_only_at_cron_interval = "ApplyOnlyAtCronInterval",
            .calendar_names = "CalendarNames",
            .target_locations = "TargetLocations",
            .schedule_offset = "ScheduleOffset",
            .duration = "Duration",
            .target_maps = "TargetMaps",
            .alarm_configuration = "AlarmConfiguration",
            .triggered_alarms = "TriggeredAlarms",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "target_maps", field_name))
            return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
        return false;
    }
};

pub const AlarmStateInformation = struct {
    name: []const u8,
    state: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetLocation = struct {
    accounts: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,
    target_location_max_concurrency: ?[]const u8 = null,
    target_location_max_errors: ?[]const u8 = null,
    execution_role_name: ?[]const u8 = null,
    target_location_alarm_configuration: ?AlarmConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accounts = "Accounts",
            .regions = "Regions",
            .target_location_max_concurrency = "TargetLocationMaxConcurrency",
            .target_location_max_errors = "TargetLocationMaxErrors",
            .execution_role_name = "ExecutionRoleName",
            .target_location_alarm_configuration = "TargetLocationAlarmConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceAssociationOutputLocation = struct {
    s3_location: ?S3OutputLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "S3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3OutputLocation = struct {
    output_s3_region: ?[]const u8 = null,
    output_s3_bucket_name: ?[]const u8 = null,
    output_s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_region = "OutputS3Region",
            .output_s3_bucket_name = "OutputS3BucketName",
            .output_s3_key_prefix = "OutputS3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationOverview = struct {
    status: ?[]const u8 = null,
    detailed_status: ?[]const u8 = null,
    association_status_aggregated_count: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .detailed_status = "DetailedStatus",
            .association_status_aggregated_count = "AssociationStatusAggregatedCount",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "association_status_aggregated_count", field_name))
            return try serializeMap(self.association_status_aggregated_count, self.fieldNameFor("association_status_aggregated_count"), options, out_stream);
        return false;
    }
};

pub const AssociationStatus = struct {
    date: i64,
    name: []const u8,
    message: []const u8,
    additional_info: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .name = "Name",
            .message = "Message",
            .additional_info = "AdditionalInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const Runbook = struct {
    document_name: []const u8,
    document_version: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    target_parameter_name: ?[]const u8 = null,
    targets: ?[]Target = null,
    target_maps: ?[][]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    max_concurrency: ?[]const u8 = null,
    max_errors: ?[]const u8 = null,
    target_locations: ?[]TargetLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_name = "DocumentName",
            .document_version = "DocumentVersion",
            .parameters = "Parameters",
            .target_parameter_name = "TargetParameterName",
            .targets = "Targets",
            .target_maps = "TargetMaps",
            .max_concurrency = "MaxConcurrency",
            .max_errors = "MaxErrors",
            .target_locations = "TargetLocations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "target_maps", field_name))
            return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
        return false;
    }
};

pub const Command = struct {
    command_id: ?[]const u8 = null,
    document_name: ?[]const u8 = null,
    document_version: ?[]const u8 = null,
    comment: ?[]const u8 = null,
    expires_after: ?i64 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    instance_ids: ?[][]const u8 = null,
    targets: ?[]Target = null,
    requested_date_time: ?i64 = null,
    status: ?[]const u8 = null,
    status_details: ?[]const u8 = null,
    output_s3_region: ?[]const u8 = null,
    output_s3_bucket_name: ?[]const u8 = null,
    output_s3_key_prefix: ?[]const u8 = null,
    max_concurrency: ?[]const u8 = null,
    max_errors: ?[]const u8 = null,
    target_count: ?i64 = null,
    completed_count: ?i64 = null,
    error_count: ?i64 = null,
    delivery_timed_out_count: ?i64 = null,
    service_role: ?[]const u8 = null,
    notification_config: ?NotificationConfig = null,
    cloud_watch_output_config: ?CloudWatchOutputConfig = null,
    timeout_seconds: ?i64 = null,
    alarm_configuration: ?AlarmConfiguration = null,
    triggered_alarms: ?[]AlarmStateInformation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .command_id = "CommandId",
            .document_name = "DocumentName",
            .document_version = "DocumentVersion",
            .comment = "Comment",
            .expires_after = "ExpiresAfter",
            .parameters = "Parameters",
            .instance_ids = "InstanceIds",
            .targets = "Targets",
            .requested_date_time = "RequestedDateTime",
            .status = "Status",
            .status_details = "StatusDetails",
            .output_s3_region = "OutputS3Region",
            .output_s3_bucket_name = "OutputS3BucketName",
            .output_s3_key_prefix = "OutputS3KeyPrefix",
            .max_concurrency = "MaxConcurrency",
            .max_errors = "MaxErrors",
            .target_count = "TargetCount",
            .completed_count = "CompletedCount",
            .error_count = "ErrorCount",
            .delivery_timed_out_count = "DeliveryTimedOutCount",
            .service_role = "ServiceRole",
            .notification_config = "NotificationConfig",
            .cloud_watch_output_config = "CloudWatchOutputConfig",
            .timeout_seconds = "TimeoutSeconds",
            .alarm_configuration = "AlarmConfiguration",
            .triggered_alarms = "TriggeredAlarms",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const ServiceSetting = struct {
    setting_id: ?[]const u8 = null,
    setting_value: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    last_modified_user: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .setting_id = "SettingId",
            .setting_value = "SettingValue",
            .last_modified_date = "LastModifiedDate",
            .last_modified_user = "LastModifiedUser",
            .arn = "ARN",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ComplianceExecutionSummary = struct {
    execution_time: i64,
    execution_id: ?[]const u8 = null,
    execution_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_time = "ExecutionTime",
            .execution_id = "ExecutionId",
            .execution_type = "ExecutionType",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDataSyncS3Destination = struct {
    bucket_name: []const u8,
    prefix: ?[]const u8 = null,
    sync_format: []const u8,
    region: []const u8,
    awskms_key_arn: ?[]const u8 = null,
    destination_data_sharing: ?ResourceDataSyncDestinationDataSharing = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .prefix = "Prefix",
            .sync_format = "SyncFormat",
            .region = "Region",
            .awskms_key_arn = "AWSKMSKeyARN",
            .destination_data_sharing = "DestinationDataSharing",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceDataSyncDestinationDataSharing = struct {
    destination_data_sharing_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_data_sharing_type = "DestinationDataSharingType",
        };
        return @field(mappings, field_name);
    }
};

pub const NonCompliantSummary = struct {
    non_compliant_count: ?i64 = null,
    severity_summary: ?SeveritySummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .non_compliant_count = "NonCompliantCount",
            .severity_summary = "SeveritySummary",
        };
        return @field(mappings, field_name);
    }
};

pub const SeveritySummary = struct {
    critical_count: ?i64 = null,
    high_count: ?i64 = null,
    medium_count: ?i64 = null,
    low_count: ?i64 = null,
    informational_count: ?i64 = null,
    unspecified_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .critical_count = "CriticalCount",
            .high_count = "HighCount",
            .medium_count = "MediumCount",
            .low_count = "LowCount",
            .informational_count = "InformationalCount",
            .unspecified_count = "UnspecifiedCount",
        };
        return @field(mappings, field_name);
    }
};

pub const CompliantSummary = struct {
    compliant_count: ?i64 = null,
    severity_summary: ?SeveritySummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliant_count = "CompliantCount",
            .severity_summary = "SeveritySummary",
        };
        return @field(mappings, field_name);
    }
};

pub const ComplianceStringFilter = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const OpsItemIdentity = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryFilter = struct {
    key: []const u8,
    values: [][]const u8,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const CommandFilter = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    version: ?i64 = null,
    selector: ?[]const u8 = null,
    source_result: ?[]const u8 = null,
    last_modified_date: ?i64 = null,
    arn: ?[]const u8 = null,
    data_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .value = "Value",
            .version = "Version",
            .selector = "Selector",
            .source_result = "SourceResult",
            .last_modified_date = "LastModifiedDate",
            .arn = "ARN",
            .data_type = "DataType",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterStringFilter = struct {
    key: []const u8,
    option: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .option = "Option",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterInlinePolicy = struct {
    policy_text: ?[]const u8 = null,
    policy_type: ?[]const u8 = null,
    policy_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_text = "PolicyText",
            .policy_type = "PolicyType",
            .policy_status = "PolicyStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const OpsFilter = struct {
    key: []const u8,
    values: [][]const u8,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ResolvedTargets = struct {
    parameter_values: ?[][]const u8 = null,
    truncated: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_values = "ParameterValues",
            .truncated = "Truncated",
        };
        return @field(mappings, field_name);
    }
};

pub const StepExecution = struct {
    step_name: ?[]const u8 = null,
    action: ?[]const u8 = null,
    timeout_seconds: ?i64 = null,
    on_failure: ?[]const u8 = null,
    max_attempts: ?i64 = null,
    execution_start_time: ?i64 = null,
    execution_end_time: ?i64 = null,
    step_status: ?[]const u8 = null,
    response_code: ?[]const u8 = null,
    inputs: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    outputs: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    response: ?[]const u8 = null,
    failure_message: ?[]const u8 = null,
    failure_details: ?FailureDetails = null,
    step_execution_id: ?[]const u8 = null,
    overridden_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    is_end: ?bool = null,
    next_step: ?[]const u8 = null,
    is_critical: ?bool = null,
    valid_next_steps: ?[][]const u8 = null,
    targets: ?[]Target = null,
    target_location: ?TargetLocation = null,
    triggered_alarms: ?[]AlarmStateInformation = null,
    parent_step_details: ?ParentStepDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_name = "StepName",
            .action = "Action",
            .timeout_seconds = "TimeoutSeconds",
            .on_failure = "OnFailure",
            .max_attempts = "MaxAttempts",
            .execution_start_time = "ExecutionStartTime",
            .execution_end_time = "ExecutionEndTime",
            .step_status = "StepStatus",
            .response_code = "ResponseCode",
            .inputs = "Inputs",
            .outputs = "Outputs",
            .response = "Response",
            .failure_message = "FailureMessage",
            .failure_details = "FailureDetails",
            .step_execution_id = "StepExecutionId",
            .overridden_parameters = "OverriddenParameters",
            .is_end = "IsEnd",
            .next_step = "NextStep",
            .is_critical = "IsCritical",
            .valid_next_steps = "ValidNextSteps",
            .targets = "Targets",
            .target_location = "TargetLocation",
            .triggered_alarms = "TriggeredAlarms",
            .parent_step_details = "ParentStepDetails",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "inputs", field_name))
            return try serializeMap(self.inputs, self.fieldNameFor("inputs"), options, out_stream);
        if (std.mem.eql(u8, "outputs", field_name))
            return try serializeMap(self.outputs, self.fieldNameFor("outputs"), options, out_stream);
        if (std.mem.eql(u8, "overridden_parameters", field_name))
            return try serializeMap(self.overridden_parameters, self.fieldNameFor("overridden_parameters"), options, out_stream);
        return false;
    }
};

pub const ParentStepDetails = struct {
    step_execution_id: ?[]const u8 = null,
    step_name: ?[]const u8 = null,
    action: ?[]const u8 = null,
    iteration: ?i64 = null,
    iterator_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_execution_id = "StepExecutionId",
            .step_name = "StepName",
            .action = "Action",
            .iteration = "Iteration",
            .iterator_value = "IteratorValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureDetails = struct {
    failure_stage: ?[]const u8 = null,
    failure_type: ?[]const u8 = null,
    details: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_stage = "FailureStage",
            .failure_type = "FailureType",
            .details = "Details",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "details", field_name))
            return try serializeMap(self.details, self.fieldNameFor("details"), options, out_stream);
        return false;
    }
};

pub const PatchBaselineIdentity = struct {
    baseline_id: ?[]const u8 = null,
    baseline_name: ?[]const u8 = null,
    operating_system: ?[]const u8 = null,
    baseline_description: ?[]const u8 = null,
    default_baseline: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baseline_id = "BaselineId",
            .baseline_name = "BaselineName",
            .operating_system = "OperatingSystem",
            .baseline_description = "BaselineDescription",
            .default_baseline = "DefaultBaseline",
        };
        return @field(mappings, field_name);
    }
};

pub const PatchOrchestratorFilter = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindowFilter = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryDeletionSummary = struct {
    total_count: ?i64 = null,
    remaining_count: ?i64 = null,
    summary_items: ?[]InventoryDeletionSummaryItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_count = "TotalCount",
            .remaining_count = "RemainingCount",
            .summary_items = "SummaryItems",
        };
        return @field(mappings, field_name);
    }
};

pub const InventoryDeletionSummaryItem = struct {
    version: ?[]const u8 = null,
    count: ?i64 = null,
    remaining_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
            .count = "Count",
            .remaining_count = "RemainingCount",
        };
        return @field(mappings, field_name);
    }
};

pub const InstancePatchState = struct {
    instance_id: []const u8,
    patch_group: []const u8,
    baseline_id: []const u8,
    snapshot_id: ?[]const u8 = null,
    install_override_list: ?[]const u8 = null,
    owner_information: ?[]const u8 = null,
    installed_count: ?i64 = null,
    installed_other_count: ?i64 = null,
    installed_pending_reboot_count: ?i64 = null,
    installed_rejected_count: ?i64 = null,
    missing_count: ?i64 = null,
    failed_count: ?i64 = null,
    unreported_not_applicable_count: ?i64 = null,
    not_applicable_count: ?i64 = null,
    operation_start_time: i64,
    operation_end_time: i64,
    operation: []const u8,
    last_no_reboot_install_operation_time: ?i64 = null,
    reboot_option: ?[]const u8 = null,
    critical_non_compliant_count: ?i64 = null,
    security_non_compliant_count: ?i64 = null,
    other_non_compliant_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .patch_group = "PatchGroup",
            .baseline_id = "BaselineId",
            .snapshot_id = "SnapshotId",
            .install_override_list = "InstallOverrideList",
            .owner_information = "OwnerInformation",
            .installed_count = "InstalledCount",
            .installed_other_count = "InstalledOtherCount",
            .installed_pending_reboot_count = "InstalledPendingRebootCount",
            .installed_rejected_count = "InstalledRejectedCount",
            .missing_count = "MissingCount",
            .failed_count = "FailedCount",
            .unreported_not_applicable_count = "UnreportedNotApplicableCount",
            .not_applicable_count = "NotApplicableCount",
            .operation_start_time = "OperationStartTime",
            .operation_end_time = "OperationEndTime",
            .operation = "Operation",
            .last_no_reboot_install_operation_time = "LastNoRebootInstallOperationTime",
            .reboot_option = "RebootOption",
            .critical_non_compliant_count = "CriticalNonCompliantCount",
            .security_non_compliant_count = "SecurityNonCompliantCount",
            .other_non_compliant_count = "OtherNonCompliantCount",
        };
        return @field(mappings, field_name);
    }
};

pub const Patch = struct {
    id: ?[]const u8 = null,
    release_date: ?i64 = null,
    title: ?[]const u8 = null,
    description: ?[]const u8 = null,
    content_url: ?[]const u8 = null,
    vendor: ?[]const u8 = null,
    product_family: ?[]const u8 = null,
    product: ?[]const u8 = null,
    classification: ?[]const u8 = null,
    msrc_severity: ?[]const u8 = null,
    kb_number: ?[]const u8 = null,
    msrc_number: ?[]const u8 = null,
    language: ?[]const u8 = null,
    advisory_ids: ?[][]const u8 = null,
    bugzilla_ids: ?[][]const u8 = null,
    cve_ids: ?[][]const u8 = null,
    name: ?[]const u8 = null,
    epoch: ?i64 = null,
    version: ?[]const u8 = null,
    release: ?[]const u8 = null,
    arch: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    repository: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .release_date = "ReleaseDate",
            .title = "Title",
            .description = "Description",
            .content_url = "ContentUrl",
            .vendor = "Vendor",
            .product_family = "ProductFamily",
            .product = "Product",
            .classification = "Classification",
            .msrc_severity = "MsrcSeverity",
            .kb_number = "KbNumber",
            .msrc_number = "MsrcNumber",
            .language = "Language",
            .advisory_ids = "AdvisoryIds",
            .bugzilla_ids = "BugzillaIds",
            .cve_ids = "CVEIds",
            .name = "Name",
            .epoch = "Epoch",
            .version = "Version",
            .release = "Release",
            .arch = "Arch",
            .severity = "Severity",
            .repository = "Repository",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAssociationBatchRequestEntry = struct {
    name: []const u8,
    instance_id: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    automation_target_parameter_name: ?[]const u8 = null,
    document_version: ?[]const u8 = null,
    targets: ?[]Target = null,
    schedule_expression: ?[]const u8 = null,
    output_location: ?InstanceAssociationOutputLocation = null,
    association_name: ?[]const u8 = null,
    max_errors: ?[]const u8 = null,
    max_concurrency: ?[]const u8 = null,
    compliance_severity: ?[]const u8 = null,
    sync_compliance: ?[]const u8 = null,
    apply_only_at_cron_interval: ?bool = null,
    calendar_names: ?[][]const u8 = null,
    target_locations: ?[]TargetLocation = null,
    schedule_offset: ?i64 = null,
    duration: ?i64 = null,
    target_maps: ?[][]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    alarm_configuration: ?AlarmConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .instance_id = "InstanceId",
            .parameters = "Parameters",
            .automation_target_parameter_name = "AutomationTargetParameterName",
            .document_version = "DocumentVersion",
            .targets = "Targets",
            .schedule_expression = "ScheduleExpression",
            .output_location = "OutputLocation",
            .association_name = "AssociationName",
            .max_errors = "MaxErrors",
            .max_concurrency = "MaxConcurrency",
            .compliance_severity = "ComplianceSeverity",
            .sync_compliance = "SyncCompliance",
            .apply_only_at_cron_interval = "ApplyOnlyAtCronInterval",
            .calendar_names = "CalendarNames",
            .target_locations = "TargetLocations",
            .schedule_offset = "ScheduleOffset",
            .duration = "Duration",
            .target_maps = "TargetMaps",
            .alarm_configuration = "AlarmConfiguration",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "target_maps", field_name))
            return try serializeMap(self.target_maps, self.fieldNameFor("target_maps"), options, out_stream);
        return false;
    }
};
